%% t4enc.def
%%
%% (c) Copyright 1994--2004 J"org Knappen
%%
\ProvidesFile{t4enc.def}[2004/06/01 v2.0 
   Fontencoding for the fc (aFrican Computer) fonts]
\NeedsTeXFormat{LaTeX2e}[1999/06/01] % \AA and some other commands changed
\DeclareFontEncoding{T4}{}{}
\DeclareTextAccent{\`}{T4}{0}
\DeclareTextAccent{\'}{T4}{1}
\DeclareTextAccent{\^}{T4}{2}
\DeclareTextAccent{\~}{T4}{3}
\DeclareTextAccent{\"}{T4}{4}
\DeclareTextAccent{\H}{T4}{5}
\DeclareTextAccent{\r}{T4}{6}
\DeclareTextAccent{\v}{T4}{7}
\DeclareTextAccent{\u}{T4}{8}
\DeclareTextAccent{\=}{T4}{9}
\DeclareTextAccent{\.}{T4}{10}
\DeclareTextAccent{\I}{T4}{'277}% single universal accent
\DeclareTextAccent{\U}{T4}{'274}% double universal accent
\DeclareTextAccent{\G}{T4}{'237}% double grave accent
\DeclareTextCommand{\b}{T4}[1]
   {\oalign{\null#1\crcr\hidewidth\sh@ft{29}
    \vbox to.2ex{\hbox{\char9}\vss}\hidewidth}}
\DeclareTextCommand{\c}{T4}[1]
   {\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\hidewidth\char11\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\d}{T4}[1]
   {\oalign{\null#1\crcr\hidewidth\sh@ft{08}.\hidewidth}}
\DeclareTextCommand{\k}{T4}[1]
   {\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent12 #1%
     \else{\ooalign{\hidewidth\char12\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\m}{T4}[1]
   {\errhelp{The modified letter \m #1 does not exist in the 
             T4 encoding}
    \errmessage{t4enc.def: Non existent modified letter}}
\DeclareTextCommand{\M}{T4}[1]
   {\errhelp{The modified letter \M #1 does not exist in the 
             T4 encoding}
    \errmessage{Non existent modified letter}}
\DeclareTextCommand{\B}{T4}[1]
   {\errhelp{The modified letter \B #1 does not exist in the 
             T4 encoding}
    \errmessage{t4enc.def: Non existent modified letter}}
\DeclareTextCommand{\T}{T4}[1]
   {\errhelp{The modified letter with tilde \T #1 does not exist in the 
             T4 encoding}
    \errmessage{t4enc.def: Non existent modified letter}}
\DeclareTextCommand{\textcopyleft}{T4}
    {{\ooalign{\hfil
     \raise.07ex\hbox{\mdseries\upshape \m{o}}\hfil\crcr
     \mathhexbox20D}}}
\DeclareTextSymbol{\AE}{T4}{198}
\DeclareTextCommand{\L}{T4}
   {\leavevmode\setbox0\hbox{L}\hbox to\wd0{\hss\char'337L}}
\DeclareTextSymbol{\O}{T4}{216}
\DeclareTextSymbol{\OE}{T4}{215}
\DeclareTextCommand{\SS}{T4}{SS}
\DeclareTextSymbol{\_}{T4}{95}
\DeclareTextSymbol{\ae}{T4}{230}
\DeclareTextSymbol{\guillemotleft}{T4}{19}
\DeclareTextSymbol{\guillemotright}{T4}{20}
\DeclareTextSymbol{\guilsinglleft}{T4}{14}
\DeclareTextSymbol{\guilsinglright}{T4}{15}
\DeclareTextSymbol{\i}{T4}{25}
\DeclareTextSymbol{\j}{T4}{26}
\DeclareTextCommand{\l}{T4}{\char'337l}
\DeclareTextSymbol{\o}{T4}{248}
\DeclareTextSymbol{\oe}{T4}{247}
\DeclareTextSymbol{\quotedblbase}{T4}{18}
\DeclareTextSymbol{\quotesinglbase}{T4}{13}
\DeclareTextSymbol{\ss}{T4}{255}
\DeclareTextSymbol{\textendash}{T4}{21}
\DeclareTextSymbol{\textemdash}{T4}{22}
\DeclareTextSymbol{\textexclamdown}{T4}{189}
\DeclareTextSymbol{\textquestiondown}{T4}{190}
\DeclareTextSymbol{\textquotedblleft}{T4}{16}
\DeclareTextSymbol{\textquotedblright}{T4}{17}
\DeclareTextSymbol{\textquotedbl}{T4}{`\"}
\DeclareTextSymbol{\textquoteleft}{T4}{`\`}
\DeclareTextSymbol{\textquoteright}{T4}{`\'}
\DeclareTextSymbol{\textvisiblespace}{T4}{32}
\DeclareTextSymbol{\textgreater}{T4}{`\>}
\DeclareTextSymbol{\textless}{T4}{`\<}
\DeclareTextSymbol{\textbraceright}{T4}{`\}}
\DeclareTextSymbol{\textbraceleft}{T4}{`\{}
\DeclareTextSymbol{\textbar}{T4}{`\|}
\DeclareTextSymbol{\textbackslash}{T4}{`\\}
\DeclareTextSymbol{\textasciicircum}{T4}{`\^}
\DeclareTextSymbol{\textasciitilde}{T4}{`\~}
\DeclareTextCommand{\textdollar}{T4}{\nfss@text{%
   \ifdim \fontdimen\@ne\font >\z@
      \slshape
   \else
      \upshape
   \fi
   \char`\$}}
\DeclareTextCommand{\textsterling}{T4}{\nfss@text{%
   \ifdim \fontdimen\@ne\font >\z@
      \itshape
   \else
      \fontshape{ui}\selectfont
   \fi
   \char`\$}}
\DeclareTextSymbol{\NG}{T4}{141}
\DeclareTextSymbol{\ng}{T4}{173}
%\DeclareTextSymbol{\TH}{T4}{'227}  % best replacement
%\DeclareTextSymbol{\th}{T4}{'267}  % best replacement
\DeclareTextSymbol{\DH}{T4}{208}
%\DeclareTextSymbol{\dh}{T4}{158}   % best replacement
\DeclareTextSymbol{\DJ}{T4}{208}
\DeclareTextSymbol{\dj}{T4}{158}
\DeclareTextSymbol{\tsh}{T4}{156}
\DeclareTextCommand{\TSH}{T4}{T\m S}
\DeclareTextComposite{\m}{T4}{B}{128}
\DeclareTextComposite{\m}{T4}{D}{129}
\DeclareTextComposite{\m}{T4}{E}{130}
\DeclareTextComposite{\M}{T4}{E}{131}
\DeclareTextComposite{\m}{T4}{F}{132}
\DeclareTextComposite{\v}{T4}{E}{133}
\DeclareTextComposite{\m}{T4}{G}{134}
\DeclareTextComposite{\B}{T4}{H}{135}
\DeclareTextComposite{\m}{T4}{K}{136}
\DeclareTextComposite{\m}{T4}{J}{137}
\DeclareTextComposite{\m}{T4}{O}{138}
\DeclareTextComposite{\'}{T4}{N}{139}
\DeclareTextComposite{\m}{T4}{S}{140}
\DeclareTextComposite{\m}{T4}{N}{141}
\DeclareTextComposite{\m}{T4}{U}{142}
\DeclareTextComposite{\m}{T4}{V}{142}
\DeclareTextComposite{\m}{T4}{Y}{143}
\DeclareTextComposite{\m}{T4}{C}{144}
\DeclareTextComposite{\m}{T4}{P}{145}
\DeclareTextComposite{\v}{T4}{S}{146}
\DeclareTextComposite{\.}{T4}{N}{147}
\DeclareTextComposite{\b}{T4}{N}{148}
\DeclareTextComposite{\d}{T4}{S}{149}
\DeclareTextComposite{\m}{T4}{Z}{150}
\DeclareTextComposite{\B}{T4}{T}{151}
\DeclareTextComposite{\.}{T4}{E}{152}
\DeclareTextComposite{\d}{T4}{E}{153}
\DeclareTextComposite{\m}{T4}{T}{154}
\DeclareTextComposite{\M}{T4}{T}{155}
\DeclareTextComposite{\B}{T4}{d}{158}
\DeclareTextComposite{\m}{T4}{b}{160}
\DeclareTextComposite{\m}{T4}{d}{161}
\DeclareTextComposite{\m}{T4}{e}{162}
\DeclareTextComposite{\M}{T4}{e}{163}
\DeclareTextComposite{\m}{T4}{f}{164}
\DeclareTextComposite{\v}{T4}{e}{165}
\DeclareTextComposite{\m}{T4}{g}{166}
\DeclareTextComposite{\B}{T4}{h}{167}
\DeclareTextComposite{\m}{T4}{k}{168}
\DeclareTextComposite{\m}{T4}{j}{169}
\DeclareTextComposite{\m}{T4}{o}{170}
\DeclareTextComposite{\'}{T4}{n}{171}
\DeclareTextComposite{\m}{T4}{s}{172}
\DeclareTextComposite{\m}{T4}{n}{173}
\DeclareTextComposite{\m}{T4}{u}{174}
\DeclareTextComposite{\m}{T4}{v}{174}
\DeclareTextComposite{\m}{T4}{y}{175}
\DeclareTextComposite{\m}{T4}{c}{176}
\DeclareTextComposite{\m}{T4}{p}{177}
\DeclareTextComposite{\v}{T4}{s}{178}
\DeclareTextComposite{\.}{T4}{n}{179}
\DeclareTextComposite{\b}{T4}{n}{180}
\DeclareTextComposite{\d}{T4}{s}{181}
\DeclareTextComposite{\m}{T4}{z}{182}
\DeclareTextComposite{\B}{T4}{t}{183}
\DeclareTextComposite{\.}{T4}{e}{184}
\DeclareTextComposite{\d}{T4}{e}{185}
\DeclareTextComposite{\m}{T4}{t}{186}
\DeclareTextComposite{\M}{T4}{t}{187}
\DeclareTextComposite{\m}{T4}{I}{192}
\DeclareTextComposite{\d}{T4}{I}{193}
\DeclareTextComposite{\T}{T4}{E}{194}
\DeclareTextComposite{\~}{T4}{A}{195}
\DeclareTextComposite{\'}{T4}{M}{196}
\DeclareTextComposite{\T}{T4}{O}{197}
\DeclareTextComposite{\c}{T4}{C}{199}
\DeclareTextComposite{\`}{T4}{E}{200}
\DeclareTextComposite{\'}{T4}{E}{201}
\DeclareTextComposite{\^}{T4}{E}{202}
\DeclareTextComposite{\"}{T4}{E}{203}
\DeclareTextComposite{\b}{T4}{E}{204}
\DeclareTextComposite{\=}{T4}{E}{205}
\DeclareTextComposite{\~}{T4}{E}{206}
\DeclareTextComposite{\~}{T4}{I}{207}
\DeclareTextComposite{\M}{T4}{D}{208}
\DeclareTextComposite{\B}{T4}{D}{208}
\DeclareTextComposite{\~}{T4}{N}{209}
\DeclareTextComposite{\`}{T4}{O}{210}
\DeclareTextComposite{\.}{T4}{O}{211}
\DeclareTextComposite{\^}{T4}{O}{212}
\DeclareTextComposite{\~}{T4}{O}{213}
\DeclareTextComposite{\"}{T4}{O}{214}
\DeclareTextComposite{\d}{T4}{O}{217}
\DeclareTextComposite{\b}{T4}{O}{218}
\DeclareTextComposite{\=}{T4}{O}{219}
\DeclareTextComposite{\v}{T4}{O}{220}
\DeclareTextComposite{\d}{T4}{U}{221}
\DeclareTextComposite{\~}{T4}{U}{222}
\DeclareTextComposite{\m}{T4}{i}{224}
\DeclareTextComposite{\d}{T4}{i}{225}
\DeclareTextComposite{\T}{T4}{e}{226}
\DeclareTextComposite{\~}{T4}{a}{227}
\DeclareTextComposite{\'}{T4}{m}{228}
\DeclareTextComposite{\T}{T4}{o}{229}
\DeclareTextComposite{\c}{T4}{c}{231}
\DeclareTextComposite{\`}{T4}{e}{232}
\DeclareTextComposite{\'}{T4}{e}{233}
\DeclareTextComposite{\^}{T4}{e}{234}
\DeclareTextComposite{\"}{T4}{e}{235}
\DeclareTextComposite{\b}{T4}{e}{236}
\DeclareTextComposite{\=}{T4}{e}{237}
\DeclareTextComposite{\~}{T4}{e}{238}
\DeclareTextComposite{\~}{T4}{i}{239}
\DeclareTextComposite{\~}{T4}{\i}{239}
\DeclareTextComposite{\M}{T4}{d}{240}
\DeclareTextComposite{\~}{T4}{n}{241}
\DeclareTextComposite{\`}{T4}{o}{242}
\DeclareTextComposite{\.}{T4}{o}{243}
\DeclareTextComposite{\^}{T4}{o}{244}
\DeclareTextComposite{\~}{T4}{o}{245}
\DeclareTextComposite{\"}{T4}{o}{246}
\DeclareTextComposite{\d}{T4}{o}{249}
\DeclareTextComposite{\b}{T4}{o}{250}
\DeclareTextComposite{\=}{T4}{o}{251}
\DeclareTextComposite{\v}{T4}{o}{252}
\DeclareTextComposite{\d}{T4}{u}{253}
\DeclareTextComposite{\~}{T4}{u}{254}

% Compatibility section
% 
% t4enc.def v 1.3 had \| as command for the universal accent in text mode
\def\|{\ifmmode\Vert\else\I\fi}% single universal accent
%
% t4enc.def v 1.3 used \copyleft instead of \textcopyleft
\def\copyleft{\textcopyleft}
\endinput
%% 
%% End of file `T4enc.def'.
