%%
%% This is file `he8enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hebfontenc.fdd  (with options: `HE8enc')
%% 
%% This is a generated file.
%% 
%% Hebrew language font and input encodings, and additional packages.
%% Copyright (C) 1997 -- 2005 Boris Lavva and Johannes Braams.
%% 
%% Copyright (C) 2023 Udi Fogiel.
%% All rights reserved.
%% 
%% It may be distributed and/or modified under the conditions of the
%% LaTeX Project Public License, either version 1.3 of this license or
%% (at your option) any later version. The latest version of this
%% license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX version
%% 2003/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainer of this work is Udi Fogiel
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.
\ProvidesFile{he8enc.def}
        [2023/08/21 v1.3 %
                 8-bit Hebrew font encoding
         (test version: still liable to change)]
\DeclareFontEncoding{HE8}{}{}
\DeclareFontSubstitution{HE8}{cmr}{m}{n}
\ProvideTextCommand{\textcopyright}{HE8}{\textcircled{\@latin{c}}}
\ProvideTextCommand{\textregistered}{HE8}{\textcircled{\scshape%
                                          \@latin{r}}}
\ProvideTextCommand{\texttrademark}{HE8}{\textsuperscript{\@latin{TM}}}
\ProvideTextCommand{\textcopyright}{HE8}{\textcircled{\@latin{c}}}
\ProvideTextCommand{\textregistered}{HE8}{\textcircled{\scshape%
                                          \@latin{r}}}
\ProvideTextCommand{\texttrademark}{HE8}{\textsuperscript{\@latin{TM}}}
\DeclareTextSymbol{\sheva}{HE8}{192}
\DeclareTextSymbol{\hatafsegol}{HE8}{193}
\DeclareTextSymbol{\hatafpatah}{HE8}{194}
\DeclareTextSymbol{\hatafqamats}{HE8}{195}
\DeclareTextSymbol{\hiriq}{HE8}{196}
\DeclareTextSymbol{\tsere}{HE8}{197}
\DeclareTextSymbol{\segol}{HE8}{198}
\DeclareTextSymbol{\patah}{HE8}{199}
\DeclareTextSymbol{\qamats}{HE8}{200}
\DeclareTextSymbol{\holam}{HE8}{201}
\DeclareTextSymbol{\qubuts}{HE8}{203}
\DeclareTextSymbol{\dagesh}{HE8}{204}
\DeclareTextSymbol{\meteg}{HE8}{205}
\DeclareTextSymbol{\maqaf}{HE8}{206}
\DeclareTextSymbol{\rafe}{HE8}{207}
\DeclareTextSymbol{\paseq}{HE8}{208}
\DeclareTextSymbol{\shindot}{HE8}{209}
\DeclareTextSymbol{\sindot}{HE8}{210}
\DeclareTextSymbol{\sofpasuq}{HE8}{211}
\DeclareTextSymbol{\doublevav}{HE8}{212}
\DeclareTextSymbol{\vavyod}{HE8}{213}
\DeclareTextSymbol{\doubleyod}{HE8}{214}
\DeclareTextSymbol{\hebgeresh}{HE8}{215}
\DeclareTextSymbol{\hebgershayim}{HE8}{216}
\DeclareTextSymbol{\hebalef}{HE8}{224}
\DeclareTextSymbol{\hebbet}{HE8}{225}
\DeclareTextSymbol{\hebgimel}{HE8}{226}
\DeclareTextSymbol{\hebdalet}{HE8}{227}
\DeclareTextSymbol{\hebhe}{HE8}{228}
\DeclareTextSymbol{\hebvav}{HE8}{229}
\DeclareTextSymbol{\hebzayin}{HE8}{230}
\DeclareTextSymbol{\hebhet}{HE8}{231}
\DeclareTextSymbol{\hebtet}{HE8}{232}
\DeclareTextSymbol{\hebyod}{HE8}{233}
\DeclareTextSymbol{\hebfinalkaf}{HE8}{234}
\DeclareTextSymbol{\hebkaf}{HE8}{235}
\DeclareTextSymbol{\heblamed}{HE8}{236}
\DeclareTextSymbol{\hebfinalmem}{HE8}{237}
\DeclareTextSymbol{\hebmem}{HE8}{238}
\DeclareTextSymbol{\hebfinalnun}{HE8}{239}
\DeclareTextSymbol{\hebnun}{HE8}{240}
\DeclareTextSymbol{\hebsamekh}{HE8}{241}
\DeclareTextSymbol{\hebayin}{HE8}{242}
\DeclareTextSymbol{\hebfinalpe}{HE8}{243}
\DeclareTextSymbol{\hebpe}{HE8}{244}
\DeclareTextSymbol{\hebfinaltsadi}{HE8}{245}
\DeclareTextSymbol{\hebtsadi}{HE8}{246}
\DeclareTextSymbol{\hebqof}{HE8}{247}
\DeclareTextSymbol{\hebresh}{HE8}{248}
\DeclareTextSymbol{\hebshin}{HE8}{249}
\DeclareTextSymbol{\hebtav}{HE8}{250}
\let\hebsin=\hebshin
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\endinput
%%
%% End of file `he8enc.def'.
