\addlanguage{afrikaans}{loadhyph-af.tex}{}{1}{2}
\addlanguage{armenian}{loadhyph-hy.tex}{}{1}{2}
\addlanguage{coptic}{loadhyph-cop.tex}{}{1}{1}
\addlanguage{esperanto}{loadhyph-eo.tex}{}{2}{2}
\addlanguage{ethiopic}{loadhyph-mul-ethi.tex}{}{1}{1}
\addlanguage{amharic}{loadhyph-mul-ethi.tex}{}{1}{1}
\addlanguage{geez}{loadhyph-mul-ethi.tex}{}{1}{1}
\addlanguage{georgian}{loadhyph-ka.tex}{}{1}{2}
\addlanguage{hebrew}{hyph-he.tex}{}{0}{0}
\addlanguage{assamese}{loadhyph-as.tex}{}{1}{1}
\addlanguage{bengali}{loadhyph-bn.tex}{}{1}{1}
\addlanguage{gujarati}{loadhyph-gu.tex}{}{1}{1}
\addlanguage{hindi}{loadhyph-hi.tex}{}{1}{1}
\addlanguage{kannada}{loadhyph-kn.tex}{}{1}{1}
\addlanguage{malayalam}{loadhyph-ml.tex}{}{1}{1}
\addlanguage{marathi}{loadhyph-mr.tex}{}{1}{1}
\addlanguage{oriya}{loadhyph-or.tex}{}{1}{1}
\addlanguage{pali}{loadhyph-pi.tex}{}{1}{2}
\addlanguage{panjabi}{loadhyph-pa.tex}{}{1}{1}
\addlanguage{tamil}{loadhyph-ta.tex}{}{1}{1}
\addlanguage{telugu}{loadhyph-te.tex}{}{1}{1}
\addlanguage{indonesian}{loadhyph-id.tex}{}{2}{2}
\addlanguage{interlingua}{loadhyph-ia.tex}{}{2}{2}
\addlanguage{sanskrit}{loadhyph-sa.tex}{}{1}{3}
\addlanguage{thai}{loadhyph-th.tex}{}{2}{3}
\addlanguage{turkmen}{loadhyph-tk.tex}{}{2}{2}
\addlanguage{vietnamese}{hyph-vi.tex}{}{0}{0}
