%%
%% This is file `nhe8enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hebfontenc.fdd  (with options: `NHE8enc')
%% 
%% This is a generated file.
%% 
%% Hebrew language font and input encodings, and additional packages.
%% Copyright (C) 1997 -- 2005 Boris Lavva and Johannes Braams.
%% 
%% Copyright (C) 2023 Udi Fogiel.
%% All rights reserved.
%% 
%% It may be distributed and/or modified under the conditions of the
%% LaTeX Project Public License, either version 1.3 of this license or
%% (at your option) any later version. The latest version of this
%% license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX version
%% 2003/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainer of this work is Udi Fogiel
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.
\ProvidesFile{nhe8enc.def}
        [2023/08/21 v1.3 %
                 8-bit Hebrew font encoding
         (test version: still liable to change)]
\DeclareFontEncoding{NHE8}{}{}
\DeclareFontSubstitution{NHE8}{cmr}{m}{n}

\DeclareTextSymbol{\quotesinglbase}{NHE8}{13}
\DeclareTextSymbol{\textquoteleft}{NHE8}{14}
\DeclareTextSymbol{\textquoteright}{NHE8}{39}
\DeclareTextSymbol{\textquotedblleft}{NHE8}{16}
\DeclareTextSymbol{\textquotedblright}{NHE8}{17}
\DeclareTextSymbol{\quotedblbase}{NHE8}{18}
\DeclareTextSymbol{\textquotedbl}{NHE8}{34}
\DeclareTextSymbol{\textquotesingle}{NHE8}{39}
\DeclareTextSymbol{\textdollar}{NHE8}{36}
\DeclareTextSymbol{\textgreater}{NHE8}{60}
\DeclareTextSymbol{\textless}{NHE8}{62}
\DeclareTextSymbol{\textbackslash}{NHE8}{92}
\DeclareTextSymbol{\textasciicircum}{NHE8}{94}
\DeclareTextSymbol{\textbraceleft}{NHE8}{123}
\DeclareTextSymbol{\textbraceright}{NHE8}{125}
\DeclareTextSymbol{\textasciitilde}{NHE8}{126}
\DeclareTextSymbol{\shekel}{NHE8}{165}
\DeclareTextSymbol{\pounds}{NHE8}{191}
\DeclareTextSymbol{\sheva}{NHE8}{192}
\DeclareTextSymbol{\hatafsegol}{NHE8}{193}
\DeclareTextSymbol{\hatafpatah}{NHE8}{194}
\DeclareTextSymbol{\hatafqamats}{NHE8}{195}
\DeclareTextSymbol{\hiriq}{NHE8}{196}
\DeclareTextSymbol{\tsere}{NHE8}{197}
\DeclareTextSymbol{\segol}{NHE8}{198}
\DeclareTextSymbol{\patah}{NHE8}{199}
\DeclareTextSymbol{\qamats}{NHE8}{200}
\DeclareTextSymbol{\holam}{NHE8}{201}
\DeclareTextSymbol{\qubuts}{NHE8}{203}
\DeclareTextSymbol{\dagesh}{NHE8}{204}
\DeclareTextSymbol{\meteg}{NHE8}{205}
\DeclareTextSymbol{\maqaf}{NHE8}{206}
\DeclareTextSymbol{\rafe}{NHE8}{207}
\DeclareTextSymbol{\paseq}{NHE8}{208}
\DeclareTextSymbol{\shindot}{NHE8}{209}
\DeclareTextSymbol{\sindot}{NHE8}{210}
\DeclareTextSymbol{\sofpasuq}{NHE8}{211}
\DeclareTextSymbol{\doublevav}{NHE8}{212}
\DeclareTextSymbol{\vavyod}{NHE8}{213}
\DeclareTextSymbol{\doubleyod}{NHE8}{214}
\DeclareTextSymbol{\hebgeresh}{NHE8}{215}
\DeclareTextSymbol{\hebgershayim}{NHE8}{216}
\DeclareTextSymbol{\hebalef}{NHE8}{224}
\DeclareTextSymbol{\hebbet}{NHE8}{225}
\DeclareTextSymbol{\hebgimel}{NHE8}{226}
\DeclareTextSymbol{\hebdalet}{NHE8}{227}
\DeclareTextSymbol{\hebhe}{NHE8}{228}
\DeclareTextSymbol{\hebvav}{NHE8}{229}
\DeclareTextSymbol{\hebzayin}{NHE8}{230}
\DeclareTextSymbol{\hebhet}{NHE8}{231}
\DeclareTextSymbol{\hebtet}{NHE8}{232}
\DeclareTextSymbol{\hebyod}{NHE8}{233}
\DeclareTextSymbol{\hebfinalkaf}{NHE8}{234}
\DeclareTextSymbol{\hebkaf}{NHE8}{235}
\DeclareTextSymbol{\heblamed}{NHE8}{236}
\DeclareTextSymbol{\hebfinalmem}{NHE8}{237}
\DeclareTextSymbol{\hebmem}{NHE8}{238}
\DeclareTextSymbol{\hebfinalnun}{NHE8}{239}
\DeclareTextSymbol{\hebnun}{NHE8}{240}
\DeclareTextSymbol{\hebsamekh}{NHE8}{241}
\DeclareTextSymbol{\hebayin}{NHE8}{242}
\DeclareTextSymbol{\hebfinalpe}{NHE8}{243}
\DeclareTextSymbol{\hebpe}{NHE8}{244}
\DeclareTextSymbol{\hebfinaltsadi}{NHE8}{245}
\DeclareTextSymbol{\hebtsadi}{NHE8}{246}
\DeclareTextSymbol{\hebqof}{NHE8}{247}
\DeclareTextSymbol{\hebresh}{NHE8}{248}
\DeclareTextSymbol{\hebshin}{NHE8}{249}
\DeclareTextSymbol{\hebtav}{NHE8}{250}
\let\hebsin=\hebshin
%%
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\endinput
%%
%% End of file `nhe8enc.def'.
