\qt@newcmd\qurantrans@ur@i{شروع الله کا نام لے کر جو بڑا مہربان نہایت رحم والا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@ii{سب طرح کی تعریف خدا ہی کو (سزاوار) ہے جو تمام مخلوقات کا پروردگار ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@iii{بڑا مہربان نہایت رحم والا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@iv{انصاف کے دن کا حاکم\qt@no{4}}%
\qt@newcmd\qurantrans@ur@v{اے پروردگار) ہم تیری ہی عبادت کرتے ہیں اور تجھ ہی سے مدد مانگتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@vi{ہم کو سیدھے رستے چلا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@vii{ان لوگوں کے رستے جن پر تو اپنا فضل وکرم کرتا رہا نہ ان کے جن پر غصے ہوتا رہا اور نہ گمراہوں کے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@viii{\basmalahur الم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@ix{یہ کتاب (قرآن مجید) اس میں کچھ شک نہیں (کہ کلامِ خدا ہے۔ خدا سے) ڈرنے والوں کی رہنما ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@x{جو غیب پر ایمان لاتے اور آداب کے ساتھ نماز پڑھتے اور جو کچھ ہم نے ان کو عطا فرمایا ہے اس میں سے خرچ کرتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@xi{اور جو کتاب (اے محمدﷺ) تم پر نازل ہوئی اور جو کتابیں تم سے پہلے (پیغمبروں پر) نازل ہوئیں سب پر ایمان لاتے اور آخرت کا یقین رکھتے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@xii{یہی لوگ اپنے پروردگار (کی طرف) سے ہدایت پر ہیں اور یہی نجات پانے والے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@xiii{جو لوگ کافر ہیں انہیں تم نصیحت کرو یا نہ کرو ان کے لیے برابر ہے۔ وہ ایمان نہیں لانے کے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@xiv{خدا نے ان کے دلوں اور کانوں پر مہر لگا رکھی ہے اور ان کی آنکھوں پر پردہ (پڑا ہوا) ہے اور ان کے لیے بڑا عذاب (تیار) ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@xv{اور بعض لوگ ایسے ہیں جو کہتے ہیں کہ ہم خدا پر اور روزِ آخرت پر ایمان رکھتے ہیں حالانکہ وہ ایمان نہیں رکھتے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@xvi{یہ (اپنے پندار میں) خدا کو اور مومنوں کو چکما دیتے ہیں مگر (حقیقت میں) اپنے سوا کسی کو چکما نہیں دیتے اور اس سے بے خبر ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@xvii{ان کے دلوں میں (کفر کا) مرض تھا۔ خدا نے ان کا مرض اور زیادہ کر دیا اور ان کے جھوٹ بولنے کے سبب ان کو دکھ دینے والا عذاب ہوگا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@xviii{اور جب ان سے کہا جاتا ہے کہ زمین میں فساد نہ ڈالو تو کہتے ہیں، ہم تو اصلاح کرنے والے ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@xix{دیکھو یہ بلاشبہ مفسد ہیں، لیکن خبر نہیں رکھتے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@xx{اور جب ان سے کہا جاتا ہے کہ جس طرح اور لوگ ایمان لے آئے، تم بھی ایمان لے آؤ تو کہتے ہیں، بھلا جس طرح بےوقوف ایمان لے آئے ہیں اسی طرح ہم بھی ایمان لے آئیں؟ سن لو کہ یہی بےوقوف ہیں لیکن نہیں جانتے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@xxi{اور یہ لوگ جب مومنوں سے ملتے ہیں تو کہتے ہیں کہ ہم ایمان لے آئے ہیں، اور جب اپنے شیطانوں میں جاتے ہیں تو (ان سے) کہتے ہیں کہ ہم تمھارے ساتھ ہیں اور (پیروانِ محمدﷺ سے) تو ہم ہنسی کیا کرتے ہیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@xxii{ان (منافقوں) سے خدا ہنسی کرتا ہے اور انہیں مہلت دیئے جاتا ہے کہ شرارت وسرکشی میں پڑے بہک رہے ہیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@xxiii{یہ وہ لوگ ہیں جنہوں نے ہدایت چھوڑ کر گمراہی خریدی، تو نہ تو ان کی تجارت ہی نے کچھ نفع دیا اور نہ وہ ہدایت یاب ہی ہوئے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@xxiv{ان کی مثال اس شخص کی سی ہے کہ جس نے (شبِ تاریک میں) آگ جلائی۔ جب آگ نے اس کے اردگرد کی چیزیں روشن کیں تو خدا نے ان کی روشنی زائل کر دی اور ان کو اندھیروں میں چھوڑ دیا کہ کچھ نہیں دیکھتے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@xxv{یہ) بہرے ہیں، گونگے ہیں، اندھے ہیں کہ (کسی طرح سیدھے رستے کی طرف) لوٹ ہی نہیں سکتے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@xxvi{یا ان کی مثال مینہ کی سی ہے کہ آسمان سے (برس رہا ہو اور) اس میں اندھیرے پر اندھیرا (چھا رہا) ہو اور (بادل) گرج (رہا) ہو اور بجلی (کوند رہی) ہو تو یہ کڑک سے (ڈر کر) موت کے خوف سے کانوں میں انگلیاں دے لیں اور الله کافروں کو (ہر طرف سے) گھیرے ہوئے ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@xxvii{قریب ہے کہ بجلی (کی چمک) ان کی آنکھوں (کی بصارت) کو اچک لے جائے۔ جب بجلی (چمکتی اور) ان پر روشنی ڈالی ہے تو اس میں چل پڑتے ہیں اور جب اندھیرا ہو جاتا ہے تو کھڑے کے کھڑے رہ جاتے ہیں اور اگر الله چاہتا تو ان کے کانوں (کی شنوائی) اور آنکھوں (کی بینائی دونوں) کو زائل کر دیتا ہے۔ بے شک الله ہر چیز پر قادر ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@xxviii{لوگو! اپنے پروردگار کی عبات کرو جس نے تم کو اور تم سے پہلے لوگوں کو پیدا کیا تاکہ تم (اس کے عذاب سے) بچو\qt@no{21}}%
\qt@newcmd\qurantrans@ur@xxix{جس نے تمھارے لیے زمین کو بچھونا اور آسمان کو چھت بنایا اور آسمان سے مینہ برسا کر تمہارے کھانے کے لیے انواع و اقسام کے میوے پیدا کئے۔ پس کسی کو خدا کا ہمسر نہ بناؤ۔ اور تم جانتے تو ہو\qt@no{22}}%
\qt@newcmd\qurantrans@ur@xxx{اور اگر تم کو اس (کتاب) میں، جو ہم نے اپنے بندے (محمدﷺ عربی) پر نازل فرمائی ہے کچھ شک ہو تو اسی طرح کی ایک سورت تم بھی بنا لاؤ اور خدا کے سوا جو تمہارے مددگار ہوں ان کو بھی بلالو اگر تم سچے ہو\qt@no{23}}%
\qt@newcmd\qurantrans@ur@xxxi{لیکن اگر (ایسا) نہ کر سکو اور ہرگز نہیں کر سکو گے تو اس آگ سے ڈرو جس کا ایندھن آدمی اور پتھر ہوں گے (اور جو) کافروں کے لیے تیار کی گئی ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@xxxii{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے، ان کو خوشخبری سنا دو کہ ان کے لیے (نعمت کے) باغ ہیں، جن کے نیچے نہریں بہہ رہی ہیں۔ جب انہیں ان میں سے کسی قسم کا میوہ کھانے کو دیا جائے گا تو کہیں گے، یہ تو وہی ہے جو ہم کو پہلے دیا گیا تھا۔ اور ان کو ایک دوسرے کے ہم شکل میوے دیئے جائیں گے اور وہاں ان کے لیے پاک بیویاں ہوں گی اور وہ بہشتوں میں ہمیشہ رہیں گے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@xxxiii{الله اس بات سے عار نہیں کرتا کہ مچھر یا اس سے بڑھ کر کسی چیز (مثلاً مکھی مکڑی وغیرہ) کی مثال بیان فرمائے۔ جو مومن ہیں، وہ یقین کرتے ہیں وہ ان کے پروردگار کی طرف سے سچ ہے اور جو کافر ہیں وہ کہتے ہیں کہ اس مثال سے خدا کی مراد ہی کیا ہے۔ اس سے (خدا) بہتوں کو گمراہ کرتا ہے اور بہتوں کو ہدایت بخشتا ہے اور گمراہ بھی کرتا تو نافرمانوں ہی کو\qt@no{26}}%
\qt@newcmd\qurantrans@ur@xxxiv{جو خدا کے اقرار کو مضبوط کرنے کے بعد توڑ دیتے ہیں اور جس چیز (یعنی رشتہٴ قرابت) کے جوڑے رکھنے کا الله نے حکم دیا ہے اس کو قطع کئے ڈالتے ہیں اور زمین میں خرابی کرتے ہیں یہی لوگ نقصان اٹھانے والے ہیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@xxxv{کافرو!) تم خدا سے کیوں کر منکر ہو سکتے ہو جس حال میں کہ تم بےجان تھے تو اس نے تم کو جان بخشی پھر وہی تم کو مارتا ہے پھر وہی تم کو زندہ کرے گا پھر تم اسی کی طرف لوٹ کر جاؤ گے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@xxxvi{وہی تو ہے جس نے سب چیزیں جو زمین میں ہیں تمہارے لیے پیدا کیں پھر آسمان کی طرف متوجہ ہوا تو ان کو ٹھیک سات آسمان بنا دیا اور وہ ہر چیز سے خبردار ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@xxxvii{اور (وہ وقت یاد کرنے کے قابل ہے) جب تمہارے پروردگار نے فرشتوں سے فرمایا کہ میں زمین میں (اپنا) نائب بنانے والا ہوں۔ انہوں نے کہا۔ کیا تُو اس میں ایسے شخص کو نائب بنانا چاہتا ہے جو خرابیاں کرے اور کشت وخون کرتا پھرے اور ہم تیری تعریف کے ساتھ تسبیح وتقدیس کرتے رہتے ہیں۔ (خدا نے) فرمایا میں وہ باتیں جانتا ہوں جو تم نہیں جانتے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@xxxviii{اور اس نے آدم کو سب (چیزوں کے) نام سکھائے پھر ان کو فرشتوں کے سامنے کیا اور فرمایا کہ اگر تم سچے ہو تو مجھے ان کے نام بتاؤ\qt@no{31}}%
\qt@newcmd\qurantrans@ur@xxxix{انہوں نے کہا، تو پاک ہے۔ جتنا علم تو نے ہمیں بخشا ہے، اس کے سوا ہمیں کچھ معلوم نہیں۔ بے شک تو دانا (اور) حکمت والا ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@xl{تب) خدا نے (آدم کو) حکم دیا کہ آدم! تم ان کو ان (چیزوں) کے نام بتاؤ۔ جب انہوں نے ان کو ان کے نام بتائے تو (فرشتوں سے) فرمایا کیوں میں نے تم سے نہیں کہا تھا کہ میں آسمانوں اور زمین کی (سب) پوشیدہ باتیں جاتنا ہوں اور جو تم ظاہر کرتے ہو اور جو پوشیدہ کرتے ہو (سب) مجھ کو معلوم ہے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@xli{اور جب ہم نے فرشتوں کو حکم دیا کہ آدم کے آگے سجدہ کرو تو وہ سجدے میں گر پڑے مگر شیطان نے انکار کیا اور غرور میں آکر کافر بن گیا\qt@no{34}}%
\qt@newcmd\qurantrans@ur@xlii{اور ہم نے کہا کہ اے آدم تم اور تمہاری بیوی بہشت میں رہو اور جہاں سے چاہو بے روک ٹوک کھاؤ (پیو) لیکن اس درخت کے پاس نہ جانا نہیں تو ظالموں میں (داخل) ہو جاؤ گے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@xliii{پھر شیطان نے دونوں کو وہاں سے پھسلا دیا اور جس (عیش ونشاط) میں تھے، اس سے ان کو نکلوا دیا۔ تب ہم نے حکم دیا کہ (بہشت بریں سے) چلے جاؤ۔ تم ایک دوسرے کے دشمن ہو، اور تمہارے لیے زمین میں ایک وقت تک ٹھکانا اور معاش (مقرر کر دیا گیا) ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@xliv{پھر آدم نے اپنے پروردگار سے کچھ کلمات سیکھے (اور معافی مانگی) تو اس نے ان کا قصور معاف کر دیا بے شک وہ معاف کرنے والا (اور) صاحبِ رحم ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@xlv{ہم نے فرمایا کہ تم سب یہاں سے اتر جاؤ جب تمہارے پاس میری طرف سے ہدایت پہنچے تو (اس کی پیروی کرنا کہ) جنہوں نے میری ہدایت کی پیروی کی ان کو نہ کچھ خوف ہوگا اور نہ وہ غمناک ہوں گے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@xlvi{اور جنہوں نے (اس کو) قبول نہ کیا اور ہماری آیتوں کو جھٹلایا، وہ دوزخ میں جانے والے ہیں (اور) وہ ہمیشہ اس میں رہیں گے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@xlvii{اے یعقوب کی اولاد! میرے وہ احسان یاد کرو جو میں نے تم پر کئے تھے اور اس اقرار کو پورا کرو جو تم نے مجھ سے کیا تھا۔ میں اس اقرار کو پورا کروں گا جو میں نے تم سے کیا تھا اور مجھی سے ڈرتے رہو\qt@no{40}}%
\qt@newcmd\qurantrans@ur@xlviii{اور جو کتاب میں نے (اپنے رسول محمدﷺ پر) نازل کی ہے جو تمہاری کتاب تورات کو سچا کہتی ہے، اس پر ایمان لاؤ اور اس سے منکرِ اول نہ بنو، اور میری آیتوں میں (تحریف کر کے) ان کے بدلے تھوڑی سی قیمت (یعنی دنیاوی منعفت) نہ حاصل کرو، اور مجھی سے خوف رکھو\qt@no{41}}%
\qt@newcmd\qurantrans@ur@xlix{اور حق کو باطل کے ساتھ نہ ملاؤ، اور سچی بات کو جان بوجھ کر نہ چھپاؤ\qt@no{42}}%
\qt@newcmd\qurantrans@ur@l{اور نماز پڑھا کرو اور زکوٰة دیا کرو اور (خدا کے آگے) جھکنے والوں کے ساتھ جھکا کرو\qt@no{43}}%
\qt@newcmd\qurantrans@ur@li{یہ) کیا (عقل کی بات ہے کہ) تم لوگوں کو نیکی کرنے کو کہتے ہو اور اپنے تئیں فراموش کئے دیتے ہو، حالانکہ تم کتاب (خدا) بھی پڑھتے ہو۔ کیا تم سمجھتے نہیں؟\qt@no{44}}%
\qt@newcmd\qurantrans@ur@lii{اور (رنج وتکلیف میں) صبر اور نماز سے مدد لیا کرو اور بے شک نماز گراں ہے، مگر ان لوگوں پر (گراں نہیں) جو عجز کرنے والے ہیں\qt@no{45}}%
\qt@newcmd\qurantrans@ur@liii{اور جو یقین کئے ہوئے ہیں کہ وہ اپنے پروردگار سے ملنے والے ہیں اور اس کی طرف لوٹ کر جانے والے ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@liv{اے یعقوب کی اولاد! میرے وہ احسان یاد کرو، جو میں نے تم پر کئے تھے اور یہ کہ میں نے تم کو جہان کے لوگوں پر فضیلت بخشی تھی\qt@no{47}}%
\qt@newcmd\qurantrans@ur@lv{اور اس دن سے ڈرو جب کوئی کسی کے کچھ کام نہ آئے اور نہ کسی کی سفارش منظور کی جائے اور نہ کسی سے کسی طرح کا بدلہ قبول کیا جائے اور نہ لوگ (کسی اور طرح) مدد حاصل کر سکیں\qt@no{48}}%
\qt@newcmd\qurantrans@ur@lvi{اور (ہمارے ان احسانات کو یاد کرو) جب ہم نے تم کو قومِ فرعون سے نجات بخشی وہ (لوگ) تم کو بڑا دکھ دیتے تھے تمہارے بیٹوں کو تو قتل کر ڈالتے تھے اور بیٹیوں کو زندہ رہنے دیتے تھے اور اس میں تمہارے پروردگار کی طرف سے بڑی (سخت) آزمائش تھی\qt@no{49}}%
\qt@newcmd\qurantrans@ur@lvii{اور جب ہم نے تمہارے لیے دریا کو پھاڑ دیا تم کو نجات دی اور فرعون کی قوم کو غرق کر دیا اور تم دیکھ ہی تو رہے تھے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@lviii{اور جب ہم نے موسیٰ سے چالیس رات کا وعدہ کیا تو تم نے ان کے پیچھے بچھڑے کو (معبود) مقرر کر لیا اور تم ظلم کر رہے تھے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@lix{پھر اس کے بعد ہم نے تم کو معاف کر دیا، تاکہ تم شکر کرو\qt@no{52}}%
\qt@newcmd\qurantrans@ur@lx{اور جب ہم نے موسیٰ کو کتاب اور معجزے عنایت کئے، تاکہ تم ہدایت حاصل کرو\qt@no{53}}%
\qt@newcmd\qurantrans@ur@lxi{اور جب موسیٰ نے اپنی قوم کے لوگوں سے کہا کہ بھائیو، تم نے بچھڑے کو (معبود) ٹھہرانے میں (بڑا) ظلم کیا ہے، تو اپنے پیدا کرنے والے کے آگے توبہ کرو اور اپنے تئیں ہلاک کر ڈالو۔ تمہارے خالق کے نزدیک تمہارے حق میں یہی بہتر ہے۔ پھر اس نے تمہارا قصور معاف کر دیا۔ وہ بے شک معاف کرنے والا (اور) صاحبِ رحم ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@lxii{اور جب تم نے (موسیٰ) سے کہا کہ موسیٰ، جب تک ہم خدا کو سامنے نہ دیکھ لیں گے، تم پر ایمان نہیں لائیں گے، تو تم کو بجلی نے آ گھیرا اور تم دیکھ رہے تھے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@lxiii{پھر موت آ جانے کے بعد ہم نے تم کو ازسرِ نو زندہ کر دیا، تاکہ احسان مانو\qt@no{56}}%
\qt@newcmd\qurantrans@ur@lxiv{اور بادل کا تم پر سایہ کئے رکھا اور (تمہارے لیے) من و سلویٰ اتارتے رہے کہ جو پاکیزہ چیزیں ہم نے تم کو عطا فرمائی ہیں، ان کو کھاؤ (پیو) مگر تمہارے بزرگوں نے ان نعمتوں کی کچھ قدر نہ جانی (اور) وہ ہمارا کچھ نہیں بگاڑتے تھے بلکہ اپنا ہی نقصان کرتے تھے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@lxv{اور جب ہم نے (ان سے) کہا کہ اس گاؤں میں داخل ہو جاؤ اور اس میں جہاں سے چاہو، خوب کھاؤ (پیو) اور (دیکھنا) دروازے میں داخل ہونا تو سجدہ کرنا اور حطة کہنا، ہم تمہارے گناہ معاف کر دیں گے اور نیکی کرنے والوں کو اور زیادہ دیں گے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@lxvi{تو جو ظالم تھے، انہوں نے اس لفظ کو، جس کا ان کو حکم دیا تھا، بدل کر اس کی جگہ اور لفظ کہنا شروع کیا، پس ہم نے (ان) ظالموں پر آسمان سے عذاب نازل کیا، کیونکہ نافرمانیاں کئے جاتے تھے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@lxvii{اور جب موسیٰ نے اپنی قوم کے لیے (خدا سے) پانی مانگا تو ہم نے کہا کہ اپنی لاٹھی پتھر پر مارو۔ (انہوں نے لاٹھی ماری) تو پھر اس میں سے بارہ چشمے پھوٹ نکلے، اور تمام لوگوں نے اپنا اپنا گھاٹ معلوم کر (کے پانی پی) لیا۔ (ہم نے حکم دیا کہ) خدا کی (عطا فرمائی ہوئی) روزی کھاؤ اور پیو، مگر زمین میں فساد نہ کرتے پھرنا\qt@no{60}}%
\qt@newcmd\qurantrans@ur@lxviii{اور جب تم نے کہا کہ موسیٰ! ہم سے ایک (ہی) کھانے پر صبر نہیں ہو سکتا تو اپنے پروردگار سے دعا کیجئے کہ ترکاری اور ککڑی اور گیہوں اور مسور اور پیاز (وغیرہ) جو نباتات زمین سے اُگتی ہیں، ہمارے لیے پیدا کر دے۔ انہوں نے کہا کہ بھلا عمدہ چیزیں چھوڑ کر ان کے عوض ناقص چیزیں کیوں چاہتے ہوں۔ (اگر یہی چیزیں مطلوب ہیں) تو کسی شہر میں جا اترو، وہاں جو مانگتے ہو، مل جائے گا۔ اور (آخرکار) ذلت (ورسوائی) اور محتاجی (وبے نوائی) ان سے چمٹا دی گئی اور وہ الله کے غضب میں گرفتار ہو گئے۔ یہ اس لیے کہ وہ الله کی آیتوں سے انکار کرتے تھے اور (اس کے) نبیوں کو ناحق قتل کر دیتے تھے۔ (یعنی) یہ اس لیے کہ نافرمانی کئے جاتے اور حد سے بڑھے جاتے تھے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@lxix{جو لوگ مسلمان ہیں یا یہودی یا عیسائی یا ستارہ پرست، (یعنی کوئی شخص کسی قوم و مذہب کا ہو) جو خدا اور روز قیامت پر ایمان لائے گا، اور نیک عمل کرے گا، تو ایسے لوگوں کو ان (کے اعمال) کا صلہ خدا کے ہاں ملے گا اور (قیامت کے دن) ان کو نہ کسی طرح کا خوف ہوگا اور نہ وہ غم ناک ہوں گے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@lxx{اور جب ہم نے تم سے عہد (کر) لیا اور کوہِ طُور کو تم پر اٹھا کھڑا کیا (اور حکم دیا) کہ جو کتاب ہم نے تم کو دی ہے، اس کو زور سے پکڑے رہو، اور جو اس میں (لکھا) ہے، اسے یاد رکھو، تاکہ (عذاب سے) محفوظ رہو\qt@no{63}}%
\qt@newcmd\qurantrans@ur@lxxi{تو تم اس کے بعد (عہد سے) پھر گئے اور اگر تم پر خدا کا فضل اور اس کی مہربانی نہ ہوتی تو تم خسارے میں پڑے گئے ہوتے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@lxxii{اور تم ان لوگوں کو خوب جانتے ہوں، جو تم میں سے ہفتے کے دن (مچھلی کا شکار کرنے) میں حد سے تجاوز کر گئے تھے، تو ہم نے ان سے کہا کہ ذلیل وخوار بندر ہو جاؤ\qt@no{65}}%
\qt@newcmd\qurantrans@ur@lxxiii{اور اس قصے کو اس وقت کے لوگوں کے لیے اور جو ان کے بعد آنے والے تھے عبرت اور پرہیز گاروں کے لیے نصیحت بنا دیا\qt@no{66}}%
\qt@newcmd\qurantrans@ur@lxxiv{اور جب موسیٰ نے اپنی قوم کے لوگوں سے کہا کہ خدا تم کو حکم دیتا ہے کہ ایک بیل ذبح کرو۔ وہ بولے، کیا تم ہم سے ہنسی کرتے ہو۔ (موسیٰ نے) کہا کہ میں الله کی پناہ مانگتا ہوں کہ نادان بنوں\qt@no{67}}%
\qt@newcmd\qurantrans@ur@lxxv{انہوں نے کہا کہ اپنے پروردگار سے التجا کیجئے کہ وہ ہمیں یہ بتائے کہ وہ بیل کس طرح کا ہو۔ (موسیٰ نے) کہا کہ پروردگار فرماتا ہے کہ وہ بیل نہ تو بوڑھا ہو اور نہ بچھڑا، بلکہ ان کے درمیان (یعنی جوان) ہو۔ جیسا تم کو حکم دیا گیا ہے، ویسا کرو\qt@no{68}}%
\qt@newcmd\qurantrans@ur@lxxvi{انہوں نے کہا کہ پروردگار سے درخواست کیجئے کہ ہم کو یہ بھی بتائے کہ اس کا رنگ کیسا ہو۔ موسیٰ نے کہا، پروردگار فرماتا ہے کہ اس کا رنگ گہرا زرد ہو کہ دیکھنے والوں (کے دل) کو خوش کر دیتا ہو\qt@no{69}}%
\qt@newcmd\qurantrans@ur@lxxvii{انہوں نے کہا کہ (اب کے) پروردگار سے پھر درخواست کیجئے کہ ہم کو بتا دے کہ وہ اور کس کس طرح کا ہو، کیونکہ بہت سے بیل ہمیں ایک دوسرے کے مشابہ معلوم ہوتے ہیں، (پھر) خدا نے چاہا تو ہمیں ٹھیک بات معلوم ہو جائے گی\qt@no{70}}%
\qt@newcmd\qurantrans@ur@lxxviii{موسیٰ نے کہا کہ خدا فرماتا ہے کہ وہ بیل کام میں لگا ہوا نہ ہو، نہ تو زمین جوتتا ہو اور نہ کھیتی کو پانی دیتا ہو۔ اس میں کسی طرح کا داغ نہ ہو۔ کہنے لگے، اب تم نے سب باتیں درست بتا دیں۔ غرض (بڑی مشکل سے) انہوں نے اس بیل کو ذبح کیا، اور وہ ایسا کرنے والے تھے نہیں\qt@no{71}}%
\qt@newcmd\qurantrans@ur@lxxix{اور جب تم نے ایک شخص کو قتل کیا، تو اس میں باہم جھگڑنے لگے۔ لیکن جو بات تم چھپا رہے تھے، خدا اس کو ظاہر کرنے والا تھا\qt@no{72}}%
\qt@newcmd\qurantrans@ur@lxxx{تو ہم نے کہا کہ اس بیل کا کوئی سا ٹکڑا مقتول کو مارو۔ اس طرح خدا مردوں کو زندہ کرتا ہے اور تم کو اپنی (قدرت کی) نشانیاں دکھاتا ہے تاکہ تم سمجھو\qt@no{73}}%
\qt@newcmd\qurantrans@ur@lxxxi{پھر اس کے بعد تمہارے دل سخت ہو گئے۔ گویا وہ پتھر ہیں یا ان سے بھی زیادہ سخت۔ اور پتھر تو بعضے ایسے ہوتے ہیں کہ ان میں سے چشمے پھوٹ نکلتے ہیں، اور بعضے ایسے ہوتے ہیں کہ پھٹ جاتے ہیں، اور ان میں سے پانی نکلنے لگتا ہے، اور بعضے ایسے ہوتے ہیں کہ خدا کے خوف سے گر پڑتے ہیں، اور خدا تمہارے عملوں سے بے خبر نہیں\qt@no{74}}%
\qt@newcmd\qurantrans@ur@lxxxii{مومنو) کیا تم امید رکھتے ہو کہ یہ لوگ تمہارے (دین کے) قائل ہو جائیں گے، (حالانکہ) ان میں سے کچھ لوگ کلامِ خدا (یعنی تورات) کو سنتے، پھر اس کے سمجھ لینے کے بعد اس کو جان بوجھ کر بدل دیتے رہے ہیں\qt@no{75}}%
\qt@newcmd\qurantrans@ur@lxxxiii{اور یہ لوگ جب مومنوں سے ملتے ہیں تو کہتے ہیں، ہم ایمان لے آئے ہیں۔ اور جب آپس میں ایک دوسرے سے ملتے ہیں تو کہتے ہیں، جو بات خدا نے تم پر ظاہر فرمائی ہے، وہ تم ان کو اس لیے بتائے دیتے ہو کہ (قیامت کے دن) اسی کے حوالے سے تمہارے پروردگار کے سامنے تم کو الزام دیں۔ کیا تم سمجھتے نہیں؟\qt@no{76}}%
\qt@newcmd\qurantrans@ur@lxxxiv{کیا یہ لوگ یہ نہیں جانتے کہ جو کچھ یہ چھپاتے اور جو کچھ ظاہر کرتے ہیں، خدا کو (سب) معلوم ہے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@lxxxv{اور بعض ان میں ان پڑھ ہیں کہ اپنے باطل خیالات کے سوا (خدا کی) کتاب سے واقف ہی نہیں اور وہ صرف ظن سے کام لیتے ہیں\qt@no{78}}%
\qt@newcmd\qurantrans@ur@lxxxvi{تو ان لوگوں پر افسوس ہے جو اپنے ہاتھ سے تو کتاب لکھتے ہیں اور کہتے یہ ہیں کہ یہ خدا کے پاس سے (آئی) ہے، تاکہ اس کے عوض تھوڑی سے قیمت (یعنی دنیوی منفعت) حاصل کریں۔ ان پر افسوس ہے، اس لیے کہ (بےاصل باتیں) اپنے ہاتھ سے لکھتے ہیں اور (پھر) ان پر افسوس ہے، اس لیے کہ ایسے کام کرتے ہیں\qt@no{79}}%
\qt@newcmd\qurantrans@ur@lxxxvii{اور کہتے ہیں کہ (دوزخ کی) آگ ہمیں چند روز کے سوا چھو ہی نہیں سکے گی۔ ان سے پوچھو، کیا تم نے خدا سے اقرار لے رکھا ہے کہ خدا اپنے اقرار کے خلاف نہیں کرے گا۔ (نہیں)، بلکہ تم خدا کے بارے میں ایسی باتیں کہتے ہو جن کا تمہیں مطلق علم نہیں\qt@no{80}}%
\qt@newcmd\qurantrans@ur@lxxxviii{ہاں جو برے کام کرے، اور اس کے گناہ (ہر طرف سے) گھیر لیں تو ایسے لوگ دوزخ (میں جانے) والے ہیں (اور) وہ ہمیشہ اس میں (جلتے) رہیں گے\qt@no{81}}%
\qt@newcmd\qurantrans@ur@lxxxix{اور جو ایمان لائیں اور نیک کام کریں، وہ جنت کے مالک ہوں گے (اور) ہمیشہ اس میں (عیش کرتے) رہیں گے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@xc{اور جب ہم نے بنی اسرائیل سے عہد لیا کہ خدا کے سوا کسی کی عبادت نہ کرنا اور ماں باپ اور رشتہ داروں اور یتیموں اور محتاجوں کے ساتھ بھلائی کرتے رہنا اور لوگوں سے اچھی باتیں کہنا، اور نماز پڑھتے اور زکوٰة دیتے رہنا، تو چند شخصوں کے سوا تم سب (اس عہد سے) منہ پھیر کر پھر بیٹھے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@xci{اور جب ہم نے تم سے عہد لیا کہ آپس میں کشت وخون نہ کرنا اور اپنے کو ان کے وطن سے نہ نکالنا تو تم نے اقرار کر لیا، اور تم (اس بات کے) گواہ ہو\qt@no{84}}%
\qt@newcmd\qurantrans@ur@xcii{پھر تم وہی ہو کہ اپنوں کو قتل بھی کر دیتے ہو اور اپنے میں سے بعض لوگوں پر گناہ اور ظلم سے چڑھائی کرکے انہیں وطن سے نکال بھی دیتے ہو، اور اگر وہ تمہارے پاس قید ہو کر آئیں تو بدلہ دے کر ان کو چھڑا بھی لیتے ہو، حالانکہ ان کا نکال دینا ہی تم کو حرام تھا۔ (یہ) کیا (بات ہے کہ) تم کتابِ (خدا) کے بعض احکام کو تو مانتے ہو اور بعض سے انکار کئے دیتے ہو، تو جو تم میں سے ایسی حرکت کریں، ان کی سزا اس کے سوا اور کیا ہو سکتی ہے کہ دنیا کی زندگی میں تو رسوائی ہو اور قیامت کے دن سخت سے سخت عذاب میں ڈال دیئے جائیں اور جو کام تم کرتے ہو، خدا ان سے غافل نہیں\qt@no{85}}%
\qt@newcmd\qurantrans@ur@xciii{یہ وہ لوگ ہیں جنہوں نے آخرت کے بدلے دنیا کی زندگی خریدی۔ سو نہ تو ان سے عذاب ہی ہلکا کیا جائے گا اور نہ ان کو (اور طرح کی) مدد ملے گی\qt@no{86}}%
\qt@newcmd\qurantrans@ur@xciv{اور ہم نے موسیٰ کو کتاب عنایت کی اور ان کے پیچھے یکے بعد دیگرے پیغمبر بھیجتے رہے اور عیسیٰ بن مریم کو کھلے نشانات بخشے اور روح القدس (یعنی جبرئیل) سے ان کو مدد دی۔تو جب کوئی پیغمبر تمہارے پاس ایسی باتیں لے کر آئے، جن کو تمہارا جی نہیں چاہتا تھا، تو تم سرکش ہو جاتے رہے، اور ایک گروہ (انبیاء) کو تو جھٹلاتے رہے اور ایک گروہ کو قتل کرتے رہے\qt@no{87}}%
\qt@newcmd\qurantrans@ur@xcv{اور کہتے ہیں، ہمارے دل پردے میں ہیں۔ (نہیں) بلکہ الله نے ان کے کفر کے سبب ان پر لعنت کر رکھی ہے۔ پس یہ تھوڑے ہی پر ایمان لاتے ہیں\qt@no{88}}%
\qt@newcmd\qurantrans@ur@xcvi{اور جب الله کے ہاں سے ان کے پاس کتاب آئی جو ان کی (آسمانی) کتاب کی بھی تصدیق کرتی ہے، اور وہ پہلے (ہمیشہ) کافروں پر فتح مانگا کرتے تھے، تو جس چیز کو وہ خوب پہچانتے تھے، جب ان کے پاس آپہنچی تو اس سے کافر ہو گئے۔ پس کافروں پر الله کی لعنت\qt@no{89}}%
\qt@newcmd\qurantrans@ur@xcvii{جس چیز کے بدلے انہوں نے اپنے تئیں بیچ ڈالا، وہ بہت بری ہے، یعنی اس جلن سے کہ خدا اپنے بندوں میں جس پر چاہتا ہے، اپنی مہربانی سے نازل فرماتا ہے۔ خدا کی نازل کی ہوئی کتاب سے کفر کرنے لگے تو وہ (اس کے) غضب بالائے غضب میں مبتلا ہو گئے۔ اور کافروں کے لیے ذلیل کرنے والا عذاب ہے\qt@no{90}}%
\qt@newcmd\qurantrans@ur@xcviii{اور جب ان سے کہا جاتا ہے کہ جو (کتاب) خدا نے (اب) نازل فرمائی ہے، اس کو مانو۔ تو کہتے ہیں کہ جو کتاب ہم پر (پہلے) نازل ہو چکی ہے، ہم تو اسی کو مانتے ہیں۔ (یعنی) یہ اس کے سوا کسی اور (کتاب) کو نہیں مانتے، حالانکہ وہ (سراسر) سچی ہے اور جو ان کی (آسمانی) کتاب ہے، اس کی بھی تصدیق کرتی ہے۔ (ان سے) کہہ دو کہ اگر تم صاحبِ ایمان ہوتے تو الله کے پیغمبروں کو پہلے ہی کیوں قتل کیا کرتے\qt@no{91}}%
\qt@newcmd\qurantrans@ur@xcix{اور موسیٰ تمہارے پاس کھلے ہوئے معجزات لے کر آئے تو تم ان کے (کوہِ طور جانے کے) بعد بچھڑے کو معبود بنا بیٹھے اور تم (اپنے ہی حق میں) ظلم کرتے تھے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@c{اور جب ہم نے تم (لوگوں) سے عہد واثق لیا اور کوہ طور کو تم پر اٹھا کھڑا کیا (اور حکم دیا کہ) جو (کتاب) ہم نے تم کو دی ہے، اس کو زور سے پکڑو اور جو تمہیں حکم ہوتا ہے (اس کو) سنو تو وہ (جو تمہارے بڑے تھے) کہنے لگے کہ ہم نے سن تو لیا لیکن مانتے نہیں۔ اور ان کے کفر کے سبب بچھڑا (گویا) ان کے دلوں میں رچ گیا تھا۔ (اے پیغمبر ان سے) کہہ دو کہ اگر تم مومن ہو تو تمہارا ایمان تم کو بری بات بتاتا ہے\qt@no{93}}%
\qt@newcmd\qurantrans@ur@ci{کہہ دو کہ اگر آخرت کا گھر اور لوگوں (یعنی مسلمانوں) کے لیے نہیں اور خدا کے نزدیک تمہارے ہی لیے مخصوص ہے تو اگر سچے ہو تو موت کی آرزو تو کرو\qt@no{94}}%
\qt@newcmd\qurantrans@ur@cii{لیکن ان اعمال کی وجہ سے، جو ان کے ہاتھ آگے بھیج چکے ہیں، یہ کبھی اس کی آرزو نہیں کریں گے، اور خدا ظالموں سے (خوب) واقف ہے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@ciii{بلکہ ان کو تم اور لوگوں سے زندگی کے کہیں حریص دیکھو گے، یہاں تک کہ مشرکوں سے بھی۔ ان میں سے ہر ایک یہی خواہش کرتا ہے کہ کاش وہ ہزار برس جیتا رہے، مگر اتنی لمبی عمر اس کو مل بھی جائے تو اسے عذاب سے تو نہیں چھڑا سکتی۔ اور جو کام یہ کرتے ہیں، خدا ان کو دیکھ رہا ہے\qt@no{96}}%
\qt@newcmd\qurantrans@ur@civ{کہہ دو کہ جو شخص جبرئیل کا دشمن ہو (اس کو غصے میں مر جانا چاہیئے) اس نے تو (یہ کتاب) خدا کے حکم سے تمہارے دل پر نازل کی ہے جو پہلی کتابوں کی تصدیق کرتی ہے، اور ایمان والوں کے لیے ہدایت اور بشارت ہے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@cv{جو شخص خدا کا اور اس کے فرشتوں کا اور اس کے پیغمبروں کا اور جبرئیل اور میکائیل کا دشمن ہو تو ایسے کافروں کا خدا دشمن ہے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@cvi{اور ہم نے تمہارے پاس سلجھی ہوئی آیتیں ارسال فرمائی ہیں، اور ان سے انکار وہی کرتے ہیں جو بدکار ہیں\qt@no{99}}%
\qt@newcmd\qurantrans@ur@cvii{ان لوگوں نے جب (خدا سے) عہد واثق کیا تو ان میں سے ایک فریق نے اس کو (کسی چیز کی طرح) پھینک دیا۔ حقیقت یہ ہے کہ ان میں اکثر بے ایمان ہیں\qt@no{100}}%
\qt@newcmd\qurantrans@ur@cviii{اور جب ان کے پاس الله کی طرف سے پیغمبر (آخرالزماں) آئے، اور وہ ان کی (آسمانی) کتاب کی بھی تصدیق کرتے ہیں تو جن لوگوں کو کتاب دی گئی تھی، ان میں سے ایک جماعت نے خدا کی کتاب کو پیٹھ پیچھے پھینک دیا، گویا وہ جانتے ہی نہیں\qt@no{101}}%
\qt@newcmd\qurantrans@ur@cix{اور ان (ہزلیات) کے پیچھے لگ گئے جو سلیمان کے عہدِ سلطنت میں شیاطین پڑھا کرتے تھے اور سلیمان نے مطلق کفر کی بات نہیں کی، بلکہ شیطان ہی کفر کرتے تھے کہ لوگوں کو جادو سکھاتے تھے۔ اور ان باتوں کے بھی (پیچھے لگ گئے) جو شہر بابل میں دو فرشتوں (یعنی) ہاروت اور ماروت پر اتری تھیں۔ اور وہ دونوں کسی کو کچھ نہیں سکھاتے تھے، جب تک یہ نہ کہہ دیتے کہ ہم تو (ذریعہٴ) آزمائش ہیں۔ تم کفر میں نہ پڑو۔ غرض لوگ ان سے (ایسا) جادو سیکھتے، جس سے میاں بیوی میں جدائی ڈال دیں۔ اور خدا کے حکم کے سوا وہ اس (جادو) سے کسی کا کچھ بھی نہیں بگاڑ سکتے تھے۔ اور کچھ ایسے (منتر) سیکھتے جو ان کو نقصان ہی پہنچاتے اور فائدہ کچھ نہ دیتے۔ اور وہ جانتے تھے کہ جو شخص ایسی چیزوں (یعنی سحر اور منتر وغیرہ) کا خریدار ہوگا، اس کا آخرت میں کچھ حصہ نہیں۔ اور جس چیز کے عوض انہوں نے اپنی جانوں کو بیچ ڈالا، وہ بری تھی۔ کاش وہ (اس بات کو) جانتے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@cx{اور اگر وہ ایمان لاتے اور پرہیز گاری کرتے تو خدا کے ہاں سے بہت اچھا صلہ ملتا۔ اے کاش، وہ اس سے واقف ہوتے\qt@no{103}}%
\qt@newcmd\qurantrans@ur@cxi{اے اہل ایمان! (گفتگو کے وقت پیغمبرِ خدا سے) راعنا نہ کہا کرو۔ انظرنا کہا کرو۔ اور خوب سن رکھو، اور کافروں کے لیے دکھ دینے والا عذاب ہے\qt@no{104}}%
\qt@newcmd\qurantrans@ur@cxii{جو لوگ کافر ہیں، اہل کتاب یا مشرک وہ اس بات کو پسند نہیں کرتے کہ تم پر تمہارے پروردگار کی طرف سے خیر (وبرکت) نازل ہو۔ اور خدا تو جس کو چاہتا ہے، اپنی رحمت کے ساتھ خاص کر لیتا ہے اور خدا بڑے فضل کا مالک ہے\qt@no{105}}%
\qt@newcmd\qurantrans@ur@cxiii{ہم جس آیت کو منسوخ کر دیتے یا اسے فراموش کرا دیتے ہیں تو اس سے بہتر یا ویسی ہی اور آیت بھیج دیتے ہیں۔ کیا تم نہیں جانتے کہ خدا ہر بات پر قادر ہے\qt@no{106}}%
\qt@newcmd\qurantrans@ur@cxiv{تمہیں معلوم نہیں کہ آسمانوں اور زمین کی بادشاہت خدا ہی کی ہے، اور خدا کے سوا تمہارا کوئی دوست اور مدد گار نہیں\qt@no{107}}%
\qt@newcmd\qurantrans@ur@cxv{کیا تم یہ چاہتے ہو کہ اپنے پیغمبر سے اسی طرح کے سوال کرو، جس طرح کے سوال پہلے موسیٰ سے کئے گئے تھے۔ اور جس شخص نے ایمان (چھوڑ کر اس) کے بدلے کفر لیا، وہ سیدھے رستے سے بھٹک گیا\qt@no{108}}%
\qt@newcmd\qurantrans@ur@cxvi{بہت سے اہل کتاب اپنے دل کی جلن سے یہ چاہتے ہیں کہ ایمان لا چکنے کے بعد تم کو پھر کافر بنا دیں۔ حالانکہ ان پر حق ظاہر ہو چکا ہے۔ تو تم معاف کردو اور درگزر کرو۔ یہاں تک کہ خدا اپنا (دوسرا) حکم بھیجے۔ بے شک خدا ہر بات پر قادر ہے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@cxvii{اور نماز ادا کرتے رہو اور زکوٰة دیتے رہو۔ اور جو بھلائی اپنے لیے آگے بھیج رکھو گے، اس کو خدا کے ہاں پا لو گے۔ کچھ شک نہیں کہ خدا تمہارے سب کاموں کو دیکھ رہا ہے\qt@no{110}}%
\qt@newcmd\qurantrans@ur@cxviii{اور (یہودی اور عیسائی) کہتے ہیں کہ یہودیوں اور عیسائیوں کے سوا کوئی بہشت میں نہیں جانے کا۔ یہ ان لوگوں کے خیالاتِ باطل ہیں۔ (اے پیغمبر ان سے) کہہ دو کہ اگر سچے ہو تو دلیل پیش کرو\qt@no{111}}%
\qt@newcmd\qurantrans@ur@cxix{ہاں جو شخص خدا کے آگے گردن جھکا دے، (یعنی ایمان لے آئے) اور وہ نیکو کار بھی ہو تو اس کا صلہ اس کے پروردگار کے پاس ہے اور ایسے لوگوں کو (قیامت کے دن) نہ کسی طرح کا خوف ہوگا اور نہ وہ غمناک ہوں گے\qt@no{112}}%
\qt@newcmd\qurantrans@ur@cxx{اور یہودی کہتے ہیں کہ عیسائی رستے پر نہیں اور عیسائی کہتے ہیں کہ یہودی رستے پر نہیں۔ حالانکہ وہ کتاب (الہٰی) پڑھتے ہیں۔ اسی طرح بالکل انہی کی سی بات وہ لوگ کہتے ہیں جو (کچھ) نہیں جانتے (یعنی مشرک) تو جس بات میں یہ لوگ اختلاف کر رہے خدا قیامت کے دن اس کا ان میں فیصلہ کر دے گا\qt@no{113}}%
\qt@newcmd\qurantrans@ur@cxxi{اور اس سے بڑھ کر ظالم کون، جو خدا کی مسجدوں میں خدا کے نام کا ذکر کئے جانے کو منع کرے اور ان کی ویرانی میں ساعی ہو۔ان لوگوں کو کچھ حق نہیں کہ ان میں داخل ہوں، مگر ڈرتے ہوئے۔ ان کے لیے دنیا میں رسوائی ہے اور آخرت میں بڑا عذاب\qt@no{114}}%
\qt@newcmd\qurantrans@ur@cxxii{اور مشرق اور مغرب سب خدا ہی کا ہے۔ تو جدھر تم رخ کرو۔ ادھر خدا کی ذات ہے۔ بے شک خدا صاحبِ وسعت اور باخبر ہے\qt@no{115}}%
\qt@newcmd\qurantrans@ur@cxxiii{اور یہ لوگ اس بات کے قائل ہیں کہ خدا اولاد رکھتا ہے۔ (نہیں) وہ پاک ہے، بلکہ جو کچھ آسمانوں اور زمین میں ہے، سب اسی کا ہے اور سب اس کے فرماں بردار ہیں\qt@no{116}}%
\qt@newcmd\qurantrans@ur@cxxiv{وہی) آسمانوں اور زمین کا پیدا کرنے والاہے۔ جب کوئی کام کرنا چاہتا ہے تو اس کو ارشاد فرما دیتا ہے کہ ہوجا تو وہ ہو جاتا ہے.\qt@no{117}}%
\qt@newcmd\qurantrans@ur@cxxv{اور جو لوگ (کچھ) نہیں جانتے (یعنی مشرک) وہ کہتے ہیں کہ خدا ہم سے کلام کیوں نہیں کرتا۔ یا ہمارے پاس کوئی نشانی کیوں نہیں آتی۔ اسی طرح جو لوگ ان سے پہلے تھے، وہ بھی انہی کی سی باتیں کیا کرتے تھے۔ ان لوگوں کے دل آپس میں ملتے جلتے ہیں۔ جو لوگ صاحبِ یقین ہیں، ان کے (سمجھانے کے) لیے نشانیاں بیان کردی ہیں\qt@no{118}}%
\qt@newcmd\qurantrans@ur@cxxvi{اے محمدﷺ) ہم نے تم کو سچائی کے ساتھ خوشخبری سنانے والا اور ڈرانے والا بنا کر بھیجا ہے۔ اور اہل دوزخ کے بارے میں تم سے کچھ پرسش نہیں ہوگی\qt@no{119}}%
\qt@newcmd\qurantrans@ur@cxxvii{اور تم سے نہ تو یہودی کبھی خوش ہوں گے اور نہ عیسائی، یہاں تک کہ تم ان کے مذہب کی پیروی اختیار کرلو۔ (ان سے) کہہ دو کہ خدا کی ہدایت (یعنی دین اسلام) ہی ہدایت ہے۔ اور (اے پیغمبر) اگر تم اپنے پاس علم (یعنی وحی خدا) کے آ جانے پر بھی ان کی خواہشوں پر چلو گے تو تم کو (عذاب) خدا سے (بچانے والا) نہ کوئی دوست ہوگا اور نہ کوئی مددگار\qt@no{120}}%
\qt@newcmd\qurantrans@ur@cxxviii{جن لوگوں کو ہم نے کتاب عنایت کی ہے، وہ اس کو (ایسا) پڑھتے ہیں جیسا اس کے پڑھنے کا حق ہے۔ یہی لوگ اس پر ایمان رکھنے والے ہیں، اور جو اس کو نہیں مانتے، وہ خسارہ پانے والے ہیں\qt@no{121}}%
\qt@newcmd\qurantrans@ur@cxxix{اے بنی اسرائیل! میرے وہ احسان یاد کرو، جو میں نے تم پر کئے اور یہ کہ میں نے تم کو اہلِ عالم پر فضیلت بخشی\qt@no{122}}%
\qt@newcmd\qurantrans@ur@cxxx{اور اس دن سے ڈرو جب کوئی شخص کسی شخص کے کچھ کام نہ آئے، اور نہ اس سے بدلہ قبول کیا جائے اور نہ اس کو کسی کی سفارش کچھ فائدہ دے اور نہ لوگوں کو (کسی اور طرح کی) مدد مل سکے\qt@no{123}}%
\qt@newcmd\qurantrans@ur@cxxxi{اور جب پروردگار نے چند باتوں میں ابراہیم کی آزمائش کی تو ان میں پورے اترے۔ خدا نے کہا کہ میں تم کو لوگوں کا پیشوا بناؤں گا۔ انہوں نے کہا کہ (پروردگار) میری اولاد میں سے بھی (پیشوا بنائیو) ۔ خدا نے فرمایا کہ ہمارا اقرار ظالموں کے لیے نہیں ہوا کرتا\qt@no{124}}%
\qt@newcmd\qurantrans@ur@cxxxii{اور جب ہم نے خانہٴ کعبہ کو لوگوں کے لیے جمع ہونے اور امن پانے کی جگہ مقرر کیا اور (حکم دیا کہ) جس مقام پر ابراہیم کھڑے ہوئے تھے، اس کو نماز کی جگہ بنا لو۔ اور ابراہیم اور اسمٰعیل کو کہا کہ طواف کرنے والوں اور اعتکاف کرنے والوں اور رکوع کرنے والوں اور سجدہ کرنے والوں کے لیے میرے گھر کو پاک صاف رکھا کرو\qt@no{125}}%
\qt@newcmd\qurantrans@ur@cxxxiii{اور جب ابراہیم نے دعا کی کہ اے پروردگار، اس جگہ کو امن کا شہر بنا اور اس کے رہنے والوں میں سے جو خدا پر اور روزِ آخرت پر ایمان لائیں، ان کے کھانے کو میوے عطا کر، تو خدا نے فرمایا کہ جو کافر ہوگا، میں اس کو بھی کسی قدر متمتع کروں گا، (مگر) پھر اس کو (عذاب) دوزخ کے (بھگتنے کے) لیے ناچار کردوں گا، اور وہ بری جگہ ہے\qt@no{126}}%
\qt@newcmd\qurantrans@ur@cxxxiv{اور جب ابراہیم اور اسمٰعیل بیت الله کی بنیادیں اونچی کر رہے تھے (تو دعا کئے جاتے تھے کہ) اے پروردگار، ہم سے یہ خدمت قبول فرما۔ بےشک تو سننے والا (اور) جاننے والا ہے\qt@no{127}}%
\qt@newcmd\qurantrans@ur@cxxxv{اے پروردگار، ہم کو اپنا فرمانبردار بنائے رکھیو۔ اور ہماری اولاد میں سے بھی ایک گروہ کو اپنا مطیع بنائے رہیو، اور (پروردگار) ہمیں طریق عبادت بتا اور ہمارے حال پر (رحم کے ساتھ) توجہ فرما۔ بے شک تو توجہ فرمانے والا مہربان ہے\qt@no{128}}%
\qt@newcmd\qurantrans@ur@cxxxvi{اے پروردگار، ان (لوگوں) میں انہیں میں سے ایک پیغمبر مبعوث کیجیو جو ان کو تیری آیتیں پڑھ پڑھ کر سنایا کرے اور کتاب اور دانائی سکھایا کرے اور ان (کے دلوں) کو پاک صاف کیا کرے۔ بےشک تو غالب اور صاحبِ حکمت ہے\qt@no{129}}%
\qt@newcmd\qurantrans@ur@cxxxvii{اور ابراہیم کے دین سے کون رو گردانی کر سکتا ہے، بجز اس کے جو نہایت نادان ہو۔ ہم نے ان کو دنیا میں بھی منتخب کیا تھا اور آخرت میں بھی وہ (زمرہٴ) صلحا میں سے ہوں گے\qt@no{130}}%
\qt@newcmd\qurantrans@ur@cxxxviii{جب ان سے ان کے پروردگار نے فرمایا کہ اسلام لے آؤ تو انہوں نے عرض کی کہ میں رب العالمین کے آگے سر اطاعت خم کرتا ہوں\qt@no{131}}%
\qt@newcmd\qurantrans@ur@cxxxix{اور ابرہیم نے اپنے بیٹوں کو اسی بات کی وصیت کی اور یعقوب نے بھی (اپنے فرزندوں سے یہی کہا) کہ بیٹا خدا نے تمہارے لیے یہی دین پسند فرمایا ہے تو مرنا ہے تو مسلمان ہی مرنا\qt@no{132}}%
\qt@newcmd\qurantrans@ur@cxl{بھلا جس وقت یعقوب وفات پانے لگے تو تم اس وقت موجود تھے، جب انہوں نے اپنے بیٹوں سے پوچھا کہ میرے بعد تم کس کی عبادت کرو گے، تو انہوں نے کہا کہ آپ کے معبود اور آپ کے باپ دادا ابراہیم اور اسمٰعیل اور اسحاق کے معبود کی عبادت کریں گے جو معبود یکتا ہے اور ہم اُسی کے حکم بردار ہیں\qt@no{133}}%
\qt@newcmd\qurantrans@ur@cxli{یہ جماعت گزرچکی۔ ان کو اُن کے اعمال (کا بدلہ ملے گا) اور تم کو تمھارے اعمال (کا) اور جو عمل وہ کرتے تھے ان کی پرسش تم سے نہیں ہوگی\qt@no{134}}%
\qt@newcmd\qurantrans@ur@cxlii{اور (یہودی اور عیسائی) کہتے ہیں کہ یہودی یا عیسائی ہو جاؤ تو سیدھے رستے پر لگ جاؤ۔ (اے پیغمبر ان سے) کہہ دو، (نہیں) بلکہ (ہم) دین ابراہیم (اختیار کئے ہوئے ہیں) جو ایک خدا کے ہو رہے تھے اور مشرکوں میں سے نہ تھے\qt@no{135}}%
\qt@newcmd\qurantrans@ur@cxliii{مسلمانو) کہو کہ ہم خدا پر ایمان لائے اور جو (کتاب) ہم پر اتری، اس پر اور جو (صحیفے) ابراہیم اور اسمٰعیل اور اسحاق اور یعقوب اور ان کی اولاد پر نازل ہوئے ان پر اور جو (کتابیں) موسیٰ اور عیسی کو عطا ہوئیں، ان پر، اور جو اور پیغمبروں کو ان کے پروردگار کی طرف سے ملیں، ان پر (سب پر ایمان لائے) ہم ان پیغمروں میں سے کسی میں کچھ فرق نہیں کرتے اور ہم اسی (خدائے واحد) کے فرمانبردار ہیں\qt@no{136}}%
\qt@newcmd\qurantrans@ur@cxliv{تو اگر یہ لوگ بھی اسی طرح ایمان لے آئیں جس طرح تم ایمان لے آئے ہو تو ہدایت یاب ہو جائیں اور اگر منہ پھیر لیں (اور نہ مانیں) تو وہ (تمھارے) مخالف ہیں اور ان کے مقابلے میں تمھیں خدا کافی ہے۔ اور وہ سننے والا (اور) جاننے والا ہے\qt@no{137}}%
\qt@newcmd\qurantrans@ur@cxlv{کہہ دو کہ ہم نے) خدا کا رنگ (اختیار کر لیا ہے) اور خدا سے بہتر رنگ کس کا ہو سکتا ہے۔ اور ہم اسی کی عبادت کرنے والے ہیں\qt@no{138}}%
\qt@newcmd\qurantrans@ur@cxlvi{ان سے) کہو، کیا تم خدا کے بارے میں ہم سے جھگڑتے ہو، حالانکہ وہی ہمارا اور تمھارا پروردگار ہے اور ہم کو ہمارے اعمال (کا بدلہ ملے گا) اور تم کو تمھارے اعمال (کا) اور ہم خاص اسی کی عبادت کرنے والے ہیں\qt@no{139}}%
\qt@newcmd\qurantrans@ur@cxlvii{اے یہود ونصاریٰ) کیا تم اس بات کے قائل ہو کہ ابراہیم اور اسمٰعیل اور اسحاق اور یعقوب اور ان کی اولاد یہودی یا عیسائی تھے۔ (اے محمدﷺ ان سے) کہو کہ بھلا تم زیادہ جانتے ہو یا خدا؟ اور اس سے بڑھ کر ظالم کون، جو خدا کی شہادت کو، جو اس کے پاس (کتاب میں موجود) ہے چھپائے۔ اور جو کچھ تم کر رہے ہو، خدا اس سے غافل نہیں\qt@no{140}}%
\qt@newcmd\qurantrans@ur@cxlviii{یہ جماعت گزر چکی۔ ان کو وہ (ملے گا) جو انہوں نے کیا، اور تم کو وہ جو تم نے کیا۔ اور جو عمل وہ کرتے تھے، اس کی پرسش تم سے نہیں ہوگی\qt@no{141}}%
\qt@newcmd\qurantrans@ur@cxlix{احمق لوگ کہیں گے کہ مسلمان جس قبلے پر (پہلے سے چلے آتے) تھے (اب) اس سے کیوں منہ پھیر بیٹھے۔ تم کہہ دو کہ مشرق اور مغرب سب خدا ہی کا ہے۔ وہ جس کو چاہتا ہے، سیدھے رستے پر چلاتا ہے\qt@no{142}}%
\qt@newcmd\qurantrans@ur@cl{اور اسی طرح ہم نے تم کو امتِ معتدل بنایا ہے، تاکہ تم لوگوں پر گواہ بنو اور پیغمبر (آخرالزماں) تم پر گواہ بنیں۔ اور جس قبلے پر تم (پہلے) تھے، اس کو ہم نے اس لیے مقرر کیا تھا کہ معلوم کریں، کون (ہمارے) پیغمبر کا تابع رہتا ہے، اور کون الٹے پاؤں پھر جاتا ہے۔ اور یہ بات (یعنی تحویل قبلہ لوگوں کو) گراں معلوم ہوئی، مگر جن کو خدا نے ہدایت بخشی (وہ اسے گراں نہیں سمجھتے) اور خدا ایسا نہیں کہ تمہارے ایمان کو یونہی کھو دے۔ خدا تو لوگوں پر بڑا مہربان (اور) صاحبِ رحمت ہے\qt@no{143}}%
\qt@newcmd\qurantrans@ur@cli{اے محمدﷺ) ہم تمہارا آسمان کی طرف منہ پھیر پھیر کر دیکھنا دیکھ رہے ہیں۔ سو ہم تم کو اسی قبلے کی طرف جس کو تم پسند کرتے ہو، منہ کرنے کا حکم دیں گے تو اپنا منہ مسجد حرام (یعنی خانہٴ کعبہ) کی طرف پھیر لو۔ اور تم لوگ جہاں ہوا کرو، (نماز پڑھنے کے وقت) اسی مسجد کی طرف منہ کر لیا کرو۔ اور جن لوگوں کو کتاب دی گئی ہے، وہ خوب جانتے ہیں کہ (نیا قبلہ) ان کے پروردگار کی طرف سے حق ہے۔ اور جو کام یہ لوگ کرتے ہیں، خدا ان سے بے خبر نہیں\qt@no{144}}%
\qt@newcmd\qurantrans@ur@clii{اور اگر تم ان اہلِ کتاب کے پاس تمام نشانیاں بھی لے کر آؤ، تو بھی یہ تمہارے قبلے کی پیروی نہ کریں۔ اور تم بھی ان کے قبلے کی پیروی کرنے والے نہیں ہو۔ اور ان میں سے بھی بعض بعض کے قبلے کے پیرو نہیں۔ اور اگر تم باوجود اس کے کہ تمہارے پاس دانش (یعنی وحئ خدا) آ چکی ہے، ان کی خواہشوں کے پیچھے چلو گے تو ظالموں میں (داخل) ہو جاؤ گے\qt@no{145}}%
\qt@newcmd\qurantrans@ur@cliii{جن لوگوں کو ہم نے کتاب دی ہے، وہ ان (پیغمبر آخرالزماں) کو اس طرح پہچانتے ہیں، جس طرح اپنے بیٹوں کو پہچانا کرتے ہیں، مگر ایک فریق ان میں سے سچی بات کو جان بوجھ کر چھپا رہا ہے\qt@no{146}}%
\qt@newcmd\qurantrans@ur@cliv{اے پیغمبر، یہ نیا قبلہ) تمہارے پروردگار کی طرف سے حق ہے تو تم ہرگز شک کرنے والوں میں نہ ہونا\qt@no{147}}%
\qt@newcmd\qurantrans@ur@clv{اور ہر ایک (فرقے) کے لیے ایک سمت (مقرر) ہے۔ جدھر وہ (عبادت کے وقت) منہ کیا کرتے ہیں۔ تو تم نیکیوں میں سبقت حاصل کرو۔ تم جہاں رہو گے خدا تم سب کو جمع کرلے گا۔ بے شک خدا ہر چیز پر قادر ہے\qt@no{148}}%
\qt@newcmd\qurantrans@ur@clvi{اور تم جہاں سے نکلو، (نماز میں) اپنا منہ مسجد محترم کی طرف کر لیا کرو بےشک وہ تمہارے پروردگار کی طرف سے حق ہے۔ اور تم لوگ جو کچھ کرتے ہو۔ خدا اس سے بے خبر نہیں\qt@no{149}}%
\qt@newcmd\qurantrans@ur@clvii{اور تم جہاں سے نکلو، مسجدِ محترم کی طرف منہ (کرکے نماز پڑھا) کرو۔ اور مسلمانو، تم جہاں ہوا کرو، اسی (مسجد) کی طرف رخ کیا کرو۔ (یہ تاکید) اس لیے (کی گئی ہے) کہ لوگ تم کو کسی طرح کا الزام نہ دے سکیں۔ مگر ان میں سے جو ظالم ہیں، (وہ الزام دیں تو دیں) سو ان سے مت ڈرنا اور مجھی سے ڈرتے رہنا۔ اور یہ بھی مقصود ہے کہ تم کو اپنی تمام نعمتیں بخشوں اور یہ بھی کہ تم راہِ راست پر چلو\qt@no{150}}%
\qt@newcmd\qurantrans@ur@clviii{جس طرح (منجملہ اور نعمتوں کے) ہم نے تم میں تمھیں میں سے ایک رسول بھیجے ہیں جو تم کو ہماری آیتیں پڑھ پڑھ کر سناتے اور تمہیں پاک بناتے اور کتاب (یعنی قرآن) اور دانائی سکھاتے ہیں، اور ایسی باتیں بتاتے ہیں، جو تم پہلے نہیں جانتے تھے\qt@no{151}}%
\qt@newcmd\qurantrans@ur@clix{سو تم مجھے یاد کرو۔ میں تمہیں یاد کیا کروں گا۔ اور میرے احسان مانتے رہنا اور ناشکری نہ کرنا\qt@no{152}}%
\qt@newcmd\qurantrans@ur@clx{اے ایمان والو صبر اور نماز سے مدد لیا کرو بےشک خدا صبر کرنے والوں کے ساتھ ہے\qt@no{153}}%
\qt@newcmd\qurantrans@ur@clxi{اور جو لوگ خدا کی راہ میں مارے جائیں ان کی نسبت یہ کہنا کہ وہ مرے ہوئے ہیں (وہ مردہ نہیں) بلکہ زندہ ہیں لیکن تم نہیں جانتے\qt@no{154}}%
\qt@newcmd\qurantrans@ur@clxii{اور ہم کسی قدر خوف اور بھوک اور مال اور جانوں اور میوؤں کے نقصان سے تمہاری آزمائش کریں گے توصبر کرنے والوں کو (خدا کی خوشنودی کی) بشارت سنا دو\qt@no{155}}%
\qt@newcmd\qurantrans@ur@clxiii{ان لوگوں پر جب کوئی مصیبت واقع ہوتی ہے تو کہتے ہیں کہ ہم خدا ہی کا مال ہیں اور اسی کی طرف لوٹ کر جانے والے ہیں\qt@no{156}}%
\qt@newcmd\qurantrans@ur@clxiv{یہی لوگ ہیں جن پر ان کے پروردگار کی مہربانی اور رحمت ہے۔ اور یہی سیدھے رستے پر ہیں\qt@no{157}}%
\qt@newcmd\qurantrans@ur@clxv{بےشک (کوہ) صفا اور مروہ خدا کی نشانیوں میں سے ہیں۔ تو جو شخص خانہٴ کعبہ کا حج یا عمرہ کرے اس پر کچھ گناہ نہیں کہ دونوں کا طواف کرے۔ (بلکہ طواف ایک قسم کا نیک کام ہے) اور جو کوئی نیک کام کرے تو خدا قدر شناس اور دانا ہے\qt@no{158}}%
\qt@newcmd\qurantrans@ur@clxvi{جو لوگ ہمارے حکموں اور ہدایتوں کو جو ہم نے نازل کی ہیں (کسی غرض فاسد سے) چھپاتے ہیں باوجود یہ کہ ہم نے ان لوگوں کے (سمجھانے کے) لئے اپنی کتاب میں کھول کھول کر بیان کردیا ہے۔ ایسوں پر خدا اور تمام لعنت کرنے والے لعنت کرتے ہیں\qt@no{159}}%
\qt@newcmd\qurantrans@ur@clxvii{ہاں جو توبہ کرتے ہیں اور اپنی حالت درست کرلیتے اور (احکام الہیٰ کو) صاف صاف بیان کردیتے ہیں تو میں ان کے قصور معاف کردیتا ہوں اور میں بڑا معاف کرنے والا (اور) رحم والا ہوں\qt@no{160}}%
\qt@newcmd\qurantrans@ur@clxviii{جو لوگ کافر ہوئے اور کافر ہی مرے ایسوں پر خدا کی اور فرشتوں اور لوگوں کی سب کی لعنت\qt@no{161}}%
\qt@newcmd\qurantrans@ur@clxix{وہ ہمیشہ اسی (لعنت) میں (گرفتار) رہیں گے۔ ان سے نہ تو عذاب ہی ہلکا کیا جائے گا اور نہ انہیں (کچھ) مہلت ملے گی\qt@no{162}}%
\qt@newcmd\qurantrans@ur@clxx{اور (لوگو) تمہارا معبود خدائے واحد ہے اس بڑے مہربان (اور) رحم کرنے کے سوا کوئی عبادت کے لائق نہیں\qt@no{163}}%
\qt@newcmd\qurantrans@ur@clxxi{بےشک آسمانوں اور زمین کے پیدا کرنے میں اور رات اور دن کے ایک دوسرے کے پیچھے آنے جانے میں اور کشتیوں اور جہازوں میں جو دریا میں لوگوں کے فائدے کی چیزیں لے کر رواں ہیں اور مینہ میں جس کو خدا آسمان سے برساتا اور اس سے زمین کو مرنے کے بعد زندہ (یعنی خشک ہوئے پیچھے سرسبز) کردیتا ہے اور زمین پر ہر قسم کے جانور پھیلانے میں اور ہواؤں کے چلانےمیں اور بادلوں میں جو آسمان اور زمین کے درمیان گھرے رہتے ہیں۔ عقلمندوں کے لئے (خدا کی قدرت کی) نشانیاں ہیں\qt@no{164}}%
\qt@newcmd\qurantrans@ur@clxxii{اور بعض لوگ ایسے ہیں جو غیر خدا کو شریک (خدا) بناتے اور ان سے خدا کی سی محبت کرتے ہیں۔ لیکن جو ایمان والے ہیں وہ تو خدا ہی کے سب سے زیادہ دوستدار ہیں۔ اور اے کاش ظالم لوگ جو بات عذاب کے وقت دیکھیں گے اب دیکھ لیتے کہ سب طرح کی طاقت خدا ہی کو ہے۔ اور یہ کہ خدا سخت عذاب کرنے والا ہے\qt@no{165}}%
\qt@newcmd\qurantrans@ur@clxxiii{اس دن (کفر کے) پیشوا اپنے پیرووں سے بیزاری ظاہر کریں گے اور (دونوں) عذاب (الہیٰ) دیکھ لیں گے اور ان کے آپس کے تعلقات منقطع ہوجائیں گے\qt@no{166}}%
\qt@newcmd\qurantrans@ur@clxxiv{یہ حال دیکھ کر) پیروی کرنے والے (حسرت سے) کہیں گے کہ اے کاش ہمیں پھر دنیا میں جانا نصیب ہو تاکہ جس طرح یہ ہم سے بیزار ہو رہے ہیں اسی طرح ہم بھی ان سے بیزار ہوں۔ اسی طرح خدا ان کے اعمال انہیں حسرت بنا کر دکھائے گااور وہ دوزخ سے نکل نہیں سکیں گے\qt@no{167}}%
\qt@newcmd\qurantrans@ur@clxxv{لوگو جو چیزیں زمین میں حلال طیب ہیں وہ کھاؤ۔ اور شیطان کے قدموں پر نہ چلو۔ وہ تمہارا کھلا دشمن ہے\qt@no{168}}%
\qt@newcmd\qurantrans@ur@clxxvi{وہ تو تم کو برائی اور بےحیائی ہی کے کام کرنے کو کہتا ہے اور یہ بھی کہ خدا کی نسبت ایسی باتیں کہو جن کا تمہیں (کچھ بھی) علم نہیں\qt@no{169}}%
\qt@newcmd\qurantrans@ur@clxxvii{اور جب ان لوگوں سے کہا جاتا ہے کہ جو (کتاب) خدا نے نازل فرمائی ہے اس کی پیروی کرو تو کہتے ہیں (نہیں) بلکہ ہم تو اسی چیز کی پیروی کریں گے جس پر ہم نے اپنے باپ دادا کو پایا۔ بھلا اگرچہ ان کے باپ دادا نہ کچھ سمجھتے ہوں اورنہ سیدھے رستے پر ہوں (تب بھی وہ انہیں کی تقلید کئے جائیں گے)\qt@no{170}}%
\qt@newcmd\qurantrans@ur@clxxviii{جو لوگ کافر ہیں ان کی مثال اس شخص کی سی ہے جو کسی ایسی چیز کو آواز دے جو پکار اور آواز کے سوا کچھ سن نہ سکے۔ (یہ) بہرے ہیں گونگے ہیں اندھے ہیں کہ (کچھ) سمجھ ہی نہیں سکتے\qt@no{171}}%
\qt@newcmd\qurantrans@ur@clxxix{اے اہل ایمان جو پاکیزہ چیزیں ہم نے تم کو عطا فرمائیں ہیں ان کو کھاؤ اور اگر خدا ہی کے بندے ہو تو اس (کی نعمتوں) کا شکر بھی ادا کرو\qt@no{172}}%
\qt@newcmd\qurantrans@ur@clxxx{اس نے تم پر مرا ہوا جانور اور لہو اور سور کا گوشت اور جس چیز پر خدا کے سوا کسی اور کا نام پکارا جائے حرام کردیا ہے ہاں جو ناچار ہوجائے (بشرطیکہ) خدا کی نافرمانی نہ کرے اور حد (ضرورت) سے باہر نہ نکل جائے اس پر کچھ گناہ نہیں۔ بےشک خدا بخشنے والا (اور) رحم کرنے والا ہے\qt@no{173}}%
\qt@newcmd\qurantrans@ur@clxxxi{جو لوگ (خدا) کی کتاب سے ان (آیتوں اور ہدایتوں) کو جو اس نے نازل فرمائی ہیں چھپاتے اور ان کے بدلے تھوڑی سی قیمت (یعنی دنیاوی منفعت) حاصل کرتے ہیں وہ اپنے پیٹوں میں محض آگ بھرتے ہیں۔ ایسے لوگوں سے خدا قیامت کے دن نہ کلام کرے گا اور نہ ان کو (گناہوں سے) پاک کرے گا۔اور ان کے لئے دکھ دینے والا عذاب ہے\qt@no{174}}%
\qt@newcmd\qurantrans@ur@clxxxii{یہ وہ لوگ ہیں جنہوں نے ہدایت چھوڑ کر گمراہی اور بخشش چھوڑ کر عذاب خریدا۔ یہ (آتش) جہنم کی کیسی برداشت کرنے والے ہیں!\qt@no{175}}%
\qt@newcmd\qurantrans@ur@clxxxiii{یہ اس لئے کہ خدا نے کتاب سچائی کے ساتھ نازل فرمائی۔ اور جن لوگوں نے اس کتاب میں اختلاف کیا وہ ضد میں (آکر نیکی سے) دور (ہوگئے) ہیں\qt@no{176}}%
\qt@newcmd\qurantrans@ur@clxxxiv{نیکی یہی نہیں کہ تم مشرق یا مغرب کو (قبلہ سمجھ کر ان) کی طرف منہ کرلو بلکہ نیکی یہ ہے کہ لوگ خدا پر اور روز آخرت پر اور فرشتوں پر اور (خدا کی) کتاب پر اور پیغمبروں پر ایمان لائیں۔ اور مال باوجود عزیز رکھنے کے رشتہ داروں اور یتیموں اور محتاجوں اور مسافروں اور مانگنے والوں کو دیں اور گردنوں (کے چھڑانے) میں (خرچ کریں) اور نماز پڑھیں اور زکوٰة دیں۔ اور جب عہد کرلیں تو اس کو پورا کریں۔ اور سختی اور تکلیف میں اور (معرکہ) کارزار کے وقت ثابت قدم رہیں۔ یہی لوگ ہیں جو (ایمان میں) سچے ہیں اور یہی ہیں جو (خدا سے) ڈرنے والے ہیں\qt@no{177}}%
\qt@newcmd\qurantrans@ur@clxxxv{مومنو! تم کو مقتولوں کے بارےمیں قصاص (یعنی خون کے بدلے خون) کا حکم دیا جاتا ہے (اس طرح پر کہ) آزاد کے بدلے آزاد (مارا جائے) اور غلام کے بدلے غلام اور عورت کے بدلے عورت اور قاتل کو اس کے (مقتول) بھائی (کے قصاص میں) سے کچھ معاف کردیا جائے تو (وارث مقتول) کو پسندیدہ طریق سے (قرار داد کی) پیروی (یعنی مطالبہٴ خون بہا) کرنا اور (قاتل کو) خوش خوئی کے ساتھ ادا کرنا چاہیئے یہ پروردگار کی طرف سے تمہارے لئے آسانی اور مہربانی ہے جو اس کے بعد زیادتی کرے اس کے لئے دکھ کا عذاب ہے\qt@no{178}}%
\qt@newcmd\qurantrans@ur@clxxxvi{اور اے اہل عقل (حکم) قصاص میں (تمہاری) زندگانی ہے کہ تم (قتل و خونریزی سے) بچو\qt@no{179}}%
\qt@newcmd\qurantrans@ur@clxxxvii{تم پر فرض کیا جاتا ہے کہ جب تم میں سے کسی کو موت کا وقت آجائے تو اگر وہ کچھ مال چھوڑ جانے والا ہو تو ماں با پ اور رشتہ داروں کے لئے دستور کے مطابق وصیت کرجائے (خدا سے) ڈر نے والوں پر یہ ایک حق ہے\qt@no{180}}%
\qt@newcmd\qurantrans@ur@clxxxviii{جو شخص وصیت کو سننے کے بعد بدل ڈالے تو اس (کے بدلنے) کا گناہ انہیں لوگوں پر ہے جو اس کو بدلیں۔ اور بےشک خدا سنتا جانتا ہے\qt@no{181}}%
\qt@newcmd\qurantrans@ur@clxxxix{اگر کسی کو وصیت کرنے والے کی طرف سے (کسی وارث کی) طرفداری یا حق تلفی کا اندیشہ ہو تو اگر وہ (وصیت کو بدل کر) وارثوں میں صلح کرادے تو اس پر کچھ گناہ نہیں۔ بےشک خدا بخشنے والا (اور) رحم والا ہے\qt@no{182}}%
\qt@newcmd\qurantrans@ur@cxc{مومنو! تم پر روزے فرض کئے گئے ہیں۔ جس طرح تم سے پہلے لوگوں پر فرض کئے گئے تھے تاکہ تم پرہیزگار بنو\qt@no{183}}%
\qt@newcmd\qurantrans@ur@cxci{روزوں کے دن) گنتی کے چند روز ہیں تو جو شخص تم میں سے بیمار ہو یا سفر میں ہو تو دوسرے دنوں میں روزوں کا شمار پورا کرلے اور جو لوگ روزہ رکھنے کی طاقت رکھیں (لیکن رکھیں نہیں) وہ روزے کے بدلے محتاج کو کھانا کھلا دیں اور جو کوئی شوق سے نیکی کرے تو اس کے حق میں زیادہ اچھا ہے۔ اور اگر سمجھو تو روزہ رکھنا ہی تمہارے حق میں بہتر ہے\qt@no{184}}%
\qt@newcmd\qurantrans@ur@cxcii{روزوں کا مہینہ) رمضان کا مہینہ (ہے) جس میں قرآن (اول اول) نازل ہوا جو لوگوں کا رہنما ہے اور (جس میں) ہدایت کی کھلی نشانیاں ہیں اور (جو حق و باطل کو) الگ الگ کرنے والا ہے تو جو کوئی تم میں سے اس مہینے میں موجود ہو چاہیئے کہ پورے مہینے کے روزے رکھے اور جو بیمار ہو یا سفر میں ہو تو دوسرے دنوں میں (رکھ کر) ان کا شمار پورا کرلے۔ خدا تمہارے حق میں آسانی چاہتا ہے اور سختی نہیں چاہتا اور (یہ آسانی کا حکم) اس لئے (دیا گیا ہے) کہ تم روزوں کا شمار پورا کرلو اور اس احسان کے بدلے کہ خدا نے تم کو ہدایت بخشی ہے تم اس کو بزرگی سے یاد کر واور اس کا شکر کرو\qt@no{185}}%
\qt@newcmd\qurantrans@ur@cxciii{اور (اے پیغمبر) جب تم سے میرے بندے میرے بارے میں دریافت کریں تو (کہہ دو کہ) میں تو (تمہارے) پاس ہوں جب کوئی پکارنے والا مجھے پکارتا ہے تو میں اس کی دعا قبول کرتا ہوں تو ان کو چاہیئے کہ میرے حکموں کو مانیں اور مجھ پر ایمان لائیں تاکہ نیک رستہ پائیں\qt@no{186}}%
\qt@newcmd\qurantrans@ur@cxciv{روزوں کی راتوں میں تمہارے لئے اپنی عورتوں کے پاس جانا کردیا گیا ہے وہ تمہاری پوشاک ہیں اور تم ان کی پوشاک ہو خدا کو معلوم ہے کہ تم (ان کے پاس جانے سے) اپنے حق میں خیانت کرتے تھے سو اس نے تم پر مہربانی کی اور تمہاری حرکات سےدرگزرفرمائی۔اب (تم کو اختیار ہے کہ) ان سے مباشرت کرو۔ اور خدا نے جو چیز تمہارے لئے لکھ رکھی ہے (یعنی اولاد) اس کو (خدا سے) طلب کرو اور کھاؤ پیو یہاں تک کہ صبح کی سفید دھاری (رات کی) سیاہ دھاری سے الگ نظر آنے لگے۔ پھر روزہ (رکھ کر) رات تک پورا کرو اور جب تم مسجدوں میں اعتکاف بیٹھے ہو تو ان سے مباشرت نہ کرو۔ یہ خدا کی حدیں ہیں ان کے پاس نہ جانا۔ اسی طرح خدا اپنی آیتیں لوگوں کے (سمجھانے کے) لئے کھول کھول کر بیان فرماتا ہے تاکہ وہ پرہیزگار بنیں\qt@no{187}}%
\qt@newcmd\qurantrans@ur@cxcv{اور ایک دوسرے کا مال ناحق نہ کھاؤ اورنہ اس کو (رشوةً) حاکموں کے پاس پہنچاؤ تاکہ لوگوں کے مال کا کچھ حصہ ناجائز طور پر کھا جاؤ اور (اسے) تم جانتے بھی ہو\qt@no{188}}%
\qt@newcmd\qurantrans@ur@cxcvi{اے محمدﷺ) لوگ تم سے نئے چاند کے بارے میں دریافت کرتے ہیں (کہ گھٹتا بڑھتا کیوں ہے) کہہ دو کہ وہ لوگوں کے (کاموں کی میعادیں) اور حج کے وقت معلوم ہونے کا ذریعہ ہے اور نیکی اس بات میں نہیں کہ (احرام کی حالت میں) گھروں میں ان کے پچھواڑے کی طرف سے آؤ۔ بلکہ نیکوکار وہ ہے جو پرہیز گار ہو اور گھروں میں ان کے دروازوں سے آیا کرو اور خدا سے ڈرتے رہو تاکہ نجات پاؤ\qt@no{189}}%
\qt@newcmd\qurantrans@ur@cxcvii{اور جو لوگ تم سے لڑتے ہیں تم بھی خدا کی راہ میں ان سے لڑو مگر زیادتی نہ کرنا کہ خدا زیادتی کرنے والوں کو دوست نہیں رکھتا\qt@no{190}}%
\qt@newcmd\qurantrans@ur@cxcviii{اور ان کو جہاں پاؤ قتل کردو اور جہاں سے انہوں نے تم کو نکالا ہے (یعنی مکے سے) وہاں سے تم بھی ان کو نکال دو۔ اور (دین سے گمراہ کرنے کا) فساد قتل وخونریزی سے کہیں بڑھ کر ہے اور جب تک وہ تم سے مسجد محترم (یعنی خانہ کعبہ) کے پاس نہ لڑیں تم بھی وہاں ان سے نہ لڑنا۔ ہاں اگر وہ تم سے لڑیں تو تم ان کو قتل کرڈالو۔ کافروں کی یہی سزا ہے\qt@no{191}}%
\qt@newcmd\qurantrans@ur@cxcix{اور اگر وہ باز آجائیں تو خدا بخشنے والا (اور) رحم کرنے والا ہے\qt@no{192}}%
\qt@newcmd\qurantrans@ur@cc{اور ان سے اس وقت تک لڑتے رہنا کہ فساد نابود ہوجائے اور (ملک میں) خدا ہی کا دین ہوجائے اور اگر وہ (فساد سے) باز آجائیں تو ظالموں کے سوا کسی پر زیادتی نہیں (کرنی چاہیئے)\qt@no{193}}%
\qt@newcmd\qurantrans@ur@cci{ادب کا مہینہ ادب کے مہینے کے مقابل ہے اور ادب کی چیزیں ایک دوسرے کا بدلہ ہیں۔ پس اگر کوئی تم پر زیادتی کرے تو جیسی زیادتی وہ تم پر کرے ویسی ہی تم اس پر کرو۔ اور خدا سے ڈرتے رہو اور جان رکھو کہ خدا ڈرنے والوں کے ساتھ ہے\qt@no{194}}%
\qt@newcmd\qurantrans@ur@ccii{اور خدا کی راہ میں (مال) خرچ کرو اور اپنے آپ کو ہلاکت میں نہ ڈالو اور نیکی کرو بےشک خدا نیکی کرنے والوں کو دوست رکھتا ہے\qt@no{195}}%
\qt@newcmd\qurantrans@ur@cciii{اور خدا (کی خوشنودی) کے لئے حج اور عمرے کو پورا کرو۔ اور اگر (راستےمیں) روک لئے جاؤ تو جیسی قربانی میسر ہو (کردو) اور جب تک قربانی اپنے مقام پر نہ پہنچ جائے سر نہ منڈاؤ۔ اور اگر کوئی تم میں بیمار ہو یا اس کے سر میں کسی طرح کی تکلیف ہو تو (اگر وہ سر منڈالے تو) اس کے بدلے روزے رکھے یا صدقہ دے یا قربانی کرے پھر جب (تکلیف دور ہو کر) تم مطمئن ہوجاؤ تو جو (تم میں) حج کے وقت تک عمرے سے فائدہ اٹھانا چاہے وہ جیسی قربانی میسر ہو کرے۔ اور جس کو (قربانی) نہ ملے وہ تین روزے ایام حج میں رکھے اور سات جب واپس ہو۔ یہ پورے دس ہوئے۔ یہ حکم اس شخص کے لئے ہے جس کے اہل وعیال مکے میں نہ رہتے ہوں اور خدا سے ڈرتے رہو اور جان رکھو کہ خدا سخت عذاب دینے والا ہے\qt@no{196}}%
\qt@newcmd\qurantrans@ur@cciv{حج کے مہینے (معین ہیں جو) معلوم ہیں تو شخص ان مہینوں میں حج کی نیت کرلے تو حج (کے دنوں) میں نہ عورتوں سے اختلاط کرے نہ کوئی برا کام کرے نہ کسی سے جھگڑے۔ اور جو نیک کام تم کرو گے وہ خدا کو معلوم ہوجائے گا اور زاد راہ (یعنی رستے کا خرچ) ساتھ لے جاؤ کیونکہ بہتر (فائدہ) زاد راہ (کا) پرہیزگاری ہے اور اے اہل عقل مجھ سے ڈرتے رہو\qt@no{197}}%
\qt@newcmd\qurantrans@ur@ccv{اس کا تمہیں کچھ گناہ نہیں کہ (حج کے دنوں میں بذریعہ تجارت) اپنے پروردگار سے روزی طلب کرو اور جب عرفات سے واپس ہونے لگو تو مشعر حرام (یعنی مزدلفے) میں خدا کا ذکر کرو اور اس طرح ذکر کرو جس طرح اس نے تم کو سکھایا۔ اور اس سے پیشتر تم لوگ (ان طریقوں سے) محض ناواقف تھے\qt@no{198}}%
\qt@newcmd\qurantrans@ur@ccvi{پھر جہاں سے اور لوگ واپس ہوں وہیں سے تم بھی واپس ہو اور خدا سے بخشش مانگو۔ بےشک خدا بخشنے والا اور رحمت کرنے والا ہے\qt@no{199}}%
\qt@newcmd\qurantrans@ur@ccvii{پھر جب حج کے تمام ارکان پورے کرچکو تو (منیٰ میں) خدا کو یاد کرو۔ جس طرح اپنے باپ دادا کو یاد کیا کرتے تھے بلکہ اس سے بھی زیادہ اور بعض لوگ ایسے ہیں جو (خدا سے) التجا کرتے ہیں کہ اے پروردگار ہم کو (جو دنیا ہے) دنیا ہی میں عنایت کر ایسے لوگوں کا آخرت میں کچھ حصہ نہیں\qt@no{200}}%
\qt@newcmd\qurantrans@ur@ccviii{اور بعضے ایسے ہیں کہ دعا کرتے ہیں کہ پروردگار ہم کو دنیا میں بھی نعمت عطا فرما اور آخرت میں بھی نعمت بخشیو اور دوزخ کے عذاب سے محفوظ رکھیو\qt@no{201}}%
\qt@newcmd\qurantrans@ur@ccix{یہی لوگ ہیں جن کے لئے ان کے کاموں کا حصہ (یعنی اجر نیک تیار) ہے اور خدا جلد حساب لینے والا (اور جلد اجر دینے والا) ہے\qt@no{202}}%
\qt@newcmd\qurantrans@ur@ccx{اور (قیام منیٰ کے) دنوں میں (جو) گنتی کے (دن میں) خدا کو یاد کرو۔ اگر کوئی جلدی کرے (اور) دو ہی دن میں (چل دے) تو اس پر بھی کچھ گناہ نہیں۔ اور جو بعد تک ٹھہرا رہے اس پر بھی کچھ گناہ نہیں۔ یہ باتیں اس شخص کے لئے ہیں جو (خدا سے) ڈرے اور تم لوگ خدا سے ڈرتے رہو اور جان رکھو کہ تم سب اس کے پاس جمع کئے جاؤ گے۔\qt@no{203}}%
\qt@newcmd\qurantrans@ur@ccxi{اور کوئی شخص تو ایسا ہے جس کی گفتگو دنیا کی زندگی میں تم کو دلکش معلوم ہوتی ہے اور وہ اپنی مانی الضمیر پر خدا کو گواہ بناتا ہے حالانکہ وہ سخت جھگڑالو ہے\qt@no{204}}%
\qt@newcmd\qurantrans@ur@ccxii{اور جب پیٹھ پھیر کر چلا جاتا ہے تو زمین میں دوڑتا پھرتا ہے تاکہ اس میں فتنہ انگیزی کرے اور کھیتی کو (برباد) اور (انسانوں اور حیوانوں کی) نسل کو نابود کردے اور خدا فتنہ انگیزی کو پسند نہیں کرتا\qt@no{205}}%
\qt@newcmd\qurantrans@ur@ccxiii{اور جب اس سے کہا جاتا ہے کہ خدا سے خوف کر تو غرور اس کو گناہ میں پھنسا دیتا ہے۔ سو ایسے کو جہنم سزاوار ہے۔ اور وہ بہت برا ٹھکانہ ہے\qt@no{206}}%
\qt@newcmd\qurantrans@ur@ccxiv{اور کوئی شخص ایسا ہے کہ خدا کی خوشنودی حاصل کرنے کے لئے اپنی جان بیچ ڈالتا ہے اور خدا بندوں پر بہت مہربان ہے\qt@no{207}}%
\qt@newcmd\qurantrans@ur@ccxv{مومنو! اسلام میں پورے پورے داخل ہوجاؤ اور شیطان کے پیچھے نہ چلو وہ تو تمہارا صریح دشمن ہے\qt@no{208}}%
\qt@newcmd\qurantrans@ur@ccxvi{پھر اگر تم احکام روشن پہنچ جانے کے بعد لڑکھڑاجاؤ تو جان جاؤ کہ خدا غالب (اور) حکمت والا ہے\qt@no{209}}%
\qt@newcmd\qurantrans@ur@ccxvii{کیا یہ لوگ اسی بات کے منتظر ہیں کہ ان پر خدا (کاعذاب) بادل کے سائبانوں میں آنازل ہو اور فرشتے بھی (اتر آئیں) اور کام تمام کردیا جائے اور سب کاموں کا رجوع خدا ہی کی طرف ہے\qt@no{210}}%
\qt@newcmd\qurantrans@ur@ccxviii{اے محمد) بنی اسرائیل سے پوچھو کہ ہم نے ان کو کتنی کھلی نشانیاں دیں۔ اور جو شخص خدا کی نعمت کو اپنے پاس آنے کے بعد بدل دے تو خدا سخت عذاب کرنے والا ہے\qt@no{211}}%
\qt@newcmd\qurantrans@ur@ccxix{اور جو کافر ہیں ان کے لئے دنیا کی زندگی خوشنما کر دی گئی ہے اور وہ مومنوں سے تمسخر کرتے ہیں لیکن جو پرہیز گار ہیں وہ قیامت کے دن ان پر غالب ہوں گے اور خدا جس کو چاہتا ہے بےشمار رزق دیتا ہے\qt@no{212}}%
\qt@newcmd\qurantrans@ur@ccxx{پہلے تو سب) لوگوں کا ایک ہی مذہب تھا (لیکن وہ آپس میں اختلاف کرنے لگے) تو خدا نے (ان کی طرف) بشارت دینے والے اور ڈر سنانے والے پیغمبر بھیجے اور ان پر سچائی کے ساتھ کتابیں نازل کیں تاکہ جن امور میں لوگ اختلاف کرتے تھے ان کا ان میں فیصلہ کردے۔ اور اس میں اختلاف بھی انہیں لوگوں نے کیا جن کو کتاب دی گئی تھی باوجود یہ کہ ان کے پاس کھلے ہوئے احکام آچکے تھے (اور یہ اختلاف انہوں نے صرف) آپس کی ضد سے (کیا) تو جس امر حق میں وہ اختلاف کرتے تھے خدا نے اپنی مہربانی سے مومنوں کو اس کی راہ دکھا دی۔ اور خدا جس کو چاہتا ہے سیدھا رستہ دکھا دیتا ہے\qt@no{213}}%
\qt@newcmd\qurantrans@ur@ccxxi{کیا تم یہ خیال کرتے ہو کہ (یوں ہی) بہشت میں داخل ہوجاؤ گے اور ابھی تم کو پہلے لوگوں کی سی (مشکلیں) تو پیش آئی ہی نہیں۔ ان کو (بڑی بڑی) سختیاں اور تکلیفیں پہنچیں اور وہ (صعوبتوں میں) ہلا ہلا دیئے گئے۔ یہاں تک کہ پیغمبر اور مومن لوگ جو ان کے ساتھ تھے سب پکار اٹھے کہ کب خدا کی مدد آئے گی ۔ دیکھو خدا کی مدد (عن) قریب (آيا چاہتی) ہے\qt@no{214}}%
\qt@newcmd\qurantrans@ur@ccxxii{اے محمدﷺ) لوگ تم سے پوچھتے ہیں کہ (خدا کی راہ میں) کس طرح کا مال خرچ کریں۔ کہہ دو کہ (جو چاہو خرچ کرو لیکن) جو مال خرچ کرنا چاہو وہ (درجہ بدرجہ اہل استحقاق یعنی) ماں باپ اور قریب کے رشتے داروں کو اور یتیموں کو اور محتاجوں کو اور مسافروں کو (سب کو دو) اور جو بھلائی تم کرو گے خدا اس کو جانتا ہے\qt@no{215}}%
\qt@newcmd\qurantrans@ur@ccxxiii{مسلمانو) تم پر (خدا کے رستے میں) لڑنا فرض کردیا گیا ہے وہ تمہیں ناگوار تو ہوگا مگر عجب نہیں کہ ایک چیز تم کو بری لگے اور وہ تمہارے حق میں بھلی ہو اور عجب نہیں کہ ایک چیز تم کو بھلی لگے اور وہ تمہارے لئے مضر ہو۔ اور ان باتوں کو) خدا ہی بہتر جانتا ہے اور تم نہیں جانتے\qt@no{216}}%
\qt@newcmd\qurantrans@ur@ccxxiv{اے محمدﷺ) لوگ تم سے عزت والے مہینوں میں لڑائی کرنے کے بارے میں دریافت کرتے ہیں کہہ دو کہ ان میں لڑنا بڑا (گناہ) ہےاور خدا کی راہ سے روکنا اور اس سے کفر کرنا اور مسجد حرام (یعنی خانہ کعبہ میں جانے) سے (بند کرنا) ۔ اور اہل مسجد کو اس میں سے نکال دینا (جو یہ کفار کرتے ہیں) خدا کے نزدیک اس سے بھی زیادہ (گناہ) ہے۔ اور فتنہ انگیزی خونریزی سے بھی بڑھ کر ہے۔ اور یہ لوگ ہمیشہ تم سے لڑتے رہیں گے یہاں تک کہ اگر مقدور رکھیں تو تم کو تمہارے دین سے پھیر دیں۔ اور جو کوئی تم میں سے اپنے دین سے پھر کر (کافر ہو) جائے گا اور کافر ہی مرے گا تو ایسے لوگوں کے اعمال دنیا اور آخرت دونوں میں برباد ہوجائیں گے اور یہی لوگ دوزخ (میں جانے) والے ہیں جس میں ہمیشہ رہیں گے\qt@no{217}}%
\qt@newcmd\qurantrans@ur@ccxxv{جو لوگ ایمان لائے اور خدا کے لئے وطن چھوڑ گئے اور (کفار سے) جنگ کرتے رہے وہی خدا کی رحمت کے امیدوار ہیں۔ اور خدا بخشنے والا (اور) رحمت کرنے والا ہے\qt@no{218}}%
\qt@newcmd\qurantrans@ur@ccxxvi{اے پیغمبر) لوگ تم سے شراب اور جوئے کا حکم دریافت کرتے ہیں۔ کہہ دو کہ ان میں نقصان بڑے ہیں اور لوگوں کے لئے کچھ فائدے بھی ہیں مگر ان کے نقصان فائدوں سے کہیں زیادہ ہیں اور یہ بھی تم سے پوچھتے ہیں کہ (خدا کی راہ میں) کون سا مال خرچ کریں۔ کہہ دو کہ جو ضرورت سے زیادہ ہو۔ اس طرح خدا تمہارے لئے اپنے احکام کھول کھول کر بیان فرماتا ہے تاکہ تم سوچو\qt@no{219}}%
\qt@newcmd\qurantrans@ur@ccxxvii{یعنی) دنیا اور آخرت (کی باتوں) میں (غور کرو) ۔ اور تم سے یتیموں کے بارے میں دریافت کرتے ہیں کہہ دو کہ ان کی (حالت کی) اصلاح بہت اچھا کام ہے۔ اور اگر تم ان سے مل جل کر رہنا (یعنی خرچ اکھٹا رکھنا) چاہو تو وہ تمہارے بھائی ہیں اور خدا خوب جانتا ہے کہ خرابی کرنے والا کون ہے اور اصلاح کرنے والا کون۔ اور اگر خدا چاہتا تو تم کو تکلیف میں ڈال دیتا۔بےشک خدا غالب (اور) حکمت والا ہے\qt@no{220}}%
\qt@newcmd\qurantrans@ur@ccxxviii{اور (مومنو) مشرک عورتوں سے جب تک کہ ایمان نہ لائیں نکاح نہ کرنا۔ کیونکہ مشرک عورت خواہ تم کو کیسی ہی بھلی لگے اس سے مومن لونڈی بہتر ہے۔ اور (اسی طرح) مشرک مرد جب تک ایمان نہ لائیں مومن عورتوں کو ان کو زوجیت میں نہ دینا کیونکہ مشرک (مرد) سے خواہ وہ تم کو کیسا ہی بھلا لگے مومن غلام بہتر ہے۔ یہ (مشرک لوگوں کو) دوزخ کی طرف بلاتے ہیں۔ اور خدا اپنی مہربانی سے بہشت اور بخشش کی طرف بلاتا ہے۔ اور اپنے حکم لوگوں سے کھول کھول کر بیان کرتا ہے تاکہ نصیحت حاصل کریں\qt@no{221}}%
\qt@newcmd\qurantrans@ur@ccxxix{اور تم سے حیض کے بارے میں دریافت کرتے ہیں۔ کہہ دو کہ وہ تو نجاست ہے۔ سو ایام حیض میں عورتوں سے کنارہ کش رہو۔ اور جب تک پاک نہ ہوجائیں ان سے مقاربت نہ کرو۔ ہاں جب پاک ہوجائیں تو جس طریق سے خدا نے ارشاد فرمایا ہے ان کے پاس جاؤ۔ کچھ شک نہیں کہ خدا توبہ کرنے والوں اور پاک صاف رہنے والوں کو دوست رکھتا ہے\qt@no{222}}%
\qt@newcmd\qurantrans@ur@ccxxx{تمہاری عورتیں تمہارای کھیتی ہیں تو اپنی کھیتی میں جس طرح چاہو جاؤ۔ اور اپنے لئے (نیک عمل) آگے بھیجو۔ اور خدا سے ڈرتے رہو اور جان رکھو کہ (ایک دن) تمہیں اس کے روبرو حاضر ہونا ہے اور (اے پیغمبر) ایمان والوں کو بشارت سنا دو\qt@no{223}}%
\qt@newcmd\qurantrans@ur@ccxxxi{اور خدا (کے نام کو) اس بات کا حیلہ نہ بنانا کہ (اس کی) قسمیں کھا کھا کر سلوک کرنے اورپرہیزگاری کرنے اور لوگوں میں صلح و سازگاری کرانے سے رک جاؤ۔ اور خدا سب کچھ سنتا اور جانتا ہے\qt@no{224}}%
\qt@newcmd\qurantrans@ur@ccxxxii{خدا تمہاری لغو قسموں پر تم سے مواخذہ نہ کرے گا۔ لیکن جو قسمیں تم قصد دلی سے کھاؤ گے ان پر مواخذہ کرے گا۔ اور خدا بخشنے والا بردبار ہے\qt@no{225}}%
\qt@newcmd\qurantrans@ur@ccxxxiii{جو لوگ اپنی عورتوں کے پاس جانے سے قسم کھالیں ان کو چار مہینے تک انتظار کرنا چاہیئے۔ اگر (اس عرصے میں قسم سے) رجوع کرلیں تو خدا بخشنے والا مہربان ہے\qt@no{226}}%
\qt@newcmd\qurantrans@ur@ccxxxiv{اور اگر طلاق کا ارادہ کرلیں تو بھی خدا سنتا (اور) جانتا ہے\qt@no{227}}%
\qt@newcmd\qurantrans@ur@ccxxxv{اور طلاق والی عورتیں تین حیض تک اپنی تئیں روکے رہیں۔ اور اگر وہ خدا اور روز قیامت پر ایمان رکھتی ہیں تو ان کا جائز نہیں کہ خدا نے جو کچھ ان کے شکم میں پیدا کیا ہے اس کو چھپائیں۔ اور ان کے خاوند اگر پھر موافقت چاہیں تو اس (مدت) میں وہ ان کو اپنی زوجیت میں لے لینے کے زیادہ حقدار ہیں۔ اور عورتوں کا حق (مردوں پر) ویسا ہی ہے جیسے دستور کے مطابق (مردوں کا حق) عورتوں پر ہے۔ البتہ مردوں کو عورتوں پر فضیلت ہے۔ اور خدا غالب (اور) صاحب حکمت ہے\qt@no{228}}%
\qt@newcmd\qurantrans@ur@ccxxxvi{طلاق (صرف) دوبار ہے (یعنی جب دو دفعہ طلاق دے دی جائے تو) پھر (عورتوں کو) یا تو بطریق شائستہ (نکاح میں) رہنے دینا یا بھلائی کے ساتھ چھوڑ دینا۔ اور یہ جائز نہیں کہ جو مہر تم ان کو دے چکے ہو اس میں سے کچھ واپس لے لو۔ ہاں اگر زن و شوہر کو خوف ہو کہ وہ خدا کی حدوں کو قائم نہیں رکھ سکیں گے تو اگر عورت (خاوند کے ہاتھ سے) رہائی پانے کے بدلے میں کچھ دے ڈالے تو دونوں پر کچھ گناہ نہیں۔ یہ خدا کی (مقرر کی ہوئی) حدیں ہیں ان سے باہر نہ نکلنا۔ اور جو لوگ خدا کی حدوں سے باہر نکل جائیں گے وہ گنہگار ہوں گے\qt@no{229}}%
\qt@newcmd\qurantrans@ur@ccxxxvii{پھر اگر شوہر (دو طلاقوں کے بعد تیسری) طلاق عورت کو دے دے تو اس کے بعد جب تک عورت کسی دوسرے شخص سے نکاح نہ کرلے اس (پہلے شوہر) پر حلال نہ ہوگی۔ ہاں اگر دوسرا خاوند بھی طلاق دے دے اورعورت اور پہلا خاوند پھر ایک دوسرے کی طرف رجوع کرلیں تو ان پر کچھ گناہ نہیں بشرطیکہ دونوں یقین کریں کہ خدا کی حدوں کو قائم رکھ سکیں گے اور یہ خدا کی حدیں ہیں ان کو وہ ان لوگوں کے لئے بیان فرماتا ہے جو دانش رکھتے ہیں\qt@no{230}}%
\qt@newcmd\qurantrans@ur@ccxxxviii{اور جب تم عورتوں کو (دو دفعہ) طلاق دے چکو اور ان کی عدت پوری ہوجائے تو انہیں یا تو حسن سلوک سے نکاح میں رہنے دو یا بطریق شائستہ رخصت کردو اور اس نیت سے ان کو نکاح میں نہ رہنے دینا چاہئے کہ انہیں تکلیف دو اور ان پر زیادتی کرو۔ اور جو ایسا کرے گا وہ اپنا ہی نقصان کرے گا اور خدا کے احکام کو ہنسی (اور کھیل) نہ بناؤ اور خدا نے تم کو جو نعمتیں بخشی ہیں اور تم پر جو کتاب اور دانائی کی باتیں نازل کی ہیں جن سے وہ تمہیں نصیحت فرماتا ہے ان کو یاد کرو۔ اور خدا سے ڈرتے رہو اور جان رکھوکہ خدا ہر چیز سے واقف ہے\qt@no{231}}%
\qt@newcmd\qurantrans@ur@ccxxxix{اور جب تم عورتوں کو طلاق دے چکو اور ان کی عدت پوری ہوجائے تو ان کو دوسرے شوہروں کے ساتھ جب وہ آپس میں جائز طور پر راضی ہوجائیں نکاح کرنے سے مت روکو۔ اس (حکم) سے اس شخص کو نصیحت کی جاتی ہے جو تم میں خدا اور روز آخرت پر یقین رکھتا ہے۔ یہ تمہارے لئے نہایت خوب اور بہت پاکیزگی کی بات ہے اور خدا جانتا ہے اور تم نہیں جانتے\qt@no{232}}%
\qt@newcmd\qurantrans@ur@ccxl{اور مائیں اپنے بچوں کو پورے دو سال دودھ پلائیں یہ (حکم) اس شخص کے لئے ہے جو پوری مدت تک دودھ پلوانا چاہے۔ اور دودھ پلانے والی ماؤں کا کھانا اور کپڑا دستور کے مطابق باپ کے ذمے ہوگا۔ کسی شخص کو اس کی طاقت سے زیادہ تکلیف نہیں دی جاتی (تو یاد رکھو کہ) نہ تو ماں کو اس کے بچے کے سبب نقصان پہنچایا جائے اور نہ باپ کو اس کی اولاد کی وجہ سے نقصان پہنچایا جائے اور اسی طرح (نان نفقہ) بچے کے وارث کے ذمے ہے۔ اور اگر دونوں (یعنی ماں باپ) آپس کی رضامندی اور صلاح سے بچے کا دودھ چھڑانا چاہیں تو ان پر کچھ گناہ نہیں۔ اور اگر تم اپنی اولاد کو دودھ پلوانا چاہو تو تم پر کچھ گناہ نہیں بشرطیکہ تم دودھ پلانے والیوں کو دستور کے مطابق ان کا حق جو تم نے دینا کیا تھا دے دو اور خدا سے ڈرتے رہو اور جان رکھو کہ جو کچھ تم کرتے ہو خدا اس کو دیکھ رہا ہے\qt@no{233}}%
\qt@newcmd\qurantrans@ur@ccxli{اور جو لوگ تم میں سے مرجائیں اور عورتیں چھوڑ جائیں تو عورتیں چار مہینے دس دن اپنے آپ کو روکے رہیں۔ اور جب (یہ) عدت پوری کرچکیں اور اپنے حق میں پسندیدہ کام (یعنی نکاح) کرلیں تو ان پر کچھ گناہ نہیں۔ اور خدا تمہارے سب کاموں سے واقف ہے\qt@no{234}}%
\qt@newcmd\qurantrans@ur@ccxlii{اور اگر تم کنائے کی باتوں میں عورتوں کو نکاح کا پیغام بھیجو یا (نکاح کی خواہش کو) اپنے دلوں میں مخفی رکھو تو تو تم پر کچھ گناہ نہیں۔ خدا کو معلوم ہے کہ تم ان سے (نکاح کا) ذکر کرو گے۔ مگر (ایام عدت میں) اس کے سوا کہ دستور کے مطابق کوئی بات کہہ دو پوشیدہ طور پر ان سے قول واقرار نہ کرنا۔ اور جب تک عدت پوری نہ ہولے نکاح کا پختہ ارادہ نہ کرنا۔ اور جان رکھو کہ جو کچھ تمہارے دلوں میں ہے خدا کو سب معلوم ہے تو اس سے ڈرتے رہو اور جان رکھو کہ خدا بخشنے والا اور حلم والا ہے\qt@no{235}}%
\qt@newcmd\qurantrans@ur@ccxliii{اور اگر تم عورتوں کو ان کے پاس جانے یا ان کا مہر مقرر کرنے سے پہلے طلاق دے دو تو تم پر کچھ گناہ نہیں۔ ہاں ان کو دستور کے مطابق کچھ خرچ ضرور دو (یعنی) مقدور والا اپنے مقدور کے مطابق دے اور تنگدست اپنی حیثیت کے مطابق۔ نیک لوگوں پر یہ ایک طرح کا حق ہے\qt@no{236}}%
\qt@newcmd\qurantrans@ur@ccxliv{اور اگر تم عورتوں کو ان کے پاس جانے سے پہلے طلاق دے دو لیکن مہر مقرر کرچکے ہو تو آدھا مہر دینا ہوگا۔ ہاں اگر عورتیں مہر بخش دیں یا مرد جن کے ہاتھ میں عقد نکاح ہے (اپنا حق) چھوڑ دیں۔ (اور پورا مہر دے دیں تو ان کو اختیار ہے) اور اگر تم مرد لوگ ہ اپنا حق چھوڑ دو تو یہ پرہیزگاری کی بات ہے۔ اور آپس میں بھلائی کرنے کو فراموش نہ کرنا۔ کچھ شک نہیں کہ خدا تمہارے سب کاموں کو دیکھ رہا ہے\qt@no{237}}%
\qt@newcmd\qurantrans@ur@ccxlv{مسلمانو) سب نمازیں خصوصاً بیچ کی نماز (یعنی نماز عصر) پورے التزام کے ساتھ ادا کرتے رہو۔ اور خدا کے آگے ادب سے کھڑے رہا کرو\qt@no{238}}%
\qt@newcmd\qurantrans@ur@ccxlvi{اگر تم خوف کی حالت میں ہو تو پیادے یا سوار (جس حال میں ہو نماز پڑھ لو) پھر جب امن (واطمینان) ہوجائے تو جس طریق سے خدا نے تم کو سکھایا ہے جو تم پہلے نہیں جانتے تھے خدا کو یاد کرو\qt@no{239}}%
\qt@newcmd\qurantrans@ur@ccxlvii{اور جو لوگ تم میں سے مرجائیں اور عورتیں چھوڑ جائیں وہ اپنی عورتوں کے حق میں وصیت کرجائیں کہ ان کو ایک سال تک خرچ دیا جائے اور گھر سے نہ نکالی جائیں۔ ہاں اگر وہ خود گھر سے نکل جائیں اور اپنے حق میں پسندیدہ کام (یعنی نکاح) کرلیں تو تم پر کچھ گناہ نہیں۔ اور خدا زبردست حکمت والا ہے\qt@no{240}}%
\qt@newcmd\qurantrans@ur@ccxlviii{اور مطلقہ عورتوں کو بھی دستور کے مطابق نان و نفقہ دینا چاہیئے پرہیزگاروں پر (یہ بھی) حق ہے\qt@no{241}}%
\qt@newcmd\qurantrans@ur@ccxlix{اسی طرح خدا اپنے احکام تمہارے لئے بیان فرماتا ہے تاکہ تم سمجھو\qt@no{242}}%
\qt@newcmd\qurantrans@ur@ccl{بھلا تم نے ان لوگوں کو نہیں دیکھا جو (شمار میں) ہزاروں ہی تھے اور موت کے ڈر سے اپنے گھروں سے نکل بھاگے تھے۔ تو خدا نے ان کو حکم دیا کہ مرجاؤ۔ پھر ان کو زندہ بھی کردیا۔ کچھ شک نہیں کہ خدا لوگوں پر مہربانی رکھتا ہے۔ لیکن اکثر لوگ شکر نہیں کرتے\qt@no{243}}%
\qt@newcmd\qurantrans@ur@ccli{اور (مسلمانو) خدا کی راہ میں جہاد کرو اور جان رکھو کہ خدا (سب کچھ) جانتا ہے\qt@no{244}}%
\qt@newcmd\qurantrans@ur@cclii{کوئی ہے کہ خدا کو قرض حسنہ دے کہ وہ اس کے بدلے اس کو کئی حصے زیادہ دے گا۔ اور خدا ہی روزی کو تنگ کرتا اور (وہی اسے) کشادہ کرتا ہے۔ اور تم اسی کی طرف لوٹ کر جاؤ گے\qt@no{245}}%
\qt@newcmd\qurantrans@ur@ccliii{بھلا تم نے بنی اسرائیل کی ایک جماعت کو نہیں دیکھا جس نے موسیٰ کے بعد اپنے پیغمبر سے کہا کہ آپ ہمارے لئے ایک بادشاہ مقرر کردیں تاکہ ہم خدا کی راہ میں جہاد کریں۔ پیغمبر نے کہا کہ اگر تم کو جہاد کا حکم دیا جائے تو عجب نہیں کہ لڑنے سے پہلو تہی کرو۔ وہ کہنے لگے کہ ہم راہ خدا میں کیوں نہ لڑیں گے جب کہ ہم وطن سے (خارج) اور بال بچوں سے جدا کردیئے گئے۔ لیکن جب ان کو جہاد کا حکم دیا گیا تو چند اشخاص کے سوا سب پھر گئے۔ اور خدا ظالموں سے خوب واقف ہے\qt@no{246}}%
\qt@newcmd\qurantrans@ur@ccliv{اور پیغمبر نے ان سے (یہ بھی) کہا کہ خدا نے تم پر طالوت کو بادشاہ مقرر فرمایا ہے۔ وہ بولے کہ اسے ہم پر بادشاہی کا حق کیونکر ہوسکتا ہےبادشاہی کے مستحق تو ہم ہیں اور اس کے پاس تو بہت سی دولت بھی نہیں۔ پیغمبر نے کہا کہ خدا نےاس کو تم پر فضیلت دی ہے اور (بادشاہی کے لئے) منتخب فرمایا ہے اس نے اسے علم بھی بہت سا بخشا ہے اور تن و توش بھی (بڑا عطا کیا ہے) اور خدا (کو اختیار ہے) جسے چاہے بادشاہی بخشے۔ وہ بڑا کشائش والا اور دانا ہے\qt@no{247}}%
\qt@newcmd\qurantrans@ur@cclv{اور پیغمبر نے ان سے کہا کہ ان کی بادشاہی کی نشانی یہ ہے کہ تمہارے پاس ایک صندوق آئے گا جس کو فرشتے اٹھائے ہوئے ہوں گے اس میں تمہارے پروردگار کی طرف سے تسلی (بخشنے والی چیز) ہوگی اور کچھ اور چیزیں بھی ہوں گی جو موسیٰ اور ہارون چھوڑ گئے تھے۔ اگر تم ایمان رکھتے ہو تو یہ تمہارے لئے ایک بڑی نشانی ہے\qt@no{248}}%
\qt@newcmd\qurantrans@ur@cclvi{غرض جب طالوت فوجیں لے کر روانہ ہوا تو اس نے (ان سے) کہا کہ خدا ایک نہر سے تمہاری آزمائش کرنے والا ہے۔ جو شخص اس میں سے پانی پی لے گا (اس کی نسبت تصور کیا جائے گا کہ) وہ میرا نہیں۔ اور جو نہ پئے گا وہ (سمجھا جائے گا کہ) میرا ہے۔ ہاں اگر کوئی ہاتھ سے چلو بھر پانی پی لے (تو خیر۔ جب وہ لوگ نہر پر پہنچے) تو چند شخصوں کے سوا سب نے پانی پی لیا۔ پھر جب طالوت اور مومن لوگ جو اس کے ساتھ تھے نہر کے پار ہوگئے۔ تو کہنے لگے کہ آج ہم میں جالوت اور اس کے لشکر سے مقابلہ کرنے کی طاقت نہیں۔ جو لوگ یقین رکھتے تھے کہ ان کو خدا کے روبرو حاضر ہونا ہے وہ کہنے لگے کہ بسااوقات تھوڑی سی جماعت نے خدا کے حکم سے بڑی جماعت پر فتح حاصل کی ہے اور خدا استقلال رکھنے والوں کے ساتھ ہے\qt@no{249}}%
\qt@newcmd\qurantrans@ur@cclvii{اور جب وہ لوگ جالوت اور اس کے لشکر کے مقابل آئے تو (خدا سے) دعا کی کہ اے پروردگار ہم پر صبر کے دہانے کھول دے اور ہمیں (لڑائی میں) ثابت قدم رکھ اور (لشکر) کفار پر فتحیاب کر\qt@no{250}}%
\qt@newcmd\qurantrans@ur@cclviii{تو طالوت کی فوج نے خدا کے حکم سے ان کو ہزیمت دی۔ اور داؤد نے جالوت کو قتل کر ڈالا۔ اور خدا نے اس کو بادشاہی اور دانائی بخشی اور جو کچھ چاہا سکھایا۔ اور خدا لوگوں کو ایک دوسرے (پر چڑھائی اور حملہ کرنے) سے ہٹاتا نہ رہتا تو ملک تباہ ہوجاتا لیکن خدا اہل عالم پر بڑا مہربان ہے\qt@no{251}}%
\qt@newcmd\qurantrans@ur@cclix{یہ خدا کی آیتیں ہیں جو ہم تم کو سچائی کے ساتھ پڑھ کر سناتے ہیں (اور اے محمدﷺ) تم بلاشبہ پیغمبروں میں سے ہو\qt@no{252}}%
\qt@newcmd\qurantrans@ur@cclx{یہ پیغمبر (جو ہم وقتاً فوقتاً بھیجتے رہیں ہیں) ان میں سے ہم نے بعض کو بعض پر فضیلت دی ہے۔ بعض ایسے ہیں جن سے خدا نے گفتگو فرمائی اور بعض کے (دوسرے امور میں) مرتبے بلند کئے۔ اور عیسیٰ بن مریم کو ہم نے کھلی ہوئی نشانیاں عطا کیں اور روح القدس سے ان کو مدد دی۔ اور اگر خداچاہتا تو ان سے پچھلے لوگ اپنے پاس کھلی نشانیاں آنے کے بعد آپس میں نہ لڑتے لیکن انہوں نے اختلاف کیا تو ان میں سے بعض تو ایمان لے آئے اور بعض کافر ہی رہے۔ اور اگر خدا چاہتا تو یہ لوگ باہم جنگ و قتال نہ کرتے۔ لیکن خدا جو چاہتا ہے کرتا ہے\qt@no{253}}%
\qt@newcmd\qurantrans@ur@cclxi{اے ایمان والو جو (مال) ہم نے تم کو دیا ہے اس میں سے اس دن کے آنے سے پہلے پہلے خرچ کرلو جس میں نہ (اعمال کا) سودا ہو اور نہ دوستی اور سفارش ہو سکے اور کفر کرنے والے لوگ ظالم ہیں\qt@no{254}}%
\qt@newcmd\qurantrans@ur@cclxii{خدا (وہ معبود برحق ہے کہ) اس کے سوا کوئی عبادت کے لائق نہیں زندہ ہمیشہ رہنے والا اسے نہ اونگھ آتی ہے نہ نیند جو کچھ آسمانوں میں اور جو کچھ زمین میں ہیں سب اسی کا ہے کون ہے جو اس کی اجازت کے بغیر اس سے (کسی کی) سفارش کر سکے جو کچھ لوگوں کے روبرو ہو رہا ہے اور جو کچھ ان کے پیچھے ہوچکا ہے اسے سب معلوم ہے اور وہ اس کی معلومات میں سے کسی چیز پر دسترس حاصل نہیں کر سکتے ہاں جس قدر وہ چاہتا ہے (اسی قدر معلوم کرا دیتا ہے) اس کی بادشاہی (اور علم) آسمان اور زمین سب پر حاوی ہے اور اسے ان کی حفاظت کچھ بھی دشوار نہیں وہ بڑا عالی رتبہ اور جلیل القدر ہے\qt@no{255}}%
\qt@newcmd\qurantrans@ur@cclxiii{دین (اسلام) میں زبردستی نہیں ہے ہدایت (صاف طور پر ظاہر اور) گمراہی سے الگ ہو چکی ہے تو جو شخص بتوں سے اعتقاد نہ رکھے اور خدا پر ایمان لائے اس نے ایسی مضبوط رسی ہاتھ میں پکڑ لی ہے جو کبھی ٹوٹنے والی نہیں اور خدا (سب کچھ) سنتا اور (سب کچھ) جانتا ہے\qt@no{256}}%
\qt@newcmd\qurantrans@ur@cclxiv{جو لوگ ایمان لائے ہیں ان کا دوست خدا ہے کہ اُن کو اندھیرے سے نکال کر روشنی میں لے جاتا ہے اور جو کافر ہیں ان کے دوست شیطان ہیں کہ ان کو روشنی سے نکال کر اندھیرے میں لے جاتے ہیں یہی لوگ اہل دوزخ ہیں کہ اس میں ہمیشہ رہیں گے\qt@no{257}}%
\qt@newcmd\qurantrans@ur@cclxv{بھلا تم نے اس شخص کو نہیں دیکھا جو اس (غرور کے) سبب سے کہ خدا نے اس کو سلطنت بخشی تھی ابراہیم سے پروردگار کے بارے میں جھگڑنے لگا۔ جب ابراہیم نے کہا میرا پروردگار تو وہ ہے جو جلاتا اور مارتا ہے۔ وہ بولا کہ جلا اور مار تو میں بھی سکتا ہوں۔ ابراہیم نے کہا کہ خدا تو سورج کو مشرق سے نکالتا ہے آپ اسے مغرب سے نکال دیجیئے (یہ سن کر) کافر حیران رہ گیا اور خدا بےانصافوں کو ہدایت نہیں دیا کرتا\qt@no{258}}%
\qt@newcmd\qurantrans@ur@cclxvi{یا اسی طرح اس شخص کو (نہیں دیکھا) جسے ایک گاؤں میں جو اپنی چھتوں پر گرا پڑا تھا اتفاق گزر ہوا۔ تو اس نے کہا کہ خدا اس (کے باشندوں) کو مرنے کے بعد کیونکر زندہ کرے گا۔ تو خدا نے اس کی روح قبض کرلی (اور) سو برس تک (اس کو مردہ رکھا) پھر اس کو جلا اٹھایا اور پوچھا تم کتنا عرصہ (مرے) رہے ہو اس نے جواب دیا کہ ایک دن یا اس سے بھی کم۔ خدا نے فرمایا (نہیں) بلکہ سو برس (مرے) رہے ہو۔ اور اپنے کھانے پینے کی چیزوں کو دیکھو کہ (اتنی مدت میں مطلق) سڑی بسی نہیں اور اپنے گدھے کو بھی دیکھو (جو مرا پڑا ہے) غرض (ان باتوں سے) یہ ہے کہ ہم تم کو لوگوں کے لئے (اپنی قدرت کی) نشانی بنائیں اور (ہاں گدھے) کی ہڈیوں کو دیکھو کہ ہم ان کو کیونکر جوڑے دیتے اور ان پر (کس طرح) گوشت پوست چڑھا دیتے ہیں۔ جب یہ واقعات اس کے مشاہدے میں آئے تو بول اٹھا کہ میں یقین کرتا ہوں کہ خدا ہر چیز پر قادر ہے\qt@no{259}}%
\qt@newcmd\qurantrans@ur@cclxvii{اور جب ابراہیم نے (خدا سے) کہا کہ اے پروردگار مجھے دکھا کہ تو مردوں کو کیونکر زندہ کرے گا۔ خدا نے فرمایا کیا تم نے (اس بات کو) باور نہیں کیا۔ انہوں نے کہا کیوں نہیں۔ لیکن (میں دیکھنا) اس لئے (چاہتا ہوں) کہ میرا دل اطمینان کامل حاصل کرلے۔ خدا نے فرمایا کہ چار جانور پکڑوا کر اپنے پاس منگا لو (اور ٹکڑے ٹکڑے کرادو) پھر ان کا ایک ٹکڑا ہر ایک پہاڑ پر رکھوا دو پھر ان کو بلاؤ تو وہ تمہارے پاس دوڑتے چلے آئیں گے۔ اور جان رکھو کہ خدا غالب اور صاحب حکمت ہے۔\qt@no{260}}%
\qt@newcmd\qurantrans@ur@cclxviii{جو لوگ اپنا مال خدا کی راہ میں خرچ کرتے ہیں ان (کے مال) کی مثال اس دانے کی سی ہے جس سے سات بالیں اگیں اور ہر ایک بال میں سو سو دانے ہوں اور خدا جس (کے مال) کو چاہتا ہے زیادہ کرتا ہے۔ وہ بڑی کشائش والا اور سب کچھ جاننے والا ہے\qt@no{261}}%
\qt@newcmd\qurantrans@ur@cclxix{جو لوگ اپنا مال خدا کے رستے میں صرف کرتے ہیں پھر اس کے بعد نہ اس خرچ کا (کسی پر) احسان رکھتے ہیں اور نہ (کسی کو) تکلیف دیتے ہیں۔ ان کا صلہ ان کے پروردگار کے پاس (تیار) ہے۔ اور (قیامت کے روز) نہ ان کو کچھ خوف ہوگا اور نہ وہ غمگین ہوں گے\qt@no{262}}%
\qt@newcmd\qurantrans@ur@cclxx{جس خیرات دینے کے بعد (لینے والے کو) ایذا دی جائے اس سے تو نرم بات کہہ دینی اور (اس کی بے ادبی سے) درگزر کرنا بہتر ہے اور خدا بےپروا اور بردبار ہے\qt@no{263}}%
\qt@newcmd\qurantrans@ur@cclxxi{مومنو! اپنے صدقات (وخیرات) احسان رکھنے اور ایذا دینے سے اس شخص کی طرح برباد نہ کردینا۔ جو لوگوں کو دکھاوے کے لئے مال خرچ کرتا ہے اور خدا اور روز آخرت پر ایمان نہیں رکھتا۔ تو اس (کے مال) کی مثال اس چٹان کی سی ہے جس پر تھوڑی سی مٹی پڑی ہو اور اس پر زور کا مینہ برس کر اسے صاف کر ڈالے۔ (اسی طرح) یہ (ریاکار) لوگ اپنے اعمال کا کچھ بھی صلہ حاصل نہیں کرسکیں گے۔ اور خدا ایسے ناشکروں کو ہدایت نہیں دیا کرتا\qt@no{264}}%
\qt@newcmd\qurantrans@ur@cclxxii{اور جو لوگ خدا کی خوشنودی حاصل کرنے کے لئے خلوص نیت سے اپنا مال خرچ کرتے ہیں ان کی مثال ایک باغ کی سی ہے جو اونچی جگہ پر واقع ہو (جب) اس پر مینہ پڑے تو دگنا پھل لائے۔ اور اگر مینہ نہ بھی پڑے تو خیر پھوار ہی سہی اور خدا تمہارے کاموں کو دیکھ رہا ہے\qt@no{265}}%
\qt@newcmd\qurantrans@ur@cclxxiii{بھلا تم میں کوئی یہ چاہتا ہے کہ اس کا کھجوروں اور انگوروں کا باغ ہو جس میں نہریں بہہ رہی ہوں اور اس میں اس کے لئے ہر قسم کے میوے موجود ہوں اور اسے بڑھاپا آپکڑے اور اس کے ننھے ننھے بچے بھی ہوں۔ تو (ناگہاں) اس باغ پر آگ کا بھرا ہوا بگولا چلے اور وہ جل کر (راکھ کا ڈھیر ہو) جائے۔ اس طرح خدا تم سے اپنی آیتیں کھول کھول کر بیان فرماتا ہے تاکہ تم سوچو (اور سمجھو)\qt@no{266}}%
\qt@newcmd\qurantrans@ur@cclxxiv{مومنو! جو پاکیزہ اور عمدہ مال تم کماتے ہوں اور جو چیزیں ہم تمہارے لئے زمین سےنکالتے ہیں ان میں سے (راہ خدا میں) خرچ کرو۔ اور بری اور ناپاک چیزیں دینے کا قصد نہ کرنا کہ (اگر وہ چیزیں تمہیں دی جائیں تو) بجز اس کے کہ (لیتے وقت) آنکھیں بند کرلو ان کو کبھی نہ لو۔ اور جان رکھو کہ خدا بےپروا (اور) قابل ستائش ہے\qt@no{267}}%
\qt@newcmd\qurantrans@ur@cclxxv{اور دیکھنا) شیطان (کا کہنا نہ ماننا وہ) تمہیں تنگ دستی کا خوف دلاتا اور بےحیائی کے کام کر نے کو کہتا ہے۔ اور خدا تم سے اپنی بخشش اور رحمت کا وعدہ کرتا ہے۔ اور خدا بڑی کشائش والا (اور) سب کچھ جاننے والا ہے\qt@no{268}}%
\qt@newcmd\qurantrans@ur@cclxxvi{وہ جس کو چاہتا ہے دانائی بخشتا ہے۔ اور جس کو دانائی ملی بےشک اس کو بڑی نعمت ملی۔ اور نصیحت تو وہی لوگ قبول کرتے ہیں جو عقلمند ہیں\qt@no{269}}%
\qt@newcmd\qurantrans@ur@cclxxvii{اور تم (خدا کی راہ میں) جس طرح کا خرچ کرو یا کوئی نذر مانو خدا اس کو جانتا ہے اور ظالموں کا کوئی مددگار نہیں\qt@no{270}}%
\qt@newcmd\qurantrans@ur@cclxxviii{اگر تم خیرات ظاہر دو تو وہ بھی خوب ہے اور اگر پوشیدہ دو اور دو بھی اہل حاجت کو تو وہ خوب تر ہے اور (اس طرح کا دینا) تمہارے گناہوں کو بھی دور کردے گا۔ اور خدا کو تمہارے سب کاموں کی خبر ہے\qt@no{271}}%
\qt@newcmd\qurantrans@ur@cclxxix{اے محمدﷺ) تم ان لوگوں کی ہدایت کے ذمہ دار نہیں ہو بلکہ خدا ہی جس کو چاہتا ہے ہدایت بخشتا ہے۔ اور (مومنو) تم جو مال خرچ کرو گے تو اس کا فائدہ تمہیں کو ہے اور تم جو خرچ کرو گے خدا کی خوشنودی کے لئے کرو گے۔ اور جو مال تم خرچ کرو گے وہ تمہیں پورا پورا دے دیا جائے گا اور تمہارا کچھ نقصان نہیں کیا جائے گا،\qt@no{272}}%
\qt@newcmd\qurantrans@ur@cclxxx{اور ہاں تم جو خرچ کرو گے تو) ان حاجتمندوں کے لئے جو خدا کی راہ میں رکے بیٹھے ہیں اور ملک میں کسی طرف جانے کی طاقت نہیں رکھتے (اور مانگنے سے عار رکھتے ہیں) یہاں تک کہ نہ مانگنے کی وجہ سے ناواقف شخص ان کو غنی خیال کرتا ہے اور تم قیافے سے ان کو صاف پہچان لو (کہ حاجتمند ہیں اور شرم کے سبب) لوگوں سے (منہ پھوڑ کر اور) لپٹ کر نہیں مانگ سکتے اور تم جو مال خرچ کرو گے کچھ شک نہیں کہ خدا اس کو جانتا ہے\qt@no{273}}%
\qt@newcmd\qurantrans@ur@cclxxxi{جو لوگ اپنا مال رات اور دن اور پوشیدہ اور ظاہر (راہ خدا میں) خرچ کرتے رہتے ہیں ان کا صلہ پروردگار کے پاس ہے اور ان کو (قیامت کے دن) نہ کسی طرح کا خوف ہوگا اور نہ غم\qt@no{274}}%
\qt@newcmd\qurantrans@ur@cclxxxii{جو لوگ سود کھاتے ہیں وہ (قبروں سے) اس طرح (حواس باختہ) اٹھیں گے جیسے کسی کو جن نے لپٹ کر دیوانہ بنا دیا ہو یہ اس لئے کہ وہ کہتے ہیں کہ سودا بیچنا بھی تو (نفع کے لحاظ سے) ویسا ہی ہے جیسے سود (لینا) حالانکہ سودے کو خدا نے حلال کیا ہے اور سود کو حرام۔ تو جس شخص کے پاس خدا کی نصیحت پہنچی اور وہ (سود لینے سے) باز آگیا تو جو پہلے ہوچکا وہ اس کا۔ اور (قیامت میں) اس کا معاملہ خدا کے سپرد اور جو پھر لینے لگا تو ایسے لوگ دوزخی ہیں کہ ہمیشہ دوزخ میں (جلتے) رہیں گے\qt@no{275}}%
\qt@newcmd\qurantrans@ur@cclxxxiii{خدا سود کو نابود (یعنی بےبرکت) کرتا اور خیرات (کی برکت) کو بڑھاتا ہے اور خدا کسی ناشکرے گنہگار کو دوست نہیں رکھتا\qt@no{276}}%
\qt@newcmd\qurantrans@ur@cclxxxiv{جو لوگ ایمان لائے اور نیک عمل کرتے اور نماز پڑھتے اور زکوٰة دیتے رہے ان کو ان کے کاموں کا صلہ خدا کے ہاں ملے گا اور (قیامت کے دن) ان کو نہ کچھ خوف ہوا اور نہ وہ غمناک ہوں گے\qt@no{277}}%
\qt@newcmd\qurantrans@ur@cclxxxv{مومنو! خدا سے ڈرو اور اگر ایمان رکھتے ہو تو جتنا سود باقی رہ گیا ہے اس کو چھوڑ دو\qt@no{278}}%
\qt@newcmd\qurantrans@ur@cclxxxvi{اگر ایسا نہ کرو گے تو خبردار ہوجاؤ (کہ تم) خدا اور رسول سے جنگ کرنے کے لئے (تیار ہوتے ہو) اور اگر توبہ کرلو گے (اور سود چھوڑ دو گے) تو تم کو اپنی اصل رقم لینے کا حق ہے جس میں نہ اوروں کا نقصان اور تمہارا نقصان\qt@no{279}}%
\qt@newcmd\qurantrans@ur@cclxxxvii{اور اگر قرض لینے والا تنگ دست ہو تو (اسے) کشائش (کے حاصل ہونے) تک مہلت (دو) اور اگر (زر قرض) بخش ہی دو توتمہارے لئے زیادہ اچھا ہے بشرطیکہ سمجھو\qt@no{280}}%
\qt@newcmd\qurantrans@ur@cclxxxviii{اور اس دن سے ڈرو جب کہ تم خدا کے حضور میں لوٹ کر جاؤ گے اور ہر شخص اپنے اعمال کا پورا پورا بدلہ پائے گا۔ اور کسی کا کچھ نقصان نہ ہوگا\qt@no{281}}%
\qt@newcmd\qurantrans@ur@cclxxxix{مومنو! جب تم آپس میں کسی میعاد معین کے لئے قرض کا معاملہ کرنے لگو تو اس کو لکھ لیا کرو اور لکھنے والا تم میں (کسی کا نقصان نہ کرے بلکہ) انصاف سے لکھے نیز لکھنے والا جیسا اسے خدا نے سکھایا ہے لکھنے سے انکار بھی نہ کرے اور دستاویز لکھ دے۔ اور جو شخص قرض لے وہی (دستاویز کا) مضمون بول کر لکھوائے اور خدا سے کہ اس کا مالک ہے خوف کرے اور زر قرض میں سے کچھ کم نہ لکھوائے۔ اور اگر قرض لینے والا بےعقل یا ضعیف ہو یا مضمون لکھوانے کی قابلیت نہ رکھتا ہو تو جو اس کا ولی ہو وہ انصاف کے ساتھ مضمون لکھوائے۔ اور اپنے میں سے دو مردوں کو (ایسے معاملے کے) گواہ کرلیا کرو۔ اور اگر دو مرد نہ ہوں تو ایک مرد اور دو عورتیں جن کو تم گواہ پسند کرو (کافی ہیں) کہ اگر ان میں سے ایک بھول جائے گی تو دوسری اسے یاد دلادے گی۔ اور جب گواہ (گواہی کے لئے طلب کئے جائیں تو انکار نہ کریں۔ اور قرض تھوڑا ہو یا بہت اس (کی دستاویز) کے لکھنے میں کاہلی نہ کرنا۔ یہ بات خدا کے نزدیک نہایت قرین انصاف ہے اور شہادت کے لئے بھی یہ بہت درست طریقہ ہے۔ اس سے تمہیں کسی طرح کا شک وہ شبہ بھی نہیں پڑے گا۔ ہاں اگر سودا دست بدست ہو جو تم آپس میں لیتے دیتے ہو تو اگر (ایسے معاملے کی) دستاویز نہ لکھوتو تم پر کچھ گناہ نہیں۔ اور جب خرید وفروخت کیا کرو تو بھی گواہ کرلیا کرو۔ اور کاتب دستاویز اور گواہ (معاملہ کرنے والوں کا) کسی طرح نقصان نہ کریں۔ اگر تم (لوگ) ایسا کرو تو یہ تمہارے لئے گناہ کی بات ہے۔ اور خدا سے ڈرو اور (دیکھو کہ) وہ تم کو (کیسی مفید باتیں) سکھاتا ہے اور خدا ہر چیز سے واقف ہے\qt@no{282}}%
\qt@newcmd\qurantrans@ur@ccxc{اور اگر تم سفر پر ہواور (دستاویز) لکھنے والا مل نہ سکے تو (کوئی چیز) رہن یا قبضہ رکھ کر (قرض لے لو) اور اگر کوئی کسی کو امین سمجھے (یعنی رہن کے بغیر قرض دیدے) تو امانتدار کو چاہیئے کہ صاحب امانت کی امانت ادا کردے اور خدا سے جو اس کا پروردگار ہے ڈرے۔اور (دیکھنا) شہادت کو مت چھپانا۔ جو اس کو چھپائے گا وہ دل کا گنہگار ہوگا۔ اور خدا تمہارے سب کاموں سے واقف ہے\qt@no{283}}%
\qt@newcmd\qurantrans@ur@ccxci{جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے سب خدا ہی کا ہے۔ تم اپنے دلوں کی بات کو ظاہر کرو گے تو یا چھپاؤ گے تو خدا تم سے اس کا حساب لے گا پھر وہ جسے چاہے مغفرت کرے اور جسے چاہے عذاب دے۔ اور خدا ہر چیز پر قادر ہے\qt@no{284}}%
\qt@newcmd\qurantrans@ur@ccxcii{رسول (خدا) اس کتاب پر جو ان کے پروردگار کی طرف سے ان پر نازل ہوئی ایمان رکھتے ہیں اور مومن بھی۔ سب خدا پر اور اس کے فرشتوں پر اور اس کی کتابوں پر اور اس کے پیغمبروں پر ایمان رکھتے ہیں (اورکہتے ہیں کہ) ہم اس کے پیغمبروں سے کسی میں کچھ فرق نہیں کرتے اور وہ (خدا سے) عرض کرتے ہیں کہ ہم نے (تیرا حکم) سنا اور قبول کیا۔ اے پروردگار ہم تیری بخشش مانگتے ہیں اور تیری ہی طرف لوٹ کر جانا ہے\qt@no{285}}%
\qt@newcmd\qurantrans@ur@ccxciii{خدا کسی شخص کو اس کی طاقت سے زیادہ تکلیف نہیں دیتا۔ اچھے کام کرے گا تو اس کو ان کا فائدہ ملے گا برے کرے گا تو اسے ان کا نقصان پہنچے گا۔ اے پروردگار اگر ہم سے بھول یا چوک ہوگئی ہو تو ہم سے مؤاخذہ نہ کیجیو۔ اے پروردگار ہم پر ایسا بوجھ نہ ڈالیو جیسا تو نے ہم سے پہلے لوگوں پر ڈالا تھا۔ اے پروردگار جتنا بوجھ اٹھانے کی ہم میں طاقت نہیں اتنا ہمارے سر پر نہ رکھیو۔ اور (اے پروردگار) ہمارے گناہوں سے درگزر کر اور ہمیں بخش دے۔ اور ہم پر رحم فرما۔ تو ہی ہمارا مالک ہے اور ہم کو کافروں پر غالب فرما\qt@no{286}}%
\qt@newcmd\qurantrans@ur@ccxciv{\basmalahur الم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@ccxcv{خدا (جو معبود برحق ہے) اس کے سوا کوئی عبادت کے لائق نہیں ہمیشہ زندہ رہنے والا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@ccxcvi{اس نے (اے محمدﷺ) تم پر سچی کتاب نازل کی جو پہلی (آسمانی) کتابوں کی تصدیق کرتی ہے اور اسی نے تورات اور انجیل نازل کی\qt@no{3}}%
\qt@newcmd\qurantrans@ur@ccxcvii{یعنی) لوگوں کی ہدایت کے لیے پہلے (تورات اور انجیل اتاری) اور (پھر قرآن جو حق اور باطل کو) الگ الگ کر دینے والا (ہے) نازل کیا جو لوگ خدا کی آیتوں کا انکار کرتے ہیں ان کو سخت عذاب ہوگا اور خدا زبردست (اور) بدلہ لینے والا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@ccxcviii{خدا (ایسا خبیر وبصیر ہے کہ) کوئی چیز اس سے پوشیدہ نہیں نہ زمین میں اور نہ آسمان میں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@ccxcix{وہی تو ہے جو (ماں کے پیٹ میں) جیسی چاہتا ہے تمہاری صورتیں بناتا ہے اس غالب حکمت والے کے سوا کوئی عبادت کے لائق نہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@ccc{وہی تو ہے جس نے تم پر کتاب نازل کی جس کی بعض آیتیں محکم ہیں (اور) وہی اصل کتاب ہیں اور بعض متشابہ ہیں تو جن لوگوں کے دلوں میں کجی ہے وہ متشابہات کا اتباع کرتے ہیں تاکہ فتنہ برپا کریں اور مراد اصلی کا پتہ لگائیں حالانکہ مراد اصلی خدا کے سوا کوئی نہیں جانتا اور جو لوگ علم میں دست گاہ کامل رکھتے ہیں وہ یہ کہتے ہیں کہ ہم ان پر ایمان لائے یہ سب ہمارے پروردگار کی طرف سے ہیں اور نصیحت تو عقل مند ہی قبول کرتے ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@ccci{اے پروردگار جب تو نے ہمیں ہدایت بخشی ہے تو اس کے بعد ہمارے دلوں میں کجی نہ پیدا کر دیجیو اور ہمیں اپنے ہاں سے نعمت عطا فرما تو تو بڑا عطا فرمانے والا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@cccii{اے پروردگار! تو اس روز جس (کے آنے) میں کچھ بھی شک نہیں سب لوگوں کو (اپنے حضور میں) جمع کرلے گا بے شک خدا خلاف وعدہ نہیں کرتا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@ccciii{جو لوگ کافر ہوئے (اس دن) نہ تو ان کا مال ہی خدا (کے عذاب) سے ان کو بچا سکے گا اور نہ ان کی اولاد ہی (کچھ کام آئے گی) اور یہ لوگ آتش (جہنم) کا ایندھن ہوں گے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@ccciv{ان کا حال بھی فرعونیوں اور ان سے پہلے لوگوں کا سا ہوگا جنہوں نے ہماری آیتوں کی تکذیب کی تھی تو خدا نے ان کو ان کے گناہوں کے سبب (عذاب میں) پکڑ لیا تھا اور خدا سخت عذاب کرنے والا ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@cccv{اے پیغمبر) کافروں سے کہدو کہ تم (دنیا میں بھی) عنقریب مغلوب ہو جاؤ گے اور (آخرت میں) جہنم کی طرف ہانکے جاؤ گے اور وہ بری جگہ ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@cccvi{تمہارے لیے دو گروہوں میں جو (جنگ بدر کے دن) آپس میں بھڑ گئے (قدرت خدا کی عظیم الشان) نشانی تھی ایک گروہ (مسلمانوں کا تھا وہ) خدا کی راہ میں لڑ رہا تھا اور دوسرا گروہ (کافروں کا تھا وہ) ان کو اپنی آنکھوں سے اپنے سے دگنا مشاہدہ کر رہا تھا اور خدا اپنی نصرت سے جس کو چاہتا ہے مدد دیتا ہے جو اہل بصارت ہیں ان کے لیے اس (واقعے) میں بڑی عبرت ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@cccvii{لوگوں کو ان کی خواہشوں کی چیزیں یعنی عورتیں اور بیٹے اور سونے اور چاندی کے بڑے بڑے ڈھیر اور نشان لگے ہوئے گھوڑے اور مویشی اور کھیتی بڑی زینت دار معلوم ہوتی ہیں (مگر) یہ سب دنیا ہی کی زندگی کے سامان ہیں اور خدا کے پاس بہت اچھا ٹھکانا ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@cccviii{اے پیغمبر ان سے) کہو کہ بھلا میں تم کو ایسی چیز بتاؤں جو ان چیزوں سے کہیں اچھی ہو (سنو) جو لوگ پرہیزگار ہیں ان کے لیے خدا کے ہاں باغات (بہشت) ہیں جن کے نیچے نہریں بہہ رہی ہیں ان میں وہ ہمیشہ رہیں گے اور پاکیزہ عورتیں ہیں اور (سب سے بڑھ کر) خدا کی خوشنودی اور خدا (اپنے نیک) بندوں کو دیکھ رہا ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@cccix{جو خدا سے التجا کرتے ہیں کہ اے پروردگار ہم ایمان لے آئے سو ہم کو ہمارے گناہ معاف فرما اور دوزخ کے عذاب سے محفوظ رکھ\qt@no{16}}%
\qt@newcmd\qurantrans@ur@cccx{یہ وہ لوگ ہیں جو (مشکلات میں) صبر کرتے اور سچ بولتے اور عبادت میں لگے رہتے اور (راہ خدا میں) خرچ کرتے اور اوقات سحر میں گناہوں کی معافی مانگا کرتے ہیں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@cccxi{خدا تو اس بات کی گواہی دیتا ہے کہ اس کے سوا کوئی معبود نہیں اور فرشتے اور علم والے لوگ جو انصاف پر قائم ہیں وہ بھی (گواہی دیتے ہیں کہ) اس غالب حکمت والے کے سوا کوئی عبادت کے لائق نہیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@cccxii{دین تو خدا کے نزدیک اسلام ہے اور اہل کتاب نے جو (اس دین سے) اختلاف کیا تو علم ہونے کے بعد آپس کی ضد سے کیا اور جو شخص خدا کی آیتوں کو نہ مانے تو خدا جلد حساب لینے والا (اور سزا دینے والا) ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@cccxiii{اے پیغمبر اگر یہ لوگ تم سے جھگڑنے لگیں تو کہنا کہ میں اور میرے پیرو تو خدا کے فرمانبردار ہو چکے اور اہل کتاب اور ان پڑھ لوگوں سے کہو کہ کیا تم بھی (خدا کے فرمانبردار بنتے ہو) اور اسلام لاتے ہو؟ اگر یہ لوگ اسلام لے آئیں تو بے شک ہدایت پالیں اور اگر (تمہارا کہا) نہ مانیں تو تمہارا کام صرف خدا کا پیغام پہنچا دینا ہے اور خدا (اپنے) بندوں کو دیکھ رہا ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@cccxiv{جو لوگ خدا کی آیتوں کو نہیں مانتے اور انبیاء کو ناحق قتل کرتے رہے ہیں اور جو انصاف (کرنے) کا حکم دیتے ہیں انہیں بھی مار ڈالتے ہیں ان کو دکھ دینے والے عذاب کی خوشخبری سنا دو\qt@no{21}}%
\qt@newcmd\qurantrans@ur@cccxv{یہ ایسے لوگ ہیں جن کے اعمال دنیا اور آخرت دونوں میں برباد ہیں اور ان کا کوئی مددگار نہیں (ہوگا)\qt@no{22}}%
\qt@newcmd\qurantrans@ur@cccxvi{بھلا تم نے ان لوگوں کو نہیں دیکھا جن کو کتاب (خدا یعنی تورات سے) بہرہ دیا گیا اور وہ (اس) کتاب الله کی طرف بلائے جاتے ہیں تاکہ وہ (ان کے تنازعات کا) ان میں فیصلہ کر دے تو ایک فریق ان میں سے کج ادائی کے ساتھ منہ پھیر لیتا ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@cccxvii{یہ اس لیے کہ یہ اس بات کے قائل ہیں کہ (دوزخ کی) آگ ہمیں چند روز کے سوا چھو ہی نہیں سکے گی اور جو کچھ یہ دین کے بارے میں بہتان باندھتے رہے ہیں اس نے ان کو دھوکے میں ڈال رکھا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@cccxviii{تو اس وقت کیا حال ہوگا جب ہم ان کو جمع کریں گے (یعنی) اس روز جس (کے آنے) میں کچھ بھی شک نہیں اور ہر نفس اپنے اعمال کا پورا پورا بدلہ پائے گا اور ان پر ظلم نہیں کیا جائے گا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@cccxix{کہو کہ اے خدا (اے) بادشاہی کے مالک تو جس کو چاہے بادشاہی بخشے اور جس سے چاہے بادشاہی چھین لے اور جس کو چاہے عزت دے اور جسے چاہے ذلیل کرے ہر طرح کی بھلائی تیرے ہی ہاتھ ہے اور بے شک تو ہر چیز پر قادر ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@cccxx{تو ہی رات کو دن میں داخل کرتا اور تو ہی دن کو رات میں داخل کرتا ہے تو ہی بے جان سے جاندار پیدا کرتا ہے اور تو ہی جاندار سے بے جان پیدا کرتا ہے اور توہی جس کو چاہتا ہے بے شمار رزق بخشتا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@cccxxi{مؤمنوں کو چاہئے کہ مؤمنوں کے سوا کافروں کو دوست نہ بنائیں اور جو ایسا کرے گا اس سے خدا کا کچھ (عہد) نہیں ہاں اگر اس طریق سے تم ان (کے شر) سے بچاؤ کی صورت پیدا کرو (تو مضائقہ نہیں) اور خدا تم کو اپنے (غضب) سے ڈراتا ہے اور خدا ہی کی طرف (تم کو) لوٹ کر جانا ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@cccxxii{اے پیغمبر لوگوں سے) کہہ دو کہ کوئی بات تم اپنے دلوں میں مخفی رکھو یا اسے ظاہر کرو خدا اس کو جانتا ہے اور جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے اس کو سب کی خبر ہے اور وہ ہر چیز پر قادر ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@cccxxiii{جس دن ہر شخص اپنے اعمال کی نیکی کو موجود پالے گا اور ان کی برائی کو بھی (دیکھ لے گا) تو آرزو کرے گا کہ اے کاش اس میں اور اس برائی میں دور کی مسافت ہو جاتی اور خدا تم کو اپنے (غضب) سے ڈراتا ہے اور خدا اپنے بندوں پر نہایت مہربان ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@cccxxiv{اے پیغمبر لوگوں سے) کہہ دو کہ اگر تم خدا کو دوست رکھتے ہو تو میری پیروی کرو خدا بھی تمہیں دوست رکھے گا اور تمہارے گناہ معاف کر دے گا اور خدا بخشنے والا مہربان ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@cccxxv{کہہ دو کہ خدا اور اس کے رسول کا حکم مانو اگر نہ مانیں تو خدا بھی کافروں کو دوست نہیں رکھتا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@cccxxvi{خدا نے آدم اور نوح اور خاندان ابراہیم اور خاندان عمران کو تمام جہان کے لوگوں میں منتخب فرمایا تھا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@cccxxvii{ان میں سے بعض بعض کی اولاد تھے اور خدا سننے والا (اور) جاننے والا ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@cccxxviii{وہ وقت یاد کرنے کے لائق ہے) جب عمران کی بیوی نے کہا کہ اے پروردگار جو (بچہ) میرے پیٹ میں ہے میں اس کو تیری نذر کرتی ہوں اسے دنیا کے کاموں سے آزاد رکھوں گی تو (اسے) میری طرف سے قبول فرما توتو سننے والا (اور) جاننے والا ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@cccxxix{جب ان کے ہاں بچہ پیدا ہوا اور جو کچھ ان کے ہاں پیدا ہوا تھا خدا کو خوب معلوم تھا تو کہنے لگیں کہ پروردگار! میرے تو لڑکی ہوئی ہے اور (نذر کے لیے) لڑکا (موزوں تھا کہ وہ) لڑکی کی طرح (ناتواں) نہیں ہوتا اور میں نے اس کا نام مریم رکھا ہے اور میں اس کو اور اس کی اولاد کو شیطان مردود سے تیری پناہ میں دیتی ہوں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@cccxxx{تو پروردگار نے اس کو پسندیدگی کے ساتھ قبول فرمایا اور اسے اچھی طرح پرورش کیا اور زکریا کو اس کا متکفل بنایا زکریا جب کبھی عبادت گاہ میں اس کے پاس جاتے تو اس کے پاس کھانا پاتے (یہ کیفیت دیکھ کر ایک دن مریم سے) پوچھنے لگے کہ مریم یہ کھانا تمہارے پاس کہاں سے آتا ہے وہ بولیں خدا کے ہاں سے (آتا ہے) بیشک خدا جسے چاہتا ہے بے شمار رزق دیتا ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@cccxxxi{اس وقت زکریا نے اپنے پروردگار سے دعا کی (اور) کہا کہ پروردگار مجھے اپنی جناب سے اولاد صالح عطا فرما تو بے شک دعا سننے (اور قبول کرنے) والا ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@cccxxxii{وہ ابھی عبادت گاہ میں کھڑے نماز ہی پڑھ رہے تھے کہ فرشتوں نے آواز دی کہ (زکریا) خدا تمہیں یحییٰ کی بشارت دیتا ہے جو خدا کے فیض یعنی (عیسیٰ) کی تصدیق کریں گے اور سردار ہوں گے اور عورتوں سے رغبت نہ رکھنے والے اور (خدا کے) پیغمبر (یعنی) نیکو کاروں میں ہوں گے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@cccxxxiii{زکریا نے کہا اے پروردگار میرے ہاں لڑکا کیونکر پیدا ہوگا کہ میں تو بڈھا ہوگیا ہوں اور میری بیوی بانجھ ہے خدا نے فرمایا اسی طرح خدا جو چاہتا ہے کرتا ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@cccxxxiv{زکریا نے کہا کہ پروردگار (میرے لیے) کوئی نشانی مقرر فرما خدا نے فرمایا نشانی یہ ہے کہ تم لوگوں سے تین دن اشارے کے سوا بات نہ کر سکو گے تو (ان دنوں میں) اپنے پروردگار کی کثرت سے یاد اور صبح و شام اس کی تسبیح کرنا\qt@no{41}}%
\qt@newcmd\qurantrans@ur@cccxxxv{اور جب فرشتوں نے (مریم سے) کہا کہ مریم! خدا نے تم کو برگزیدہ کیا ہے اور پاک بنایا ہے اور جہان کی عورتوں میں منتخب کیا ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@cccxxxvi{مریم اپنے پروردگار کی فرمانبرداری کرنا اور سجدہ کرنا اور رکوع کرنے والوں کے ساتھ رکوع کرنا\qt@no{43}}%
\qt@newcmd\qurantrans@ur@cccxxxvii{اے محمدﷺ) یہ باتیں اخبار غیب میں سے ہیں جو ہم تمہارے پاس بھیجتے ہیں اور جب وہ لوگ اپنے قلم (بطور قرعہ) ڈال رہے تھے کہ مریم کا متکفل کون بنے تو تم ان کے پاس نہیں تھے اور نہ اس وقت ہی ان کے پاس تھے جب وہ آپس میں جھگڑ رہے تھے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@cccxxxviii{وہ وقت بھی یاد کرنے کے لائق ہے) جب فرشتوں نے (مریم سے کہا) کہ مریم خدا تم کو اپنی طرف سے ایک فیض کی بشارت دیتا ہے جس کا نام مسیح (اور مشہور) عیسیٰ ابن مریم ہوگا (اور) جو دنیا اور آخرت میں باآبرو اور (خدا کے) خاصوں میں سے ہوگا\qt@no{45}}%
\qt@newcmd\qurantrans@ur@cccxxxix{اور ماں کی گود میں اور بڑی عمر کا ہو کر (دونوں حالتوں میں) لوگوں سے (یکساں) گفتگو کرے گا اور نیکو کاروں میں ہوگا\qt@no{46}}%
\qt@newcmd\qurantrans@ur@cccxl{مریم نے کہا پروردگار میرے ہاں بچہ کیونکر ہوگا کہ کسی انسان نے مجھے ہاتھ تک تو لگایا نہیں فرمایا کہ خدا اسی طرح جو چاہتا ہے پیدا کرتا ہے جب وہ کوئی کام کرنا چاہتا ہے تو ارشاد فرما دیتا ہے کہ ہوجا تو وہ ہو جاتا ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@cccxli{اور وہ انہیں لکھنا (پڑھنا) اور دانائی اور تورات اور انجیل سکھائے گا\qt@no{48}}%
\qt@newcmd\qurantrans@ur@cccxlii{اور (عیسیٰ) بنی اسرائیل کی طرف پیغمبر (ہو کر جائیں گے اور کہیں گے) کہ میں تمہارے پروردگار کی طرف سے نشانی لے کر آیا ہوں وہ یہ کہ تمہارے سامنے مٹی کی مورت بشکل پرند بناتا ہوں پھر اس میں پھونک مارتا ہوں تو وہ خدا کے حکم سے (سچ مچ) جانور ہو جاتا ہے اور اندھے اور ابرص کو تندرست کر دیتا ہوں اور خدا کے حکم سے مردے میں جان ڈال دیتا ہوں اور جو کچھ تم کھا کر آتے ہو اور جو اپنے گھروں میں جمع کر رکھتے ہو سب تم کو بتا دیتا ہوں اگر تم صاحب ایمان ہو تو ان باتوں میں تمہارے لیے (قدرت خدا کی) نشانی ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@cccxliii{اور مجھ سے پہلے جو تورات (نازل ہوئی) تھی اس کی تصدیق بھی کرتا ہوں اور (میں) اس لیے بھی (آیا ہوں) کہ بعض چیزیں جو تم پر حرام تھیں ان کو تمہارے لیے حلال کر دوں اور میں تو تمہارے پروردگار کی طرف سے نشانی لے کر آیا ہوں تو خدا سے ڈرو اور میرا کہا مانو\qt@no{50}}%
\qt@newcmd\qurantrans@ur@cccxliv{کچھ شک نہیں کہ خدا ہی میرا اور تمہارا پروردگار ہے تو اسی کی عبادت کرو یہی سیدھا رستہ ہے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@cccxlv{جب عیسیٰؑ نے ان کی طرف سے نافرمانی اور (نیت قتل) دیکھی تو کہنے لگے کہ کوئی ہے جو خدا کا طرف دار اور میرا مددگار ہو حواری بولے کہ ہم خدا کے (طرفدار اور آپ کے) مددگار ہیں ہم خدا پر ایمان لائے اور آپ گواہ رہیں کہ ہم فرمانبردار ہیں\qt@no{52}}%
\qt@newcmd\qurantrans@ur@cccxlvi{اے پروردگار جو (کتاب) تو نے نازل فرمائی ہے ہم اس پر ایمان لے آئے اور (تیرے) پیغمبر کے متبع ہو چکے تو ہم کو ماننے والوں میں لکھ رکھ\qt@no{53}}%
\qt@newcmd\qurantrans@ur@cccxlvii{اور وہ (یعنی یہود قتل عیسیٰ کے بارے میں ایک) چال چلے اور خدا بھی (عیسیٰ کو بچانے کے لیے) چال چلا اور خدا خوب چال چلنے والا ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@cccxlviii{اس وقت خدا نے فرمایا کہ عیسیٰ! میں تمہاری دنیا میں رہنے کی مدت پوری کرکے تم کو اپنی طرف اٹھا لوں گا اور تمہیں کافروں (کی صحبت) سے پاک کر دوں گا اور جو لوگ تمہاری پیروی کریں گے ان کو کافروں پر قیامت تک فائق (وغالب) رکھوں گا پھر تم سب میرے پاس لوٹ کر آؤ گے تو جن باتوں میں تم اختلاف کرتے تھے اس دن تم میں ان کا فیصلہ کردوں گا\qt@no{55}}%
\qt@newcmd\qurantrans@ur@cccxlix{یعنی جو کافر ہوئے ان کو دنیا اور آخرت (دونوں) میں سخت عذاب دوں گا اور ان کا کوئی مددگار نہ ہوگا\qt@no{56}}%
\qt@newcmd\qurantrans@ur@cccl{اور جو ایمان لائے اور نیک عمل کرتے رہے ان کو خدا پورا پورا صلہ دے گا اور خدا ظالموں کو دوست نہیں رکھتا\qt@no{57}}%
\qt@newcmd\qurantrans@ur@cccli{اے محمدﷺ) یہ ہم تم کو (خدا کی) آیتیں اور حکمت بھری نصیحتیں پڑھ پڑھ کر سناتے ہیں\qt@no{58}}%
\qt@newcmd\qurantrans@ur@ccclii{عیسیٰ کا حال خدا کے نزدیک آدم کا سا ہے کہ اس نے (پہلے) مٹی سے ان کا قالب بنایا پھر فرمایا کہ (انسان) ہو جا تو وہ (انسان) ہو گئے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@cccliii{یہ بات) تمہارے پروردگار کی طرف سے حق ہے تو تم ہرگز شک کرنے والوں میں نہ ہونا\qt@no{60}}%
\qt@newcmd\qurantrans@ur@cccliv{پھر اگر یہ لوگ عیسیٰ کے بارے میں تم سے جھگڑا کریں اور تم کو حقیقت الحال تو معلوم ہو ہی چلی ہے تو ان سے کہنا کہ آؤ ہم اپنے بیٹوں اور عورتوں کو بلائیں تم اپنے بیٹوں اور عورتوں کو بلاؤ اور ہم خود بھی آئیں اور تم خود بھی آؤ پھر دونوں فریق (خدا سے) دعا والتجا کریں اور جھوٹوں پر خدا کی لعنت بھیجیں\qt@no{61}}%
\qt@newcmd\qurantrans@ur@ccclv{یہ تمام بیانات صحیح ہیں اور خدا کے سوا کوئی معبود نہیں اور بیشک خدا غالب اور صاحبِ حکمت ہے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@ccclvi{تو اگر یہ لوگ پھر جائیں تو خدا مفسدوں کو خوب جانتا ہے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@ccclvii{کہہ دو کہ اے اہل کتاب جو بات ہمارے اور تمہارے دونوں کے درمیان یکساں (تسلیم کی گئی) ہے اس کی طرف آؤ وہ یہ کہ خدا کے سوا ہم کسی کی عبادت نہ کریں اور اس کے ساتھ کسی چیز کو شریک نہ بنائیں اور ہم میں سے کوئی کسی کو خدا کے سوا اپنا کار ساز نہ سمجھے اگر یہ لوگ (اس بات کو) نہ مانیں تو (ان سے) کہہ دو کہ تم گواہ رہو کہ ہم (خدا کے) فرماں بردار ہیں\qt@no{64}}%
\qt@newcmd\qurantrans@ur@ccclviii{اے اہلِ کتاب تم ابراہیم کے بارے میں کیوں جھگڑتے ہو حالانکہ تورات اور انجیل ان کے بعد اتری ہیں (اور وہ پہلے ہو چکے ہیں) تو کیا تم عقل نہیں رکھتے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@ccclix{دیکھو ایسی بات میں تو تم نے جھگڑا کیا ہی تھا جس کا تمہیں کچھ علم تھا بھی مگر ایسی بات میں کیوں جھگڑتے ہو جس کا تمہیں کچھ بھی علم نہیں اور خدا جانتا ہے اور تم نہیں جانتے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@ccclx{ابراہیم نہ تو یہودی تھے اور نہ عیسائی بلکہ سب سے بے تعلق ہو کر ایک (خدا) کے ہو رہے تھے اور اسی کے فرماں بردار تھے اور مشرکوں میں نہ تھے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@ccclxi{ابراہیم سے قرب رکھنے والے تو وہ لوگ ہیں جو ان کی پیروی کرتے ہیں اور پیغمبر (آخرالزمان) اور وہ لوگ جو ایمان لائے ہیں اور خدا مومنوں کا کارساز ہے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@ccclxii{اے اہل اسلام) بعضے اہلِ کتاب اس بات کی خواہش رکھتے ہیں کہ تم کو گمراہ کر دیں مگر یہ (تم کو کیا گمراہ کریں گے) اپنے آپ کو ہی گمراہ کر رہے ہیں اور نہیں جانتے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@ccclxiii{اے اہلِ کتاب تم خدا کی آیتوں سے کیوں انکار کرتے ہو اور تم (تورات کو) مانتے تو ہو\qt@no{70}}%
\qt@newcmd\qurantrans@ur@ccclxiv{اے اہلِ کتاب تم سچ کو جھوٹ کے ساتھ خلط ملط کیوں کرتے ہو اور حق کو کیوں چھپاتے ہو اور تم جانتے بھی ہو\qt@no{71}}%
\qt@newcmd\qurantrans@ur@ccclxv{اور اہلِ کتاب ایک دوسرے سے کہتے ہیں کہ جو (کتاب) مومنوں پر نازل ہوئی ہے اس پر دن کے شروع میں تو ایمان لے آیا کرو اور اس کے آخر میں انکار کر دیا کرو تاکہ وہ (اسلام سے) برگشتہ ہو جائیں\qt@no{72}}%
\qt@newcmd\qurantrans@ur@ccclxvi{اور اپنے دین کے پیرو کے سوا کسی اور کے قائل نہ ہونا (اے پیغمبر) کہہ دو کہ ہدایت تو خدا ہی کی ہدایت ہے (وہ یہ بھی کہتے ہیں) یہ بھی (نہ ماننا) کہ جو چیز تم کو ملی ہے ویسی کسی اور کو ملے گی یا وہ تمہیں خدا کے روبرو قائل معقول کر سکیں گے یہ بھی کہہ دو کہ بزرگی خدا ہی کے ہاتھ میں ہے وہ جسے چاہتا ہے دیتا ہے اور خدا کشائش والا (اور) علم والا ہے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@ccclxvii{وہ اپنی رحمت سے جس کو چاہتا ہے خاص کر لیتا ہے اور خدا بڑے فضل کا مالک ہے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@ccclxviii{اور اہلِ کتاب میں سے کوئی تو ایسا ہے کہ اگر تم اس کے پاس (روپوں کا) ڈھیر امانت رکھ دو تو تم کو (فوراً) واپس دے دے اور کوئی اس طرح کا ہے کہ اگر اس کے پاس ایک دینار بھی امانت رکھو تو جب تک اس کے سر پر ہر وقت کھڑے نہ رہو تمہیں دے ہی نہیں یہ اس لیے کہ وہ کہتے ہیں کہ امیوں کے بارے میں ہم سے مواخذہ نہیں ہوگا یہ خدا پر محض جھوٹ بولتے ہیں اور (اس بات کو) جانتے بھی ہیں\qt@no{75}}%
\qt@newcmd\qurantrans@ur@ccclxix{ہاں جو شخص اپنے اقرار کو پورا کرے اور (خدا سے) ڈرے تو خدا ڈرنے والوں کو دوست رکھتا ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@ccclxx{جو لوگ خدا کے اقراروں اور اپنی قسموں (کو بیچ ڈالتے ہیں اور ان) کے عوض تھوڑی سی قیمت حاصل کرتے ہیں ان کا آخرت میں کچھ حصہ نہیں ان سے خدا نہ تو کلام کرے گا اور نہ قیامت کے روز ان کی طرف دیکھے گا اور نہ ان کو پاک کرے گا اور ان کو دکھ دینے والا عذاب ہوگا\qt@no{77}}%
\qt@newcmd\qurantrans@ur@ccclxxi{اور ان (اہلِ کتاب) میں بعضے ایسے ہیں کہ کتاب (تورات) کو زبان مروڑ مروڑ کر پڑھتے ہیں تاکہ تم سمجھو کہ جو کچھ وہ پڑھتے ہیں کتاب میں سے ہے حالانکہ وہ کتاب میں سے نہیں ہے اور کہتے ہیں کہ وہ خدا کی طرف سے (نازل ہوا) ہے حالانکہ وہ خدا کی طرف سے نہیں ہوتا اور خدا پر جھوٹ بولتے ہیں اور (یہ بات) جانتے بھی ہیں\qt@no{78}}%
\qt@newcmd\qurantrans@ur@ccclxxii{کسی آدمی کو شایاں نہیں کہ خدا تو اسے کتاب اور حکومت اور نبوت عطا فرمائے اور وہ لوگوں سے کہے کہ خدا کو چھوڑ کر میرے بندے ہو جاؤ بلکہ (اس کو یہ کہنا سزاوار ہے کہ اے اہلِ کتاب) تم (علمائے) ربانی ہو جاؤ کیونکہ تم کتابِ (خدا) پڑھتے پڑھاتے رہتے ہو\qt@no{79}}%
\qt@newcmd\qurantrans@ur@ccclxxiii{اور اس کو یہ بھی نہیں کہنا چاہیے کہ تم فرشتوں اور پیغمبروں کو خدا بنالو بھلا جب تم مسلمان ہو چکے تو کیا اسے زیبا ہے کہ تمہیں کافر ہونے کو کہے\qt@no{80}}%
\qt@newcmd\qurantrans@ur@ccclxxiv{اور جب خدا نے پیغمبروں سے عہد لیا کہ جب میں تم کو کتاب اور دانائی عطا کروں پھر تمہارے پاس کوئی پیغمبر آئے جو تمہاری کتاب کی تصدیق کرے تو تمھیں ضرور اس پر ایمان لانا ہوگا اور ضرور اس کی مدد کرنی ہوگی اور (عہد لینے کے بعد) پوچھا کہ بھلا تم نے اقرار کیا اور اس اقرار پر میرا ذمہ لیا (یعنی مجھے ضامن ٹہرایا) انہوں نے کہا (ہاں) ہم نے اقرار کیا (خدا نے) فرمایا کہ تم (اس عہد وپیمان کے) گواہ رہو اور میں بھی تمہارے ساتھ گواہ ہوں\qt@no{81}}%
\qt@newcmd\qurantrans@ur@ccclxxv{تو جو اس کے بعد پھر جائیں وہ بد کردار ہیں\qt@no{82}}%
\qt@newcmd\qurantrans@ur@ccclxxvi{کیا یہ (کافر) خدا کے دین کے سوا کسی اور دین کے طالب ہیں حالانکہ سب اہلِ آسمان و زمین خوشی یا زبردستی سے خدا کے فرماں بردار ہیں اور اسی کی طرف لوٹ کر جانے والے ہیں\qt@no{83}}%
\qt@newcmd\qurantrans@ur@ccclxxvii{کہو کہ ہم خدا پر ایمان لائے اور جو کتاب ہم پر نازل ہوئی اور جو صحیفے ابراہیم اور اسماعیل اور اسحٰق اور یعقوب اور ان کی اولاد پر اترے اور جو کتابیں موسیٰ اور عیسیٰ اور دوسرے انبیاء کو پروردگار کی طرف سے ملیں سب پر ایمان لائے ہم ان پیغمبروں میں سے کسی میں کچھ فرق نہیں کرتے اور ہم اسی (خدائے واحد) کے فرماں بردار ہیں\qt@no{84}}%
\qt@newcmd\qurantrans@ur@ccclxxviii{اور جو شخص اسلام کے سوا کسی اور دین کا طالب ہوگا وہ اس سے ہرگز قبول نہیں کیا جائے گا اور ایسا شخص آخرت میں نقصان اٹھانے والوں میں ہوگا\qt@no{85}}%
\qt@newcmd\qurantrans@ur@ccclxxix{خدا ایسے لوگوں کو کیونکر ہدایت دے جو ایمان لانے کے بعد کافر ہوگئے اور (پہلے) اس بات کی گواہی دے چکے کہ یہ پیغمبر برحق ہے اور ان کے پاس دلائل بھی آگئے اور خدا بے انصافوں کو ہدایت نہیں دیتا\qt@no{86}}%
\qt@newcmd\qurantrans@ur@ccclxxx{ان لوگوں کی سزا یہ ہے کہ ان پر خدا کی اور فرشتوں کی اور انسانوں کی سب کی لعنت ہو\qt@no{87}}%
\qt@newcmd\qurantrans@ur@ccclxxxi{ہمیشہ اس لعنت میں (گرفتار) رہیں گے ان سے نہ تو عذاب ہلکا کیا جائے گا اور نہ انہیں مہلت دے جائے گی\qt@no{88}}%
\qt@newcmd\qurantrans@ur@ccclxxxii{ہاں جنہوں نے اس کے بعد توبہ کی اور اپنی حالت درست کر لی تو خدا بخشنے والا مہربان ہے\qt@no{89}}%
\qt@newcmd\qurantrans@ur@ccclxxxiii{جو لوگ ایمان لانے کے بعد کافر ہو گئے پھر کفر میں بڑھتے گئے ایسوں کی توبہ ہرگز قبول نہ ہوگی اور یہ لوگ گمراہ ہیں\qt@no{90}}%
\qt@newcmd\qurantrans@ur@ccclxxxiv{جو لوگ کافر ہوئے اور کفر ہی کی حالت میں مر گئے وہ اگر (نجات حاصل کرنی چاہیں اور) بدلے میں زمین بھر کر سونا دیں تو ہرگز قبول نہ کیا جائے گا ان لوگوں کو دکھ دینے والا عذاب ہو گا اور ان کی کوئی مدد نہیں کرے گا\qt@no{91}}%
\qt@newcmd\qurantrans@ur@ccclxxxv{مومنو!) جب تک تم ان چیزوں میں سے جو تمھیں عزیز ہیں (راہِ خدا میں) صرف نہ کرو گے کبھی نیکی حاصل نہ کر سکو گے اور جو چیز تم صرف کرو گے خدا اس کو جانتا ہے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@ccclxxxvi{بنی اسرائیل کے لیے (تورات کے نازل ہونے سے) پہلے کھانے کی تمام چیزیں حلال تھیں بجز ان کے جو یعقوب نے خود اپنے اوپر حرام کر لی تھیں کہہ دو کہ اگر سچے ہو تو تورات لاؤ اور اسے پڑھو (یعنی دلیل پیش کرو)\qt@no{93}}%
\qt@newcmd\qurantrans@ur@ccclxxxvii{جو اس کے بعد بھی خدا پر جھوٹے افترا کریں تو ایسے لوگ ہی بےانصاف ہیں\qt@no{94}}%
\qt@newcmd\qurantrans@ur@ccclxxxviii{کہہ دو کہ خدا نے سچ فرمایا دیا پس دین ابراہیم کی پیروی کرو جو سب سے بےتعلق ہو کر ایک (خدا) کے ہو رہے تھے اور مشرکوں سے نہ تھے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@ccclxxxix{پہلا گھر جو لوگوں (کے عبادت کرنے) کے لیے مقرر کیا گیا تھا وہی ہے جو مکے میں ہے بابرکت اور جہاں کے لیے موجبِ ہدایت\qt@no{96}}%
\qt@newcmd\qurantrans@ur@cccxc{اس میں کھلی ہوئی نشانیاں ہیں جن میں سے ایک ابراہیم کے کھڑے ہونے کی جگہ ہے جو شخص اس (مبارک) گھر میں داخل ہوا اس نے امن پا لیا اور لوگوں پر خدا کا حق (یعنی فرض) ہے کہ جو اس گھر تک جانے کا مقدور رکھے وہ اس کا حج کرے اور جو اس حکم کی تعمیل نہ کرے گا تو خدا بھی اہلِ عالم سے بے نیاز ہے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@cccxci{کہو کہ اہلِ کتاب! تم خدا کی آیتوں سے کیوں کفر کرتے ہو اور خدا تمہارے سب اعمال سے باخبر ہے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@cccxcii{کہو کہ اہلِ کتاب تم مومنوں کو خدا کے رستے سے کیوں روکتے ہو اور باوجود یہ کہ تم اس سے واقف ہو اس میں کجی نکالتے ہو اور خدا تمھارے کاموں سے بےخبر نہیں\qt@no{99}}%
\qt@newcmd\qurantrans@ur@cccxciii{مومنو! اگر تم اہلِ کتاب کے کسی فریق کا کہا مان لو گے تو وہ تمھیں ایمان لانے کے بعد کافر بنا دیں گے\qt@no{100}}%
\qt@newcmd\qurantrans@ur@cccxciv{اور تم کیونکر کفر کرو گے جبکہ تم کو خدا کی آیتیں پڑھ پڑھ کر سنائی جاتی ہیں اور تم میں اس کے پیغمبر موجود ہیں اور جس نے خدا (کی ہدایت کی رسی) کو مضبوط پکڑ لیا وہ سیدھے رستے لگ گیا\qt@no{101}}%
\qt@newcmd\qurantrans@ur@cccxcv{مومنو! خدا سے ڈرو جیسا کہ اس سے ڈرنے کا حق ہے اور مرنا تو مسلمان ہی مرنا\qt@no{102}}%
\qt@newcmd\qurantrans@ur@cccxcvi{اور سب مل کر خدا کی (ہدایت کی رسی) کو مضبوط پکڑے رہنا اور متفرق نہ ہونا اور خدا کی اس مہربانی کو یاد کرو جب تم ایک دوسرے کے دشمن تھے تو اس نے تمہارے دلوں میں الفت ڈال دی اور تم اس کی مہربانی سے بھائی بھائی ہوگئے اور تم آگ کے گڑھے کے کنارے تک پہنچ چکے تھے تو خدا نے تم کو اس سے بچا لیا اس طرح خدا تم کو اپنی آیتیں کھول کھول کر سناتا ہے تاکہ تم ہدایت پاؤ\qt@no{103}}%
\qt@newcmd\qurantrans@ur@cccxcvii{اور تم میں ایک جماعت ایسی ہونی چاہیئے جو لوگوں کو نیکی کی طرف بلائے اور اچھے کام کرنے کا حکم دے اور برے کاموں سے منع کرے یہی لوگ ہیں جو نجات پانے والے ہیں\qt@no{104}}%
\qt@newcmd\qurantrans@ur@cccxcviii{اور ان لوگوں کی طرح نہ ہونا جو متفرق ہو گئے اور احکام بین آنے کے بعد ایک دوسرےسے (خلاف و) اختلاف کرنے لگے یہ وہ لوگ ہیں جن کو قیامت کے دن بڑا عذاب ہوگا\qt@no{105}}%
\qt@newcmd\qurantrans@ur@cccxcix{جس دن بہت سے منہ سفید ہوں گے اور بہت سے منہ سیاہ تو جن لوگوں کے منہ سیاہ ہوں گے (ان سے خدا فرمائے گا) کیا تم ایمان لا کر کافر ہوگئے تھے؟ سو (اب) اس کفر کے بدلے عذاب (کے مزے) چکھو\qt@no{106}}%
\qt@newcmd\qurantrans@ur@cd{اور جن لوگوں کے منہ سفید ہوں گے وہ خدا کی رحمت (کے باغوں) میں ہوں گے اور ان میں ہمیشہ رہیں گے\qt@no{107}}%
\qt@newcmd\qurantrans@ur@cdi{یہ خدا کی آیتیں ہیں جو ہم تم کو صحت کے ساتھ پڑھ کر سناتے ہیں اور خدا اہلِ عالم پر ظلم نہیں کرنا چاہتا\qt@no{108}}%
\qt@newcmd\qurantrans@ur@cdii{اور جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے سب خدا ہی کا ہے اور سب کاموں کا رجوع (اور انجام) خدا ہی کی طرف ہے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@cdiii{مومنو) جتنی امتیں (یعنی قومیں) لوگوں میں پیدا ہوئیں تم ان سب سے بہتر ہو کہ نیک کام کرنے کو کہتے ہو اور برے کاموں سے منع کرتے ہو اور خدا پر ایمان رکھتے ہو اور اگر اہلِ کتاب بھی ایمان لے آتے تو ان کے لیے بہت اچھا ہوتا ان میں ایمان لانے والے بھی ہیں (لیکن تھوڑے) اور اکثر نافرمان ہیں\qt@no{110}}%
\qt@newcmd\qurantrans@ur@cdiv{اور یہ تمہیں خفیف سی تکلیف کے سوا کچھ نقصان نہیں پہنچا سکیں گے اور اگر تم سے لڑیں گے تو پیٹھ پھیر کر بھاگ جائیں گے پھر ان کو مدد بھی (کہیں سے) نہیں ملے گی\qt@no{111}}%
\qt@newcmd\qurantrans@ur@cdv{یہ جہاں نظر آئیں گے ذلت (کو دیکھو گے کہ) ان سے چمٹ رہی ہے بجز اس کے کہ یہ خدا اور (مسلمان) لوگوں کی پناہ میں آ جائیں اور یہ لوگ خدا کے غضب میں گرفتار ہیں اور ناداری ان سے لپٹ رہی ہے یہ اس لیے کہ خدا کی آیتوں سے انکار کرتےتھے اور (اس کے) پیغمبروں کو ناحق قتل کر دیتے تھے یہ اس لیے کہ یہ نافرمانی کیے جاتے اور حد سے بڑھے جاتے تھے\qt@no{112}}%
\qt@newcmd\qurantrans@ur@cdvi{یہ بھی سب ایک جیسے نہیں ہیں ان اہلِ کتاب میں کچھ لوگ (حکمِ خدا پر) قائم بھی ہیں جو رات کے وقت خدا کی آیتیں پڑھتے اور (اس کے آگے) سجدہ کرتے ہیں\qt@no{113}}%
\qt@newcmd\qurantrans@ur@cdvii{اور) خدا پر اور روز آخرت پر ایمان رکھتے اور اچھے کام کرنےکو کہتے اور بری باتوں سے منع کرتےاور نیکیوں پر لپکتے ہیں اور یہی لوگ نیکوکار ہیں\qt@no{114}}%
\qt@newcmd\qurantrans@ur@cdviii{اور یہ جس طرح کی نیکی کریں گے اس کی ناقدری نہیں کی جائے گی اور خدا پرہیزگاروں کو خوب جانتا ہے\qt@no{115}}%
\qt@newcmd\qurantrans@ur@cdix{جو لوگ کافر ہیں ان کے مال اور اولاد خدا کے غضب کو ہرگز نہیں ٹال سکیں گے اور یہ لوگ اہلِ دوزخ ہیں کہ ہمیشہ اسی میں رہیں گے\qt@no{116}}%
\qt@newcmd\qurantrans@ur@cdx{یہ جو مال دنیا کی زندگی میں خرچ کرتے ہیں اس کی مثال ہوا کی سی ہے جس میں سخت سردی ہو اور وہ ایسے لوگوں کی کھیتی پر جو اپنے آپ پر ظلم کرتے تھے چلے اور اسے تباہ کر دے اور خدا نے ان پر کچھ ظلم نہیں کیا بلکہ یہ خود اپنے اوپر ظلم کر رہے ہیں\qt@no{117}}%
\qt@newcmd\qurantrans@ur@cdxi{مومنو! کسی غیر (مذہب کے آدمی) کو اپنا رازداں نہ بنانا یہ لوگ تمہاری خرابی اور (فتنہ انگیزی کرنے) میں کسی طرح کی کوتاہی نہیں کرتے اور چاہتے ہیں کہ (جس طرح ہو) تمہیں تکلیف پہنچے ان کی زبانوں سے تو دشمنی ظاہر ہوہی چکی ہے اور جو (کینے) ان کے سینوں میں مخفی ہیں وہ کہیں زیادہ ہیں اگر تم عقل رکھتے ہو تو ہم نے تم کو اپنی آیتیں کھول کھول کر سنا دی ہیں\qt@no{118}}%
\qt@newcmd\qurantrans@ur@cdxii{دیکھو تم ایسے (صاف دل) لوگ ہو کہ ان لوگوں سے دوستی رکھتے ہو حالانکہ وہ تم سے دوستی نہیں رکھتے اور تم سب کتابوں پر ایمان رکھتے ہو (اور وہ تمہاری کتاب کو نہیں مانتے) اور جب تم سے ملتے ہیں تو کہتے ہیں ہم ایمان لے آئے اور جب الگ ہوتے ہیں تو تم پر غصے کے سبب انگلیاں کاٹ کاٹ کھاتے ہیں (ان سے) کہہ دو کہ (بدبختو) غصے میں مر جاؤ خدا تمہارے دلوں کی باتوں سے خوب واقف ہے\qt@no{119}}%
\qt@newcmd\qurantrans@ur@cdxiii{اگر تمہیں آسودگی حاصل ہو تو ان کو بری لگتی ہے اور اگر رنج پہنچے تو خوش ہوتے ہیں اور اگر تم تکلیفوں کی برداشت اور (ان سے) کنارہ کشی کرتے رہو گے تو ان کا فریب تمھیں کچھ بھی نقصان نہ پہنچا سکے گا یہ جو کچھ کرتے ہیں خدا اس پر احاطہ کیے ہوئے ہے\qt@no{120}}%
\qt@newcmd\qurantrans@ur@cdxiv{اور (اس وقت کو یاد کرو) جب تم صبح کو اپنے گھر روانہ ہو کر ایمان والوں کو لڑائی کے لیے مورچوں پر (موقع بہ موقع) متعین کرنے لگے اور خدا سب کچھ سنتا اور جانتا ہے\qt@no{121}}%
\qt@newcmd\qurantrans@ur@cdxv{اس وقت تم میں سے دو جماعتوں نے جی چھوڑ دینا چاہا مگر خدا ان کا مددگار تھا اور مومنوں کو خدا ہی پر بھروسہ رکھنا چاہیئے\qt@no{122}}%
\qt@newcmd\qurantrans@ur@cdxvi{اور خدا نے جنگِ بدر میں بھی تمہاری مدد کی تھی اور اس وقت بھی تم بے سرو وسامان تھے پس خدا سے ڈرو (اور ان احسانوں کو یاد کرو) تاکہ شکر کرو\qt@no{123}}%
\qt@newcmd\qurantrans@ur@cdxvii{جب تم مومنوں سے یہ کہہ (کر ان کے دل بڑھا) رہے تھے کہ کیا یہ کافی نہیں کہ پروردگار تین ہزار فرشتے نازل کر کے تمہیں مدد دے\qt@no{124}}%
\qt@newcmd\qurantrans@ur@cdxviii{ہاں اگر تم دل کو مضبوط رکھو اور (خدا سے) ڈرتے رہو اور کافر تم پر جوش کے ساتھ دفعتہً حملہ کردیں تو پروردگار پانچ ہزار فرشتے جن پر نشان ہوں گے تمہاری مدد کو بھیجے گا\qt@no{125}}%
\qt@newcmd\qurantrans@ur@cdxix{اور اس مدد کو خدا نے تمھارے لیے (ذریعہٴ) بشارت بنایا یعنی اس لیے کہ تمہارے دلوں کو اس سے تسلی حاصل ہو ورنہ مدد تو خدا ہی کی ہے جو غالب (اور) حکمت والا ہے\qt@no{126}}%
\qt@newcmd\qurantrans@ur@cdxx{یہ خدا نے) اس لیے (کیا) کہ کافروں کی ایک جماعت کو ہلاک یا انہیں ذلیل ومغلوب کر دے کہ (جیسے آئے تھے ویسے ہی) ناکام واپس جائیں\qt@no{127}}%
\qt@newcmd\qurantrans@ur@cdxxi{اے پیغمبر) اس کام میں تمہارا کچھ اختیار نہیں (اب دو صورتیں ہیں) یا خدا انکے حال پر مہربانی کرے یا انہیں عذاب دے کہ یہ ظالم لوگ ہیں\qt@no{128}}%
\qt@newcmd\qurantrans@ur@cdxxii{اور جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے سب خدا ہی کا ہے وہ جسے چاہے بخش دے اور جسے چاہے عذاب کرے اور خدا بخشنے والا مہربان ہے\qt@no{129}}%
\qt@newcmd\qurantrans@ur@cdxxiii{اےایمان والو! دگنا چوگنا سود نہ کھاؤ اور خدا سے ڈرو تاکہ نجات حاصل کرو\qt@no{130}}%
\qt@newcmd\qurantrans@ur@cdxxiv{اور (دوزخ کی) آگ سے بچو جو کافروں کے لیے تیار کی گئی ہے\qt@no{131}}%
\qt@newcmd\qurantrans@ur@cdxxv{اور خدا اور اس کے رسول کی اطاعت کرو تاکہ تم پر رحمت کی جائے\qt@no{132}}%
\qt@newcmd\qurantrans@ur@cdxxvi{اپنے پروردگار کی بخشش اور بہشت کی طرف لپکو جس کا عرض آسمان اور زمین کے برابر ہے اور جو (خدا سے) ڈرنے والوں کے لیے تیار کی گئی ہے\qt@no{133}}%
\qt@newcmd\qurantrans@ur@cdxxvii{جو آسودگی اور تنگی میں (اپنا مال خدا کی راہ میں) خرچ کرتےہیں اور غصے کو روکتے اور لوگوں کے قصور معاف کرتے ہیں اور خدا نیکو کاروں کو دوست رکھتا ہے\qt@no{134}}%
\qt@newcmd\qurantrans@ur@cdxxviii{اور وہ کہ جب کوئی کھلا گناہ یا اپنے حق میں کوئی اور برائی کر بیٹھتے ہیں تو خدا کو یاد کرتے اور اپنے گناہوں کی بخشش مانگتے ہیں اور خدا کے سوا گناہ بخش بھی کون سکتا ہے؟ اور جان بوجھ کر اپنے افعال پر اڑے نہیں رہتے\qt@no{135}}%
\qt@newcmd\qurantrans@ur@cdxxix{ایسے ہی لوگوں کا صلہ پروردگار کی طرف سے بخشش اور باغ ہیں جن کے نیچے نہریں بہہ رہی ہیں (اور) وہ ان میں ہمیشہ بستے رہیں گے اور (اچھے) کام کرنے والوں کا بدلہ بہت اچھا ہے\qt@no{136}}%
\qt@newcmd\qurantrans@ur@cdxxx{تم لوگوں سے پہلے بھی بہت سے واقعات گزر چکے ہیں تو تم زمین کی سیر کرکے دیکھ لو کہ جھٹلانے والوں کا کیسا انجام ہوا\qt@no{137}}%
\qt@newcmd\qurantrans@ur@cdxxxi{یہ (قرآن) لوگوں کے لیے بیان صریح اور اہلِ تقویٰ کے لیے ہدایت اور نصیحت ہے\qt@no{138}}%
\qt@newcmd\qurantrans@ur@cdxxxii{اور (دیکھو) بے دل نہ ہونا اور نہ کسی طرح کا غم کرنا اگر تم مومن (صادق) ہو تو تم ہی غالب رہو گے\qt@no{139}}%
\qt@newcmd\qurantrans@ur@cdxxxiii{اگر تمہیں زخم (شکست) لگا ہے تو ان لوگوں کو بھی ایسا زخم لگ چکا ہے اور یہ دن ہیں کہ ہم ان کو لوگوں میں بدلتے رہتے ہیں اور اس سے یہ بھی مقصود تھا کہ خدا ایمان والوں کو متمیز کر دے اور تم میں سے گواہ بنائے اور خدا بےانصافوں کو پسند نہیں کرتا\qt@no{140}}%
\qt@newcmd\qurantrans@ur@cdxxxiv{اور یہ بھی مقصود تھا کہ خدا ایمان والوں کو خالص (مومن) بنا دے اور کافروں کو نابود کر دے\qt@no{141}}%
\qt@newcmd\qurantrans@ur@cdxxxv{کیا تم یہ سمجھتے ہو کہ (بےآزمائش) بہشت میں جا داخل ہو گے حالانکہ ابھی خدا نے تم میں سے جہاد کرنے والوں کو تو اچھی طرح معلوم کیا ہی نہیں اور (یہ بھی مقصود ہے) کہ وہ ثابت قدم رہنے والوں کو معلوم کرے\qt@no{142}}%
\qt@newcmd\qurantrans@ur@cdxxxvi{اور تم موت (شہادت) کے آنے سے پہلے اس کی تمنا کیا کرتے تھے سو تم نے اس کو آنکھوں سے دیکھ لیا\qt@no{143}}%
\qt@newcmd\qurantrans@ur@cdxxxvii{اور محمد (صلی الله علیہ وسلم) تو صرف (خدا کے) پیغمبر ہیں ان سے پہلے بھی بہت سے پیغمبر ہو گزرے ہیں بھلا اگر یہ مر جائیں یا مارے جائیں تو تم الٹے پاؤں پھر جاؤ؟ (یعنی مرتد ہو جاؤ؟) اور جو الٹے پاؤں پھر جائے گا تو خدا کا کچھ نقصان نہ کر سکے گا اور خدا شکر گزاروں کو (بڑا) ثواب دے گا\qt@no{144}}%
\qt@newcmd\qurantrans@ur@cdxxxviii{اور کسی شخص میں طاقت نہیں کہ خدا کے حکم کے بغیر مر جائے (اس نے موت کا) وقت مقرر کر کے لکھ رکھا ہے اور جو شخص دنیا میں (اپنے اعمال کا) بدلہ چاہے اس کو ہم یہیں بدلہ دے دیں گے اور جو آخرت میں طالبِ ثواب ہو اس کو وہاں اجر عطا کریں گے اور ہم شکر گزاروں کو عنقریب (بہت اچھا) صلہ دیں گے\qt@no{145}}%
\qt@newcmd\qurantrans@ur@cdxxxix{اور بہت سے نبی ہوئے ہیں جن کے ساتھ ہو کر اکثر اہل الله (خدا کے دشمنوں سے) لڑے ہیں تو جو مصبتیں ان پر راہِ خدا میں واقع ہوئیں ان کے سبب انہوں نے نہ تو ہمت ہاری اور نہ بزدلی کی نہ (کافروں سے) دبے اور خدا استقلال رکھنے والوں کو دوست رکھتا ہے\qt@no{146}}%
\qt@newcmd\qurantrans@ur@cdxl{اور (اس حالت میں) ان کے منہ سے کوئی بات نکلتی ہے تو یہی کہ اے پروردگار ہمارے گناہ اور زیادتیاں جو ہم اپنے کاموں میں کرتے رہے ہیں معاف فرما اور ہم کو ثابت قدم رکھ اور کافروں پر فتح عنایت فرما\qt@no{147}}%
\qt@newcmd\qurantrans@ur@cdxli{تو خدا نے ان کو دنیا میں بھی بدلہ دیا اور آخرت میں بھی بہت اچھا بدلہ (دے گا) اور خدا نیکو کاروں کو دوست رکھتا ہے\qt@no{148}}%
\qt@newcmd\qurantrans@ur@cdxlii{مومنو! اگر تم کافروں کا کہا مان لو گے تو وہ تم کو الٹے پاؤں پھیر کر (مرتد کر) دیں گے پھر تم بڑے خسارے میں پڑ جاؤ گے\qt@no{149}}%
\qt@newcmd\qurantrans@ur@cdxliii{یہ تمہارے مددگار نہیں ہیں) بلکہ خدا تمہارا مددگار ہے اور وہ سب سے بہتر مددگار ہے\qt@no{150}}%
\qt@newcmd\qurantrans@ur@cdxliv{ہم عنقریب کافروں کے دلوں میں تمہارا رعب بٹھا دیں گے کیونکہ یہ خدا کے ساتھ شرک کرتے ہیں جس کی اس نے کوئی بھی دلیل نازل نہیں کی اور ان کا ٹھکانہ دوزخ ہے وہ ظالموں کا بہت بُرا ٹھکانا ہے\qt@no{151}}%
\qt@newcmd\qurantrans@ur@cdxlv{اور خدا نے اپنا وعدہ سچا کر دیا (یعنی) اس وقت جبکہ تم کافروں کو اس کے حکم سے قتل کر رہے تھے یہاں تک کہ جو تم چاہتے تھے خدا نے تم کو دکھا دیا اس کے بعد تم نے ہمت ہار دی اور حکم (پیغمبر) میں جھگڑا کرنے لگے اور اس کی نافرمانی کی بعض تو تم میں سے دنیا کے خواستگار تھے اور بعض آخرت کے طالب اس وقت خدا نے تم کو ان (کے مقابلے) سے پھیر (کر بھگا) دیا تاکہ تمہاری آزمائش کرے اور اس نے تمہارا قصور معاف کر دیا اور خدا مومنو پر بڑا فضل کرنے والا ہے\qt@no{152}}%
\qt@newcmd\qurantrans@ur@cdxlvi{وہ وقت بھی یاد کرنے کے لائق ہے) جب تم لوگ دور بھاگے جاتے تھے اور کسی کو پیچھے پھر کر نہیں دیکھتے تھے اور رسول الله تم کو تمہارے پیچھے کھڑے بلا رہے تھے تو خدا نے تم کو غم پر غم پہنچایا تاکہ جو چیز تمہارے ہاتھ سے جاتی رہی یا جو مصیبت تم پر واقع ہوئی ہے اس سے تم اندوہ ناک نہ ہو اور خدا تمہارے سب اعمال سے خبردار ہے\qt@no{153}}%
\qt@newcmd\qurantrans@ur@cdxlvii{پھر خدا نے غم ورنج کے بعد تم پر تسلی نازل فرمائی (یعنی) نیند کہ تم میں سے ایک جماعت پر طاری ہو گئی اور کچھ لوگ جن کو جان کے لالے پڑ رہے تھے خدا کے بارے میں ناحق (ایام) کفر کے سے گمان کرتے تھے اور کہتے تھے بھلا ہمارے اختیار کی کچھ بات ہے؟ تم کہہ دو کہ بےشک سب باتیں خدا ہی کے اختیار میں ہیں یہ لوگ (بہت سی باتیں) دلوں میں مخفی رکھتے ہیں جو تم پر ظاہر نہیں کرتے تھے کہتے تھے کہ ہمارے بس کی بات ہوتی تو ہم یہاں قتل ہی نہ کیے جاتے کہہ دو کہ اگر تم اپنے گھروں میں بھی ہوتے تو جن کی تقدیر میں مارا جانا لکھا تھا وہ اپنی اپنی قتل گاہوں کی طرف ضرور نکل آتے اس سے غرض یہ تھی کہ خدا تمہارے سینوں کی باتوں کو آزمائے اور جو کچھ تمہارے دلوں میں ہے اس کو خالص اور صاف کر دے اور خدا دلوں کی باتوں سے خوب واقف ہے\qt@no{154}}%
\qt@newcmd\qurantrans@ur@cdxlviii{جو لوگ تم میں سے (اُحد کے دن) جبکہ (مومنوں اور کافروں کی) دو جماعتیں ایک دوسرے سے گتھ گئیں (جنگ سے) بھاگ گئے تو ان کے بعض افعال کے سبب شیطان نے ان کو پھسلا دیا مگر خدا نے ان کا قصور معاف کر دیا بےشک خدا بخشنے والا اور بردبار ہے\qt@no{155}}%
\qt@newcmd\qurantrans@ur@cdxlix{مومنو! ان لوگوں جیسے نہ ہونا جو کفر کرتے ہیں اور ان کے (مسلمان) بھائی جب (خدا کی راہ میں) سفر کریں (اور مر جائیں) یا جہاد کو نکلیں (اور مارے جائیں) تو ان کی نسبت کہتے ہیں کہ اگر وہ ہمارے پاس رہتے تو نہ مرتے اور نہ مارے جاتے۔ ان باتوں سے مقصود یہ ہے کہ خدا ان لوگوں کے دلوں میں افسوس پیدا کر دے اور زندگی اور موت تو خدا ہی دیتا ہے اور خدا تمہارے سب کاموں کو دیکھ رہا ہے\qt@no{156}}%
\qt@newcmd\qurantrans@ur@cdl{اور اگر تم خدا کے رستے میں مارے جاؤ یا مرجاؤ تو جو (مال و متاع) لوگ جمع کرتے ہیں اس سے خدا کی بخشش اور رحمت کہیں بہتر ہے\qt@no{157}}%
\qt@newcmd\qurantrans@ur@cdli{اور اگر تم مرجاؤ یا مارے جاؤ خدا کے حضور میں ضرور اکھٹے کئے جاؤ گے\qt@no{158}}%
\qt@newcmd\qurantrans@ur@cdlii{اے محمدﷺ) خدا کی مہربانی سے تمہاری افتاد مزاج ان لوگوں کے لئے نرم واقع ہوئی ہے۔ اور اگر تم بدخو اور سخت دل ہوتے تو یہ تمہارے پاس سے بھاگ کھڑے ہوتے۔ تو ان کو معاف کردو اور ان کے لئے (خدا سے) مغفرت مانگو۔ اور اپنے کاموں میں ان سے مشورت لیا کرو۔ اور جب (کسی کام کا) عزم مصمم کرلو تو خدا پر بھروسا رکھو۔ بےشک خدا بھروسا رکھنے والوں کو دوست رکھتا ہے\qt@no{159}}%
\qt@newcmd\qurantrans@ur@cdliii{اور خدا تمہارا مددگار ہے تو تم پر کوئی غالب نہیں آسکتا۔ اور اگر وہ تمہیں چھوڑ دے تو پھر کون ہے کہ تمہاری مدد کرے اور مومنوں کو چاہیئے کہ خدا ہی پر بھروسا رکھیں\qt@no{160}}%
\qt@newcmd\qurantrans@ur@cdliv{اور کبھی نہیں ہوسکتا کہ پیغمبر (خدا) خیانت کریں۔ اور خیانت کرنے والوں کو قیامت کے دن خیانت کی ہوئی چیز (خدا کے روبرو) لاحاضر کرنی ہوگی۔ پھر ہر شخص کو اس کے اعمال کا پورا پورا بدلا دیا جائے گا اور بےانصافی نہیں کی جائے گی\qt@no{161}}%
\qt@newcmd\qurantrans@ur@cdlv{بھلا جو شخص خدا کی خوشنودی کا تابع ہو وہ اس شخص کی طرح (مرتکب خیانت) ہوسکتا ہے جو خدا کی ناخوشی میں گرفتار ہو اور جس کا ٹھکانہ دوزخ ہے، اور وہ برا ٹھکانا ہے\qt@no{162}}%
\qt@newcmd\qurantrans@ur@cdlvi{ان لوگوں کے خدا کے ہاں (مختلف اور متفاوت) درجے ہیں اور خدا ان کے سب اعمال کو دیکھ رہا ہے\qt@no{163}}%
\qt@newcmd\qurantrans@ur@cdlvii{خدا نے مومنوں پر بڑا احسان کیا ہے کہ ان میں انہیں میں سے ایک پیغمبر بھیجے۔ جو ان کو خدا کی آیتیں پڑھ پڑھ کر سناتے اور ان کو پاک کرتے اور (خدا کی) کتاب اور دانائی سکھاتے ہیں اور پہلے تو یہ لوگ صریح گمراہی میں تھے\qt@no{164}}%
\qt@newcmd\qurantrans@ur@cdlviii{بھلا یہ) کیا (بات ہے کہ) جب (اُحد کے دن کافر کے ہاتھ سے) تم پر مصیبت واقع ہوئی حالانکہ (جنگ بدر میں) اس سے دوچند مصیبت تمہارے ہاتھ سے ان پر پڑچکی ہے توتم چلا اٹھے کہ (ہائے) آفت (ہم پر) کہاں سے آپڑی کہہ دو کہ یہ تمہاری ہی شامت اعمال ہے (کہ تم نے پیغمبر کے حکم کے خلاف کیا) بےشک خدا ہر چیز پر قادر ہے\qt@no{165}}%
\qt@newcmd\qurantrans@ur@cdlix{اور جو مصیبت تم پر دونوں جماعتوں کے مقابلے کے دن واقع ہوئی سو خدا کے حکم سے (واقع ہوئی) اور (اس سے) یہ مقصود تھا کہ خدا مومنوں کو اچھی طرح معلوم\qt@no{166}}%
\qt@newcmd\qurantrans@ur@cdlx{اور منافقوں کو بھی معلوم کرلے اور (جب) ان سے کہا گیا کہ آؤ خدا کے رستے میں جنگ کرو یا (کافروں کے) حملوں کو روکو۔ تو کہنے لگے کہ اگر ہم کو لڑائی کی خبر ہوتی تو ہم ضرور تمہارے ساتھ رہتے یہ اس دن ایمان کی نسبت کفر سے زیادہ قریب تھے منہ سے وہ باتیں کہتے ہیں جو ان کے دل میں نہیں ہیں۔ اور جو کچھ یہ چھپاتے ہیں خدا ان سے خوب واقف ہے\qt@no{167}}%
\qt@newcmd\qurantrans@ur@cdlxi{یہ خود تو (جنگ سے بچ کر) بیٹھ ہی رہے تھے مگر (جنہوں نے راہ خدا میں جانیں قربان کردیں) اپنے (ان) بھائیوں کے بارے میں بھی کہتے ہیں کہ اگر ہمارا کہا مانتے تو قتل نہ ہوتے۔ کہہ دو کہ اگر سچے ہو تو اپنے اوپر سے موت کو ٹال دینا\qt@no{168}}%
\qt@newcmd\qurantrans@ur@cdlxii{جو لوگ خدا کی راہ میں مارے گئے ان کو مرے ہوئے نہ سمجھنا (وہ مرے ہوئے نہیں ہیں) بلکہ خدا کے نزدیک زندہ ہیں اور ان کو رزق مل رہا ہے\qt@no{169}}%
\qt@newcmd\qurantrans@ur@cdlxiii{جو کچھ خدا نے ان کو اپنے فضل سے بخش رکھا ہے اس میں خوش ہیں۔ اور جو لوگ ان کے پیچھے رہ گئے اور (شہید ہوکر) ان میں شامل نہیں ہوسکے ان کی نسبت خوشیاں منا رہے ہیں کہ (قیامت کے دن) ان کو بھی نہ کچھ خوف ہوگا اور نہ وہ غمناک ہوں گے\qt@no{170}}%
\qt@newcmd\qurantrans@ur@cdlxiv{اور خدا کے انعامات اور فضل سے خوش ہورہے ہیں۔ اور اس سے کہ خدا مومنوں کا اجر ضائع نہیں کرتا\qt@no{171}}%
\qt@newcmd\qurantrans@ur@cdlxv{جنہوں نے باوجود زخم کھانے کے خدا اور رسول (کے حکم) کو قبول کیا جو لوگ ان میں نیکوکار اور پرہیزگار ہیں ان کے لئے بڑا ثواب ہے\qt@no{172}}%
\qt@newcmd\qurantrans@ur@cdlxvi{جب) ان سے لوگوں نے آکر بیان کیا کہ کفار نے تمہارے (مقابلے کے) لئے لشکر کثیر) جمع کیا ہے تو ان سے ڈرو۔ تو ان کا ایمان اور زیادہ ہوگیا۔ اور کہنے لگے ہم کو خدا کافی ہے اور وہ بہت اچھا کارساز ہے\qt@no{173}}%
\qt@newcmd\qurantrans@ur@cdlxvii{پھر وہ خدا کی نعمتوں اور اس کے فضل کے ساتھ (خوش وخرم) واپس آئے ان کو کسی طرح کا ضرر نہ پہنچا۔ اور وہ خدا کی خوشنودی کے تابع رہے۔ اور خدا بڑے فضل کا مالک ہے\qt@no{174}}%
\qt@newcmd\qurantrans@ur@cdlxviii{یہ (خوف دلانے والا) تو شیطان ہے جو اپنے دوستوں سے ڈراتا ہے تو اگر تم مومن ہو تو ان سے مت ڈرنا اور مجھ ہی سے ڈرتے رہنا\qt@no{175}}%
\qt@newcmd\qurantrans@ur@cdlxix{اور جو لوگ کفر میں جلدی کرتے ہیں ان (کی وجہ) سے غمگین نہ ہونا۔ یہ خدا کا کچھ نقصان نہیں کرسکتے خدا چاہتا ہے کہ آخرت میں ان کو کچھ حصہ نہ دے اور ان کے لئے بڑا عذاب تیار ہے\qt@no{176}}%
\qt@newcmd\qurantrans@ur@cdlxx{جن لوگوں نے ایمان کے بدلے کفر خریدا وہ خدا کا کچھ نہیں بگاڑ سکتے اور ان کو دکھ دینے والا عذاب ہوگا\qt@no{177}}%
\qt@newcmd\qurantrans@ur@cdlxxi{اور کافر لوگ یہ نہ خیال کریں کہ ہم جو ان کو مہلت دیئے جاتے ہیں تو یہ ان کے حق میں اچھا ہے۔ (نہیں بلکہ) ہم ان کو اس لئے مہلت دیتے ہیں کہ اور گناہ کرلیں۔ آخرکار ان کو ذلیل کرنے والا عذاب ہوگا\qt@no{178}}%
\qt@newcmd\qurantrans@ur@cdlxxii{لوگو) جب تک خدا ناپاک کو پاک سے الگ نہ کردے گا مومنوں کو اس حال میں جس میں تم ہو ہرگز نہیں رہنے دے گا۔ اور الله تم کوغیب کی باتوں سے بھی مطلع نہیں کرے گاالبتہ خدا اپنے پیغمبروں میں سے جسے چاہتا ہے انتخاب کرلیتا ہے۔ تو تم خدا پر اور اس کے رسولوں پر ایمان لاؤاور اگر ایمان لاؤ گے اور پرہیزگاری کرو گے تو تم کو اجر عظیم ملے گا\qt@no{179}}%
\qt@newcmd\qurantrans@ur@cdlxxiii{جو لوگ مال میں جو خدا نے اپنے فضل سے ان کو عطا فرمایا ہے بخل کرتے ہیں وہ اس بخل کو اپنے حق میں اچھا نہ سمجھیں۔ (وہ اچھا نہیں) بلکہ ان کے لئے برا ہے وہ جس مال میں بخل کرتے ہیں قیامت کے دن اس کا طوق بنا کر ان کی گردنوں میں ڈالا جائے گا۔ اور آسمانوں اور زمین کا وارث خدا ہی ہے۔ اور جو عمل تم کرتے ہوخدا کو معلوم ہے\qt@no{180}}%
\qt@newcmd\qurantrans@ur@cdlxxiv{خدا نے ان لوگوں کا قول سن لیا ہے جو کہتے ہیں کہ خدا فقیر ہے۔ اور ہم امیر ہیں۔ یہ جو کہتے ہیں ہم اس کو لکھ لیں گے۔ اور پیغمبروں کو جو یہ ناحق قتل کرتے رہے ہیں اس کو بھی (قلمبند کر رکھیں گے) اور (قیامت کے روز) کہیں گے کہ عذاب (آتش) سوزاں کے مزے چکھتے رہو\qt@no{181}}%
\qt@newcmd\qurantrans@ur@cdlxxv{یہ ان کاموں کی سزا ہے جو تمہارے ہاتھ آگے بھیجتے رہے ہیں اور خدا تو بندوں پر مطلق ظلم نہیں کرتا\qt@no{182}}%
\qt@newcmd\qurantrans@ur@cdlxxvi{جو لوگ کہتے ہی کہ خدا نے ہمیں حکم بھیجا ہے کہ جب تک کوئی پیغمبر ہمارے پاس ایسی نیاز لے کر نہ آئے جس کو آگ آکر کھا جائے تب تک ہم اس پر ایمان نہ لائیں گے (اے پیغمبر ان سے) کہہ دو کہ مجھ سے پہلے کئی پیغمبر تمہارے پاس کھلی ہوئی نشانیاں لے کر آئے اور وہ (معجزہ) بھی لائے جو تم کہتے ہو تو اگر سچے ہو تو تم نے ان کو قتل کیوں کیا؟\qt@no{183}}%
\qt@newcmd\qurantrans@ur@cdlxxvii{پھر اگر یہ لوگ تم کو سچا نہ سمجھیں تو تم سے پہلے بہت سے پیغمبر کھلی ہوئی نشانیاں اور صحیفے اور روشن کتابیں لے کر آچکے ہیں اور لوگوں نے ان کو بھی سچا نہیں سمجھا\qt@no{184}}%
\qt@newcmd\qurantrans@ur@cdlxxviii{ہر متنفس کو موت کا مزا چکھنا ہے اور تم کو قیامت کے دن تمہارے اعمال کا پورا پورا بدلا دیا جائے گا۔ تو جو شخص آتش جہنم سے دور رکھا گیا اور بہشت میں داخل کیا گیا وہ مراد کو پہنچ گیا اور دنیا کی زندگی تو دھوکے کا سامان ہے\qt@no{185}}%
\qt@newcmd\qurantrans@ur@cdlxxix{اے اہل ایمان) تمہارے مال و جان میں تمہاری آزمائش کی جائے گی۔ اور تم اہل کتاب سے اور ان لوگوں سے جو مشرک ہیں بہت سی ایذا کی باتیں سنو گے۔ اور تو اگر صبر اور پرہیزگاری کرتے رہو گے تو یہ بڑی ہمت کے کام ہیں\qt@no{186}}%
\qt@newcmd\qurantrans@ur@cdlxxx{اور جب خدا نے ان لوگوں سے جن کو کتاب عنایت کی گئی تھی اقرار کرلیا کہ (جو کچھ اس میں لکھا ہے) اسے صاف صاف بیان کرتے رہنا۔ اور اس (کی کسی بات) کو نہ چھپانا تو انہں نے اس کو پس پشت پھینک دیا اور اس کے بدلے تھوڑی سی قیمت حاصل کی۔ یہ جو کچھ حاصل کرتے ہیں برا ہے\qt@no{187}}%
\qt@newcmd\qurantrans@ur@cdlxxxi{جو لوگ اپنے (ناپسند) کاموں سے خوش ہوتے ہیں اور پسندیدہ کام) جو کرتے نہیں ان کے لئے چاہتے ہیں کہ ان ک تعریف کی جائے ان کی نسبت خیال نہ کرنا کہ وہ عذاب سے رستگار ہوجائیں گے۔ اور انہیں درد دینے والا عذاب ہوگا\qt@no{188}}%
\qt@newcmd\qurantrans@ur@cdlxxxii{اور آسمانوں اور زمین کی بادشاہی خدا ہی کو ہے اور خدا ہر چیز پر قادر ہے\qt@no{189}}%
\qt@newcmd\qurantrans@ur@cdlxxxiii{بے شک آسمانوں اور زمین کی پیدائش اور رات اور دن کے بدل بدل کے آنے جانے میں عقل والوں کے لیے نشانیاں ہیں\qt@no{190}}%
\qt@newcmd\qurantrans@ur@cdlxxxiv{جو کھڑے اور بیٹھے اور لیٹے (ہر حال میں) خدا کو یاد کرتے اور آسمان اور زمین کی پیدائش میں غور کرتے (اور کہتے ہیں) کہ اے پروردگار! تو نے اس (مخلوق) کو بے فائدہ نہیں پیدا کیا تو پاک ہے تو (قیامت کے دن) ہمیں دوزخ کے عذاب سے بچائیو\qt@no{191}}%
\qt@newcmd\qurantrans@ur@cdlxxxv{اے پروردگار جس کو تو نے دوزخ میں ڈالا اسے رسوا کیا اور ظالموں کا کوئی مددگار نہیں\qt@no{192}}%
\qt@newcmd\qurantrans@ur@cdlxxxvi{اے پروردگارہم نے ایک ندا کرنے والے کو سنا کہ ایمان کے لیے پکار رہا تھا (یعنی) اپنے پروردگار پر ایمان لاؤ تو ہم ایمان لے آئے اے پروردگار ہمارے گناہ معاف فرما اور ہماری برائیوں کو ہم سے محو کر اور ہم کو دنیا سے نیک بندوں کے ساتھ اٹھا\qt@no{193}}%
\qt@newcmd\qurantrans@ur@cdlxxxvii{اے پروردگار تو نے جن جن چیزوں کے ہم سے اپنے پیغمبروں کے ذریعے سے وعدے کیے ہیں وہ ہمیں عطا فرما اور قیامت کے دن ہمیں رسوا نہ کیجو کچھ شک نہیں کہ تو خلاف وعدہ نہیں کرتا\qt@no{194}}%
\qt@newcmd\qurantrans@ur@cdlxxxviii{تو ان کے پرردگار نے ان کی دعا قبول کر لی (اور فرمایا) کہ میں کسی عمل کرنے والے کے عمل کو مرد ہو یا عورت ضائع نہیں کرتا تم ایک دوسرے کی جنس ہو تو جو لوگ میرے لیے وطن چھوڑ گئے اور اپنے گھروں سے نکالے گئے اور ستائے گئے اور لڑے اور قتل کیے گئے میں ان کے گناہ دور کردوں گا اور ان کو بہشتوں میں داخل کروں گا جن کے نیچے نہریں بہ رہی ہیں (یہ) خدا کے ہاں سے بدلہ ہے اور خدا کے ہاں اچھا بدلہ ہے\qt@no{195}}%
\qt@newcmd\qurantrans@ur@cdlxxxix{اے پیغمبر) کافروں کا شہروں میں چلنا پھرنا تمہیں دھوکا نہ دے\qt@no{196}}%
\qt@newcmd\qurantrans@ur@cdxc{یہ دنیا کا) تھوڑا سا فائدہ ہے پھر (آخرت میں) تو ان کا ٹھکانا دوزخ ہے اور وہ بری جگہ ہے\qt@no{197}}%
\qt@newcmd\qurantrans@ur@cdxci{لیکن جو لوگ اپنے پروردگار سے ڈرتے رہے ان کے لیے باغ ہے جن کے نیچے نہریں بہہ رہی ہیں (اور) ان میں ہمیشہ رہیں گے (یہ) خدا کے ہاں سے (ان کی) مہمانی ہے اور جو کچھ خدا کے ہاں ہے وہ نیکو کاروں کے لیے بہت اچھا ہے\qt@no{198}}%
\qt@newcmd\qurantrans@ur@cdxcii{اور بعض اہلِ کتاب ایسے بھی ہیں جو خدا پر اور اس (کتاب) پر جو تم پر نازل ہوئی اور اس پر جو ان پر نازل ہوئی ایمان رکھتے ہیں اور خدا کے آگے عاجزی کرتے ہیں اور خدا کی آیتوں کے بدلے تھوڑی سی قیمت نہیں لیتے یہی لوگ ہیں جن کا صلہ ان کے پروردگار کے ہاں تیار ہے اور خدا جلد حساب لینے والا ہے\qt@no{199}}%
\qt@newcmd\qurantrans@ur@cdxciii{اے اہل ایمان (کفار کے مقابلے میں) ثابت قدم رہو اور استقامت رکھو اور مورچوں پر جمے رہو اور خدا سے ڈرو تاکہ مراد حاصل کرو\qt@no{200}}%
\qt@newcmd\qurantrans@ur@cdxciv{\basmalahur لوگو اپنے پروردگار سے ڈرو جس نے تم کو ایک شخص سے پیدا کیا (یعنی اول) اس سے اس کا جوڑا بنایا۔ پھر ان دونوں سے کثرت سے مرد وعورت (پیدا کرکے روئے زمین پر) پھیلا دیئے۔ اور خدا سے جس کے نام کو تم اپنی حاجت بر آری کا ذریعہ بناتے ہو ڈرو اور (قطع مودت) ارحام سے (بچو) کچھ شک نہیں کہ خدا تمہیں دیکھ رہا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@cdxcv{اور یتیموں کا مال (جو تمہاری تحویل میں ہو) ان کے حوالے کردو اور ان کے پاکیزہ (اور عمدہ) مال کو (اپنے ناقص اور) برے مال سے نہ بدلو۔ اور نہ ان کا مال اپنے مال میں ملا کر کھاؤ۔ کہ یہ بڑا سخت گناہ ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@cdxcvi{اور اگر تم کو اس بات کا خوف ہو کہ یتیم لڑکیوں کے بارےانصاف نہ کرسکوگے تو ان کے سوا جو عورتیں تم کو پسند ہوں دو دو یا تین تین یا چار چار ان سے نکاح کرلو۔ اور اگر اس بات کا اندیشہ ہو کہ (سب عورتوں سے) یکساں سلوک نہ کرسکو گے تو ایک عورت (کافی ہے) یا لونڈی جس کے تم مالک ہو۔ اس سے تم بےانصافی سے بچ جاؤ گے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@cdxcvii{اور عورتوں کو ان کے مہر خوشی سے دے دیا کرو۔ ہاں اگر وہ اپنی خوشی سے اس میں سے کچھ تم کو چھوڑ دیں تو اسے ذوق شوق سے کھالو\qt@no{4}}%
\qt@newcmd\qurantrans@ur@cdxcviii{اور بےعقلوں کو ان کا مال جسے خدا نے تم لوگوں کے لئے سبب معیشت بنایا ہے مت دو (ہاں) اس میں سے ان کو کھلاتے اور پہناتے رہے اور ان سے معقول باتیں کہتے رہو\qt@no{5}}%
\qt@newcmd\qurantrans@ur@cdxcix{اور یتمیوں کو بالغ ہونے تک کام کاج میں مصروف رکھو پھر (بالغ ہونے پر) اگر ان میں عقل کی پختگی دیکھو تو ان کا مال ان کے حوالے کردو اور اس خوف سے کہ وہ بڑے ہوجائیں گے (یعنی بڑے ہو کر تم سے اپنا مال واپس لے لیں گے) اس کو فضول خرچی اور جلدی میں نہ اڑا دینا۔ جو شخص آسودہ حال ہو اس کو (ایسے مال سے قطعی طور پر) پرہیز رکھنا چاہیئے اور جو بے مقدور ہو وہ مناسب طور پر (یعنی بقدر خدمت) کچھ لے لے اور جب ان کا مال ان کے حوالے کرنے لگو تو گواہ کرلیا کرو۔ اور حقیقت میں تو خدا ہی (گواہ اور) حساب لینے والا کافی ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@d{جو مال ماں باپ اور رشتہ دار چھوڑ مریں تھوڑا ہو یا بہت۔ اس میں مردوں کا بھی حصہ ہے اور عورتوں کا بھی یہ حصے (خدا کے) مقرر کئے ہوئے ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@di{اور جب میراث کی تقسیم کے وقت (غیر وارث) رشتہ دار اور یتیم اور محتاج آجائیں تو ان کو بھی اس میں سے کچھ دے دیا کرو۔ اور شیریں کلامی سے پیش آیا کرو\qt@no{8}}%
\qt@newcmd\qurantrans@ur@dii{اور ایسے لوگوں کو ڈرنا چاہیئے جو (ایسی حالت میں ہوں کہ) اپنے بعد ننھے ننھے بچے چھوڑ جائیں اور ان کو ان کی نسبت خوف ہو (کہ ان کے مرنے کے بعد ان بیچاروں کا کیا حال ہوگا) پس چاہیئے کہ یہ لوگ خدا سے ڈریں اور معقول بات کہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@diii{لوگ یتیموں کا مال ناجائز طور پر کھاتے ہیں وہ اپنے پیٹ میں آگ بھرتے ہیں۔ اور دوزخ میں ڈالے جائیں گے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@div{خدا تمہاری اولاد کے بارے میں تم کو ارشاد فرماتا ہے کہ ایک لڑکے کا حصہ دو لڑکیوں کے حصے کے برابر ہے۔ اور اگر اولاد میت صرف لڑکیاں ہی ہوں (یعنی دو یا) دو سے زیادہ تو کل ترکے میں ان کادو تہائی۔ اور اگر صرف ایک لڑکی ہو تو اس کا حصہ نصف۔ اور میت کے ماں باپ کا یعنی دونوں میں سے ہر ایک کا ترکے میں چھٹا حصہ بشرطیکہ میت کے اولاد ہو۔ اور اگر اولاد نہ ہو اور صرف ماں باپ ہی اس کے وارث ہوں تو ایک تہائی ماں کا حصہ۔ اور اگر میت کے بھائی بھی ہوں تو ماں کا چھٹا حصہ۔ (اور یہ تقسیم ترکہ میت کی) وصیت (کی تعمیل) کے بعد جو اس نے کی ہو یا قرض کے (ادا ہونے کے بعد جو اس کے ذمے ہو عمل میں آئے گی) تم کو معلوم نہیں کہ تمہارے باپ دادؤں اور بیٹوں پوتوں میں سے فائدے کے لحاظ سے کون تم سے زیادہ قریب ہے، یہ حصے خدا کے مقرر کئے ہوئے ہیں اور خدا سب کچھ جاننے والا اور حکمت والا ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@dv{اور جو مال تمہاری عورتیں چھوڑ مریں۔ اگر ان کے اولاد نہ ہو تو اس میں نصف حصہ تمہارا۔ اور اگر اولاد ہو تو ترکے میں تمہارا حصہ چوتھائی۔ (لیکن یہ تقسیم) وصیت (کی تعمیل) کے بعد جو انہوں نے کی ہو یا قرض کے (ادا ہونے کے بعد جو ان کے ذمے ہو، کی جائے گی) اور جو مال تم (مرد) چھوڑ مرو۔ اگر تمہارے اولاد نہ ہو تو تمہاری عورتوں کا اس میں چوتھا حصہ۔ اور اگر اولاد ہو تو ان کا آٹھواں حصہ (یہ حصے) تمہاری وصیت (کی تعمیل) کے بعد جو تم نے کی ہو اور (ادائے) قرض کے (بعد تقسیم کئے جائیں گے) اور اگر ایسے مرد یا عورت کی میراث ہو جس کے نہ باپ ہو نہ بیٹا مگر اس کے بھائی بہن ہو تو ان میں سے ہر ایک کا چھٹا حصہ اور اگر ایک سے زیادہ ہوں تو سب ایک تہائی میں شریک ہوں گے (یہ حصے بھی ادائے وصیت و قرض بشرطیکہ ان سے میت نے کسی کا نقصان نہ کیا ہو (تقسیم کئے جائیں گے) یہ خدا کا فرمان ہے۔ اور خدا نہایت علم والا (اور) نہایت حلم والا ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@dvi{یہ تمام احکام) خدا کی حدیں ہیں۔ اور جو شخص خدا اور اس کے پیغمبر کی فرمانبرداری کرے گا خدا اس کو بہشتوں میں داخل کرے گا جن میں نہریں بہہ رہی ہیں وہ ان میں ہمیشہ رہیں گے۔اور یہ بڑی کامیابی ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@dvii{اور جو خدا اور اس کے رسول کی نافرمانی کرے گا اور اس کی حدوں سے نکل جائے گا اس کو خدا دوزخ میں ڈالے گا جہاں وہ ہمیشہ رہے گا۔ اور اس کو ذلت کا عذاب ہوگا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@dviii{مسلمانو تمہاری عورتوں میں جو بدکاری کا ارتکاب کر بیٹھیں ان پر اپنے لوگوں میں سے چار شخصوں کی شہادت لو۔ اگر وہ (ان کی بدکاری کی) گواہی دیں تو ان عورتوں کو گھروں میں بند رکھو یہاں تک کہ موت ان کا کام تمام کردے یا خدا ان کے لئے کوئی اور سبیل (پیدا) کرے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@dix{اور جو دو مرد تم میں سے بدکاری کریں تو ان کو ایذا دو۔ پھر اگر وہ توبہ کرلیں اور نیکوکار ہوجائیں تو ان کا پیچھا چھوڑ دو۔ بےشک خدا توبہ قبول کرنے والا (اور) مہربان ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@dx{خدا انہیں لوگوں کی توبہ قبول فرماتا ہے جو نادانی سے بری حرکت کر بیٹھے ہیں۔ پھر جلد توبہ قبول کرلیتے ہیں پس ایسے لوگوں پر خدا مہربانی کرتا ہے۔ اور وہ سب کچھ جانتا (اور) حکمت والا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@dxi{اور ایسے لوگوں کی توبہ قبول نہیں ہوتی جو (ساری عمر) برے کام کرتے ہیں۔ یہاں تک کہ جب ان میں سے کسی موت آموجود ہو تو اس وقت کہنے لگے کہ اب میں توبہ کرتا ہوں اور نہ ان کی (توبہ قبول ہوتی ہے) جو کفر کی حالت میں مریں۔ ایسے لوگوں کے لئے ہم نے عذاب الیم تیار کر رکھا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@dxii{مومنو! تم کو جائز نہیں کہ زبردستی عورتوں کے وارث بن جاؤ۔ اور (دیکھنا) اس نیت سے کہ جو کچھ تم نے ان کو دیا ہے اس میں سے کچھ لے لو انہیں (گھروں میں) میں مت روک رکھنا ہاں اگر وہ کھلے طور پر بدکاری کی مرتکب ہوں (تو روکنا مناسب نہیں) اور ان کے ساتھ اچھی طرح رہو سہو اگر وہ تم کو ناپسند ہوں تو عجب نہیں کہ تم کسی چیز کو ناپسند کرو اور خدا اس میں بہت سی بھلائی پیدا کردے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@dxiii{اور اگر تم ایک عورت کو چھوڑ کر دوسری عورت کرنی چاہو۔ اور پہلی عورت کو بہت سال مال دے چکے ہو تو اس میں سے کچھ مت لینا۔ بھلا تم ناجائز طور پر اور صریح ظلم سے اپنا مال اس سے واپس لے لوگے؟\qt@no{20}}%
\qt@newcmd\qurantrans@ur@dxiv{اور تم دیا ہوا مال کیونکر واپس لے سکتے ہو جب کہ تم ایک دوسرے کے ساتھ صحبت کرچکے ہو۔ اور وہ تم سے عہد واثق بھی لے چکی ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@dxv{اور جن عورتوں سے تمہارے باپ نے نکاح کیا ہو ان نکاح مت کرنا (مگر جاہلیت میں) جو ہوچکا (سوہوچکا) یہ نہایت بےحیائی اور (خدا کی) ناخوشی کی بات تھی۔ اور بہت برا دستور تھا\qt@no{22}}%
\qt@newcmd\qurantrans@ur@dxvi{تم پر تمہاری مائیں اور بیٹیاں اور بہنیں اور پھوپھیاں اور خالائیں اور بھتیجیاں اور بھانجیاں اور وہ مائیں جنہوں نے تم کو دودھ پلایا ہو اور رضاعی بہنیں اور ساسیں حرام کر دی گئی ہیں اور جن عورتوں سے تم مباشرت کر چکے ہو ان کی لڑکیاں جنہیں تم پرورش کرتے (ہو وہ بھی تم پر حرام ہیں) ہاں اگر ان کے ساتھ تم نے مباشرت نہ کی ہو تو (ان کی لڑکیوں کے ساتھ نکاح کر لینے میں) تم پر کچھ گناہ نہیں اور تمہارے صلبی بیٹوں کی عورتیں بھی اور دو بہنوں کا اکٹھا کرنا بھی (حرام ہے) مگر جو ہو چکا (سو ہو چکا) بے شک خدا بخشنے والا (اور) رحم کرنے والا ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@dxvii{اور شوہر والی عورتیں بھی (تم پر حرام ہیں) مگر وہ جو (اسیر ہو کر لونڈیوں کے طور پر) تمہارے قبضے میں آجائیں (یہ حکم) خدا نے تم کو لکھ دیا ہے اور ان (محرمات) کے سوا اور عورتیں تم کو حلال ہیں اس طرح سے کہ مال خرچ کر کے ان سے نکاح کرلو بشرطیکہ (نکاح سے) مقصود عفت قائم رکھنا ہو نہ شہوت رانی تو جن عورتوں سے تم فائدہ حاصل کرو ان کا مہر جو مقرر کیا ہو ادا کردو اور اگر مقرر کرنے کے بعد آپس کی رضامندی سے مہر میں کمی بیشی کرلو تو تم پر کچھ گناہ نہیں بےشک خدا سب کچھ جاننے والا (اور) حکمت والا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@dxviii{اور جو شخص تم میں سے مومن آزاد عورتوں (یعنی بیبیوں) سے نکاح کرنے کا مقدور نہ رکھے تو مومن لونڈیوں میں ہی جو تمہارے قبضے میں آگئی ہوں (نکاح کرلے) اور خدا تمہارے ایمان کو اچھی طرح جانتا ہے تم آپس میں ایک دوسرے کے ہم جنس ہو تو ان لونڈیوں کے ساتھ ان کے مالکوں سے اجازت حاصل کرکے نکاح کر لو اور دستور کے مطابق ان کا مہر بھی ادا کردو بشرطیکہ عفیفہ ہوں نہ ایسی کہ کھلم کھلا بدکاری کریں اور نہ درپردہ دوستی کرنا چاہیں پھر اگر نکاح میں آکر بدکاری کا ارتکاب کر بیٹھیں تو جو سزا آزاد عورتوں (یعنی بیبیوں) کے لئے ہے اس کی آدھی ان کو (دی جائے) یہ (لونڈی کے ساتھ نکاح کرنے کی) اجازت اس شخص کو ہے جسے گناہ کر بیٹھنے کا اندیشہ ہو اور اگر صبر کرو تو یہ تمہارے لئے بہت اچھا ہے اور خدا بخشنے والا مہربان ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@dxix{خدا چاہتا ہے کہ (اپنی آیتیں) تم سے کھول کھول کر بیان فرمائے اور تم کو اگلے لوگوں کے طریقے بتائے اور تم پر مہربانی کرے اور خدا جاننے والا (اور) حکمت والا ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@dxx{اور خدا تو چاہتا ہے کہ تم پر مہربانی کرے اور جو لوگ اپنی خواہشوں کے پیچھے چلتے ہیں وہ چاہتے ہیں کہ تم سیدھے راستے سے بھٹک کر دور جا پڑو\qt@no{27}}%
\qt@newcmd\qurantrans@ur@dxxi{خدا چاہتا ہے کہ تم پر سے بوجھ ہلکا کرے اور انسان (طبعاً) کمزور پیدا ہوا ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@dxxii{مومنو! ایک دوسرے کا مال ناحق نہ کھاؤ ہاں اگر آپس کی رضامندی سے تجارت کا لین دین ہو (اور اس سے مالی فائدہ حاصل ہو جائے تو وہ جائز ہے) اور اپنے آپ کو ہلاک نہ کرو کچھ شک نہیں کہ خدا تم پر مہربان ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@dxxiii{اور جو تعدی اور ظلم سے ایسا کرے گا ہم اس کو عنقریب جہنم میں داخل کریں گے اور یہ خدا کو آسان ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@dxxiv{اگر تم بڑے بڑے گناہوں سے جن سے تم کو منع کیا جاتا ہے اجتناب رکھو گے تو ہم تمہارے (چھوٹے چھوٹے) گناہ معاف کردیں گے اور تمہیں عزت کے مکانوں میں داخل کریں گے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@dxxv{اور جس چیز میں خدا نے تم میں سے بعض کو بعض پر فضیلت دی ہے اس کی ہوس مت کرو مردوں کو ان کاموں کا ثواب ہے جو انہوں نے کئے اور عورتوں کو ان کاموں کا ثواب ہے جو انہوں نے کئے اور خدا سے اس کا فضل (وکرم) مانگتے رہو کچھ شک نہیں کہ خدا ہر چیز سے واقف ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@dxxvi{اور جو مال ماں باپ اور رشتہ دار چھوڑ مریں تو (حق داروں میں تقسیم کردو کہ) ہم نے ہر ایک کے حقدار مقرر کردیئے ہیں اور جن لوگوں سے تم عہد کرچکے ہو ان کو بھی ان کا حصہ دو بےشک خدا ہر چیز کے سامنے ہے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@dxxvii{مرد عورتوں پر مسلط وحاکم ہیں اس لئے کہ خدا نے بعض کو بعض سے افضل بنایا ہے اور اس لئے بھی کہ مرد اپنا مال خرچ کرتے ہیں تو جو نیک بیبیاں ہیں وہ مردوں کے حکم پر چلتی ہیں اور ان کے پیٹھ پیچھے خدا کی حفاظت میں (مال وآبرو کی) خبرداری کرتی ہیں اور جن عورتوں کی نسبت تمہیں معلوم ہو کہ سرکشی (اور بدخوئی) کرنے لگی ہیں تو (پہلے) ان کو (زبانی) سمجھاؤ (اگر نہ سمجھیں تو) پھر ان کے ساتھ سونا ترک کردو اگر اس پر بھی باز نہ آئیں تو زدوکوب کرو اور اگر فرمانبردار ہوجائیں تو پھر ان کو ایذا دینے کا کوئی بہانہ مت ڈھونڈو بےشک خدا سب سے اعلیٰ (اور) جلیل القدر ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@dxxviii{اور اگر تم کو معلوم ہو کہ میاں بیوی میں ان بن ہے تو ایک منصف مرد کے خاندان میں سے اور ایک منصف عورت کے خاندان میں سے مقرر کرو وہ اگر صلح کرا دینی چاہیں گے تو خدا ان میں موافقت پیدا کردے گا کچھ شک نہیں کہ خدا سب کچھ جانتا اور سب باتوں سے خبردار ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@dxxix{اور خدا ہی کی عبادت کرو اور اس کے ساتھ کسی چیز کو شریک نہ بناؤ اور ماں باپ اور قرابت والوں اور یتیموں اور محتاجوں اور رشتہ دار ہمسائیوں اور اجنبی ہمسائیوں اور رفقائے پہلو (یعنی پاس بیٹھنے والوں) اور مسافروں اور جو لوگ تمہارے قبضے میں ہوں سب کے ساتھ احسان کرو کہ خدا (احسان کرنے والوں کو دوست رکھتا ہے اور) تکبر کرنے والے بڑائی مارنے والے کو دوست نہیں رکھتا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@dxxx{جو خود بھی بخل کریں اور لوگوں کو بھی بخل سکھائیں اور جو (مال) خدا نے ان کو اپنے فضل سے عطا فرمایا ہے اسے چھپا چھپا کے رکھیں اور ہم نے ناشکروں کے لئے ذلت کا عذاب تیار کر رکھا ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@dxxxi{اور خرچ بھی کریں تو (خدا کے لئے نہیں بلکہ) لوگوں کے دکھانے کو اور ایمان نہ خدا پر لائیں اور نہ روز آخرت پر (ایسے لوگوں کو ساتھی شیطان ہے) اور جس کا ساتھی شیطان ہوا تو (کچھ شک نہیں کہ) وہ برا ساتھی ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@dxxxii{اور اگر یہ لوگ خدا پر اور روز قیامت پر ایمان لاتے اور جو کچھ خدا نے ان کو دیا تھا اس میں سے خرچ کرتے تو ان کا کیا نقصان ہوتا اور خدا ان کو خوب جانتا ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@dxxxiii{خدا کسی کی ذرا بھی حق تلفی نہیں کرتا اور اگر نیکی (کی) ہوگی تو اس کو دوچند کردے گا اور اپنے ہاں سے اجرعظیم بخشے گا\qt@no{40}}%
\qt@newcmd\qurantrans@ur@dxxxiv{بھلا اس دن کا کیا حال ہوگا جب ہم ہر امت میں سے احوال بتائے والے کو بلائیں گے اور تم کو ان لوگوں کا حال (بتانے کو) گواہ طلب کریں گے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@dxxxv{اس روز کافر اور پیغمبر کے نافرمان آرزو کریں گے کہ کاش ان کو زمین میں مدفون کرکے مٹی برابر کردی جاتی اور خدا سے کوئی بات چھپا نہیں سکیں گے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@dxxxvi{مومنو! جب تم نشے کی حالت میں ہو تو جب تک (ان الفاظ کو) جو منہ سے کہو سمجھنے (نہ) لگو نماز کے پاس نہ جاؤ اور جنابت کی حالت میں بھی (نماز کے پاس نہ جاؤ) جب تک کہ غسل (نہ) کرلو ہاں اگر بحالت سفر رستے چلے جارہے ہو اور پانی نہ ملنے کے سبب غسل نہ کرسکو تو تیمم کرکے نماز پڑھ لو) اور اگر تم بیمار ہو سفر میں ہو یا تم میں سے کوئی بیت الخلاء سے ہو کر آیا ہو یا تم عورتوں سے ہم بستر ہوئے ہو اور تمہیں پانی نہ ملے تو پاک مٹی لو اور منہ اور ہاتھوں پر مسح (کرکے تیمم) کرلو بےشک خدا معاف کرنے والا اور بخشنے والا ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@dxxxvii{بھلا تم نے ان لوگوں کو نہیں دیکھا جن کو کتاب سے حصہ دیا گیا تھا کہ وہ گمراہی کو خریدتے ہیں اور چاہتے ہیں کہ تم بھی رستے سے بھٹک جاؤ\qt@no{44}}%
\qt@newcmd\qurantrans@ur@dxxxviii{اور خدا تمہارے دشمنوں سے خوب واقف ہے اور خدا ہی کافی کارساز ہے اور کافی مددگار ہے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@dxxxix{اور یہ جو یہودی ہیں ان میں سے کچھ لوگ ایسے بھی ہیں کہ کلمات کو ان کے مقامات سے بدل دیتے ہیں اور کہتے ہیں کہ ہم نے سن لیا اور نہیں مانا اور سنیئے نہ سنوائے جاؤ اور زبان کو مروڑ کر اور دین میں طعن کی راہ سے (تم سے گفتگو) کے وقت راعنا کہتے ہیں اور اگر (یوں) کہتے ہیں کہ ہم نے سن لیا اور مان لیا اور (صرف) اسمع اور (راعنا کی جگہ) انظرنا (کہتے) تو ان کے حق میں بہتر ہوتا اور بات بھی بہت درست ہوتی لیکن خدان نے ان کے کفر کے سبب ان پر لعنت کر رکھی ہے تو یہ کچھ تھوڑے ہی ایمان لاتے ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@dxl{اے کتاب والو! قبل اس کے کہ ہم لوگوں کے مونہوں کو بگاڑ کر ان کی پیٹھ کی طرف پھیر دیں یا ان پر اس طرح لعنت کریں جس طرح ہفتے والوں پر کی تھی ہماری نازل کی ہوئی کتاب پر جو تمہاری کتاب کی بھی تصدیق کرتی ہے ایمان لے آؤ اور خدا نے جو حکم فرمایا سو (سمجھ لو کہ) ہوچکا\qt@no{47}}%
\qt@newcmd\qurantrans@ur@dxli{خدا اس گناہ کو نہیں بخشے گا کہ کسی کو اس کا شریک بنایا جائے اور اس کے سوا اور گناہ جس کو چاہے معاف کردے اور جس نے خدا کا شریک مقرر کیا اس نے بڑا بہتان باندھا\qt@no{48}}%
\qt@newcmd\qurantrans@ur@dxlii{کیا تم نے ان لوگوں کو نہیں دیکھا جو اپنے تئیں پاکیزہ کہتے ہیں (نہیں) بلکہ خدا ہی جس کو چاہتا ہے پاکیزہ کرتا ہے اور ان پر دھاگے کے برابر بھی ظلم نہیں ہوگا\qt@no{49}}%
\qt@newcmd\qurantrans@ur@dxliii{دیکھو یہ خدا پر کیسا جھوٹ (طوفان) باندھتے ہیں اور یہی گناہ صریح کافی ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@dxliv{بھلا تم نے ان لوگوں کو نہیں دیکھا جن کو کتاب سے حصہ دیا گیا ہے کہ بتوں اور شیطان کو مانتے ہیں اور کفار کے بارے میں کہتے ہیں کہ یہ لوگ مومنوں کی نسبت سیدھے رستے پر ہیں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@dxlv{یہی لوگ ہیں جن پر خدا نے لعنت کی ہے اور جس پر خدا لعنت کرے تو تم اس کا کسی کو مددگار نہ پاؤ گے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@dxlvi{کیا ان کے پاس بادشاہی کا کچھ حصہ ہے تو لوگوں کو تل برابر بھی نہ دیں گے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@dxlvii{یا جو خدا نے لوگوں کو اپنے فضل سے دے رکھا ہے اس کا حسد کرتے ہیں تو ہم نے خاندان ابراہیم ؑ کو کتاب اور دانائی عطا فرمائی تھی اور سلطنت عظیم بھی بخشی تھی\qt@no{54}}%
\qt@newcmd\qurantrans@ur@dxlviii{پھر لوگوں میں سے کسی نے تو اس کتاب کو مانا اور کوئی اس سے رکا (اور ہٹا) رہا تو نہ ماننے والوں (کے جلانے) کو دوزخ کی جلتی ہوئی آگ کافی ہے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@dxlix{جن لوگوں نے ہماری آیتوں سے کفر کیا ان کو ہم عنقریب آگ میں داخل کریں گے جب ان کی کھالیں گل (اور جل) جائیں گی تو ہم اور کھالیں بدل دیں گے تاکہ (ہمیشہ) عذاب (کا مزہ چکھتے) رہیں بےشک خدا غالب حکمت والا ہے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@dl{اور جو ایمان لائے اور نیک عمل کرتے رہے ان کو ہم بہشتوں میں داخل کریں گے جن کے نیچے نہریں بہہ رہی ہیں وہ ان میں ہمیشہ ہمیشہ رہیں گے وہاں ان کے لئے پاک بیبیاں ہیں اور ان کو ہم گھنے سائے میں داخل کریں گے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@dli{خدا تم کو حکم دیتا ہے کہ امانت والوں کی امانتیں ان کے حوالے کردیا کرو اور جب لوگوں میں فیصلہ کرنے لگو تو انصاف سے فیصلہ کیا کرو خدا تمہیں بہت خوب نصیحت کرتا ہے بےشک خدا سنتا اور دیکھتا ہے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@dlii{مومنو! خدا اور اس کے رسول کی فرمانبرداری کرو اور جو تم میں سے صاحب حکومت ہیں ان کی بھی اور اگر کسی بات میں تم میں اختلاف واقع ہو تو اگر خدا اور روز آخرت پر ایمان رکھتے ہو تو اس میں خدا اور اس کے رسول (کے حکم) کی طرف رجوع کرو یہ بہت اچھی بات ہے اور اس کا مآل بھی اچھا ہے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@dliii{کیا تم نے ان لوگوں کو نہیں دیکھا جو دعویٰ تو یہ کرتے ہیں کہ جو (کتاب) تم پر نازل ہوئی اور جو (کتابیں) تم سے پہلے نازل ہوئیں ان سب پر ایمان رکھتے ہیں اور چاہتے یہ ہیں کہ اپنا مقدمہ ایک سرکش کے پاس لے جا کر فیصلہ کرائیں حالانکہ ان کو حکم دیا گیا تھا کہ اس سے اعتقاد نہ رکھیں اور شیطان (تو یہ) چاہتا ہے کہ ان کو بہکا کر رستے سے دور ڈال دے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@dliv{اور جب ان سے کہا جاتا ہے کہ جو حکم خدا نے نازل فرمایا ہے اس کی طرف (رجوع کرو) اور پیغمبر کی طرف آؤ تو تم منافقوں کو دیکھتے ہو کہ تم سے اعراض کرتے اور رکے جاتے ہیں\qt@no{61}}%
\qt@newcmd\qurantrans@ur@dlv{تو کیسی (ندامت کی) بات ہے کہ جب ان کے اعمال (کی شامت سے) ان پر کوئی مصیبت واقع ہوتی ہے تو تمہارے پاس بھاگے آتے ہیں اور قسمیں کھاتے ہیں کہ والله ہمارا مقصود تو بھلائی اور موافقت تھا\qt@no{62}}%
\qt@newcmd\qurantrans@ur@dlvi{ان لوگوں کے دلوں میں جو کچھ ہے خدا اس کو خوب جانتا ہے تم ان (کی باتوں) کو کچھ خیال نہ کرو اور انہیں نصیحت کرو اور ان سے ایسی باتیں کہو جو ان کے دلوں میں اثر کر جائیں\qt@no{63}}%
\qt@newcmd\qurantrans@ur@dlvii{اور ہم نے جو پیغمبر بھیجا ہے اس لئے بھیجا ہے کہ خدا کے فرمان کے مطابق اس کا حکم مانا جائے اور یہ لوگ جب اپنے حق میں ظلم کر بیٹھے تھے اگر تمہارے پاس آتے اور خدا سے بخشش مانگتے اور رسول (خدا) بھی ان کے لئے بخشش طلب کرتے تو خدا کو معاف کرنے والا (اور) مہربان پاتے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@dlviii{تمہارے پروردگار کی قسم یہ لوگ جب تک اپنے تنازعات میں تمہیں منصف نہ بنائیں اور جو فیصلہ تم کردو اس سے اپنے دل میں تنگ نہ ہوں بلکہ اس کو خوشی سے مان لیں تب تک مومن نہیں ہوں گے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@dlix{اور اگر ہم انہیں حکم دیتے کہ اپنے آپ کو قتل کر ڈالو یا اپنے گھر چھوڑ کر نکل جاؤ تو ان میں سے تھوڑے ہی ایسا کرتے اور اگر یہ اس نصیحت پر کاربند ہوتے جو ان کو کی جاتی ہے تو ان کے حق میں بہتر اور (دین میں) زیادہ ثابت قدمی کا موجب ہوتا\qt@no{66}}%
\qt@newcmd\qurantrans@ur@dlx{اور ہم ان کو اپنے ہاں سے اجر عظیم بھی عطا فرماتے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@dlxi{اور سیدھا رستہ بھی دکھاتے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@dlxii{اور جو لوگ خدا اور اس کے رسول کی اطاعت کرتے ہیں وہ (قیامت کے روز) ان لوگوں کے ساتھ ہوں گے جن پر خدا نے بڑا فضل کیا یعنی انبیاء اور صدیق اور شہید اور نیک لوگ اور ان لوگوں کی رفاقت بہت ہی خوب ہے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@dlxiii{یہ خدا کا فضل ہے اور خدا جاننے والا کافی ہے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@dlxiv{مومنو! (جہاد کے لئے) ہتھیار لے لیا کرو پھر یا تو جماعت جماعت ہو کر نکلا کرو یا سب اکھٹے کوچ کیا کرو\qt@no{71}}%
\qt@newcmd\qurantrans@ur@dlxv{اور تم میں کوئی ایسا بھی ہے کہ (عمداً) دیر لگاتا ہے۔ پھر اگر تم پر کوئی مصیبت پڑ جائے تو کہتا ہے کہ خدا نے مجھ پر بڑی مہربانی کی کہ میں ان میں موجود نہ تھا\qt@no{72}}%
\qt@newcmd\qurantrans@ur@dlxvi{اور اگر خدا تم پر فضل کرے تو اس طرح سے کہ گویا تم میں اس میں دوستی تھی ہی نہیں (کہ افسوس کرتا اور) کہتا ہے کہ کاش میں بھی ان کے ساتھ ہوتا تو مقصد عظیم حاصل کرتا\qt@no{73}}%
\qt@newcmd\qurantrans@ur@dlxvii{تو جو لوگ آخرت (کو خریدتے اور اس) کے بدلے دنیا کی زندگی کو بیچنا چاہتے ہیں اُن کو چاہیئے کہ خدا کی راہ میں جنگ کریں اور جو شخص خدا کی راہ میں جنگ کرے اور شہید ہوجائے یا غلبہ پائے ہم عنقریب اس کو بڑا ثواب دیں گے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@dlxviii{اور تم کو کیا ہوا ہے کہ خدا کی راہ میں اور اُن بےبس مردوں اور عورتوں اور بچوں کی خاطر نہیں لڑتے جو دعائیں کیا کرتے ہیں کہ اے پروردگار ہم کو اس شہر سے جس کے رہنے والے ظالم ہیں نکال کر کہیں اور لے جا۔ اور اپنی طرف سے کسی کو ہمارا حامی بنا۔ اور اپنی ہی طرف سے کسی کو ہمارا مددگار مقرر فرما\qt@no{75}}%
\qt@newcmd\qurantrans@ur@dlxix{جو مومن ہیں وہ تو خدا کے لئے لڑتے ہیں اور جو کافر ہیں وہ بتوں کے لئے لڑتے ہیں سو تم شیطان کے مددگاروں سے لڑو۔ (اور ڈرو مت) کیونکہ شیطان کا داؤ بودا ہوتا ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@dlxx{بھلا تم نے ان لوگوں کو نہیں دیکھا جن کو (پہلے یہ) حکم دیا گیا تھا کہ اپنے ہاتھوں کو (جنگ سے) روکے رہو اور نماز پڑھتے رہو اور زکوٰة دیتے رہو پھر جب ان پر جہاد فرض کردیا گیا تو بعض لوگ ان میں سے لوگوں سے یوں ڈرنے لگے جیسے خدا سے ڈرا کرتے ہیں بلکہ اس سے بھی زیادہ اور بڑبڑانے لگے کہ اے خدا تو نے ہم پر جہاد (جلد) کیوں فرض کردیا تھوڑی مدت اور ہمیں کیوں مہلت نہ دی (اے پیغمبر ان س) ے کہہ دو کہ دنیا کا فائدہ بہت تھوڑا ہے اور بہت اچھی چیز تو پرہیزگار کے لئے (نجات) آخرت ہے اور تم پر دھاگے برابر بھی ظلم نہیں کیا جائے گا\qt@no{77}}%
\qt@newcmd\qurantrans@ur@dlxxi{اے جہاد سے ڈرنے والو) تم کہیں رہو موت تو تمہیں آ کر رہے گی خواہ بڑے بڑے محلوں میں رہو اور ان لوگوں کو اگر کوئی فائدہ پہنچتا ہے تو کہتے ہیں یہ خدا کی طرف سے ہے اور اگر کوئی گزند پہنچتا ہے تو (اے محمدﷺ تم سے) کہتے ہیں کہ یہ گزند آپ کی وجہ سے (ہمیں پہنچا) ہے کہہ دو کہ (رنج وراحت) سب الله ہی کی طرف سے ہے ان لوگوں کو کیا ہوگیا ہے کہ بات بھی نہیں سمجھ سکتے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@dlxxii{اے (آدم زاد) تجھ کو جو فائدہ پہنچے وہ خدا کی طرف سے ہے اور جو نقصان پہنچے وہ تیری ہی (شامت اعمال) کی وجہ سے ہے اور (اے محمدﷺ) ہم نے تم کو لوگوں (کی ہدایت) کے لئے پیغمبر بنا کر بھیجا ہے اور (اس بات کا) خدا ہی گواہ کافی ہے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@dlxxiii{جو شخص رسول کی فرمانبرداری کرے گا تو بےشک اس نے خدا کی فرمانبرداری کی اور جو نافرمانی کرے گا تو اے پیغمبر تمہیں ہم نے ان کا نگہبان بنا کر نہیں بھیجا\qt@no{80}}%
\qt@newcmd\qurantrans@ur@dlxxiv{اور یہ لوگ منہ سے تو کہتے ہیں کہ (آپ کی) فرمانبرداری (دل سے منظور ہے) لیکن جب تمہارے پاس سے چلے جاتے ہیں تو ان میں سے بعض لوگ رات کو تمہاری باتوں کے خلاف مشورے کرتے ہیں اور جو مشورے یہ کرتے ہیں خدا ان کو لکھ لیتا ہے تو ان کا کچھ خیال نہ کرو اور خدا پر بھروسہ رکھو اور خدا ہی کافی کارساز ہے\qt@no{81}}%
\qt@newcmd\qurantrans@ur@dlxxv{بھلا یہ قرآن میں غور کیوں نہیں کرتے؟ اگر یہ خدا کے سوا کسی اور کا (کلام) ہوتا تو اس میں (بہت سا) اختلاف پاتے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@dlxxvi{اور جب ان کے پاس امن یا خوف کی کوئی خبر پہنچتی ہے تو اس کو مشہور کردیتے ہیں اور اگر اس کو پیغمبر اور اپنے سرداروں کے پاس پہنچاتے تو تحقیق کرنے والے اس کی تحقیق کر لیتے اور اگر تم پر خدا کا فضل اور اس کی مہربانی نہ ہوتی تو چند اشخاص کے سوا سب شیطان کے پیرو ہوجاتے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@dlxxvii{تو (اے محمدﷺ) تم خدا کی راہ میں لڑو تم اپنے سوا کسی کے ذمہ دار نہیں اور مومنوں کو بھی ترغیب دو قریب ہے کہ خدا کافروں کی لڑائی کو بند کردے اور خدا لڑائی کے اعتبار سے بہت سخت ہے اور سزا کے لحاظ سے بھی بہت سخت ہے\qt@no{84}}%
\qt@newcmd\qurantrans@ur@dlxxviii{جو شخص نیک بات کی سفارش کرے تو اس کو اس (کے ثواب) میں سے حصہ ملے گا اور جو بری بات کی سفارش کرے اس کو اس (کے عذاب) میں سے حصہ ملے گا اور خدا ہر چیز پر قدرت رکھتا ہے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@dlxxix{اور جب تم کو کوئی دعا دے تو (جواب میں) تم اس سے بہتر (کلمے) سے (اسے) دعا دو یا انہیں لفظوں سے دعا دو بےشک خدا ہر چیز کا حساب لینے والا ہے\qt@no{86}}%
\qt@newcmd\qurantrans@ur@dlxxx{خدا (وہ معبود برحق ہے کہ) اس کے سوا کوئی عبادت کے لائق نہیں وہ قیامت کے دن تم سب کو ضرور جمع کرے گا اور خدا سے بڑھ کر بات کا سچا کون ہے؟\qt@no{87}}%
\qt@newcmd\qurantrans@ur@dlxxxi{تو کیا سبب ہے کہ تم منافقوں کے بارے میں دو گروہ ہو رہے ہو حالانکہ خدا نے ان کو ان کے کرتوتوں کے سبب اوندھا کردیا ہے کیا تم چاہتے ہو کہ جس شخص کو خدا نے گمراہ کردیا ہے اس کو رستے پر لے آؤ اور جس شخص کو خدا گمراہ کردے تو اس کے لئے کبھی بھی رستہ نہیں پاؤ گے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@dlxxxii{وہ تو یہی چاہتے ہیں کہ جس طرح وہ خود کافر ہیں (اسی طرح) تم بھی کافر ہو کر (سب) برابر ہوجاؤ تو جب تک وہ خدا کی راہ میں وطن نہ چھوڑ جائیں ان میں سے کسی کو دوست نہ بنانا اگر (ترک وطن کو) قبول نہ کریں تو ان کو پکڑ لو اور جہاں پاؤ قتل کردو اور ان میں سے کسی کو اپنا رفیق اور مددگار نہ بناؤ\qt@no{89}}%
\qt@newcmd\qurantrans@ur@dlxxxiii{مگر جو لوگ ایسے لوگوں سے جا ملے ہوں جن میں اور تم میں (صلح کا) عہد ہو یا اس حال میں کہ ان کے دل تمہارے ساتھ یا اپنی قوم کے ساتھ لڑنے سے رک گئے ہوں تمہارے پاس آجائیں (تو احتراز ضروری نہیں) اور اگر خدا چاہتا تو ان کو تم پر غالب کردیتا تو وہ تم سے ضرور لڑتے پھر اگر وہ تم سے (جنگ کرنے سے) کنارہ کشی کریں اور لڑیں نہیں اور تمہاری طرف صلح (کا پیغام) بھیجیں تو خدا نے تمہارے لئے ان پر (زبردستی کرنے کی) کوئی سبیل مقرر نہیں کی\qt@no{90}}%
\qt@newcmd\qurantrans@ur@dlxxxiv{تم کچھ اور لوگ ایسے بھی پاؤ گے جو یہ چاہتے ہیں کہ تم سے بھی امن میں رہیں اور اپنی قوم سے بھی امن میں رہیں لیکن فتنہ انگیزی کو بلائے جائیں تو اس میں اوندھے منہ گر پڑیں تو ایسے لوگ اگر تم سے (لڑنے سے) کنارہ کشی نہ کریں اور نہ تمہاری طرف (پیغام) صلح بھیجیں اور نہ اپنے ہاتھوں کو روکیں تو ان کو پکڑ لو اور جہاں پاؤ قتل کردو ان لوگوں کے مقابلے میں ہم نے تمہارے لئے سند صریح مقرر کردی ہے\qt@no{91}}%
\qt@newcmd\qurantrans@ur@dlxxxv{اور کسی مومن کو شایان نہیں کہ مومن کو مار ڈالے مگر بھول کر اور جو بھول کر بھی مومن کو مار ڈالے تو (ایک تو) ایک مسلمان غلام آزاد کردے اور (دوسرے) مقتول کے وارثوں کو خون بہا دے ہاں اگر وہ معاف کردیں (تو ان کو اختیار ہے) اگر مقتول تمہارے دشمنوں کی جماعت میں سے ہو اور وہ خود مومن ہو تو صرف ایک مسلمان غلام آزاد کرنا چاہیئے اور اگر مقتول ایسے لوگوں میں سے ہو جن میں اور تم میں صلح کا عہد ہو تو وارثان مقتول کو خون بہا دینا اور ایک مسلمان غلام آزاد کرنا چاہیئے اور جس کو یہ میسر نہ ہو وہ متواتر دو مہینے کے روزے رکھے یہ (کفارہ) خدا کی طرف سے (قبول) توبہ (کے لئے) ہے اور خدا (سب کچھ) جانتا اور بڑی حکمت والا ہے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@dlxxxvi{اور جو شخص مسلمان کو قصداً مار ڈالے گا تو اس کی سزا دوزخ ہے جس میں وہ ہمیشہ (جلتا) رہے گا اور خدا اس پر غضبناک ہوگا اور اس پر لعنت کرے گا اور ایسے شخص کے لئے اس نے بڑا (سخت) عذاب تیار کر رکھا ہے\qt@no{93}}%
\qt@newcmd\qurantrans@ur@dlxxxvii{مومنو! جب تم خدا کی راہ میں باہر نکلو کرو تو تحقیق سے کام لیا کرو اور جو شخص تم سے سلام علیک کرے اس سے یہ نہ کہو کہ تم مومن نہیں اور اس سے تمہاری غرض یہ ہو کہ دنیا کی زندگی کا فائدہ حاصل کرو سو خدا کے نزدیک بہت سے غنیمتیں ہیں تم بھی تو پہلے ایسے ہی تھے پھر خدا نے تم پر احسان کیا تو (آئندہ) تحقیق کرلیا کرو اور جو عمل تم کرتے ہو خدا کو سب کی خبر ہے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@dlxxxviii{جو مسلمان (گھروں میں) بیٹھ رہتے (اور لڑنے سے جی چراتے) ہیں اور کوئی عذر نہیں رکھتے وہ اور جو خدا کی راہ میں اپنے مال اور جان سے لڑتے ہیں وہ دونوں برابر نہیں ہو سکتے خدا نے مال اور جان سے جہاد کرنے والوں کو بیٹھ رہنے والوں پر درجے میں فضیلت بخشی ہے اور (گو) نیک وعدہ سب سے ہے لیکن اجر عظیم کے لحاظ سے خدا نے جہاد کرنے والوں کو بیٹھ رہنے والوں پر کہیں فضیلت بخشی ہے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@dlxxxix{یعنی) خدا کی طرف سے درجات میں اور بخشش میں اور رحمت میں اور خدا بڑا بخشنے والا (اور) مہربان ہے\qt@no{96}}%
\qt@newcmd\qurantrans@ur@dxc{اور جو لوگ اپنی جانوں پر ظلم کرتے ہیں جب فرشتے ان کی جان قبض کرنے لگتے ہیں تو ان سے پوچھتے ہیں کہ تم کس حال میں تھے وہ کہتے ہیں کہ ہم ملک میں عاجز وناتواں تھے فرشتے کہتے ہیں کیا خدا کا ملک فراخ نہیں تھا کہ تم اس میں ہجرت کر جاتے ایسے لوگوں کا ٹھکانہ دوزخ ہے اور وہ بری جگہ ہے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@dxci{ہاں جو مرد اور عورتیں اور بچے بےبس ہیں کہ نہ تو کوئی چارہ کر سکتے ہیں اور نہ رستہ جانتے ہیں\qt@no{98}}%
\qt@newcmd\qurantrans@ur@dxcii{قریب ہے کہ خدا ایسوں کو معاف کردے اور خدا معاف کرنے والا (اور) بخشنے والا ہے\qt@no{99}}%
\qt@newcmd\qurantrans@ur@dxciii{اور جو شخص خدا کی راہ میں گھر بار چھوڑ جائے وہ زمین میں بہت سی جگہ اور کشائش پائے گا اور جو شخص خدا اور رسول کی طرف ہجرت کرکے گھر سے نکل جائے پھر اس کو موت آپکڑے تو اس کا ثواب خدا کے ذمے ہوچکا اور خدا بخشنے والا اور مہربان ہے\qt@no{100}}%
\qt@newcmd\qurantrans@ur@dxciv{اور جب تم سفر کو جاؤ تو تم پر کچھ گناہ نہیں کہ نماز کو کم کرکے پڑھو بشرطیکہ تم کو خوف ہو کہ کافر لوگ تم کو ایذا دیں گے بےشک کافر تمہارے کھلے دشمن ہیں\qt@no{101}}%
\qt@newcmd\qurantrans@ur@dxcv{اور (اے پیغمبر) جب تم ان (مجاہدین کے لشکر) میں ہو اور ان کو نماز پڑھانے لگو تو چاہیئے کہ ان کی ایک جماعت تمہارے ساتھ مسلح ہو کر کھڑی رہے جب وہ سجدہ کرچکیں تو پرے ہو جائیں پھر دوسری جماعت جس نے نماز نہیں پڑھی (ان کی جگہ) آئے اور ہوشیار اور مسلح ہو کر تمہارے ساتھ نماز ادا کرے کافر اس گھات میں ہیں کہ تم ذرا اپنے ہتھیاروں اور سامان سے غافل ہو جاؤ تو تم پر یکبارگی حملہ کردیں اگر تم بارش کے سبب تکلیف میں یا بیمار ہو تو تم پر کچھ گناہ نہیں کہ ہتھیار اتار رکھو مگر ہوشیار ضرور رہنا خدا نے کافروں کے لئے ذلت کا عذاب تیار کر رکھا ہے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@dxcvi{پھر جب تم نماز تمام کرچکو تو کھڑے اور بیٹھے اور لیٹے (ہر حالت میں) خدا کو یاد کرو پھر جب خوف جاتا رہے تو (اس طرح سے) نماز پڑھو (جس طرح امن کی حالت میں پڑھتے ہو) بےشک نماز کا مومنوں پر اوقات (مقررہ) میں ادا کرنا فرض ہے\qt@no{103}}%
\qt@newcmd\qurantrans@ur@dxcvii{اور کفار کا پیچھا کرنے میں سستی نہ کرنا اگر تم بےآرام ہوتے ہو تو جس طرح تم بےآرام ہوتے ہو اسی طرح وہ بھی بےآرام ہوتے ہیں اور تم خدا سے ایسی ایسی امیدیں رکھتے ہو جو وہ نہیں رکھ سکتے اور خدا سب کچھ جانتا اور (بڑی) حکمت والا ہے\qt@no{104}}%
\qt@newcmd\qurantrans@ur@dxcviii{اے پیغمبر) ہم نے تم پر سچی کتاب نازل کی ہے تاکہ خدا کی ہدایت کے مطابق لوگوں کے مقدمات میں فیصلہ کرو اور (دیکھو) دغابازوں کی حمایت میں کبھی بحث نہ کرنا\qt@no{105}}%
\qt@newcmd\qurantrans@ur@dxcix{اور خدا سے بخشش مانگنا بےشک خدا بخشنے والا مہربان ہے\qt@no{106}}%
\qt@newcmd\qurantrans@ur@dc{اور لوگ اپنے ہم جنسوں کی خیانت کرتے ہیں ان کی طرف سے بحث نہ کرنا کیونکہ خدا خائن اور مرتکب جرائم کو دوست نہیں رکھتا\qt@no{107}}%
\qt@newcmd\qurantrans@ur@dci{یہ لوگوں سے تو چھپتے ہیں اور خدا سے نہیں چھپتے حالانکہ جب وہ راتوں کو ایسی باتوں کے مشورے کیا کرتے ہیں جن کو وہ پسند نہیں کرتا ان کے ساتھ ہوا کرتا ہے اور خدا ان کے (تمام) کاموں پر احاطہ کئے ہوئے ہے\qt@no{108}}%
\qt@newcmd\qurantrans@ur@dcii{بھلا تم لوگ دنیا کی زندگی میں تو ان کی طرف سے بحث کر لیتے ہو قیامت کو ان کی طرف سے خدا کے ساتھ کون جھگڑے گا اور کون ان کا وکیل بنے گا؟\qt@no{109}}%
\qt@newcmd\qurantrans@ur@dciii{اور جو شخص کوئی برا کام کر بیٹھے یا اپنے حق میں ظلم کرلے پھر خدا سے بخشش مانگے تو خدا کو بخشنے والا اور مہربان پائے گا\qt@no{110}}%
\qt@newcmd\qurantrans@ur@dciv{اور جو کوئی گناہ کرتا ہے تو اس کا وبال اسی پر ہے اور خدا جاننے والا (اور) حکمت والا ہے\qt@no{111}}%
\qt@newcmd\qurantrans@ur@dcv{اور جو شخص کوئی قصور یا گناہ تو خود کرے لیکن اس سے کسی بےگناہ کو مہتم کردے تو اس نے بہتان اور صریح گناہ کا بوجھ اپنے سر پر رکھا\qt@no{112}}%
\qt@newcmd\qurantrans@ur@dcvi{اور اگر تم پر خدا کا فضل اور مہربانی نہ ہوتی تو ان میں سے ایک جماعت تم کو بہکانے کا قصد کر ہی چکی تھی اور یہ اپنے سوا (کسی کو) بہکا نہیں سکتے اور نہ تمہارا کچھ بگاڑ سکتے ہیں اور خدا نے تم پر کتاب اور دانائی نازل فرمائی ہے اور تمہیں وہ باتیں سکھائی ہیں جو تم جانتے نہیں تھے اور تم پر خدا کا بڑا فضل ہے\qt@no{113}}%
\qt@newcmd\qurantrans@ur@dcvii{ان لوگوں کی بہت سی مشورتیں اچھی نہیں ہاں (اس شخص کی مشورت اچھی ہوسکتی ہے) جو خیرات یا نیک بات یا لوگوں میں صلح کرنے کو کہے اور جو ایسے کام خدا کی خوشنودی حاصل کرنے کے لئے کرے گا تو ہم اس کو بڑا ثواب دیں گے\qt@no{114}}%
\qt@newcmd\qurantrans@ur@dcviii{اور جو شخص سیدھا رستہ معلوم ہونے کے بعد پیغمبر کی مخالف کرے اور مومنوں کے رستے کے سوا اور رستے پر چلے تو جدھر وہ چلتا ہے ہم اسے ادھر ہی چلنے دیں گے اور (قیامت کے دن) جہنم میں داخل کریں گے اور وہ بری جگہ ہے\qt@no{115}}%
\qt@newcmd\qurantrans@ur@dcix{خدا اس کے گناہ کو نہیں بخشے گا کہ کسی کو اس کا شریک بنایا جائے اور اس کے سوا (اور گناہ) جس کو چاہیے گا بخش دے گا۔ اور جس نے خدا کے ساتھ شریک بنایا وہ رستے سے دور جا پڑا\qt@no{116}}%
\qt@newcmd\qurantrans@ur@dcx{یہ جو خدا کے سوا پرستش کرتے ہیں تو عورتوں کی اور پکارتے ہیں تو شیطان کی سرکش ہی کو\qt@no{117}}%
\qt@newcmd\qurantrans@ur@dcxi{جس پر خدا نے لعنت کی ہے (جو خدا سے) کہنے لگا میں تیرے بندوں سے (غیر خدا کی نذر دلوا کر مال کا) ایک مقرر حصہ لے لیا کروں گا۔\qt@no{118}}%
\qt@newcmd\qurantrans@ur@dcxii{اور ان کو گمراہ کرتا اور امیدیں دلاتا ہروں گا اور یہ سکھاتا رہوں گا کہ جانوروں کے کان چیرتے رہیں اور (یہ بھی) کہتا رہوں گا کہ وہ خدا کی بنائی ہوئی صورتوں کو بدلتے رہیں اور جس شخص نے خدا کو چھوڑ کر شیطان کو دوست بنایا اور وہ صریح نقصان میں پڑ گیا\qt@no{119}}%
\qt@newcmd\qurantrans@ur@dcxiii{وہ ان کو وعدے دیتا رہا اور امیدیں دلاتا ہے اور جو کچھ شیطان انہیں وعدے دیتا ہے جو دھوکا ہی دھوکا ہے\qt@no{120}}%
\qt@newcmd\qurantrans@ur@dcxiv{ایسے لوگوں کا ٹھکانا جہنم ہے۔ اور وہ وہاں سے مخلصی نہیں پاسکیں گے\qt@no{121}}%
\qt@newcmd\qurantrans@ur@dcxv{اور جو لوگ ایمان لائے اور نیک کام کرتے رہے ان کو ہم بہشتوں میں داخل کریں گے جن کے نیچے نہریں جاری ہیں۔ ابدالآباد ان میں رہیں گے۔ یہ خدا کا سچا وعدہ ہے۔ اور خدا سے زیادہ بات کا سچا کون ہوسکتا ہے\qt@no{122}}%
\qt@newcmd\qurantrans@ur@dcxvi{نجات) نہ تو تمہاری آرزوؤں پر ہے اور نہ اہل کتاب کی آرزوؤں پر۔ جو شخص برے عمل کرے گا اسے اسی (طرح) کا بدلا دیا جائے گا اور وہ خدا کے سوا نہ کسی کو حمایتی پائے گا اور نہ مددگار\qt@no{123}}%
\qt@newcmd\qurantrans@ur@dcxvii{اور جو نیک کام کرے گا مرد ہو یا عورت اور وہ صاحب ایمان بھی ہوگا تو ایسے لوگ بہشت میں داخل ہوں گے اور ان کی تل برابر بھی حق تلفی نہ کی جائے گی\qt@no{124}}%
\qt@newcmd\qurantrans@ur@dcxviii{اور اس شخص سے کس کا دین اچھا ہوسکتا ہے جس نے حکم خدا کو قبول کیا اور وہ نیکوکار بھی ہے۔ اور ابراہیم کے دین کا پیرو ہے جو یکسوں (مسلمان) تھے اور خدا نے ابراہیم کو اپنا دوست بنایا تھا\qt@no{125}}%
\qt@newcmd\qurantrans@ur@dcxix{اور آسمان وزمین میں جو کچھ ہے سب خدا ہی کا ہے۔ اور خدا ہر چیز پر احاطے کئے ہوئے ہے\qt@no{126}}%
\qt@newcmd\qurantrans@ur@dcxx{اے پیغمبر) لوگ تم سے (یتیم) عورتوں کے بارے میں فتویٰ طلب کرتے ہیں۔ کہہ دو کہ خدا تم کو ان کے (ساتھ نکاح کرنے کے) معاملے میں اجازت دیتا ہے اور جو حکم اس کتاب میں پہلے دیا گیا ہے وہ ان یتیم عورتوں کے بارے میں ہے جن کو تم ان کا حق تو دیتے نہیں اور خواہش رکھتے ہو کہ ان کے ساتھ نکاح کرلو اور (نیز) بیچارے بیکس بچوں کے بارے میں۔ اور یہ (بھی حکم دیتا ہے) کہ یتیموں کے بارے میں انصاف پر قائم رہو۔ اور جو بھلائی تم کرو گے خدا اس کو جانتا ہے\qt@no{127}}%
\qt@newcmd\qurantrans@ur@dcxxi{اور اگر کسی عورت کو اپنے خاوند کی طرف سے زیادتی یا بےرغبتی کا اندیشہ ہو تم میاں بیوی پر کچھ گناہ نہیں کہ آپس میں کسی قرارداد پر صلح کرلیں۔ اور صلح خوب (چیز) ہے اور طبیعتیں تو بخل کی طرف مائل ہوتی ہیں اور اگر تم نیکوکاری اور پرہیزگاری کرو گے تو خدا تمہارے سب کاموں سے واقف ہے\qt@no{128}}%
\qt@newcmd\qurantrans@ur@dcxxii{اور تم خوا کتنا ہی چاہو عورتوں میں ہرگز برابری نہیں کرسکو گے تو ایسا بھی نہ کرنا کہ ایک ہی کی طرف ڈھل جاؤ اور دوسری کو (ایسی حالت میں) چھوڑ دو کہ گویا ادھر ہوا میں لٹک رہی ہے اور اگر آپس میں موافقت کرلو اور پرہیزگاری کرو تو خدا بخشنے والا مہربان ہے\qt@no{129}}%
\qt@newcmd\qurantrans@ur@dcxxiii{اور اگر میاں بیوی (میں موافقت نہ ہوسکے اور) ایک دوسرے سے جدا ہوجائیں تو خدا ہر ایک کو اپنی دولت سے غنی کردے گا اور خدا بڑی کشائش والا اور حکمت والا ہے\qt@no{130}}%
\qt@newcmd\qurantrans@ur@dcxxiv{اور جو کچھ آسمانوں اور جو کچھ زمین میں ہے سب خدا ہی کا ہے۔ اور جن لوگوں کو تم سے پہلے کتاب دی گئی تھی ان کو بھی اور (اے محمدﷺ) تم کو بھی ہم نے حکم تاکیدی کیا ہے کہ خدا سے ڈرتے رہو اور اگر کفر کرو گے تو (سمجھ رکھو کہ) جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے سب خدا ہی کا ہے۔ اور خدا بے پروا اور سزاوار حمدوثنا ہے\qt@no{131}}%
\qt@newcmd\qurantrans@ur@dcxxv{اور (پھر سن رکھو کہ) جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے سب خدا ہی کا ہے اور خدا کارساز کافی ہے\qt@no{132}}%
\qt@newcmd\qurantrans@ur@dcxxvi{لوگو! اگر وہ چاہے تو تم کو فنا کردے اور (تمہاری جگہ) اور لوگوں کو پیدا کردے۔اور خدا اس بات پر قادر ہے\qt@no{133}}%
\qt@newcmd\qurantrans@ur@dcxxvii{جو شخص دنیا (میں عملوں) کی جزا کا طالب ہو تو خدا کے پاس دنیا اور آخرت (دونوں) کے لئے اجر (موجود) ہیں۔ اور خدا سنتا دیکھتا ہے\qt@no{134}}%
\qt@newcmd\qurantrans@ur@dcxxviii{اے ایمان والو! انصاف پر قائم رہو اور خدا کے لئے سچی گواہی دو خواہ (اس میں) تمہارا یا تمہارےماں باپ اور رشتہ داروں کا نقصان ہی ہو۔ اگر کوئی امیر ہے یا فقیر تو خدا ان کا خیر خواہ ہے۔ تو تم خواہش نفس کے پیچھے چل کر عدل کو نہ چھوڑ دینا۔ اگر تم پیچیدا شہادت دو گے یا (شہادت سے) بچنا چاہو گے تو (جان رکھو) خدا تمہارے سب کاموں سے واقف ہے\qt@no{135}}%
\qt@newcmd\qurantrans@ur@dcxxix{مومنو! خدا پر اور اس کے رسول پر اور جو کتاب اس نے اپنی پیغمبر (آخرالزماں) پر نازل کی ہے اور جو کتابیں اس سے پہلے نازل کی تھیں سب پر ایمان لاؤ۔ اور جو شخص خدا اور اس کے فرشتوں اور اس کی کتابوں اور اس کے پیغمبروں اور روزقیامت سے انکار کرے وہ رستے سے بھٹک کر دور جا پڑا\qt@no{136}}%
\qt@newcmd\qurantrans@ur@dcxxx{جو لوگ ایمان لائے پھر کافر ہوگئے پھر ایمان لائے پھر کافر ہوگئے پھر کفر میں بڑھتے گئے ان کو خدا نہ تو بخشے گا اور نہ سیدھا رستہ دکھائے گا\qt@no{137}}%
\qt@newcmd\qurantrans@ur@dcxxxi{اے پیغمبر) منافقوں (یعنی دو رخے لوگوں) کو بشارت سناد دو کہ ان کے لئے دکھ دینے والا عذاب (تیار) ہے\qt@no{138}}%
\qt@newcmd\qurantrans@ur@dcxxxii{جو مومنوں کو چھوڑ کر کافروں کو دوست بناتے ہیں۔ کیا یہ ان کے ہاں عزت حاصل کرنا چاہتے ہیں تو عزت تو سب خدا ہی کی ہے\qt@no{139}}%
\qt@newcmd\qurantrans@ur@dcxxxiii{اور خدا نے تم (مومنوں) پر اپنی کتاب میں (یہ حکم) نازل فرمایا ہے کہ جب تم (کہیں) سنو کہ خدا کی آیتوں سے انکار ہورہا ہے اور ان کی ہنسی اڑائی جاتی ہے تو جب تک وہ لوگ اور باتیں (نہ) کرنے لگیں۔ ان کے پاس مت بیٹھو۔ ورنہ تم بھی انہیں جیسے ہوجاؤ گے۔ کچھ شک نہیں کہ خدا منافقوں اور کافروں سب کو دوزخ میں اکھٹا کرنے والا ہے\qt@no{140}}%
\qt@newcmd\qurantrans@ur@dcxxxiv{جو تم کو دیکھتے رہتے ہیں اگر خدا کی طرف سے تم کو فتح ملے تو کہتے ہیں کیا ہم تمہارے ساتھ نہ تھے۔ اور اگر کافروں کو (فتح) نصیب ہو تو (ان سے) کہتے ہیں کیا ہم تم پر غالب نہیں تھے اور تم کو مسلمانوں (کے ہاتھ) سے بچایا نہیں۔ تو خدا تم میں قیامت کے دن فیصلہ کردے گا۔ اور خدا کافروں کو مومنوں پر ہرگز غلبہ نہیں دے گا\qt@no{141}}%
\qt@newcmd\qurantrans@ur@dcxxxv{منافق (ان چالوں سے اپنے نزدیک) خدا کو دھوکا دیتے ہیں (یہ اس کو کیا دھوکا دیں گے) وہ انہیں کو دھوکے میں ڈالنے والا ہے اور جب یہ نماز کو کھڑے ہوتے ہیں تو سست اور کاہل ہو کر (صرف) لوگوں کے دکھانے کو اور خدا کی یاد ہی نہیں کرتے مگر بہت کم\qt@no{142}}%
\qt@newcmd\qurantrans@ur@dcxxxvi{بیچ میں پڑے لٹک رہے ہیں نہ ان کی طرف (ہوتے ہیں) نہ ان کی طرف اور جس کو خدا بھٹکائے تو اس کے لئے کبھی بھی رستہ نہ پاؤ گے\qt@no{143}}%
\qt@newcmd\qurantrans@ur@dcxxxvii{اے اہل ایمان! مومنوں کے سوا کافروں کو دوست نہ بناؤ کیا تم چاہتے ہو کہ اپنے اوپر خدا کا صریح الزام لو؟\qt@no{144}}%
\qt@newcmd\qurantrans@ur@dcxxxviii{کچھ شک نہیں کہ منافق لوگ دوزخ کے سب سے نیچے کے درجے میں ہوں گے۔ اور تم ان کا کسی کو مددگار نہ پاؤ گے\qt@no{145}}%
\qt@newcmd\qurantrans@ur@dcxxxix{ہاں جنہوں نے توبہ کی اور اپنی حالت کو درست کیا اور خدا (کی رسی) کو مضبوط پکڑا اور خاص خدا کے فرمانبردار ہوگئے تو ایسے لوگ مومنوں کے زمرے میں ہوں گے اور خدا عنقریب مومنوں کو بڑا ثواب دے گا\qt@no{146}}%
\qt@newcmd\qurantrans@ur@dcxl{اگر تم (خدا کے شکرگزار رہو اور (اس پر) ایمان لے آؤ تو خدا تم کو عذاب دے کر کیا کرے گا۔ اور خدا تو قدرشناس اور دانا ہے\qt@no{147}}%
\qt@newcmd\qurantrans@ur@dcxli{خدا اس بات کو پسند نہیں کرتا کہ کوئی کسی کو علانیہ برا کہے مگر وہ جو مظلوم ہو۔ اور خدا (سب کچھ) سنتا (اور) جانتا ہے\qt@no{148}}%
\qt@newcmd\qurantrans@ur@dcxlii{اگر تم لوگ بھلائی کھلم کھلا کرو گے یا چھپا کر یا برائی سے درگزر کرو گے تو خدا بھی معاف کرنے والا (اور) صاحب قدرت ہے\qt@no{149}}%
\qt@newcmd\qurantrans@ur@dcxliii{جو لوگ خدا سے اور اس کے پیغمبروں سے کفر کرتے ہیں اور خدا اور اس کے پیغمبروں میں فرق کرنا چاہتے ہیں اور کہتے ہیں کہ ہم بعض کو مانتے ہیں اور بعض کو نہیں مانتے اور ایمان اور کفر کے بیچ میں ایک راہ نکالنی چاہتے ہیں\qt@no{150}}%
\qt@newcmd\qurantrans@ur@dcxliv{وہ بلا اشتباہ کافر ہیں اور کافروں کے لئے ہم نے ذلت کا عذاب تیار کر رکھا ہے\qt@no{151}}%
\qt@newcmd\qurantrans@ur@dcxlv{اور جو لوگ خدا اور اس کے پیغمبروں پر ایمان لائے اور ان میں سے کسی میں فرق نہ کیا (یعنی سب کو مانا) ایسے لوگوں کو وہ عنقریب ان (کی نیکیوں) کے صلے عطا فرمائے گا اور خدا بخشنے والا مہربان ہے\qt@no{152}}%
\qt@newcmd\qurantrans@ur@dcxlvi{اے محمدﷺ) اہل کتاب تم سے درخواست کرتے ہیں کہ تم ان پر ایک (لکھی ہوئی) کتاب آسمان سے اتار لاؤ تو یہ موسیٰ سے اس سے بھی بڑی بڑی درخواستیں کرچکے ہیں (ان سے) کہتے تھے ہمیں خدا ظاہر (یعنی آنکھوں سے) دکھا دو سو ان کے گناہ کی وجہ سے ان کو بجلی نے آپکڑا۔ پھر کھلی نشانیاں آئے پیچھے بچھڑے کو (معبود) بنا بیٹھے تو اس سے بھی ہم نے درگزر کی۔ اور موسیٰ کو صریح غلبہ دیا\qt@no{153}}%
\qt@newcmd\qurantrans@ur@dcxlvii{اور ان سے عہد لینے کو ہم نے ان پر کوہ طور اٹھا کھڑا کیا اور انہیں حکم دیا کہ (شہر کے) دروازے میں (داخل ہونا تو) سجدہ کرتے ہوئے داخل ہونا اور یہ بھی حکم دیا کہ ہفتے کے دن (مچھلیاں پکڑنے) میں تجاویز (یعنی حکم کے خلاف) نہ کرنا۔ غرض ہم نے ان سے مضبوط عہد لیا\qt@no{154}}%
\qt@newcmd\qurantrans@ur@dcxlviii{لیکن انہوں نے عہد کو توڑ ڈالا) تو ان کے عہد توڑ دینے اور خدا کی آیتوں سے کفر کرنے اور انبیاء کو ناحق مار ڈالنے اور یہ کہنے کے سبب کہ ہمارے دلوں پر پردے (پڑے ہوئے) ہیں۔ (خدا نے ان کو مردود کردیا اور ان کے دلوں پر پردے نہیں ہیں) بلکہ ان کے کفر کے سبب خدا نے ان پر مہر کردی ہے تو یہ کم ہی ایمان لاتے ہیں\qt@no{155}}%
\qt@newcmd\qurantrans@ur@dcxlix{اور ان کے کفر کے سبب اور مریم پر ایک بہتان عظیم باندھنے کے سبب\qt@no{156}}%
\qt@newcmd\qurantrans@ur@dcl{اور یہ کہنے کے سبب کہ ہم نے مریم کے بیٹے عیسیٰ مسیح کو جو خدا کے پیغمبر (کہلاتے) تھے قتل کردیا ہے (خدا نے ان کو معلون کردیا) اور انہوں نے عیسیٰ کو قتل نہیں کیا اور نہ انہیں سولی پر چڑھایا بلکہ ان کو ان کی سی صورت معلوم ہوئی اور جو لوگ ان کے بارے میں اختلاف کرتے ہیں وہ ان کے حال سے شک میں پڑے ہوئے ہیں اور پیروئی ظن کے سوا ان کو اس کا مطلق علم نہیں۔ اور انہوں نے عیسیٰ کو یقیناً قتل نہیں کیا\qt@no{157}}%
\qt@newcmd\qurantrans@ur@dcli{بلکہ خدا نے ان کو اپنی طرف اٹھا لیا۔ اور خدا غالب اور حکمت والا ہے\qt@no{158}}%
\qt@newcmd\qurantrans@ur@dclii{اور کوئی اہل کتاب نہیں ہوگا مگر ان کی موت سے پہلے ان پر ایمان لے آئے گا۔ اور وہ قیامت کے دن ان پر گواہ ہوں گے\qt@no{159}}%
\qt@newcmd\qurantrans@ur@dcliii{تو ہم نے یہودیوں کے ظلموں کے سبب (بہت سی) پاکیزہ چیزیں جو ان کو حلال تھیں ان پر حرام کردیں اور اس سبب سے بھی کہ وہ اکثر خدا کے رستے سے (لوگوں کو) روکتے تھے\qt@no{160}}%
\qt@newcmd\qurantrans@ur@dcliv{اور اس سبب سے بھی کہ باوجود منع کئے جانے کے سود لیتے تھے اور اس سبب سے بھی کہ لوگوں کا مال ناحق کھاتے تھے۔ اور ان میں سے جو کافر ہیں ان کے لئے ہم نے درد دینے والا عذاب تیار کر رکھا ہے\qt@no{161}}%
\qt@newcmd\qurantrans@ur@dclv{مگر جو لوگ ان میں سے علم میں پکے ہیں اور جو مومن ہیں وہ اس (کتاب) پر جو تم پر نازل ہوئی اور جو (کتابیں) تم سے پہلے نازل ہوئیں (سب پر) ایمان رکھتے ہیں اور نماز پڑھتے ہیں اور زکوٰة دیتے ہیں اور خدا اور روز آخرت کو مانتے ہیں۔ ان کو ہم عنقریب اجر عظیم دیں گے\qt@no{162}}%
\qt@newcmd\qurantrans@ur@dclvi{اے محمدﷺ) ہم نے تمہاری طرف اسی طرح وحی بھیجی ہے جس طرح نوح اور ان سے پچھلے پیغمبروں کی طرف بھیجی تھی۔ اور ابراہیم اور اسمعیل اور اسحاق اور یعقوب اور اولاد یعقوب اور عیسیٰ اور ایوب اور یونس اور ہارون اور سلیمان کی طرف بھی ہم نے وحی بھیجی تھی اور داؤد کو ہم نے زبور بھی عنایت کی تھی\qt@no{163}}%
\qt@newcmd\qurantrans@ur@dclvii{اور بہت سے پیغمبر ہیں جن کے حالات ہم تم سے پیشتر بیان کرچکے ہیں اور بہت سے پیغمبر ہیں جن کے حالات تم سے بیان نہیں کئے۔ اور موسیٰ سے تو خدا نے باتیں بھی کیں\qt@no{164}}%
\qt@newcmd\qurantrans@ur@dclviii{سب) پیغمبروں کو (خدا نے) خوشخبری سنانے والے اور ڈرانے والے (بنا کر بھیجا تھا) تاکہ پیغمبروں کے آنے کے بعد لوگوں کو خدا پر الزام کا موقع نہ رہے اور خدا غالب حکمت والا ہے\qt@no{165}}%
\qt@newcmd\qurantrans@ur@dclix{لیکن خدا نے جو (کتاب) تم پر نازل کی ہے اس کی نسبت خدا گواہی دیتا ہے کہ اس نے اپنے علم سے نازل کی ہے اور فرشتے بھی گواہی دیتے ہیں۔ اور گواہ تو خدا ہی کافی ہے\qt@no{166}}%
\qt@newcmd\qurantrans@ur@dclx{جن لوگوں نے کفر کیا اور (لوگوں کو) خدا کے رستے سے روکا وہ رستے سے بھٹک کر دور جا پڑے\qt@no{167}}%
\qt@newcmd\qurantrans@ur@dclxi{جو لوگ کافر ہوئے اور ظلم کرتے رہے خدا ان کو بخشنے والا نہیں اور نہ انہیں رستہ ہی دکھائے گا\qt@no{168}}%
\qt@newcmd\qurantrans@ur@dclxii{ہاں دوزخ کا رستہ جس میں وہ ہمیشہ (جلتے) رہیں گے۔ اور یہ (بات) خدا کو آسان ہے\qt@no{169}}%
\qt@newcmd\qurantrans@ur@dclxiii{لوگو! خدا کے پیغمبر تمہارے پاس تمہارے پروردگار کی طرف سے حق بات لے کر آئے ہیں تو (ان پر) ایمان لاؤ (یہی) تمہارے حق میں بہتر ہے۔ اور اگر کفر کرو گے تو (جان رکھو کہ) جو کچھ آسمانوں اور زمین میں ہے سب خداہی کا ہے اور خدا سب کچھ جاننے والا (اور) حکمت والا ہے\qt@no{170}}%
\qt@newcmd\qurantrans@ur@dclxiv{اے اہل کتاب اپنے دین (کی بات) میں حد سے نہ بڑھو اور خدا کے بارے میں حق کے سوا کچھ نہ کہو۔ مسیح (یعنی) مریم کے بیٹے عیسیٰ (نہ خدا تھے نہ خدا کے بیٹے بلکہ) خدا کے رسول اور کا کلمہٴ (بشارت) تھے جو اس نے مریم کی طرف بھیجا تھا اور اس کی طرف سے ایک روح تھے تو خدا اوراس کے رسولوں پر ایمان لاؤ۔ اور (یہ) نہ کہو (کہ خدا) تین (ہیں۔ اس اعتقاد سے) باز آؤ کہ یہ تمہارے حق میں بہتر ہے۔ خدا ہی معبود واحد ہے اور اس سے پاک ہے کہ اس کے اولاد ہو۔ جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے سب اسی کا ہے۔ اور خدا ہی کارساز کافی ہے\qt@no{171}}%
\qt@newcmd\qurantrans@ur@dclxv{مسیح اس بات سے عار نہیں رکھتے کہ خدا کے بندے ہوں اور نہ مقرب فرشتے (عار رکھتے ہیں) اور جو شخص خدا کا بندہ ہونے کو موجب عار سمجھے اور سرکشی کرے تو خدا سب کو اپنے پاس جمع کرلے گا\qt@no{172}}%
\qt@newcmd\qurantrans@ur@dclxvi{تو جو لوگ ایمان لائے اور نیک کام کرتے رہے وہ ان کو ان کا پورا بدلا دے گا اور اپنے فضل سے کچھ زیادہ بھی عنایت کرے گا۔ اور جنہوں نے (بندوں ہونے سے) عاروانکار اور تکبر کیا ان کو تکلیف دینے والا عذاب دے گا۔ اور یہ لوگ خدا کے سوا اپنا حامی اور مددگار نہ پائیں گے\qt@no{173}}%
\qt@newcmd\qurantrans@ur@dclxvii{لوگو تمہارے پروردگار کی طرف سے تمہارے پاس دلیل (روشن) آچکی ہے اور ہم نے (کفر اور ضلالت کا اندھیرا دور کرنے کو) تمہاری طرف چمکتا ہوا نور بھیج دیا ہے\qt@no{174}}%
\qt@newcmd\qurantrans@ur@dclxviii{پس جو لوگ خدا پر ایمان لائے اور اس (کے دین کی رسی) کو مضبوط پکڑے رہے ان کو وہ اپنی رحمت اور فضل (کے بہشتوں) میں داخل کرے گا۔ اور اپنی طرف (پہچنے کا) سیدھا رستہ دکھائے گا\qt@no{175}}%
\qt@newcmd\qurantrans@ur@dclxix{اے پیغمبر) لوگ تم سے (کلالہ کے بارے میں) حکم (خدا) دریافت کرتے ہیں کہہ دو کہ خدا کلالہ بارے میں یہ حکم دیتا ہے کہ اگر کوئی ایسا مرد مرجائے جس کے اولاد نہ ہو (اور نہ ماں باپ) اور اس کے بہن ہو تو اس کو بھائی کے ترکے میں سے آدھا حصہ ملے گا۔ اور اگر بہن مرجائے اور اس کے اولاد نہ ہو تو اس کے تمام مال کا وارث بھائی ہوگا اور اگر (مرنے والے بھائی کی) دو بہنیں ہوں تو دونوں کو بھائی کے ترکے میں سے دو تہائی۔ اور اگر بھائی اور بہن یعنی مرد اور عورتیں ملے جلے وارث ہوں تو مرد کا حصہ دو عورتوں کے برابر ہے۔ (یہ احکام) خدا تم سے اس لئے بیان فرماتا ہے کہ بھٹکتے نہ پھرو۔ اور خدا ہر چیز سے واقف ہے\qt@no{176}}%
\qt@newcmd\qurantrans@ur@dclxx{\basmalahur اے ایمان والو! اپنے اقراروں کو پورا کرو۔ تمہارے لیے چارپائے جانور (جو چرنے والے ہیں) حلال کر دیئے گئے ہیں۔ بجز ان کے جو تمہیں پڑھ کر سنائے جاتے ہیں مگر احرام (حج) میں شکار کو حلال نہ جاننا۔ خدا جیسا چاہتا ہے حکم دیتا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@dclxxi{مومنو! خدا کے نام کی چیزوں کی بےحرمتی نہ کرنا اور نہ ادب کے مہینے کی اور نہ قربانی کے جانوروں کی اور نہ ان جانوروں کی (جو خدا کی نذر کر دیئے گئے ہوں اور) جن کے گلوں میں پٹے بندھے ہوں اور نہ ان لوگوں کی جو عزت کے گھر (یعنی بیت الله) کو جا رہے ہوں (اور) اپنے پروردگار کے فضل اور اس کی خوشنودی کے طلبگار ہوں اور جب احرام اتار دو تو (پھر اختیار ہے کہ) شکار کرو اور لوگوں کی دشمنی اس وجہ سے کہ انہوں نے تم کو عزت والی مسجد سے روکا تھا تمہیں اس بات پر آمادہ نہ کرے کہ تم ان پر زیادتی کرنے لگو اور (دیکھو) نیکی اور پرہیزگاری کے کاموں میں ایک دوسرے کی مدد کیا کرو اور گناہ اور ظلم کی باتوں میں مدد نہ کیا کرو اور خدا سے ڈرتے رہو۔ کچھ شک نہیں کہ خدا کا عذاب سخت ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@dclxxii{تم پر مرا ہوا جانور اور (بہتا) لہو اور سور کا گوشت اور جس چیز پر خدا کے سوا کسی اور کا نام پکارا جائے اور جو جانور گلا گھٹ کر مر جائے اور جو چوٹ لگ کر مر جائے اور جو گر کر مر جائے اور جو سینگ لگ کر مر جائے یہ سب حرام ہیں اور وہ جانور بھی جس کو درندے پھاڑ کھائیں۔ مگر جس کو تم (مرنے سے پہلے) ذبح کرلو اور وہ جانور بھی جو تھان پر ذبح کیا جائے اور یہ بھی کہ پاسوں سے قسمت معلوم کرو یہ سب گناہ (کے کام) ہیں آج کافر تمہارے دین سے ناامید ہو گئے ہیں تو ان سے مت ڈرو اور مجھی سے ڈرتے رہو (اور) آج ہم نے تمہارے لئے تمہارا دین کامل کر دیا اور اپنی نعمتیں تم پر پوری کر دیں اور تمہارے لئے اسلام کو دین پسند کیا ہاں جو شخص بھوک میں ناچار ہو جائے (بشرطیکہ) گناہ کی طرف مائل نہ ہو تو خدا بخشنے والا مہربان ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@dclxxiii{تم سے پوچھتے ہیں کہ کون کون سی چیزیں ان کے لیے حلال ہیں (ان سے) کہہ دو کہ سب پاکیزہ چیزیں تم کو حلال ہیں اور وہ (شکار) بھی حلال ہے جو تمہارے لیے ان شکاری جانوروں نے پکڑا ہو جن کو تم نے سدھا رکھا ہو اور جس (طریق) سے خدا نے تمہیں (شکار کرنا) سکھایا ہے (اس طریق سے) تم نے ان کو سکھایا ہو تو جو شکار وہ تمہارے لئے پکڑ رکھیں اس کو کھا لیا کرو اور (شکاری جانوروں کو چھوڑتے وقت) خدا کا نام لے لیا کرو اور خدا سے ڈرتے رہو۔ بےشک خدا جلد حساب لینے والا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@dclxxiv{آج تمہارے لیے سب پاکیزہ چیزیں حلال کر دی گئیں اور اہل کتاب کا کھانا بھی تم کو حلال ہے اور تمہارا کھانا ان کو حلال ہے اور پاک دامن مومن عورتیں اور پاک دامن اہل کتاب عورتیں بھی (حلال ہیں) جبکہ ان کا مہر دے دو۔ اور ان سے عفت قائم رکھنی مقصود ہو نہ کھلی بدکاری کرنی اور نہ چھپی دوستی کرنی اور جو شخص ایمان سے منکر ہوا اس کے عمل ضائع ہو گئے اور وہ آخرت میں نقصان پانے والوں میں ہوگا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@dclxxv{مومنو! جب تم نماز پڑھنے کا قصد کیا کرو تم منہ اور کہنیوں تک ہاتھ دھو لیا کرو اور سر کا مسح کر لیا کرو اور ٹخنوں تک پاؤں (دھو لیا کرو) اور اگر نہانے کی حاجت ہو تو (نہا کر) پاک ہو جایا کرو اور اگر بیمار ہو یا سفر میں ہو یا کوئی تم میں سے بیت الخلا سے ہو کر آیا ہو یا تم عورتوں سے ہم بستر ہوئے ہو اور تمہیں پانی نہ مل سکے تو پاک مٹی لو اور اس سے منہ اور ہاتھوں کا مسح (یعنی تیمم) کر لو۔ خدا تم پر کسی طرح کی تنگی نہیں کرنا چاہتا بلکہ یہ چاہتا ہے کہ تمہیں پاک کرے اور اپنی نعمتیں تم پر پوری کرے تاکہ تم شکر کرو\qt@no{6}}%
\qt@newcmd\qurantrans@ur@dclxxvi{اور خدا نے جو تم پر احسان کئے ہیں ان کو یاد کرو اور اس عہد کو بھی جس کا تم سے قول لیا تھا (یعنی) جب تم نے کہا تھا کہ ہم نے (خدا کا حکم) سن لیا اور قبول کیا۔ اور الله سے ڈرو۔ کچھ شک نہیں کہ خدا دلوں کی باتوں (تک) سے واقف ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@dclxxvii{اے ایمان والوں! خدا کے لیے انصاف کی گواہی دینے کے لیے کھڑے ہو جایا کرو۔ اور لوگوں کی دشمنی تم کو اس بات پر آمادہ نہ کرے کہ انصاف چھوڑ دو۔ انصاف کیا کرو کہ یہی پرہیزگاری کی بات ہے اور خدا سے ڈرتے رہو۔ کچھ شک نہیں کہ خدا تمہارے سب اعمال سے خبردار ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@dclxxviii{جو لوگ ایمان لائے اور نیک کام کرتے رہے ان سے خدا نے وعدہ فرمایا ہے کہ ان کے لیے بخشش اور اجر عظیم ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@dclxxix{اور جنہوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا وہ جہنمی ہیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@dclxxx{اے ایمان والو! خدا نے جو تم پر احسان کیا ہے اس کو یاد کرو۔ جب ایک جماعت نے ارادہ کیا کہ تم پر دست درازی کریں تو اس نے ان کے ہاتھ روک دیئے اور خدا سے ڈرتے رہوں اور مومنو کو خدا ہی پر بھروسہ رکھنا چاہیئے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@dclxxxi{اور خدا نے بنی اسرائیل سے اقرار لیا اور ان میں ہم نے بارہ سردار مقرر کئے پھر خدا نے فرمایا کہ میں تمہارے ساتھ ہوں اگر تم نماز پڑھتے اور زکوٰة دیتے رہو گے اور میرے پیغمبروں پر ایمان لاؤ گے اور ان کی مدد کرو گے اور خدا کو قرض حسنہ دو گے تو میں تم سے تمہارے گناہ دور کر دوں گا اور تم کو بہشتوں میں داخل کروں گا جن کے نیچے نہریں بہہ رہی ہیں پھر جس نے اس کے بعد تم میں سے کفر کیا وہ سیدھے رستے سے بھٹک گیا\qt@no{12}}%
\qt@newcmd\qurantrans@ur@dclxxxii{تو ان لوگوں کے عہد توڑ دینے کے سبب ہم نے ان پر لعنت کی اور ان کے دلوں کو سخت کر دیا یہ لوگ کلمات (کتاب) کو اپنے مقامات سے بدل دیتے ہیں اور جن باتوں کی ان کو نصیحت کی گئی تھی ان کا بھی ایک حصہ فراموش کر بیٹھے اور تھوڑے آدمیوں کے سوا ہمیشہ تم ان کی (ایک نہ ایک) خیانت کی خبر پاتے رہتے ہو تو ان کی خطائیں معاف کردو اور (ان سے) درگزر کرو کہ خدا احسان کرنے والوں کو دوست رکھتا ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@dclxxxiii{اور جو لوگ (اپنے تئیں) کہتے ہیں کہ ہم نصاریٰ ہیں ہم نے ان سے بھی عہد لیا تھا مگر انہوں نے بھی اس نصیحت کا جو ان کو کی گئی تھی ایک حصہ فراموش کر دیا تو ہم نے ان کے باہم قیامت تک کے لیے دشمنی اور کینہ ڈال دیا اور جو کچھ وہ کرتے رہے خدا عنقریب ان کو اس سے آگاہ کرے گا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@dclxxxiv{اے اہل کتاب! تمہارے پاس ہمارے پیغمبر (آخرالزماں) آ گئے ہیں کہ جو کچھ تم کتاب (الہٰی) میں سے چھپاتے تھے وہ اس میں سے بہت کچھ تمہیں کھول کھول کر بتا دیتے ہیں اور تمہارے بہت سے قصور معاف کر دیتے ہیں بےشک تمہارے پاس خدا کی طرف سے نور اور روشن کتاب آ چکی ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@dclxxxv{جس سے خدا اپنی رضا پر چلنے والوں کو نجات کے رستے دکھاتا ہے اور اپنے حکم سے اندھیرے میں سے نکال کر روشنی کی طرف لے جاتا اور ان کو سیدھے رستہ پر چلاتا ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@dclxxxvi{جو لوگ اس بات کے قائل ہیں کہ عیسیٰ بن مریم خدا ہیں وہ بےشک کافر ہیں (ان سے) کہہ دو کہ اگر خدا عیسیٰ بن مریم کو اور ان کی والدہ کو اور جتنے لوگ زمین میں ہیں سب کو ہلاک کرنا چاہے تو اس کے آگے کس کی پیش چل سکتی ہے؟ اور آسمان اور زمین اور جو کچھ ان دونوں میں ہے سب پر خدا ہی کی بادشاہی ہے وہ جو چاہتا ہے پیدا کرتا ہے اور خدا ہر چیز پر قادر ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@dclxxxvii{اور یہود اور نصاریٰ کہتے ہیں کہ ہم خدا کے بیٹے اور اس کے پیارے ہیں کہو کہ پھر وہ تمہاری بداعمالیوں کے سبب تمھیں عذاب کیوں دیتا ہے (نہیں) بلکہ تم اس کی مخلوقات میں (دوسروں کی طرح کے) انسان ہو وہ جسے چاہے بخشے اور جسے چاہے عذاب دے اور آسمان زمین اور جو کچھ ان دونوں میں ہے سب پر خدا ہی کی حکومت ہے اور (سب کو) اسی کی طرف لوٹ کر جانا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@dclxxxviii{اے اہلِ کتاب پیغمبروں کے آنے کا سلسلہ جو (ایک عرصے تک) منقطع رہا تو (اب) تمہارے پاس ہمارے پیغمبر آ گئے ہیں جو تم سے (ہمارے احکام) بیان کرتے ہیں تاکہ تم یہ نہ کہو کہ ہمارے پاس کوئی خوشخبری یا ڈر سنانے والا نہیں آیا سو (اب) تمہارے پاس خوشخبری اور ڈر سنانے والے آ گئے ہیں اور خدا ہر چیز پر قادر ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@dclxxxix{اور جب موسیٰ نے اپنی قوم سے کہا کہ بھائیو تم پر خدا نے جو احسان کئے ہیں ان کو یاد کرو کہ اس نے تم میں پیغمبر پیدا کیے اور تمہیں بادشاہ بنایا اور تم کو اتنا کچھ عنایت کیا کہ اہل عالم میں سے کسی کو نہیں دیا\qt@no{20}}%
\qt@newcmd\qurantrans@ur@dcxc{تو بھائیو! تم ارض مقدس (یعنی ملک شام) میں جسے خدا نے تمہارے لیے لکھ رکھا ہے چل داخل ہو اور (دیکھنا مقابلے کے وقت) پیٹھ نہ پھیر دینا ورنہ نقصان میں پڑ جاؤ گے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@dcxci{وہ کہنے لگے کہ موسیٰ! وہاں تو بڑے زبردست لوگ (رہتے) ہیں اور جب تک وہ اس سرزمین سے نکل نہ جائیں ہم وہاں جا نہیں سکتے ہاں اگر وہ وہاں سے نکل جائیں تو ہم جا داخل ہوں گے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@dcxcii{جو لوگ (خدا سے) ڈرتے تھے ان میں سے دو شخص جن پر خدا کی عنایت تھی کہنے لگے کہ ان لوگوں پر دروازے کے رستے سے حملہ کردو جب تم دروازے میں داخل ہو گئے تو فتح تمہارے ہے اور خدا ہی پر بھروسہ رکھو بشرطیکہ صاحبِ ایمان ہو\qt@no{23}}%
\qt@newcmd\qurantrans@ur@dcxciii{وہ بولے کہ موسیٰ! جب تک وہ لوگ وہاں ہیں ہم کبھی وہاں نہیں جا سکتے (اگر لڑنا ہی ضرور ہے) تو تم اور تمہارا خدا جاؤ اور لڑو ہم یہیں بیٹھے رہیں گے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@dcxciv{موسیٰ نے (خدا سے) التجا کی کہ پروردگار میں اپنے اور اپنے بھائی کے سوا اور کسی پر اختیار نہیں رکھتا تو ہم میں اور ان نافرمان لوگوں میں جدائی کردے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@dcxcv{خدا نے فرمایا کہ وہ ملک ان پر چالیس برس تک کے لیے حرام کر دیا گیا (کہ وہاں جانے نہ پائیں گے اور جنگل کی) زمین میں سرگرداں پھرتے رہیں گے تو ان نافرمان لوگوں کے حال پر افسوس نہ کرو\qt@no{26}}%
\qt@newcmd\qurantrans@ur@dcxcvi{اور (اے محمد) ان کو آدم کے دو بیٹوں (ہابیل اور قابیل) کے حالات (جو بالکل) سچے (ہیں) پڑھ کر سنا دو کہ جب ان دونوں نے خدا (کی جناب میں) کچھ نیازیں چڑھائیں تو ایک کی نیاز تو قبول ہو گئی اور دوسرے کی قبول نہ ہوئی (تب قابیل ہابیل سے) کہنے لگا کہ میں تجھے قتل کروں گا اس نے کہا کہ خدا پرہیزگاروں ہی کی (نیاز) قبول فرمایا کرتا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@dcxcvii{اور اگر تو مجھے قتل کرنے کے لیے مجھ پر ہاتھ چلائے گا تو میں تجھ کو قتل کرنے کے لئے تجھ پر ہاتھ نہیں چلاؤں گا مجھے تو خدائے رب العالمین سے ڈر لگتا ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@dcxcviii{میں چاہتا ہوں کہ تو میرے گناہ میں بھی ماخوذ ہو اور اپنے گناہ میں بھی پھر (زمرہ) اہل دوزخ میں ہو اور ظالموں کی یہی سزا ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@dcxcix{مگر اس کے نفس نے اس کو بھائی کے قتل ہی کی ترغیب دی تو اس نے اسے قتل کر دیا اور خسارہ اٹھانے والوں میں ہو گیا\qt@no{30}}%
\qt@newcmd\qurantrans@ur@dcc{اب خدا نے ایک کوّا بھیجا جو زمین کریدنے لگا تاکہ اسے دکھائے کہ اپنے بھائی کی لاش کو کیونکر چھپائے کہنے لگا اے ہے مجھ سے اتنا بھی نہ ہو سکا کہ اس کوے کے برابر ہوتا کہ اپنے بھائی کی لاش چھپا دیتا پھر وہ پشیمان ہوا\qt@no{31}}%
\qt@newcmd\qurantrans@ur@dcci{اس قتل کی وجہ سے ہم نے بنی اسرائیل پر یہ حکم نازل کیا کہ جو شخص کسی کو (ناحق) قتل کرے گا (یعنی) بغیر اس کے کہ جان کا بدلہ لیا جائے یا ملک میں خرابی کرنے کی سزا دی جائے اُس نے گویا تمام لوگوں کو قتل کیا اور جو اس کی زندگانی کا موجب ہوا تو گویا تمام لوگوں کی زندگانی کا موجب ہوا اور ان لوگوں کے پاس ہمارے پیغمبر روشن دلیلیں لا چکے ہیں پھر اس کے بعد بھی ان سے بہت سے لوگ ملک میں حدِ اعتدال سے نکل جاتے ہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@dccii{جو لوگ خدا اور اس کے رسول سے لڑائی کریں اور ملک میں فساد کرنے کو دوڑتے پھریں ان کی یہی سزا ہے کہ قتل کر دیئے جائیں یا سولی چڑھا دیئے جائیں یا ان کے ایک ایک طرف کے ہاتھ اور ایک ایک طرف کے پاؤں کاٹ دیئے جائیں یا ملک سے نکال دیئے جائیں یہ تو دنیا میں ان کی رسوائی ہے اور آخرت میں ان کے لیے بڑا (بھاری) عذاب تیار ہے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@dcciii{ہاں جن لوگوں نے اس سے پیشتر کہ تمہارے قابو میں آ جائیں توبہ کر لی تو جان رکھو کہ خدا بخشنے والا مہربان ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@dcciv{اے ایمان والو! خدا سے ڈرتے رہو اور اس کا قرب حاصل کرنے کا ذریعہ تلاش کرتے رہو اور اس کے رستے میں جہاد کرو تاکہ رستگاری پاؤ\qt@no{35}}%
\qt@newcmd\qurantrans@ur@dccv{جو لوگ کافر ہیں اگر ان کے پاس روئے زمین (کے تمام خزانے اور اس) کا سب مال ومتاع ہو اور اس کے ساتھ اسی قدر اور بھی ہو تاکہ قیامت کے روز عذاب (سے رستگاری حاصل کرنے) کا بدلہ دیں تو ان سے قبول نہیں کیا جائے گا اور ان کو درد دینے والا عذاب ہوگا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@dccvi{ہر چند) چاہیں گے کہ آگ سے نکل جائیں مگر اس سے نہیں نکل سکیں گے اور ان کے لئے ہمیشہ کا عذاب ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@dccvii{اور جو چوری کرے مرد ہو یا عورت ان کے ہاتھ کاٹ ڈالو یہ ان کے فعلوں کی سزا اور خدا کی طرف سے عبرت ہے اور خدا زبردست (اور) صاحب حکمت ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@dccviii{اور جو شخص گناہ کے بعد توبہ کرے اور نیکوکار ہو جائے تو خدا اس کو معاف کر دے گا کچھ شک نہیں کہ خدا بخشنے والا مہربان ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@dccix{کیا تم کو معلوم نہیں کہ آسمانوں اور زمین میں خدا ہی کی سلطنت ہے؟ جس کو چاہے عذاب کرے اور جسے چاہے بخش دے اور خدا ہر چیز پر قادر ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@dccx{اے پیغمبر! جو لوگ کفر میں جلدی کرتے ہیں (کچھ تو) ان میں سے (ہیں) جو منہ سے کہتے ہیں کہ ہم مومن ہیں لیکن ان کے دل مومن نہیں ہیں اور (کچھ) ان میں سے جو یہودی ہیں ان کی وجہ سے غمناک نہ ہونا یہ غلط باتیں بنانے کے لیے جاسوسی کرتے پھرتے ہیں اور ایسے لوگوں (کے بہکانے) کے لیے جاسوس بنے ہیں جو ابھی تمہارے پاس نہیں آئے (صحیح) باتوں کو ان کے مقامات (میں ثابت ہونے) کے بعد بدل دیتے ہیں (اور لوگوں سے) کہتے ہیں کہ اگر تم کو یہی (حکم) ملے تو اسے قبول کر لینا اور اگر یہ نہ ملے تو اس سے احتراز کرنا اور اگر کسی کو خدا گمراہ کرنا چاہے تو اس کے لیے تم کچھ بھی خدا سے (ہدایت کا) اختیار نہیں رکھتے یہ وہ لوگ ہیں جن کے دلوں کو خدا نے پاک کرنا نہیں چاہا ان کے لیے دنیا میں بھی ذلت ہے اور آخرت میں بھی بڑا عذاب ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@dccxi{یہ) جھوٹی باتیں بنانے کے جاسوسی کرنے والے اور (رشوت کا) حرام مال کھانے والے ہیں اگر یہ تمہارے پاس (کوئی مقدمہ فیصل کرانے کو) آئیں تو تم ان میں فیصلہ کر دینا یا اعراض کرنا اور اگر ان سے اعراض کرو گے تو وہ تمہارا کچھ بھی نہیں بگاڑ سکیں گے اور اگر فیصلہ کرنا چاہو تو انصاف کا فیصلہ کرنا کہ خدا انصاف کرنے والوں کو دوست رکھتا ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@dccxii{اور یہ تم سے (اپنے مقدمات) کیونکر فیصل کرایں گے جبکہ خود ان کے پاس تورات (موجود) ہے جس میں خدا کا حکم (لکھا ہوا) ہے (یہ اسے جانتے ہیں) پھر اس کے بعد اس سے پھر جاتے ہیں اور یہ لوگ ایمان ہی نہیں رکھتے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@dccxiii{بیشک ہم نے توریت نازل فرمائی جس میں ہدایت اور روشنی ہے اسی کے مطابق انبیاء جو (خدا کے) فرمانبردار تھے یہودیوں کو حکم دیتے رہے ہیں اور مشائخ اور علماء بھی کیونکہ وہ کتاب خدا کے نگہبان مقرر کیے گئے تھے اور اس پر گواہ تھے (یعنی حکم الہٰی کا یقین رکھتے تھے) تو تم لوگوں سے مت ڈرنا اور مجھی سے ڈرتے رہنا اور میری آیتوں کے بدلے تھوڑی سی قیمت نہ لینا اور جو خدا کے نازل فرمائے ہوئے احکام کے مطابق حکم نہ دے تو ایسے ہی لوگ کافر ہیں\qt@no{44}}%
\qt@newcmd\qurantrans@ur@dccxiv{اور ہم نے ان لوگوں کے لیے تورات میں یہ حکم لکھ دیا تھا کہ جان کے بدلے جان اور آنکھ کے بدلے آنکھ اور ناک کے بدلے ناک اور کان کے بدلے کان اور دانت کے بدلے دانت اور سب زخموں کا اسی طرح بدلہ ہے لیکن جو شخص بدلہ معاف کر دے وہ اس کے لیے کفارہ ہوگا اور جو خدا کے نازل فرمائے ہوئے احکام کے مطابق حکم نہ دے تو ایسے ہی لوگ بےانصاف ہیں\qt@no{45}}%
\qt@newcmd\qurantrans@ur@dccxv{اور ان پیغمبروں کے بعد انہی کے قدموں پر ہم نے عیسیٰ بن مریم کو بھیجا جو اپنے سے پہلے کی کتاب تورات کی تصدیق کرتے تھے اور ان کو انجیل عنایت کی جس میں ہدایت اور نور ہے اور تورات کی جو اس سے پہلی کتاب (ہے) تصدیق کرتی ہے اور پرہیزگاروں کو راہ بتاتی اور نصیحت کرتی ہے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@dccxvi{اور اہل انجیل کو چاہیئے کہ جو احکام خدا نے اس میں نازل فرمائے ہیں اس کے مطابق حکم دیا کریں اور جو خدا کے نازل کئے ہوئے احکام کے مطابق حکم نہ دے گا تو ایسے لوگ نافرماں ہیں\qt@no{47}}%
\qt@newcmd\qurantrans@ur@dccxvii{اور (اے پیغمبر!) ہم نے تم پر سچی کتاب نازل کی ہے جو اپنے سے پہلی کتابوں کی تصدیق کرتی ہے اور ان (سب) پر شامل ہے تو جو حکم خدا نے نازل فرمایا ہے اس کے مطابق ان کا فیصلہ کرنا اور حق جو تمہارے پاس آچکا ہے اس کو چھوڑ کر ان کی خواہشوں کی پیروی نہ کرنا ہم نے تم میں سے ہر ایک (فرقے) کے لیے ایک دستور اور طریقہ مقرر کیا ہے اور اگر خدا چاہتا تو سب کو ایک ہی شریعت پر کر دیتا مگر جو حکم اس نے تم کو دیئے ہیں ان میں وہ تمہاری آزمائش کرنی چاہتا ہے سو نیک کاموں میں جلدی کرو تم سب کو خدا کی طرف لوٹ کر جانا ہے پھر جن باتوں میں تم کو اختلاف تھا وہ تم کو بتا دے گا\qt@no{48}}%
\qt@newcmd\qurantrans@ur@dccxviii{اور (ہم پھر تاکید کرتے ہیں کہ) جو (حکم) خدا نے نازل فرمایا ہے اسی کے مطابق ان میں فیصلہ کرنا اور ان کی خواہشوں کی پیروی نہ کرنا اور ان سے بچتے رہنا کہ کسی حکم سے جو خدا نے تم پر نازل فرمایا ہے یہ کہیں تم کو بہکانہ دیں اگر یہ نہ مانیں تو جان لو کہ خدا چاہتا ہے کہ ان کے بعض گناہوں کے سبب ان پر مصیبت نازل کرے اور اکثر لوگ تو نافرمان ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@dccxix{کیا یہ زمانہٴ جاہلیت کے حکم کے خواہش مند ہیں؟ اور جو یقین رکھتے ہیں ان کے لیے خدا سے اچھا حکم کس کا ہے؟\qt@no{50}}%
\qt@newcmd\qurantrans@ur@dccxx{اے ایمان والو! یہود اور نصاریٰ کو دوست نہ بناؤ یہ ایک دوسرے کے دوست ہیں اور جو شخص تم میں سے ان کو دوست بنائے گا وہ بھی انہیں میں سے ہوگا بیشک خدا ظالم لوگوں کو ہدایت نہیں دیتا\qt@no{51}}%
\qt@newcmd\qurantrans@ur@dccxxi{تو جن لوگوں کے دلوں میں (نفاق کا) مرض ہے تم ان کو دیکھو گے کہ ان میں دوڑ دوڑ کے ملے جاتے ہیں کہتے ہیں کہ ہمیں خوف ہے کہ کہیں ہم پر زمانے کی گردش نہ آجائے سو قریب ہے کہ خدا فتح بھیجے یا اپنے ہاں سے کوئی اور امر (نازل فرمائے) پھر یہ اپنے دل کی باتوں پر جو چھپایا کرتے تھے پشیمان ہو کر رہ جائیں گے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@dccxxii{اور اس (وقت) مسلمان (تعجب سے) کہیں گے کہ کیا یہ وہی ہیں جو خدا کی سخت سخت قسمیں کھایا کرتے تھے کہ ہم تمہارے ساتھ ہیں ان کےعمل اکارت گئے اور وہ خسارے میں پڑ گئے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@dccxxiii{اے ایمان والو اگر کوئی تم میں سے اپنے دین سے پھر جائے گا تو خدا ایسے لوگ پیدا کر دے گا جن کو وہ دوست رکھے اور جسے وہ دوست رکھیں اور جو مومنوں کے حق میں نرمی کریں اور کافروں سے سختی سے پیش آئیں خدا کی راہ میں جہاد کریں اور کسی ملامت کرنے والی کی ملامت سے نہ ڈریں یہ خدا کا فضل ہے وہ جسے چاہتا ہے دیتا ہے اور الله بڑی کشائش والا اور جاننے والا ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@dccxxiv{تمہارے دوست تو خدا اور اس کے پیغمبر اور مومن لوگ ہی ہیں جو نماز پڑھتے اور زکوٰة دیتے اور (خدا کے آگے) جھکتے ہیں\qt@no{55}}%
\qt@newcmd\qurantrans@ur@dccxxv{اور جو شخص خدا اور اس کے پیغمبر اور مومنوں سے دوستی کرے گا تو (وہ خدا کی جماعت میں داخل ہوگا اور) خدا کی جماعت ہی غلبہ پانے والی ہے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@dccxxvi{اے ایمان والوں! جن لوگوں کو تم سے پہلے کتابیں دی گئی تھیں ان کو اور کافروں کو جنہوں نے تمہارے دین کو ہنسی اور کھیل بنا رکھا ہے دوست نہ بناؤ اور مومن ہو تو خدا سے ڈرتے رہو\qt@no{57}}%
\qt@newcmd\qurantrans@ur@dccxxvii{اور جب تم لوگ نماز کے لیے اذان دیتے ہو تو یہ اسے بھی ہنسی اور کھیل بناتے ہیں یہ اس لیے کہ سمجھ نہیں رکھتے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@dccxxviii{کہو کہ اے اہل کتاب! تم ہم میں برائی ہی کیا دیکھتے ہو سوا اس کے کہ ہم خدا پر اور جو (کتاب) ہم پر نازل ہوئی اس پر اور جو (کتابیں) پہلے نازل ہوئیں ان پر ایمان لائے ہیں اور تم میں اکثر بدکردار ہیں\qt@no{59}}%
\qt@newcmd\qurantrans@ur@dccxxix{کہو کہ میں تمہیں بتاؤں کہ خدا کے ہاں اس سے بھی بدتر جزا پانے والے کون ہیں؟ وہ لوگ ہیں جن پر خدا نے لعنت کی اور جن پر وہ غضبناک ہوا اور (جن کو) ان میں سے بندر اور سور بنا دیا اور جنہوں نے شیطان کی پرستش کی ایسے لوگوں کا برا ٹھکانہ ہے اور وہ سیدھے رستے سے بہت دور ہیں\qt@no{60}}%
\qt@newcmd\qurantrans@ur@dccxxx{اور جب یہ لوگ تمہارے پاس آتے ہیں تو کہتے ہیں کہ ہم ایمان لے آئے حالانکہ کفر لے کر آتے ہیں اور اسی کو لیکر جاتے ہیں اور جن باتوں کو یہ مخفی رکھتے ہیں خدا ان کو خوب جانتا ہے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@dccxxxi{اور تم دیکھو گے کہ ان میں اکثر گناہ اور زیادتی اور حرام کھانے میں جلدی کر رہے ہیں بےشک یہ جو کچھ کرتے ہیں برا کرتے ہیں\qt@no{62}}%
\qt@newcmd\qurantrans@ur@dccxxxii{بھلا ان کے مشائخ اور علماء انہیں گناہ کی باتوں اور حرام کھانے سے منع کیوں نہیں کرتے؟ بلاشبہ وہ بھی برا کرتے ہیں\qt@no{63}}%
\qt@newcmd\qurantrans@ur@dccxxxiii{اور یہود کہتے ہیں کہ خدا کا ہاتھ (گردن سے) بندھا ہوا ہے (یعنی الله بخیل ہے) انہیں کے ہاتھ باندھے جائیں اور ایسا کہنے کے سبب ان پر لعنت ہو (اس کا ہاتھ بندھا ہوا نہیں) بلکہ اس کے دونوں ہاتھ کھلے ہیں وہ جس طرح (اور جتنا) چاہتا ہے خرچ کرتا ہے اور (اے محمد) یہ (کتاب) جو تمہارے پروردگار کی طرف سے تم پر نازل ہوئی اس سے ان میں سے اکثر کی شرارت اور انکار اور بڑھے گا اور ہم نے ان کے باہم عداوت اور بغض قیامت تک کے لیے ڈال دیا ہے یہ جب لڑائی کے لیے آگ جلاتے ہیں خدا اس کو بجھا دیتا ہے اور یہ ملک میں فساد کے لیے دوڑے پھرتے ہیں اور خدا فساد کرنے والوں کو دوست نہیں رکھتا\qt@no{64}}%
\qt@newcmd\qurantrans@ur@dccxxxiv{اور اگر اہل کتاب ایمان لاتے اور پرہیز گاری کرتے تو ہم ان سے ان کے گناہ محو کر دیتے اور ان کو نعمت کے باغوں میں داخل کرتے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@dccxxxv{اور اگر وہ تورات اور انجیل کو اور جو (اور کتابیں) ان کے پروردگار کی طرف سے ان پر نازل ہوئیں ان کو قائم رکھتے (تو ان پر رزق مینہ کی طرح برستا کہ) اپنے اوپر سے پاؤں کے نیچے سے کھاتے ان میں کچھ لوگ میانہ رو ہیں اور بہت سے ایسے ہیں جن کے اعمال برے ہیں\qt@no{66}}%
\qt@newcmd\qurantrans@ur@dccxxxvi{اے پیغمبر جو ارشادات خدا کی طرف سے تم پر نازل ہوئے ہیں سب لوگوں کو پہنچا دو اور اگر ایسا نہ کیا تو تم خدا کے پیغام پہنچانے میں قاصر رہے (یعنی پیغمبری کا فرض ادا نہ کیا) اور خدا تم کو لوگوں سے بچائے رکھے گا بیشک خدا منکروں کو ہدایت نہیں دیتا\qt@no{67}}%
\qt@newcmd\qurantrans@ur@dccxxxvii{کہو کہ اے اہل کتاب! جب تک تم تورات اور انجیل کو اور جو (اور کتابیں) تمہارے پروردگار کی طرف سے تم لوگوں پر نازل ہوئیں ان کو قائم نہ رکھو گے کچھ بھی راہ پر نہیں ہو سکتے اور یہ (قرآن) جو تمہارے پروردگار کی طرف سے تم پر نازل ہوا ہے ان میں سے اکثر کی سرکشی اور کفر اور بڑھے گا تو تم قوم کفار پر افسوس نہ کرو\qt@no{68}}%
\qt@newcmd\qurantrans@ur@dccxxxviii{جو لوگ خدا پر اور روز آخرت پر ایمان لائیں گے اور عمل نیک کریں گے خواہ وہ مسلمان ہوں یا یہودی یا ستارہ پرست یا عیسائی ان کو (قیامت کے دن) نہ کچھ خوف ہو گا اور نہ غمناک ہوں گے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@dccxxxix{ہم نے بنی اسرائیل سے عہد بھی لیا اور ان کی طرف پیغمبر بھی بھیجے (لیکن) جب کوئی پیغمبر ان کے پاس ایسی باتیں لےکر آتا جن کو ان کے دل نہیں چاہتے تھے تو وہ (انبیاء کی) ایک جماعت کو تو جھٹلا دیتے اور ایک جماعت کو قتل کر دیتے تھے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@dccxl{اور خیال کرتے تھے کہ (اس سے ان پر) کوئی آفت نہیں آنے کی تو وہ اندھے اور بہرے ہو گئے پھر خدا نے ان پر مہربانی فرمائی (لیکن) پھر ان میں سے بہت سے اندھے اور بہرے ہو گئے اور خدا ان کے سب کاموں کو دیکھ رہا ہے\qt@no{71}}%
\qt@newcmd\qurantrans@ur@dccxli{وہ لوگ بےشبہ کافر ہیں جو کہتے ہیں کہ مریم کے بیٹے (عیسیٰ) مسیح خدا ہیں حالانکہ مسیح یہود سے یہ کہا کرتے تھے کہ اے بنی اسرائیل خدا ہی کی عبادت کرو جو میرا بھی پروردگار ہے اور تمہارا بھی (اور جان رکھو کہ) جو شخص خدا کے ساتھ شرک کرے گا خدا اس پر بہشت حرام کر دے گا اور اس کا ٹھکانہ دوزخ ہے اور ظالموں کا کوئی مددگار نہیں\qt@no{72}}%
\qt@newcmd\qurantrans@ur@dccxlii{وہ لوگ (بھی) کافر ہیں جو اس بات کے قائل ہیں کہ خدا تین میں کا تیسرا ہے حالانکہ اس معبود یکتا کے سوا کوئی عبادت کے لائق نہیں اگر یہ لوگ ایسے اقوال (وعقائد) سے باز نہیں آئیں گے تو ان میں جو کافر ہوئے ہیں وہ تکلیف دینے والا عذاب پائیں گے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@dccxliii{تو یہ کیوں خدا کے آگے توبہ نہیں کرتے اور اس سے گناہوں کی معافی نہیں مانگتے اور خدا تو بخشنے والا مہربان ہے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@dccxliv{مسیح ابن مریم تو صرف (خدا) کے پیغمبر تھے ان سے پہلے بھی بہت سے رسول گزر چکے تھے اور ان کی والدہ (مریم خدا کی) ولی اور سچی فرمانبردار تھیں دونوں (انسان تھے اور) کھانا کھاتے تھے دیکھو ہم ان لوگوں کے لیے اپنی آیتیں کس طرح کھول کھول کر بیان کرتے ہیں پھر (یہ) دیکھو کہ یہ کدھر الٹے جا رہے ہیں\qt@no{75}}%
\qt@newcmd\qurantrans@ur@dccxlv{کہو کہ تم خدا کے سوا ایسی چیز کی کیوں پرستش کرتے ہو جس کو تمہارے نفع اور نقصان کا کچھ بھی اختیار نہیں؟ اور خدا ہی (سب کچھ) سنتا جانتا ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@dccxlvi{کہو کہ اے اہل کتاب! اپنے دین (کی بات) میں ناحق مبالغہ نہ کرو اور ایسے لوگوں کی خواہشوں کے پیچھے نہ چلو جو (خود بھی) پہلے گمراہ ہوئے اور اَور بھی اکثروں کو گمراہ کر گئے اور سیدھے رستے سے بھٹک گئے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@dccxlvii{جو لوگ بنی اسرائیل میں کافر ہوئے ان پر داؤد اور عیسیٰ بن مریم کی زبان سے لعنت کی گئی یہ اس لیے کہ نافرمانی کرتے تھے اور حد سے تجاوز کرتے تھے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@dccxlviii{اور) برے کاموں سے جو وہ کرتے تھے ایک دوسرے کو روکتے نہیں تھے بلاشبہ وہ برا کرتے تھے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@dccxlix{تم ان میں سے بہتوں کو دیکھو گے کہ کافروں سے دوستی رکھتے ہیں انہوں نے جو کچھ اپنے واسطے آگے بھیجا ہے برا ہے (وہ یہ) کہ خدا ان سے ناخوش ہوا اور وہ ہمیشہ عذاب میں (مبتلا) رہیں گے\qt@no{80}}%
\qt@newcmd\qurantrans@ur@dccl{اور اگر وہ خدا پر اور پیغمبر پر اور جو کتاب ان پر نازل ہوئی تھی اس پر یقین رکھتے تو ان لوگوں کو دوست نہ بناتے لیکن ان میں اکثر بدکردار ہیں\qt@no{81}}%
\qt@newcmd\qurantrans@ur@dccli{اے پیغمبرﷺ!) تم دیکھو گے کہ مومنوں کے ساتھ سب سے زیادہ دشمنی کرنے والے یہودی اور مشرک ہیں اور دوستی کے لحاظ سے مومنوں سے قریب تر ان لوگوں کو پاؤ گے جو کہتے ہیں کہ ہم نصاریٰ ہیں یہ اس لیے کہ ان میں عالم بھی ہیں اور مشائخ بھی اور وہ تکبر نہیں کرتے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@dcclii{اور جب اس (کتاب) کو سنتے ہیں جو (سب سے پہلے) پیغمبر (محمدﷺ) پر نازل ہوئی تو تم دیکھتے ہو کہ ان کی آنکھوں سے آنسو جاری ہو جاتے ہیں اس لیے کہ انہوں نے حق بات پہچان لی اور وہ (خدا کی جناب میں) عرض کرتے ہیں کہ اے پروردگار ہم ایمان لے آئے تو ہم کو ماننے والوں میں لکھ لے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@dccliii{اور ہمیں کیا ہوا ہے کہ خدا پر اور حق بات پر جو ہمارے پاس آئی ہے ایمان نہ لائیں اور ہم امید رکھتے ہیں کہ پروردگار ہم کو نیک بندوں کے ساتھ (بہشت میں) داخل کرے گا\qt@no{84}}%
\qt@newcmd\qurantrans@ur@dccliv{تو خدا نے ان کو اس کہنے کے عوض (بہشت کے) باغ عطا فرمائے جن کے نیچے نہریں بہہ رہی ہیں وہ ہمیشہ ان میں رہیں گے اور نیکو کاروں کا یہی صلہ ہے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@dcclv{اور جن لوگوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا وہ جہنمی ہیں\qt@no{86}}%
\qt@newcmd\qurantrans@ur@dcclvi{مومنو! جو پاکیزہ چیزیں خدا نے تمہارے لیے حلال کی ہیں ان کو حرام نہ کرو اور حد سے نہ بڑھو کہ خدا حد سے بڑھنے والوں کو دوست نہیں رکھتا\qt@no{87}}%
\qt@newcmd\qurantrans@ur@dcclvii{اور جو حلال طیّب روزی خدا نے تم کو دی ہے اسے کھاؤ اور خدا سے جس پر ایمان رکھتے ہو ڈرتے رہو\qt@no{88}}%
\qt@newcmd\qurantrans@ur@dcclviii{خدا تمہاری بےارادہ قسموں پر تم سے مواخذہ نہیں کرے گا لیکن پختہ قسموں پر (جن کے خلاف کرو گے) مواخذہ کرے گا تو اس کا کفارہ دس محتاجوں کو اوسط درجے کا کھانا کھلانا ہے جو تم اپنے اہل وعیال کو کھلاتے ہو یا ان کو کپڑے دینا یا ایک غلام آزاد کرنا اور جس کو میسر نہ ہو وہ تین روزے رکھے یہ تمہاری قسموں کا کفارہ ہے جب تم قسم کھا لو (اور اسے توڑ دو) اور (تم کو) چاہئے کہ اپنی قسموں کی حفاظت کرو اس طرح خدا تمہارے (سمجھانے کے) لیے اپنی آیتیں کھول کھول کر بیان فرماتا ہے تاکہ تم شکر کرو\qt@no{89}}%
\qt@newcmd\qurantrans@ur@dcclix{اے ایمان والو! شراب اور جوا اور بت اور پاسے (یہ سب) ناپاک کام اعمال شیطان سے ہیں سو ان سے بچتے رہنا تاکہ نجات پاؤ\qt@no{90}}%
\qt@newcmd\qurantrans@ur@dcclx{شیطان تو یہ چاہتا ہے کہ شراب اور جوئے کے سبب تمہارے آپس میں دشمنی اور رنجش ڈلوا دے اور تمہیں خدا کی یاد سے اور نماز سے روک دے تو تم کو (ان کاموں سے) باز رہنا چاہیئے\qt@no{91}}%
\qt@newcmd\qurantrans@ur@dcclxi{اور خدا کی فرمانبرداری اور رسولِ (خدا) کی اطاعت کرتے رہو اور ڈرتے رہو اگر منہ پھیرو گے تو جان رکھو کہ ہمارے پیغمبر کے ذمے تو صرف پیغام کا کھول کر پہنچا دینا ہے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@dcclxii{جو لوگ ایمان لائے اور نیک کام کرتے رہے ان پر ان چیزوں کا کچھ گناہ نہیں جو وہ کھا چکے جب کہ انہوں نے پرہیز کیا اور ایمان لائے اور نیک کام کیے پھر پرہیز کیا اور ایمان لائے پھر پرہیز کیا اور نیکو کاری کی اور خدا نیکو کاروں کو دوست رکھتا ہے\qt@no{93}}%
\qt@newcmd\qurantrans@ur@dcclxiii{مومنو! کسی قدر شکار سے جن کو تم ہاتھوں اور نیزوں سے پکڑ سکو خدا تمہاری آزمائش کرے گا (یعنی حالت احرام میں شکار کی ممانعت سے) تا کہ معلوم کرے کہ اس سے غائبانہ کون ڈرتا ہے تو جو اس کے بعد زیادتی کرے اس کے لیے دکھ دینے والا عذاب (تیار) ہے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@dcclxiv{مومنو! جب تم احرام کی حالت میں ہو تو شکار نہ مارنا اور جو تم میں سے جان بوجھ کر اسے مارے تو (یا تو اس کا) بدلہ (دے اور وہ یہ ہے کہ) اسی طرح کا چارپایہ جسے تم میں دو معتبر شخص مقرر کردیں قربانی (کرے اور یہ قربانی) کعبے پہنچائی جائے یا کفارہ (دے اور وہ) مسکینوں کو کھانا کھلانا (ہے) یا اس کے برابر روزے رکھے تاکہ اپنے کام کی سزا (کا مزہ) چکھے (اور) جو پہلے ہو چکا وہ خدا نے معاف کر دیا اور جو پھر (ایسا کام) کرے گا تو خدا اس سے انتقام لے گا اور خدا غالب اور انتقام لینے والا ہے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@dcclxv{تمہارے لیے دریا (کی چیزوں) کا شکار اور ان کا کھانا حلال کر دیا گیا ہے (یعنی) تمہارے اور مسافروں کے فائدے کے لیے اور جنگل (کی چیزوں) کا شکار جب تک تم احرام کی حالت میں رہو تم پر حرام ہے اور خدا سے جس کے پاس تم (سب) جمع کئے جاؤ گے ڈرتے رہو\qt@no{96}}%
\qt@newcmd\qurantrans@ur@dcclxvi{خدا نے عزت کے گھر (یعنی) کعبے کو لوگوں کے لیے موجب امن مقرر فرمایا ہے اور عزت کے مہینوں کو اور قربانی کو اور ان جانوروں کو جن کے گلے میں پٹے بندھے ہوں یہ اس لیے کہ تم جان لو کہ جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے خدا سب کو جانتا ہے اور یہ کہ خدا کو ہر چیز کا علم ہے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@dcclxvii{جان رکھو کہ خدا سخت غداب دینے والا ہے اور یہ کہ خدا بخشنے والا مہربان بھی ہے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@dcclxviii{پیغمبر کے ذمے تو صرف پیغام خدا کا پہنچا دینا ہے اور جو کچھ تم ظاہر کرتے ہو اور جو کچھ مخفی کرتے ہو خدا کو سب معلوم ہے\qt@no{99}}%
\qt@newcmd\qurantrans@ur@dcclxix{کہہ دو کہ ناپاک چیزیں اور پاک چیزیں برابر نہیں ہوتیں گو ناپاک چیزوں کی کثرت تمہیں خوش ہی لگے تو عقل والو خدا سے ڈرتے رہو تاکہ رستگاری حاصل کرو\qt@no{100}}%
\qt@newcmd\qurantrans@ur@dcclxx{مومنو! ایسی چیزوں کے بارے میں مت سوال کرو کہ اگر (ان کی حقیقتیں) تم پر ظاہر کر دی جائیں تو تمہیں بری لگیں اور اگر قرآن کے نازل ہونے کے ایام میں ایسی باتیں پوچھو گے تو تم پر ظاہر بھی کر دی جائیں گی (اب تو) خدا نے ایسی باتوں (کے پوچھنے) سے درگزر فرمایا ہے اور خدا بخشنے والا بردبار ہے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@dcclxxi{اس طرح کی باتیں تم سے پہلے لوگوں نے بھی پوچھی تھیں (مگر جب بتائی گئیں تو) پھر ان سے منکر ہو گئے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@dcclxxii{خدا نے نہ تو بحیرہ کچھ چیز بنایا ہے اور نہ سائبہ اور نہ وصیلہ اور نہ حام بلکہ کافر خدا پر جھوٹ افترا کرتے ہیں اور یہ اکثر عقل نہیں رکھتے\qt@no{103}}%
\qt@newcmd\qurantrans@ur@dcclxxiii{اور جب ان لوگوں سے کہا جاتا ہے کہ جو (کتاب) خدا نے نازل فرمائی ہے اس کی اور رسول الله کی طرف رجوع کرو تو کہتے ہیں کہ جس طریق پر ہم نے اپنے باپ دادا کو پایا ہے وہی ہمیں کافی ہے بھلا اگر ان کے باپ دادا نہ تو کچھ جانتے ہوں اور نہ سیدھے رستے پر ہوں (تب بھی؟)\qt@no{104}}%
\qt@newcmd\qurantrans@ur@dcclxxiv{اے ایمان والو! اپنی جانوں کی حفاظت کرو جب تم ہدایت پر ہو تو کوئی گمراہ تمہارا کچھ بھی بگاڑ نہیں سکتا تم سب کو خدا کی طرف لوٹ کر جانا ہے اس وقت وہ تم کو تمہارے سب کاموں سے جو (دنیا میں) کئے تھے آگاہ کرے گا (اور ان کا بدلہ دے گا)\qt@no{105}}%
\qt@newcmd\qurantrans@ur@dcclxxv{مومنو! جب تم میں سے کسی کی موت آموجود ہو تو شہادت (کا نصاب) یہ ہے کہ وصیت کے وقت تم (مسلمانوں) میں سے دو عادل (یعنی صاحب اعتبار) گواہ ہوں یا اگر (مسلمان نہ ملیں اور) تم سفر کر رہے ہو اور (اس وقت) تم پر موت کی مصیبت واقع ہو تو کسی دوسرے مذہب کے دو (شخصوں کو) گواہ (کر لو) اگر تم کو ان گواہوں کی نسبت کچھ شک ہو تو ان کو (عصر کی) نماز کے بعد کھڑا کرو اور دونوں خدا کی قسمیں کھائیں کہ ہم شہادت کا کچھ عوض نہیں لیں گے گو ہمارا رشتہ دار ہی ہو اور نہ ہم الله کی شہادت کو چھپائیں گے اگر ایسا کریں گے تو گنہگار ہوں گے\qt@no{106}}%
\qt@newcmd\qurantrans@ur@dcclxxvi{پھر اگر معلوم ہو جائے کہ ان دونوں نے (جھوٹ بول کر) گناہ حاصل کیا ہے تو جن لوگوں کا انہوں نے حق مارنا چاہا تھا ان میں سے ان کی جگہ اور دو گواہ کھڑے ہوں جو (میت سے) قرابت قریبہ رکھتے ہوں پھر وہ خدا کی قسمیں کھائیں کہ ہماری شہادت ان کی شہادت سے بہت اچھی ہے اور ہم نے کوئی زیادتی نہیں کی ایسا کیا ہو تو ہم بےانصاف ہیں\qt@no{107}}%
\qt@newcmd\qurantrans@ur@dcclxxvii{اس طریق سے بہت قریب ہے کہ یہ لوگ صحیح صحیح شہادت دیں یا اس بات سے خوف کریں کہ (ہماری) قسمیں ان کی قسموں کے بعد رد کر دی جائیں گی اور خدا سے ڈرو اور اس کے حکموں کو (گوشِ ہوش سے) سنو اور خدا نافرمان لوگوں کو ہدایت نہیں دیتا\qt@no{108}}%
\qt@newcmd\qurantrans@ur@dcclxxviii{وہ دن یاد رکھنے کے لائق ہے) جس دن خدا پیغمبروں کو جمع کرے گا پھر ان سے پوچھے گا کہ تمہیں کیا جواب ملا تھا وہ عرض کریں گے کہ ہمیں کچھ معلوم نہیں توہی غیب کی باتوں سے واقف ہے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@dcclxxix{جب خدا (عیسیٰ سے) فرمائے گا کہ اے عیسیٰ بن مریم! میرے ان احسانوں کو یاد کرو جو میں نے تم پر اور تمہاری والدہ پر کئے جب میں نے روح القدس (یعنی جبرئیل) سے تمہاری مدد کی تم جھولے میں اور جوان ہو کر (ایک ہی نسق پر) لوگوں سے گفتگو کرتے تھے اور جب میں نے تم کو کتاب اور دانائی اور تورات اور انجیل سکھائی اور جب تم میرے حکم سے مٹی کا جانور بنا کر اس میں پھونک مار دیتے تھے تو وہ میرے حکم سے اڑنے لگتا تھا اور مادر زاد اندھے اور سفید داغ والے کو میرے حکم سے چنگا کر دیتے تھے اور مردے کو میرے حکم سے (زندہ کرکے قبر سے) نکال کھڑا کرتے تھے اور جب میں نے بنی اسرائیل (کے ہاتھوں) کو تم سے روک دیا جب تم ان کے پاس کھلے نشان لے کر آئے تو جو ان میں سے کافر تھے کہنے لگے کہ یہ صریح جادو ہے\qt@no{110}}%
\qt@newcmd\qurantrans@ur@dcclxxx{اور جب میں نے حواریوں کی طرف حکم بھیجا کہ مجھ پر اور میرے پیغمبر پر ایمان لاؤ وہ کہنے لگے کہ (پروردگار) ہم ایمان لائے تو شاہد رہیو کہ ہم فرمانبردار ہیں\qt@no{111}}%
\qt@newcmd\qurantrans@ur@dcclxxxi{وہ قصہ بھی یاد کرو) جب حواریوں نے کہا کہ اے عیسیٰ بن مریم! کیا تمہارا پروردگار ایسا کر سکتا ہے کہ ہم پر آسمان سے (طعام کا) خوان نازل کرے؟ انہوں نے کہا کہ اگر ایمان رکھتے ہو تو خدا سے ڈرو\qt@no{112}}%
\qt@newcmd\qurantrans@ur@dcclxxxii{وہ بولے کہ ہماری یہ خواہش ہے کہ ہم اس میں سے کھائیں اور ہمارے دل تسلی پائیں اور ہم جان لیں کہ تم نے ہم سے سچ کہا ہے اور ہم اس (خوان کے نزول) پر گواہ رہیں\qt@no{113}}%
\qt@newcmd\qurantrans@ur@dcclxxxiii{تب) عیسیٰ بن مریم نے دعا کی کہ اے ہمارے پروردگار! ہم پر آسمان سے خوان نازل فرما کہ ہمارے لیے (وہ دن) عید قرار پائے یعنی ہمارے اگلوں اور پچھلوں (سب) کے لیے اور وہ تیری طرف سے نشانی ہو اور ہمیں رزق دے تو بہتر رزق دینے والا ہے\qt@no{114}}%
\qt@newcmd\qurantrans@ur@dcclxxxiv{خدا نے فرمایا میں تم پر ضرور خوان نازل فرماؤں گا لیکن جو اس کے بعد تم میں سے کفر کرے گا اسے ایسا عذاب دوں گا کہ اہل عالم میں کسی کو ایسا عذاب نہ دوں گا\qt@no{115}}%
\qt@newcmd\qurantrans@ur@dcclxxxv{اور (اس وقت کو بھی یاد رکھو) جب خدا فرمائے گا کہ اے عیسیٰ بن مریم! کیا تم نے لوگوں سے کہا تھا کہ خدا کے سوا مجھے اور میری والدہ کو معبود مقرر کرو؟ وہ کہیں گے کہ تو پاک ہے مجھے کب شایاں تھا کہ میں ایسی بات کہتا جس کا مجھے کچھ حق نہیں اگر میں نے ایسا کہا ہوگا تو تجھ کو معلوم ہوگا (کیونکہ) جو بات میرے دل میں ہے تو اسے جانتا ہے اور جو تیرے ضمیر میں ہے اسے میں نہیں جانتا بےشک تو علاّم الغیوب ہے\qt@no{116}}%
\qt@newcmd\qurantrans@ur@dcclxxxvi{میں نے ان سے کچھ نہیں کہا بجز اس کے جس کا تو نے مجھے حکم دیا ہے وہ یہ کہ تم خدا کی عبادت کرو جو میرا اور تمہارا سب کا پروردگار ہے اور جب تک میں ان میں رہا ان (کے حالات) کی خبر رکھتا رہا جب تو نے مجھے دنیا سے اٹھا لیا تو تو ان کا نگران تھا اور تو ہر چیز سے خبردار ہے\qt@no{117}}%
\qt@newcmd\qurantrans@ur@dcclxxxvii{اگر تو ان کو عذاب دے تو یہ تیرے بندے ہیں اور اگر بخش دے تو (تیری مہربانی ہے) بےشک تو غالب اور حکمت والا ہے\qt@no{118}}%
\qt@newcmd\qurantrans@ur@dcclxxxviii{خدا فرمائے گا کہ آج وہ دن ہے کہ راست بازوں کو ان کی سچائی ہی فائدہ دے گی ان کے لئے باغ ہیں جن کے نیچے نہریں بہہ رہی ہیں ابدالآباد ان میں بستے رہیں گے خدا ان سے خوش ہے اور وہ خدا سے خوش ہیں یہ بڑی کامیابی ہے\qt@no{119}}%
\qt@newcmd\qurantrans@ur@dcclxxxix{آسمان اور زمین اور جو کچھ ان (دونوں) میں ہے سب پر خدا ہی کی بادشاہی ہے اور وہ ہر چیز پر قادر ہے\qt@no{120}}%
\qt@newcmd\qurantrans@ur@dccxc{\basmalahur ہر طرح کی تعریف خدا ہی کو سزاوار ہے جس نے آسمانوں اور زمین کو پیدا کیا اور اندھیرا اور روشنی بنائی پھر بھی کافر (اور چیزوں کو) خدا کے برابر ٹھیراتے ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@dccxci{وہی تو ہے جس نے تم کو مٹی سے پیدا کیا پھر (مرنے کا) ایک وقت مقرر کر دیا اور ایک مدت اس کے ہاں اور مقرر ہے پھر بھی تم (اے کافرو خدا کے بارے میں) شک کرتے ہو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@dccxcii{اور آسمانوں اور زمین میں وہی (ایک) خدا ہے تمہاری پوشیدہ اور ظاہر سب باتیں جانتا ہے اور تم جو عمل کرتے ہو سب سے واقف ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@dccxciii{اور خدا کی نشانیوں میں سے کوئی نشانی ان لوگوں کے پاس نہیں آتی مگر یہ اس سے منہ پھیر لیتے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@dccxciv{جب ان کے پاس حق آیا تو اس کو بھی جھٹلا دیا سو ان کو ان چیزوں کا جن سے یہ استہزا کرتے ہیں عنقریب انجام معلوم ہو جائے گا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@dccxcv{کیا انہوں نے نہیں دیکھا کہ ہم نے ان سے پہلے کتنی امتوں کو ہلاک کر دیا جن کے پاؤں ملک میں ایسے جما دیئے تھے کہ تمہارے پاؤں بھی ایسے نہیں جمائے اور ان پر آسمان سے لگاتار مینہ برسایا اور نہریں بنا دیں جو ان کے (مکانوں کے) نیچے بہہ رہی تھیں پھر ان کو ان کے گناہوں کے سبب ہلاک کر دیا اور ان کے بعد اور امتیں پیدا کر دیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@dccxcvi{اور اگر ہم تم پر کاغذوں پر لکھی ہوئی کتاب نازل کرتے اور یہ اسے اپنے ہاتھوں سے بھی ٹٹول لیتے تو جو کافر ہیں وہ یہی کہہ دیتے کہ یہ تو (صاف اور) صریح جادو ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@dccxcvii{اور کہتے ہیں کہ ان (پیغمبر) پر فرشتہ کیوں نازل نہ ہوا (جو ان کی تصدیق کرتا) اگر ہم فرشتہ نازل کرتے تو کام ہی فیصل ہو جاتا پھر انھیں (مطلق) مہلت نہ دی جاتی\qt@no{8}}%
\qt@newcmd\qurantrans@ur@dccxcviii{نیز اگر ہم کسی فرشتہ کو بھیجتے تو اسے مرد کی صورت میں بھیجتے اور جو شبہ (اب) کرتے ہیں اسی شبے میں پھر انہیں ڈال دیتے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@dccxcix{اور تم سے پہلے بھی پیغمبروں کے ساتھ تمسخر ہوتے رہے ہیں سو جو لوگ ان میں سے تمسخر کیا کرتے تھے ان کو تمسخر کی سزا نے آگھیرا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@dccc{کہو کہ (اے منکرین رسالت) ملک میں چلو پھرو پھر دیکھو کہ جھٹلانے والوں کا کیا انجام ہوا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@dccci{ان سے) پوچھو کہ آسمان اور زمین میں جو کچھ ہے کس کا ہے کہہ دو خدا کا اس نے اپنی ذات (پاک) پر رحمت کو لازم کر لیا ہے وہ تم سب کو قیامت کے دن جس میں کچھ بھی شک نہیں ضرور جمع کرے گا جن لوگوں نے اپنے تیئیں نقصان میں ڈال رکھا ہے وہ ایمان نہیں لاتے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@dcccii{اور جو مخلوق رات اور دن میں بستی ہے سب اسی کی ہے اور وہ سنتا جانتا ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@dccciii{کہو کیا میں خدا کو چھوڑ کر کسی اور کو مددگار بناؤں کہ (وہی تو) آسمانوں اور زمین کا پیدا کرنے والا ہے اور وہی (سب کو) کھانا دیتا ہے اور خود کسی سے کھانا نہیں لیتا (یہ بھی) کہہ دو کہ مجھے یہ حکم ہوا ہے کہ میں سب سے پہلے اسلام لانے والا ہوں اور یہ کہ تم (اے پیغمبر!) مشرکوں میں نہ ہونا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@dccciv{یہ بھی) کہہ دو کہ اگر میں اپنے پروردگار کی نافرمانی کروں تو مجھے بڑے دن کے عذاب کا خوف ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@dcccv{جس شخص سے اس روز عذاب ٹال دیا گیا اس پر خدا نے (بڑی) مہربانی فرمائی اور یہ کھلی کامیابی ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@dcccvi{اور اگر خدا تم کو کوئی سختی پہنچائے تو اس کے سوا اس کو کوئی دور کرنے والا نہیں اور اگر نعمت (وراحت) عطا کرے تو (کوئی اس کو روکنے والا نہیں) وہ ہر چیز پر قادر ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@dcccvii{اور وہ اپنے بندوں پر غالب ہے اور وہ دانا اور خبردار ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@dcccviii{ان سے پوچھو کہ سب سے بڑھ کر (قرین انصاف) کس کی شہادت ہے کہہ دو کہ خدا ہی مجھ میں اور تم میں گواہ ہے اور یہ قرآن مجھ پر اس لیے اتارا گیا ہے کہ اس کے ذریعے سے تم کو اور جس شخص تک وہ پہنچ سکے آگاہ کردوں کیا تم لوگ اس بات کی شہادت دیتے ہو کہ خدا کے ساتھ اور بھی معبود ہیں (اے محمدﷺ!) کہہ دو کہ میں تو (ایسی) شہادت نہیں دیتا کہہ دو کہ صرف وہی ایک معبود ہے اور جن کو تم لوگ شریک بناتے ہو میں ان سے بیزار ہوں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@dcccix{جن لوگوں کو ہم نے کتاب دی ہے وہ ان (ہمارے پیغمبرﷺ) کو اس طرح پہچانتے ہیں جس طرح اپنے بیٹوں کو پہچانا کرتے ہیں جنہوں نے اپنے تئیں نقصان میں ڈال رکھا ہے وہ ایمان نہیں لاتے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@dcccx{اور اس شخص سے زیادہ کون ظالم ہے جس نے خدا پر جھوٹ افتراء کیا یا اس کی آیتوں کو جھٹلایا۔ کچھ شک نہیں کہ ظالم لوگ نجات نہیں پائیں گے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@dcccxi{اور جس دن ہم سب لوگوں کو جمع کریں گے پھر مشرکوں سے پوچھیں گے کہ (آج) وہ تمہارے شریک کہاں ہیں جن کو تمہیں دعویٰ تھا\qt@no{22}}%
\qt@newcmd\qurantrans@ur@dcccxii{تو ان سے کچھ عذر نہ بن پڑے گا (اور) بجز اس کے (کچھ چارہ نہ ہوگا) کہ کہیں خدا کی قسم جو ہمارا پروردگار ہے ہم شریک نہیں بناتے تھے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@dcccxiii{دیکھو انہوں نے اپنے اوپر کیسا جھوٹ بولا اور جو کچھ یہ افتراء کیا کرتے تھے سب ان سے جاتا رہا\qt@no{24}}%
\qt@newcmd\qurantrans@ur@dcccxiv{اور ان میں بعض ایسے ہیں کہ تمہاری (باتوں کی) طرف کان رکھتے ہیں۔ اور ہم نے ان کے دلوں پر تو پردے ڈال دیئے ہیں کہ ان کو سمجھ نہ سکیں اور کانوں میں ثقل پیدا کردیا ہے (کہ سن نہ سکیں) اور اگر یہ تمام نشانیاں بھی دیکھ لیں تب بھی ان پر ایمان نہ لائیں۔ یہاں تک کہ جب تمہارے پاس تم سے بحث کرنے کو آتے ہیں تو جو کافر ہیں کہتے ہیں یہ (قرآن) اور کچھ بھی نہیں صرف پہلے لوگوں کی کہانیاں ہیں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@dcccxv{وہ اس سے (اوروں کو بھی) روکتے ہیں اور خود بھی پرے رہتے ہیں مگر (ان باتوں سے) اپنے آپ ہی کو ہلاک کرتے ہیں اور (اس سے) بےخبر ہیں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@dcccxvi{کاش تم (ان کو اس وقت) دیکھو جب یہ دوزخ کے کنارے کھڑے کئے جائیں گے اور کہیں گے کہ اے کاش ہم پھر (دنیا میں) لوٹا دیئے جائیں تاکہ اپنے پروردگار کی آیتوں کی تکذیب نہ کریں اور مومن ہوجائیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@dcccxvii{ہاں یہ جو کچھ پہلے چھپایا کرتے تھے (آج) ان پر ظاہر ہوگیا ہے اور اگر یہ (دنیا میں) لوٹائے بھی جائیں تو جن (کاموں) سے ان کو منع کیا گیا تھا وہی پھر کرنے لگیں۔کچھ شک نہیں کہ یہ جھوٹے ہیں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@dcccxviii{اور کہتے ہیں کہ ہماری جو دنیا کی زندگی ہے بس یہی (زندگی) ہے اور ہم (مرنے کے بعد) پھر زندہ نہیں کئے جائیں گے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@dcccxix{اور کاش تم (ان کو اس وقت) دیکھو جب یہ اپنے پروردگار کےسامنے کھڑے کئے جائیں گے اور وہ فرمائےگا کیا یہ (دوبارہ زندہ ہونا) برحق نہیں تو کہیں گے کیوں نہیں پروردگار کی قسم (بالکل برحق ہے) خدا فرمائے گا اب کفر کے بدلے (جو دنیا میں کرتے تھے) عذاب (کے مزے) چکھو\qt@no{30}}%
\qt@newcmd\qurantrans@ur@dcccxx{جن لوگوں نے خدا کے روبرو حاضر ہونے کو جھوٹ سمجھا وہ گھاٹے میں آگئے۔ یہاں تک کہ جب ان پر قیامت ناگہاں آموجود ہوگی تو بول اٹھیں گے کہ (ہائے) اس تقصیر پر افسوس ہے جو ہم نے قیامت کے بارے میں کی۔ اور وہ اپنے (اعمال کے) بوجھ اپنی پیٹھوں پر اٹھائے ہوئے ہوں گے۔ دیکھو جو بوجھ یہ اٹھا رہے ہیں بہت برا ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@dcccxxi{اور دنیا کی زندگی تو ایک کھیل اور مشغولہ ہے۔ اور بہت اچھا گھر تو آخرت کا گھر ہے (یعنی) ان کے لئے جو (خدا سے) ڈرتے ہیں۔ کیا تم سمجھتے نہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@dcccxxii{ہم کو معلوم ہے کہ ان (کافروں) کی باتیں تمہیں رنج پہنچاتی ہیں (مگر) یہ تمہاری تکذیب نہیں کرتے بلکہ ظالم خدا کی آیتوں سے انکار کرتے ہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@dcccxxiii{اور تم سے پہلے کبھی پیغمبر جھٹلائے جاتے رہے تو وہ تکذیب اور ایذا پر صبر کرتے رہے یہاں تک کہ ان کے پاس ہماری مدد پہنچتی رہی اور خدا کی باتوں کو کوئی بھی بدلنے والا نہیں۔ اور تم کو پیغمبروں (کے احوال) کی خبریں پہنچ چکی ہیں (تو تم بھی صبر سے کام لو)\qt@no{34}}%
\qt@newcmd\qurantrans@ur@dcccxxiv{اور اگر ان کی روگردانی تم پر شاق گزرتی ہے تو اگر طاقت ہو تو زمین میں کوئی سرنگ ڈھونڈ نکالو یا آسمان میں سیڑھی (تلاش کرو) پھر ان کے پاس کوئی معجزہ لاؤ۔ اور اگر خدا چاہتا تو سب کو ہدایت پر جمع کردیتا پس تم ہرگز نادانوں میں نہ ہونا\qt@no{35}}%
\qt@newcmd\qurantrans@ur@dcccxxv{بات یہ ہے کہ (حق کو) قبول وہی کرتے ہیں جو سنتے بھی ہیں اور مردوں کو تو خدا (قیامت ہی کو) اٹھائے گا۔ پھر اسی کی طرف لوٹ کر جائیں گے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@dcccxxvi{اور کہتے ہیں کہ ان پر ان کے پروردگارکے پاس کوئی نشانی کیوں نازل نہیں ہوئی۔ کہہ دو کہ خدا نشانی اتارنے پر قادر ہے لیکن اکثر لوگ نہیں جانتے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@dcccxxvii{اور زمین میں جو چلنے پھرنے والا (حیوان) یا دو پروں سے اڑنے والا جانور ہے ان کی بھی تم لوگوں کی طرح جماعتیں ہیں۔ ہم نے کتاب (یعنی لوح محفوظ) میں کسی چیز (کے لکھنے) میں کوتاہی نہیں کی پھر سب اپنے پروردگار کی طرف جمع کئے جائیں گے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@dcccxxviii{اور جن لوگوں نے ہماری آیتوں کو جھٹلایا وہ بہرے اور گونگے ہیں (اس کے علاوہ) اندھیرے میں (پڑے ہوئے) جس کو خدا چاہے گمراہ کردے اور جسے چاہے سیدھے رستے پر چلا دے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@dcccxxix{کہو (کافرو) بھلا دیکھو تو اگر تم پر خدا کا عذاب آجائےیا قیامت آموجود ہو تو کیا تم (ایسی حالت میں) خدا کے سوا کسی اور کو پکارو گے؟ اگر سچے ہو (تو بتاؤ)\qt@no{40}}%
\qt@newcmd\qurantrans@ur@dcccxxx{بلکہ (مصیبت کے وقت تم) اسی کو پکارتے ہو تو جس دکھ کے لئے اسے پکارتے ہو۔ وہ اگر چاہتا ہے تو اس کو دور کردیتا ہے اور جن کو تم شریک بناتے ہو (اس وقت) انہیں بھول جاتے ہو\qt@no{41}}%
\qt@newcmd\qurantrans@ur@dcccxxxi{اور ہم نے تم سے پہلے بہت سی امتوں کی طرف پیغمبر بھیجے۔ پھر (ان کی نافرمانیوں کے سبب) ہم انہیں سختیوں اور تکلیفوں میں پکڑتے رہے تاکہ عاجزی کریں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@dcccxxxii{تو جب ان پر ہمارا عذاب آتا رہا کیوں نہیں عاجزی کرتے رہے۔ مگر ان کے تو دل ہی سخت ہوگئے تھے۔ اور جو وہ کام کرتے تھے شیطان ان کو (ان کی نظروں میں) آراستہ کر دکھاتا تھا\qt@no{43}}%
\qt@newcmd\qurantrans@ur@dcccxxxiii{پھر جب انہوں نے اس نصیحت کو جو ان کو کے گئی تھی فراموش کردیا تو ہم نے ان پر ہر چیز کے دروازے کھول دیئے۔ یہاں تک کہ جب ان چیزوں سے جو ان کو دی گئی تھیں خوب خوش ہوگئے تو ہم نے ان کو ناگہاں پکڑ لیا اور وہ اس وقت مایوس ہو کر رہ گئے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@dcccxxxiv{غرض ظالم لوگوں کی جڑ کاٹ دی گئی۔ اور سب تعریف خدائے رب العالمین ہی کو (سزاوار ہے)\qt@no{45}}%
\qt@newcmd\qurantrans@ur@dcccxxxv{ان کافروں سے) کہو کہ بھلا دیکھو تو اگر خدا تمہارے کان اور آنکھیں چھین لے اور تمہارے دلوں پر مہر لگادے تو خداکے سوا کون سا معبود ہے جو تمہیں یہ نعمتیں پھر بخشے؟ دیکھو ہم کس کس طرح اپنی آیتیں بیان کرتے ہیں۔ پھر بھی یہ لوگ ردگردانی کرتے ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@dcccxxxvi{کہو کہ بھلا بتاؤ تو اگر تم پر خدا کا عذاب بےخبری میں یا خبر آنے کے بعد آئے تو کیا ظالم لوگوں کے سوا کوئی اور بھی ہلاک ہوگا؟\qt@no{47}}%
\qt@newcmd\qurantrans@ur@dcccxxxvii{اور ہم جو پیغمبروں کو بھیجتے رہے ہیں تو خوشخبری سنانے اور ڈرانے کو پھر جو شخص ایمان لائے اور نیکوکار ہوجائے تو ایسے لوگوں کو نہ کچھ خوف ہوگا اور نہ وہ اندوہناک ہوں گے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@dcccxxxviii{اور جنہوں نے ہماری آیتوں کو جھٹلایا ان کی نافرمانیوں کے سبب انہیں عذاب ہوگا\qt@no{49}}%
\qt@newcmd\qurantrans@ur@dcccxxxix{کہہ دو کہ میں تم سے یہ نہیں کہتا کہ میرے پاس الله تعالیٰ کے خزانے ہیں اور نہ (یہ کہ) میں غیب جانتا ہوں اور نہ تم سے یہ کہتا کہ میں فرشتہ ہوں۔ میں تو صرف اس حکم پر چلتا ہوں جو مجھے (خدا کی طرف سے) آتا ہے۔ کہہ دو کہ بھلا اندھا اور آنکھ والے برابر ہوتے ہیں؟ تو پھر تم غور کیوں نہیں کرتے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@dcccxl{اور جو لوگ جو خوف رکھتے ہیں کہ اپنے پروردگار کے روبرو حاضر کئے جائیں گے (اور جانتے ہیں کہ) اس کے سوا نہ تو ان کا کوئی دوست ہوگا اور نہ سفارش کرنے والا، ان کو اس (قرآن) کے ذریعے سے نصیحت کر دو تاکہ پرہیزگار بنیں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@dcccxli{اور جو لوگ صبح وشام اپنی پروردگار سے دعا کرتے ہیں (اور) اس کی ذات کے طالب ہیں ان کو (اپنے پاس سے) مت نکالو۔ ان کے حساب (اعمال) کی جوابدہی تم پر کچھ نہیں اور تمہارے حساب کی جوابدہی ان پر کچھ نہیں (پس ایسا نہ کرنا) اگر ان کو نکالوگے تو ظالموں میں ہوجاؤ گے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@dcccxlii{اور اسی طرح ہم نے بعض لوگوں کی بعض سے آزمائش کی ہے کہ (جو دولتمند ہیں وہ غریبوں کی نسبت) کہتے ہیں کیا یہی لوگ ہیں جن پر خدا نے ہم میں سے فضل کیا ہے (خدا نے فرمایا) بھلا خدا شکر کرنے والوں سے واقف نہیں؟\qt@no{53}}%
\qt@newcmd\qurantrans@ur@dcccxliii{اور جب تمہارے پاس ایسے لوگ آیا کریں جو ہماری آیتوں پر ایمان لاتے ہیں تو (ان سے) سلام علیکم کہا کرو خدا نے اپنی ذات (پاک) پر رحمت کو لازم کرلیا ہے کہ جو کوئی تم میں نادانی سے کوئی بری حرکت کر بیٹھے پھر اس کے بعد توبہ کرلے اور نیکوکار ہوجائے تو وہ بخشنے والا مہربان ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@dcccxliv{اور اس طرح ہم اپنی آیتیں کھول کھول کر بیان کرتے ہیں (تاکہ تم لوگ ان پر عمل کرو) اور اس لئے کہ گنہگاروں کا رستہ ظاہر ہوجائے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@dcccxlv{اے پیغمبر! کفار سے) کہہ دو کہ جن کو تم خدا کے سوا پکارتے ہو مجھے ان کی عبادت سے منع کیا گیا ہے۔ (یہ بھی) کہہ دو کہ میں تمہاری خواہشوں کی پیروی نہیں کروں گا ایسا کروں تو گمراہ ہوجاؤں اور ہدایت یافتہ لوگوں میں نہ رہوں\qt@no{56}}%
\qt@newcmd\qurantrans@ur@dcccxlvi{کہہ دو کہ میں تو اپنے پروردگار کی دلیل روشن پر ہوں اور تم اس کی تکذیب کرتے ہو۔ جس چیز (یعنی عذاب) کے لئے تم جلدی کر رہے ہو وہ میرے پاس نہیں ہے (ایسا) حکم الله ہی کے اختیار میں ہے وہ سچی بات بیان فرماتا ہے اور وہ سب سے بہتر فیصلہ کرنے والا ہے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@dcccxlvii{کہہ دو کہ جس چیز کے لئے تم جلدی کر رہے ہو اگر وہ میرے اختیار میں ہوتی تو مجھ میں اور تم میں فیصلہ ہوچکا ہوتا۔ اور خدا ظالموں سے خوب واقف ہے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@dcccxlviii{اور اسی کے پاس غیب کی کنجیاں ہیں جن کو اس کے سوا کوئی نہیں جانتا۔ اور اسے جنگلوں اور دریاؤں کی سب چیزوں کا علم ہے۔ اور کوئی پتہ نہیں جھڑتا مگر وہ اس کو جانتا ہے اور زمین کے اندھیروں میں کوئی دانہ اور کوئی ہری اور سوکھی چیز نہیں ہے مگر کتاب روشن میں (لکھی ہوئی) ہے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@dcccxlix{اور وہی تو ہے جو رات کو (سونے کی حالت میں) تمہاری روح قبض کرلیتا ہے اور جو کچھ تم دن میں کرتے ہو اس سے خبر رکھتا ہے پھر تمہیں دن کو اٹھا دیتا ہے تاکہ (یہی سلسلہ جاری رکھ کر زندگی کی) معین مدت پوری کردی جائے پھر تم (سب) کو اسی کی طرف لوٹ کر جانا ہے (اس روز) وہ تم کو تمہارے عمل جو تم کرتے ہو (ایک ایک کرکے) بتائے گا\qt@no{60}}%
\qt@newcmd\qurantrans@ur@dcccl{اور وہ اپنے بندوں پر غالب ہے۔ اور تم پر نگہبان مقرر کئے رکھتا ہے۔ یہاں تک کہ جب تم میں سے کسی کی موت آتی ہے تو ہمارے فرشتے اس کی روح قبض کرلیتے ہیں اور وہ کسی طرح کی کوتاہی نہیں کرتے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@dcccli{پھر (قیامت کے دن تمام) لوگ اپنے مالک برحق خدا تعالیٰ کے پاس واپس بلائے جائیں گے۔ سن لو کہ حکم اسی کا ہے اور وہ نہایت جلد حساب لینے والا ہے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@dccclii{کہو بھلا تم کو جنگلوں اور دریاؤں کے اندھیروں سے کون مخلصی دیتا ہے (جب) کہ تم اسے عاجزی اور نیاز پنہانی سے پکارتے ہو (اور کہتے ہو) اگر خدا ہم کو اس (تنگی) سے نجات بخشے تو ہم اس کے بہت شکر گزار ہوں\qt@no{63}}%
\qt@newcmd\qurantrans@ur@dcccliii{کہو کہ خدا ہی تم کو اس (تنگی) سے اور ہر سختی سے نجات بخشتا ہے۔ پھر (تم) اس کے ساتھ شرک کرتے ہو\qt@no{64}}%
\qt@newcmd\qurantrans@ur@dcccliv{کہہ دو کہ وہ (اس پر بھی) قدرت رکھتا ہے کہ تم پر اوپر کی طرف سے یا تمہارے پاؤں کے نیچے سے عذاب بھیجے یا تمہیں فرقہ فرقہ کردے اور ایک کو دوسرے (سے لڑا کر آپس) کی لڑائی کا مزہ چکھادے۔ دیکھو ہم اپنی آیتوں کو کس کس طرح بیان کرتے ہیں تاکہ یہ لوگ سمجھیں\qt@no{65}}%
\qt@newcmd\qurantrans@ur@dccclv{اور اس (قرآن) کو تمہاری قوم نے جھٹلایا حالانکہ وہ سراسر حق ہے۔ کہہ دو کہ میں تمہارا داروغہ نہیں ہوں\qt@no{66}}%
\qt@newcmd\qurantrans@ur@dccclvi{ہر خبر کے لئے ایک وقت مقرر ہے اور تم کو عنقریب معلوم ہوجائے گا\qt@no{67}}%
\qt@newcmd\qurantrans@ur@dccclvii{اور جب تم ایسے لوگوں کو دیکھو جو ہماری آیتوں کے بارے میں بیہودہ بکواس کر رہے ہوں تو ان سے الگ ہوجاؤ یہاں تک کہ اور باتوں میں مصروف ہوجائیں۔ اور اگر (یہ بات) شیطان تمہیں بھلا دے تو یاد آنے پر ظالم لوگوں کے ساتھ نہ بیٹھو\qt@no{68}}%
\qt@newcmd\qurantrans@ur@dccclviii{اور پرہیزگاروں پر ان لوگوں کے حساب کی کچھ بھی جواب دہی نہیں ہاں نصیحت تاکہ وہ بھی پرہیزگار ہوں\qt@no{69}}%
\qt@newcmd\qurantrans@ur@dccclix{اور جن لوگوں نے اپنےدین کو کھیل اور تماشا بنا رکھا ہے اور دنیا کی زندگی نے ان کو دھوکے میں ڈال رکھا ہے ان سے کچھ کام نہ رکھو ہاں اس (قرآن) کے ذریعے سے نصیحت کرتے رہو تاکہ (قیامت کے دن) کوئی اپنے اعمال کی سزا میں ہلاکت میں نہ ڈالا جائے (اس روز) خدا کےسوا نہ تو کوئی اس کا دوست ہوگا اور نہ سفارش کرنے والا۔ اور اگر وہ ہر چیز (جو روئے زمین پر ہے بطور) معاوضہ دینا چاہے تو وہ اس سے قبول نہ ہو یہی لوگ ہیں کہ اپنے اعمال کے وبال میں ہلاکت میں ڈالے گئے ان کے لئے پینے کو کھولتا ہوا پانی اور دکھ دینے والا عذاب ہے اس لئے کہ کفر کرتے تھے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@dccclx{کہو۔ کیا ہم خدا کے سوا ایسی چیز کو پکاریں جو نہ ہمارا بھلا کرسکے نہ برا۔ اور جب ہم کو خدا نے سیدھا رستہ دکھا دیا تو (کیا) ہم الٹے پاؤں پھر جائیں؟ (پھر ہماری ایسی مثال ہو) جیسے کسی کو جنات نے جنگل میں بھلا دیا ہو (اور وہ) حیران (ہو رہا ہو) اور اس کے کچھ رفیق ہوں جو اس کو رستے کی طرف بلائیں کہ ہمارے پاس چلا آ۔ کہہ دو کہ رستہ تو وہی ہے جو خدا نے بتایا ہے۔ اور ہمیں تو یہ حکم ملا ہے کہ ہم خدائے رب العالمین کے فرمانبردار ہوں\qt@no{71}}%
\qt@newcmd\qurantrans@ur@dccclxi{اور یہ (بھی) کہ نماز پڑھتے رہو اور اس سے ڈرتے رہو۔ اور وہی تو ہے جس کے پاس تم جمع کئے جاؤ گے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@dccclxii{اور وہی تو ہے جس نے آسمانوں اور زمین کو تدبیر سے پیدا کیا ہے۔ اور جس دن وہ فرمائے گا کہ ہو جا تو (حشر برپا) ہوجائے گا ۔ اس کا ارشاد برحق ہے۔ اور جس دن صور پھونکا جائے گا (اس دن) اسی کی بادشاہت ہوگی۔ وہی پوشیدہ اور ظاہر (سب) کا جاننے والا ہے اور وہی دانا اور خبردار ہے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@dccclxiii{اور (وہ وقت بھی یاد کرنے کے لائق ہے) جب ابراہیم نے اپنے باپ آزر سے کہا کہ تم بتوں کو کیا معبود بناتے ہو۔ میں دیکھتا ہوں کہ تم اور تمہاری قوم صریح گمراہی میں ہو\qt@no{74}}%
\qt@newcmd\qurantrans@ur@dccclxiv{اور ہم اس طرح ابراہیم کو آسمانوں اور زمین کے عجائبات دکھانے لگے تاکہ وہ خوب یقین کرنے والوں میں ہوجائیں\qt@no{75}}%
\qt@newcmd\qurantrans@ur@dccclxv{یعنی) جب رات نے ان کو (پردہٴ تاریکی سے) ڈھانپ لیا (تو آسمان میں) ایک ستارا نظر پڑا۔ کہنے لگے یہ میرا پروردگار ہے۔ جب وہ غائب ہوگیا تو کہنے لگے کہ مجھے غائب ہوجانے والے پسند نہیں\qt@no{76}}%
\qt@newcmd\qurantrans@ur@dccclxvi{پھر جب چاند کو دیکھا کہ چمک رہا ہے تو کہنے لگے یہ میرا پروردگار ہے۔ لیکن جب وہ بھی چھپ گیا تو بول اٹھے کہ میرا پروردگار مجھے سیدھا رستہ نہیں دکھائے گا تو میں ان لوگوں میں ہوجاؤں گا جو بھٹک رہے ہیں\qt@no{77}}%
\qt@newcmd\qurantrans@ur@dccclxvii{پھر جب سورج کو دیکھا کہ جگمگا رہا ہے تو کہنے لگے میرا پروردگار یہ ہے یہ سب سے بڑا ہے۔ مگر جب وہ بھی غروب ہوگیا تو کہنے لگے لوگو! جن چیزوں کو تم (خدا کا) شریک بناتے ہو میں ان سے بیزار ہوں\qt@no{78}}%
\qt@newcmd\qurantrans@ur@dccclxviii{میں نے سب سے یکسو ہو کر اپنے تئیں اسی ذات کی طرف متوجہ کیا جس نے آسمانوں اور زمین کو پیدا کیا ہے اور میں مشرکوں میں سے نہیں ہوں\qt@no{79}}%
\qt@newcmd\qurantrans@ur@dccclxix{اور ان کی قوم ان سے بحث کرنے لگی تو انہوں نے کہا کہ تم مجھ سے خدا کے بارےمیں (کیا) بحث کرتے ہو اس نے تو مجھے سیدھا رستہ دکھا دیا ہے۔ اور جن چیزوں کو تم اس کا شریک بناتے ہو میں ان سے نہیں ڈرتا۔ ہاں جو میرا پروردگار چاہے۔ میرا پروردگار اپنے علم سے ہر چیز پر احاطہ کئے ہوئے ہے۔ کیا تم خیال نہیں کرتے۔\qt@no{80}}%
\qt@newcmd\qurantrans@ur@dccclxx{بھلا میں ان چیزوں سے جن کو تم (خدا کا) شریک بناتے ہو کیونکرڈروں جب کہ تم اس سے نہیں ڈرتے کہ خدا کے ساتھ شریک بناتے ہو جس کی اس نے کوئی سند نازل نہیں کی۔ اب دونوں فریق میں سے کون سا فریق امن (اور جمعیت خاطر) کا مستحق ہے۔ اگر سمجھ رکھتے ہو (تو بتاؤ)\qt@no{81}}%
\qt@newcmd\qurantrans@ur@dccclxxi{جو لوگ ایمان لائے اور اپنے ایمان کو (شرک کے) ظلم سے مخلوط نہیں کیا ان کے امن (اور جمعیت خاطر) ہے اور وہی ہدایت پانے والے ہیں\qt@no{82}}%
\qt@newcmd\qurantrans@ur@dccclxxii{اور یہ ہماری دلیل تھی جو ہم نے ابراہیم کو ان کی قوم کے مقابلے میں عطا کی تھی۔ ہم جس کے چاہتے ہیں درجے بلند کردیتے ہیں۔ بےشک تمہارا پروردگار دانا اور خبردار ہے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@dccclxxiii{اور ہم نے ان کو اسحاق اور یعقوب بخشے۔ (اور) سب کو ہدایت دی۔ اور پہلے نوح کو بھی ہدایت دی تھی اور ان کی اولاد میں سے داؤد اور سلیمان اور ایوب اور یوسف اور موسیٰ اور ہارون کو بھی۔ اور ہم نیک لوگوں کو ایسا ہی بدلا دیا کرتے ہیں\qt@no{84}}%
\qt@newcmd\qurantrans@ur@dccclxxiv{اور زکریا اور یحییٰ اور عیسیٰ اور الیاس کو بھی۔ یہ سب نیکوکار تھے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@dccclxxv{اور اسمٰعیل اور الیسع اور یونس اور لوط کو بھی۔ اور ان سب کو جہان کے لوگوں پر فضلیت بخشی تھی\qt@no{86}}%
\qt@newcmd\qurantrans@ur@dccclxxvi{اور بعض بعض کو ان کے باپ دادا اور اولاد اور بھائیوں میں سے بھی۔ اور ان کو برگزیدہ بھی کیا تھا اور سیدھا رستہ بھی دکھایا تھا\qt@no{87}}%
\qt@newcmd\qurantrans@ur@dccclxxvii{یہ خدا کی ہدایت ہے اس پر اپنے بندوں میں سے جسے چاہے چلائے۔ اور اگر وہ لوگ شرک کرتے تو جو عمل وہ کرتے تھے سب ضائع ہوجاتے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@dccclxxviii{یہ وہ لوگ تھے جن کو ہم نے کتاب اور حکم (شریعت) اور نبوت عطا فرمائی تھی۔ اگر یہ (کفار) ان باتوں سے انکار کریں تو ہم نے ان پر (ایمان لانے کے لئے) ایسے لوگ مقرر کردیئے ہیں کہ وہ ان سے کبھی انکار کرنے والے نہیں\qt@no{89}}%
\qt@newcmd\qurantrans@ur@dccclxxix{یہ وہ لوگ ہیں جن کو خدا نے ہدایت دی تھی تو تم انہیں کی ہدایت کی پیروی کرو۔ کہہ دو کہ میں تم سے اس (قرآن) کا صلہ نہیں مانگتا۔ یہ تو جہان کے لوگوں کے لئےمحض نصیحت ہے\qt@no{90}}%
\qt@newcmd\qurantrans@ur@dccclxxx{اور ان لوگوں نے خدا کی قدر جیسی جاننی چاہیئے تھی نہ جانی۔ جب انہوں نے کہا کہ خدا نے انسان پر (وحی اور کتاب وغیرہ) کچھ بھی نازل نہیں کیا۔ کہو جو کتاب موسیٰ لے کر آئے تھے اسے کس نے نازل کیا تھا جو لوگوں کے لئے نور اور ہدایت تھی اور جسے تم نے علیحدہ علیحدہ اوراق (پر نقل) کر رکھا ہے ان (کے کچھ حصے) کو تو ظاہر کرتے ہو اور اکثر کو چھپاتے ہو۔ اور تم کو وہ باتیں سکھائی گئیں جن کو نہ تم جانتے تھے اور نہ تمہارے باپ دادا۔ کہہ دو (اس کتاب کو) خدا ہی نے (نازل کیا تھا) پھر ان کو چھوڑ دیا کہ اپنی بیہودہ بکواس میں کھیلتے رہیں\qt@no{91}}%
\qt@newcmd\qurantrans@ur@dccclxxxi{اور (ویسی ہی) یہ کتاب ہے جسے ہم نے نازل کیا ہے بابرکت جو اپنے سے پہلی (کتابوں) کی تصدیق کرتی ہے اور (جو) اس لئے (نازل کی گئی ہے) کہ تم مکے اور اس کے آس پاس کے لوگوں کو آگاہ کردو۔ اور جو لوگ آخرت پر ایمان رکھتے ہیں وہ اس کتاب پر بھی ایمان رکھتے ہیں اور وہ اپنی نمازوں کی پوری خبر رکھتے ہیں\qt@no{92}}%
\qt@newcmd\qurantrans@ur@dccclxxxii{اور اس سے بڑھ کر ظالم کون ہوگا جو خدا پر جھوٹ افتراء کرے۔ یا یہ کہے کہ مجھ پر وحی آئی ہے حالانکہ اس پر کچھ بھی وحی نہ آئی ہو اور جو یہ کہے کہ جس طرح کی کتاب خدا نے نازل کی ہے اس طرح کی میں بھی بنا لیتا ہوں۔ اور کاش تم ان ظالم (یعنی مشرک) لوگوں کو اس وقت دیکھو جب موت کی سختیوں میں (مبتلا) ہوں اور فرشتے (ان کی طرف عذاب کے لئے) ہاتھ بڑھا رہے ہوں کہ نکالو اپنی جانیں۔ آج تم کو ذلت کے عذاب کی سزا دی جائے گی اس لئے کہ تم خدا پر جھوٹ بولا کرتے تھے اور اس کی آیتوں سے سرکشی کرتے تھے\qt@no{93}}%
\qt@newcmd\qurantrans@ur@dccclxxxiii{اور جیسا ہم نے تم کو پہلی دفعہ پیدا کیا تھا ایسا ہی آج اکیلے اکیلے ہمارے پاس آئے اور جو (مال ومتاع) ہم نے تمہیں عطا فرمایا تھا وہ سب اپنی پیٹھ پیچھے چھوڑ آئے اور ہم تمہارے ساتھ تمہارے سفارشیوں کو بھی نہیں دیکھتے جن کی نسبت تم خیال کرتے تھے کہ وہ تمہارے (شفیع اور ہمارے) شریک ہیں۔ (آج) تمہارے آپس کے سب تعلقات منقطع ہوگئے اور جو دعوے تم کیا کرتے تھے سب جاتے رہے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@dccclxxxiv{بے شک خدا ہی دانے اور گٹھلی کو پھاڑ کر (ان سے درخت وغیرہ) اگاتا ہے وہی جاندار کو بے جان سے نکالتا ہے اور وہی بےجان کا جاندار سے نکالنے والا ہے۔ یہی تو خدا ہے۔ پھر تم کہاں بہکے پھرتے ہو\qt@no{95}}%
\qt@newcmd\qurantrans@ur@dccclxxxv{وہی (رات کے اندھیرے سے) صبح کی روشنی پھاڑ نکالتا ہے اور اسی نے رات کو (موجب) آرام (ٹھہرایا) اور سورج اور چاند کو (ذرائع) شمار بنایا ہے۔ یہ خدا کے (مقرر کئے ہوئے) اندازے ہیں جو غالب (اور) علم والا ہے\qt@no{96}}%
\qt@newcmd\qurantrans@ur@dccclxxxvi{اور وہی تو ہے جس نے تمہارے لئے ستارے بنائے تاکہ جنگلوں اور دریاؤں کے اندھیروں میں ان سے رستے معلوم کرو۔ عقل والوں کے لئے ہم نے اپنی آیتیں کھول کھول کر بیان کردی ہیں\qt@no{97}}%
\qt@newcmd\qurantrans@ur@dccclxxxvii{اور وہی تو ہے جس نے تم کو ایک شخص سے پیدا کیا۔ پھر (تمہارے لئے) ایک ٹھہرنے کی جگہ ہے اور ایک سپرد ہونے کی سمجھنے والوں کے لئے ہم نے (اپنی) آیتیں کھول کھول کر بیان کردی ہیں\qt@no{98}}%
\qt@newcmd\qurantrans@ur@dccclxxxviii{اور وہی تو ہے جو آسمان سے مینھ برساتا ہے۔ پھر ہم ہی (جو مینھ برساتے ہیں) اس سے ہر طرح کی روئیدگی اگاتے ہیں۔ پھر اس میں سے سبز سبز کونپلیں نکالتے ہیں۔ اور ان کونپلوں میں سے ایک دوسرے کے ساتھ جڑے ہوئے دانے نکالتے ہیں اور کھجور کے گابھے میں سے لٹکتے ہوئے گچھے اور انگوروں کے باغ اور زیتون اور انار جو ایک دوسرے سے ملتے جلتے بھی ہیں۔ اور نہیں بھی ملتے۔ یہ چیزیں جب پھلتی ہیں تو ان کے پھلوں پر اور (جب پکتی ہیں تو) ان کے پکنے پر نظر کرو۔ ان میں ان لوگوں کے لئے جو ایمان لاتے ہیں (قدرت خدا کی بہت سی) نشانیاں ہیں\qt@no{99}}%
\qt@newcmd\qurantrans@ur@dccclxxxix{اور ان لوگوں نے جنوں کو خدا کا شریک ٹھہرایا۔ حالانکہ ان کو اسی نے پیدا کیا اور بےسمجھے (جھوٹ بہتان) اس کے لئے بیٹے اور بیٹیاں بنا کھڑی کیں وہ ان باتوں سے جو اس کی نسبت بیان کرتے ہیں پاک ہے اور (اس کی شان ان سے) بلند ہے\qt@no{100}}%
\qt@newcmd\qurantrans@ur@dcccxc{وہی) آسمانوں اور زمین کا پیدا کرنے والا (ہے) ۔ اس کے اولاد کہاں سے ہو جب کہ اس کی بیوی ہی نہیں۔ اور اس نے ہر چیز کو پیدا کیا ہے۔ اور وہ ہر چیز سے باخبر ہے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@dcccxci{یہی (اوصاف رکھنے والا) خدا تمہارا پروردگار ہے۔ اس کے سوا کوئی معبود نہیں۔ (وہی) ہر چیز کا پیداکرنے والا (ہے) تو اسی کی عبادت کرو۔ اور وہ ہر چیز کا نگراں ہے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@dcccxcii{وہ ایسا ہے کہ) نگاہیں اس کا ادراک نہیں کرسکتیں اور وہ نگاہوں کا ادراک کرسکتا ہے اور وہ بھید جاننے والا خبردار ہے\qt@no{103}}%
\qt@newcmd\qurantrans@ur@dcccxciii{اے محمدﷺ! ان سے کہہ دو کہ) تمہارے (پاس) پروردگار کی طرف سے (روشن) دلیلیں پہنچ چکی ہیں تو جس نے (ان کو آنکھ کھول کر) دیکھا اس نے اپنا بھلا کیا اور جو اندھا بنا رہا اس نے اپنے حق میں برا کیا۔ اور میں تمہارا نگہبان نہیں ہوں\qt@no{104}}%
\qt@newcmd\qurantrans@ur@dcccxciv{اور ہم اسی طرح اپنی آیتیں پھیر پھیر کر بیان کرتے ہیں تاکہ کافر یہ نہ کہیں کہ تم (یہ باتیں اہل کتاب سے) سیکھے ہوئے ہو اور تاکہ سمجھنے والے لوگوں کے لئے تشریح کردیں\qt@no{105}}%
\qt@newcmd\qurantrans@ur@dcccxcv{اور جو حکم تمہارے پروردگار کی طرف سے تمہارے پاس آتا ہے اسی کی پیروی کرو۔ اس (پروردگار) کے سوا کوئی معبود نہیں۔ اور مشرکوں سے کنارہ کرلو\qt@no{106}}%
\qt@newcmd\qurantrans@ur@dcccxcvi{اور اگر خدا چاہتا تو یہ لوگ شرک نہ کرتے۔ اور (اے پیغمبر!) ہم نے تم کو ان پر نگہبان مقرر نہیں کیا۔ اور نہ تم ان کے داروغہ ہو\qt@no{107}}%
\qt@newcmd\qurantrans@ur@dcccxcvii{اور جن لوگوں کو یہ مشرک خدا کے سوا پکارتے ہیں ان کو برا نہ کہنا کہ یہ بھی کہیں خدا کو بےادبی سے بے سمجھے برا (نہ) کہہ بیٹھیں۔ اس طرح ہم نے ہر ایک فرقے کے اعمال (ان کی نظروں میں) اچھے کر دکھائے ہیں۔ پھر ان کو اپنے پروردگار ک طرف لوٹ کر جانا ہے تب وہ ان کو بتائے گا کہ وہ کیا کیا کرتے تھے\qt@no{108}}%
\qt@newcmd\qurantrans@ur@dcccxcviii{اور یہ لوگ خدا کی سخت سخت قسمیں کھاتے ہیں کہ اگر ان کے پاس کوئی نشانی آئے تو وہ اس پر ضروری ایمان لے آئیں۔ کہہ دو کہ نشانیاں تو سب خدا ہی کے پاس ہیں۔ اور (مومنو!) تمہیں کیا معلوم ہے (یہ تو ایسے بدبخت ہیں کہ ان کے پاس) نشانیاں آ بھی جائیں تب بھی ایمان نہ لائیں\qt@no{109}}%
\qt@newcmd\qurantrans@ur@dcccxcix{اور ہم ان کے دلوں اور آنکھوں کو الٹ دیں گے (تو) جیسے یہ اس (قرآن) پر پہلی دفعہ ایمان نہیں لائے (ویسے پھر نہ لائیں گے) اور ان کو چھوڑ دیں گے کہ اپنی سرکشی میں بہکتے رہیں\qt@no{110}}%
\qt@newcmd\qurantrans@ur@cm{اور اگر ہم ان پر فرشتے بھی اتار دیتے اور مردے بھی ان سے گفتگو کرنے لگتے اور ہم سب چیزوں کو ان کے سامنے لا موجود بھی کر دیتے تو بھی یہ ایمان لانے والے نہ تھے اِلّا ماشائالله بات یہ ہے کہ یہ اکثر نادان ہیں\qt@no{111}}%
\qt@newcmd\qurantrans@ur@cmi{اور اسی طرح ہم نے شیطان (سیرت) انسانوں اور جنوں کو ہر پیغمبر کا دشمن بنا دیا تھا وہ دھوکا دینے کے لیے ایک دوسرے کے دل میں ملمع کی باتیں ڈالتے رہتے تھے اور اگر تمہارا پروردگار چاہتا تو وہ ایسا نہ کرتے تو ان کو اور جو کچھ یہ افتراء کرتے ہیں اسے چھوڑ دو\qt@no{112}}%
\qt@newcmd\qurantrans@ur@cmii{اور (وہ ایسے کام) اس لیے بھی (کرتے تھے) کہ جو لوگ آخرت پر ایمان نہیں رکھتے ان کے دل ان کی باتوں پر مائل ہوں اور وہ انہیں پسند کریں اور جو کام وہ کرتے تھے وہ ہی کرنے لگیں\qt@no{113}}%
\qt@newcmd\qurantrans@ur@cmiii{کہو) کیا میں خدا کے سوا اور منصف تلاش کروں حالانکہ اس نے تمہاری طرف واضع المطالب کتاب بھیجی ہے اور جن لوگوں کو ہم نے کتاب (تورات) دی ہے وہ جانتے ہیں کہ وہ تمہارے پروردگار کی طرف سے برحق نازل ہوئی ہے تو تم ہرگز شک کرنے والوں میں نہ ہونا\qt@no{114}}%
\qt@newcmd\qurantrans@ur@cmiv{اور تمہارے پروردگار کی باتیں سچائی اور انصاف میں پوری ہیں اس کی باتوں کو کوئی بدلنے والا نہیں اور وہ سنتا جانتا ہے\qt@no{115}}%
\qt@newcmd\qurantrans@ur@cmv{اور اکثر لوگ جو زمین پر آباد ہیں (گمراہ ہیں) اگر تم ان کا کہا مان لو گے تو وہ تمہیں خدا کا رستہ بھلا دیں گے یہ محض خیال کے پیچھے چلتے اور نرے اٹکل کے تیر چلاتے ہیں\qt@no{116}}%
\qt@newcmd\qurantrans@ur@cmvi{تمہارا پروردگار ان لوگوں کو خوب جانتا ہے جو اس کے رستے سے بھٹکے ہوئے ہیں اور ان سے بھی خوب واقف ہے جو رستے پر چل رہے ہیں\qt@no{117}}%
\qt@newcmd\qurantrans@ur@cmvii{تو جس چیز پر (ذبح کے وقت) خدا کا نام لیا جائے اگر تم اس کی آیتوں پر ایمان رکھتے ہو تو اسے کھا لیا کرو\qt@no{118}}%
\qt@newcmd\qurantrans@ur@cmviii{اور سبب کیا ہے کہ جس چیز پر خدا کا نام لیا جائے تم اسے نہ کھاؤ حالانکہ جو چیزیں اس نے تمہارے لیے حرام ٹھیرا دی ہیں وہ ایک ایک کر کے بیان کر دی ہیں (بے شک ان کو نہیں کھانا چاہیے) مگر اس صورت میں کہ ان کے (کھانے کے) لیے ناچار ہو جاؤ اور بہت سے لوگ بےسمجھے بوجھے اپنے نفس کی خواہشوں سے لوگوں کو بہکا رہے ہیں کچھ شک نہیں کہ ایسے لوگوں کو جو (خدا کی مقرر کی ہوئی) حد سے باہر نکل جاتے ہیں تمہارا پروردگار خوب جانتا ہے\qt@no{119}}%
\qt@newcmd\qurantrans@ur@cmix{اور ظاہری اور پوشیدہ (ہر طرح کا) گناہ ترک کر دو جو لوگ گناہ کرتے ہیں وہ عنقریب اپنے کئے کی سزا پائیں گے\qt@no{120}}%
\qt@newcmd\qurantrans@ur@cmx{اور جس چیز پر خدا کا نام نہ لیا جائے اسے مت کھاؤ کہ اس کا کھانا گناہ ہے اور شیطان (لوگ) اپنے رفیقوں کے دلوں میں یہ بات ڈالتے ہیں کہ تم سے جھگڑا کریں اور اگر تم لوگ ان کے کہے پر چلے تو بےشک تم بھی مشرک ہوئے\qt@no{121}}%
\qt@newcmd\qurantrans@ur@cmxi{بھلا جو پہلے مردہ تھا پھر ہم نے اس کو زندہ کیا اور اس کے لیے روشنی کر دی جس کے ذریعے سے وہ لوگوں میں چلتا پھرتا ہے کہیں اس شخص جیسا ہو سکتا ہے جو اندھیرے میں پڑا ہوا ہو اور اس سے نکل ہی نہ سکے اسی طرح کافر جو عمل کر رہے ہیں وہ انہیں اچھے معلوم ہوتے ہیں\qt@no{122}}%
\qt@newcmd\qurantrans@ur@cmxii{اور اسی طرح ہم نے ہر بستی میں بڑے بڑے مجرم پیدا کئے کہ ان میں مکاریاں کرتے رہیں اور جو مکاریاں یہ کرتے ہیں ان کا نقصان انہیں کو ہے اور (اس سے) بےخبر ہیں\qt@no{123}}%
\qt@newcmd\qurantrans@ur@cmxiii{اور جب ان کے پاس کوئی آیت آتی ہے تو کہتے ہیں کہ جس طرح کی رسالت خدا کے پیغمبروں کو ملی ہے جب تک اسی طرح کی رسالت ہم کو نہ ملے ہم ہرگز ایمان نہیں لائیں گے اس کو خدا ہی خوب جانتا ہے کہ (رسالت کا کون سا محل ہے اور) وہ اپنی پیغمبری کسے عنایت فرمائے جو لوگ جرم کرتے ہیں ان کو خدا کے ہاں ذلّت اور عذابِ شدید ہوگا اس لیے کہ مکّاریاں کرتے تھے\qt@no{124}}%
\qt@newcmd\qurantrans@ur@cmxiv{تو جس شخص کو خدا چاہتا ہے کہ ہدایت بخشے اس کا سینہ اسلام کے لیے کھول دیتا ہے اور جسے چاہتا ہے کہ گمراہ کرے اس کا سینہ تنگ اور گھٹا ہوا کر دیتا ہے گویا وہ آسمان پر چڑھ رہا ہے اس طرح خدا ان لوگوں پر جو ایمان نہیں لاتے عذاب بھیجتا ہے\qt@no{125}}%
\qt@newcmd\qurantrans@ur@cmxv{اور یہی تمہارے پروردگار کا سیدھا رستہ ہے جو لوگ غور کرنے والے ہیں ان کے لیے ہم نے اپنی آیتیں کھول کھول کر بیان کر دی ہیں\qt@no{126}}%
\qt@newcmd\qurantrans@ur@cmxvi{ان کے لیے ان کے اعمال کے صلے میں پروردگار کے ہاں سلامتی کا گھر ہے اور وہی ان کا دوستدار ہے\qt@no{127}}%
\qt@newcmd\qurantrans@ur@cmxvii{اور جس دن وہ سب (جنّ وانس) کو جمع کرے گا (اور فرمائے گا کہ) اے گروہ جنّات تم نے انسانوں سے بہت (فائدے) حاصل کئے تو جو انسانوں میں ان کے دوستدار ہوں گے وہ کہیں گے کہ پروردگار ہم ایک دوسرے سے فائدہ اٹھاتے رہے اور (آخر) اس وقت کو پہنچ گئے جو تو نے ہمارے لیے مقرر کیا تھا خدا فرمائے گا (اب) تمہارا ٹھکانہ دوزخ ہے ہمیشہ اس میں (جلتے) رہو گے مگر جو خدا چاہے بےشک تمہارا پروردگار دانا اور خبردار ہے\qt@no{128}}%
\qt@newcmd\qurantrans@ur@cmxviii{اور اسی طرح ہم ظالموں کو ان کے اعمال کے سبب جو وہ کرتے تھے ایک دوسرے پر مسلط کر دیتے ہیں\qt@no{129}}%
\qt@newcmd\qurantrans@ur@cmxix{اے جنّوں اور انسانوں کی جماعت کیا تمہارے پاس تم ہی میں سے پیغمبر نہیں آتے رہے جو میری آیتیں تم کو پڑھ پڑھ کر سناتے اور اس دن کے سامنے آموجود ہونے سے ڈراتے تھے وہ کہیں گے کہ (پروردگار) ہمیں اپنے گناہوں کا اقرار ہے ان لوگوں کو دنیاکی زندگی نے دھوکے میں ڈال رکھا تھا اور (اب) خود اپنے اوپر گواہی دی کہ کفر کرتے تھے\qt@no{130}}%
\qt@newcmd\qurantrans@ur@cmxx{اے محمدﷺ!) یہ (جو پیغمبر آتے رہے اور کتابیں نازل ہوتی رہیں تو) اس لیے کہ تمہارا پروردگار ایسا نہیں کہ بستیوں کو ظلم سے ہلاک کر دے اور وہاں کے رہنے والوں کو (کچھ بھی) خبر نہ ہو\qt@no{131}}%
\qt@newcmd\qurantrans@ur@cmxxi{اور سب لوگوں کے بلحاظ اعمال درجے (مقرر) ہیں اور جو کام یہ لوگ کرتے ہیں خدا ان سے بے خبر نہیں\qt@no{132}}%
\qt@newcmd\qurantrans@ur@cmxxii{اور تمہارا پروردگار بےپروا (اور) صاحب رحمت ہے اگر چاہے (تو اے بندوں) تمہیں نابود کر دے اور تمہارے بعد جن لوگوں کو چاہے تمہارا جانشین بنا دے جیسا تم کو بھی دوسرے لوگوں کی نسل سے پیدا کیا ہے\qt@no{133}}%
\qt@newcmd\qurantrans@ur@cmxxiii{کچھ شک نہیں کہ جو وعدہ تم سے کیا جاتا ہے وہ (وقوع میں) آنے والا ہے اور تم (خدا کو) مغلوب نہیں کر سکتے\qt@no{134}}%
\qt@newcmd\qurantrans@ur@cmxxiv{کہہ دو کہ لوگو تم اپنی جگہ عمل کئے جاؤ میں (اپنی جگہ) عمل کئے جاتا ہوں عنقریب تم کو معلوم ہو جائے گا کہ آخرت میں (بہشت) کس کا گھر ہوگا کچھ شک نہیں کہ مشرک نجات نہیں پانے کے\qt@no{135}}%
\qt@newcmd\qurantrans@ur@cmxxv{اور (یہ لوگ) خدا ہی کی پیدا کی ہوئی چیزوں یعنی کھیتی اور چوپایوں میں خدا کا بھی ایک حصہ مقرر کرتے ہیں اور اپنے خیال (باطل) سے کہتے ہیں کہ یہ (حصہ) تو خدا کا اور یہ ہمارے شریکوں (یعنی بتوں) کا تو جو حصہ ان کے شریکوں کا ہوتا ہے وہ تو خدا کی طرف نہیں جا سکتا اور جو حصہ خدا کا ہوتا ہے وہ ان کے شریکوں کی طرف جا سکتا ہے یہ کیسا برا انصاف ہے\qt@no{136}}%
\qt@newcmd\qurantrans@ur@cmxxvi{اسی طرح بہت سے مشرکوں کو ان کے شریکوں نے ان کے بچوں کو جان سے مار ڈالنا اچھا کر دکھایا ہے تاکہ انہیں ہلاکت میں ڈال دیں اور ان کے دین کو ان پر خلط ملط کر دیں اور اگر خدا چاہتا تو وہ ایسا نہ کرتے تو ان کو چھوڑ دو کہ وہ جانیں اور ان کا جھوٹ\qt@no{137}}%
\qt@newcmd\qurantrans@ur@cmxxvii{اور اپنے خیال سے یہ بھی کہتے ہیں کہ یہ چارپائے اور کھیتی منع ہے اسے اس شخص کے سوا جسے ہم چاہیں کوئی نہ کھائے اور (بعض) چارپائے ایسے ہیں کہ ان کی پیٹ پر چڑھنا منع کر دیا گیا ہے اور بعض مویشی ایسے ہیں جن پر (ذبح کرتے وقت) خدا کا نام نہیں لیتے سب خدا پر جھوٹ ہے وہ عنقریب ان کو ان کے جھوٹ کا بدلہ دے گا\qt@no{138}}%
\qt@newcmd\qurantrans@ur@cmxxviii{اور یہ بھی کہتے ہیں کہ جو بچہ ان چارپایوں کے پیٹ میں ہے وہ خاص ہمارے مردوں کے لئے ہے اور ہماری عورتوں کو (اس کا کھانا) حرام ہے اور اگر وہ بچہ مرا ہوا ہو تو سب اس میں شریک ہیں (یعنی اسے مرد اور عورتیں سب کھائیں) عنقریب خدا ان کو ان کے ڈھکوسلوں کی سزا دے گا بےشک وہ حکمت والا خبردار ہے\qt@no{139}}%
\qt@newcmd\qurantrans@ur@cmxxix{جن لوگوں نے اپنی اولاد کو بیوقوفی سے بے سمجھی سے قتل کیا اور خدا پر افترا کر کے اس کی عطا فرمائی کی ہوئی روزی کو حرام ٹہرایا وہ گھاٹے میں پڑ گئے وہ بےشبہ گمراہ ہیں اور ہدایت یافتہ نہیں ہیں\qt@no{140}}%
\qt@newcmd\qurantrans@ur@cmxxx{اور خدا ہی تو ہے جس نے باغ پیدا کئے چھتریوں پر چڑھائے ہوئے بھی اور جو چھتریوں پر نہیں چڑھائے ہوئے وہ بھی اور کھجور اور کھیتی جن کے طرح طرح کے پھل ہوتے ہیں اور زیتون اور انار جو (بعض باتوں میں) ایک دوسرے سے ملتے ہیں جب یہ چیزیں پھلیں تو ان کے پھل کھاؤ اور جس دن (پھل توڑو اور کھیتی) کاٹو تو خدا کا حق بھی اس میں سے ادا کرو اور بےجا نہ اڑاؤ کہ خدا بیجا اڑانے والوں کو دوست نہیں رکھتا\qt@no{141}}%
\qt@newcmd\qurantrans@ur@cmxxxi{اور چارپایوں میں بوجھ اٹھانے والے (یعنی بڑے بڑے) بھی پیدا کئے اور زمین سے لگے ہوئے (یعنی چھوٹے چھوٹے) بھی (پس) خدا کا دیا ہوا رزق کھاؤ اور شیطان کے قدموں پر نہ چلو وہ تمہارا صریح دشمن ہے\qt@no{142}}%
\qt@newcmd\qurantrans@ur@cmxxxii{یہ بڑے چھوٹے چارپائے) آٹھ قسم کے (ہیں) دو (دو) بھیڑوں میں سے اور دو (دو) بکریوں میں سے (یعنی ایک ایک نر اور اور ایک ایک مادہ) (اے پیغمبر ان سے) پوچھو کہ (خدا نے) دونوں (کے) نروں کو حرام کیا ہے یا دونوں (کی) مادنیوں کو یا جو بچہ مادنیوں کے پیٹ میں لپٹ رہا ہو اسے اگر سچے ہو تو مجھے سند سے بتاؤ\qt@no{143}}%
\qt@newcmd\qurantrans@ur@cmxxxiii{اور دو (دو) اونٹوں میں سے اور دو (دو) گایوں میں سے (ان کے بارے میں بھی ان سے) پوچھو کہ (خدا نے) دونوں (کے) نروں کو حرام کیا ہے یا دونوں (کی) مادنیوں کو یا جو بچہ مادنیوں کے پیٹ میں لپٹ رہا ہو اس کو بھلا جس وقت خدا نے تم کو اس کا حکم دیا تھا تم اس وقت موجود تھے؟ تو اس شخص سے زیادہ کون ظالم ہے جو خدا پر جھوٹ افتراء کرے تاکہ اِز راہ بے دانشی لوگوں کو گمراہ کرے کچھ شک نہیں کہ خدا ظالم لوگوں کو ہدایت نہیں دیتا\qt@no{144}}%
\qt@newcmd\qurantrans@ur@cmxxxiv{کہو کہ جو احکام مجھ پر نازل ہوئے ہیں ان میں کوئی چیز جسے کھانے والا کھائے حرام نہیں پاتا بجز اس کے کہ وہ مرا ہوا جانور یا بہتا لہو یا سور کا گوشت کہ یہ سب ناپاک ہیں یا کوئی گناہ کی چیز ہو کہ اس پر خدا کے سوا کسی اور کا نام لیا گیا ہو اور اگر کوئی مجبور ہو جائے لیکن نہ تو نافرمانی کرے اور نہ حد سے باہر نکل جائے تو تمہارا پروردگار بخشنے والا مہربان ہے\qt@no{145}}%
\qt@newcmd\qurantrans@ur@cmxxxv{اور یہودیوں پر ہم نے سب ناخن والے جانور حرام کر دئیے تھے اور گایوں اور بکریوں سے ان کی چربی حرام کر دی تھی سوا اس کے جو ان کی پیٹھ پر لگی ہو یا اوجھڑی میں ہو یا ہڈی میں ملی ہو یہ سزا ہم نے ان کو ان کی شرارت کے سبب دی تھی اور ہم تو سچ کہنے والے ہیں\qt@no{146}}%
\qt@newcmd\qurantrans@ur@cmxxxvi{اور اگر یوں لوگ تمہاری تکذیب کریں تو کہہ دو تمہارا پروردگار صاحب رحمت وسیع ہے مگر اس کا عذاب گنہ گاروں لوگوں سے نہیں ٹلے گا\qt@no{147}}%
\qt@newcmd\qurantrans@ur@cmxxxvii{جو لوگ شرک کرتے ہیں وہ کہیں گے کہ اگر خدا چاہتا تو ہم شرک نہ کرتے اور نہ ہمارے باپ دادا (شرک کرتے) اور نہ ہم کسی چیز کو حرام ٹھہراتے اسی طرح ان لوگوں نے تکذیب کی تھی جو ان سے پہلے تھے یہاں تک کہ ہمارے عذاب کا مزہ چکھ کر رہے کہہ دو کیا تمہارے پاس کوئی سند ہے (اگر ہے) تو اسے ہمارے سامنے نکالو تم محض خیال کے پیچھے چلتے اور اٹکل کی تیر چلاتے ہو\qt@no{148}}%
\qt@newcmd\qurantrans@ur@cmxxxviii{کہہ دو کہ خدا ہی کی حجت غالب ہے اگر وہ چاہتا تو تم سب کو ہدایت دے دیتا\qt@no{149}}%
\qt@newcmd\qurantrans@ur@cmxxxix{کہو کہ اپنے گواہوں کو لاؤ جو بتائیں کہ خدا نے یہ چیزیں حرام کی ہیں پھر اگر وہ (آ کر) گواہی دیں تو تم ان کے ساتھ گواہی نہ دینا اور نہ ان لوگوں کی خواہشوں کی پیروی کرنا جو ہماری آیتوں کو جھٹلاتے ہیں اور آخرت پر ایمان نہیں لاتے اور (بتوں کو) اپنے پروردگار کے برابر ٹھہراتے ہیں\qt@no{150}}%
\qt@newcmd\qurantrans@ur@cmxl{کہہ کہ (لوگو) آؤ میں تمہیں وہ چیزیں پڑھ کر سناؤں جو تمہارے پروردگار نے تم پر حرام کر دی ہیں (ان کی نسبت اس نے اس طرح ارشاد فرمایا ہے) کہ کسی چیز کو خدا کا شریک نہ بنانا اور ماں باپ (سے بدسلوکی نہ کرنا بلکہ) سلوک کرتے رہنا اور ناداری (کے اندیشے) سے اپنی اولاد کو قتل نہ کرنا کیونکہ تم کو اور ان کو ہم ہی رزق دیتے ہیں اور بےحیائی کے کام ظاہر ہوں یا پوشیدہ ان کے پاس نہ پھٹکنا اور کسی جان (والے) کو جس کے قتل کو خدا نے حرام کر دیا ہے قتل نہ کرنا مگر جائز طور پر (یعنی جس کا شریعت حکم دے) ان باتوں کا وہ تمہیں ارشاد فرماتا ہے تاکہ تم سمجھو\qt@no{151}}%
\qt@newcmd\qurantrans@ur@cmxli{اور یتیم کے مال کے پاس بھی نہ جانا مگر ایسے طریق سے کہ بہت ہی پسندیدہ ہو یہاں تک کہ وہ جوانی کو پہنچ جائے اور ناپ تول انصاف کے ساتھ پوری پوری کیا کرو ہم کسی کو تکلیف نہیں دیتے مگر اس کی طاقت کے مطابق اور جب (کسی کی نسبت) کوئی بات کہو تو انصاف سے کہو گو وہ (تمہارا) رشتہ دار ہی ہو اور خدا کے عہد کو پورا کرو ان باتوں کا خدا تمہیں حکم دیتا ہے تاکہ تم نصحیت کرو\qt@no{152}}%
\qt@newcmd\qurantrans@ur@cmxlii{اور یہ کہ میرا سیدھا رستہ یہی ہے تو تم اسی پر چلنا اور اور رستوں پر نہ چلنا کہ (ان پر چل کر) خدا کے رستے سے الگ ہو جاؤ گے ان باتوں کا خدا تمہیں حکم دیتا ہے تاکہ تم پرہیزگار بنو\qt@no{153}}%
\qt@newcmd\qurantrans@ur@cmxliii{ہاں) پھر (سن لو کہ) ہم نے موسیؑ کو کتاب عنایت کی تھی تاکہ ان لوگوں پر جو نیکوکار ہیں نعمت پوری کر دیں اور (اس میں) ہر چیز کا بیان (ہے) اور ہدایت (ہے) اور رحمت ہے تاکہ (ان کی امت کے) لوگ اپنے پروردگار کے رُوبرو حاضر ہونے کا یقین کریں\qt@no{154}}%
\qt@newcmd\qurantrans@ur@cmxliv{اور (اے کفر کرنے والوں) یہ کتاب بھی ہمیں نے اتاری ہے برکت والی تو اس کی پیروی کرو اور (خدا سے) ڈرو تاکہ تم پر مہربانی کی جائے\qt@no{155}}%
\qt@newcmd\qurantrans@ur@cmxlv{اور اس لیے اتاری ہے) کہ (تم یوں نہ) کہو کہ ہم سے پہلے دو ہی گروہوں پر کتابیں اتری تھیں اور ہم ان کے پڑھنے سے (معذور اور) بےخبر تھے\qt@no{156}}%
\qt@newcmd\qurantrans@ur@cmxlvi{یا (یہ نہ) کہو کہ اگر ہم پر بھی کتاب نازل ہوتی تو ہم ان لوگوں کی نسبت کہیں سیدھے رستے پر ہوتے سو تمہارے پاس تمہارے پروردگار کی طرف سے دلیل اور ہدایت اور رحمت آ گئی ہے تو اس سے بڑھ کر ظالم کون ہوگا جو خدا کی آیتوں کی تکذیب کرے اور ان سے (لوگوں کو) پھیرے جو لوگ ہماری آیتوں سے پھیرتے ہیں اس پھیرنے کے سبب ہم ان کو برے عذاب کی سزا دیں گے\qt@no{157}}%
\qt@newcmd\qurantrans@ur@cmxlvii{یہ اس کے سوا اور کس بات کے منتظر ہیں کہ ان کے پاس فرشتے آئیں یا خود تمہارا پروردگار آئے یا تمہارے پروردگار کی کچھ نشانیاں آئیں (مگر) جس روز تمہارے پروردگار کی کچھ نشانیاں آ جائیں گی تو جو شخص پہلے ایمان نہیں لایا ہوگا اس وقت اسے ایمان لانا کچھ فائدہ نہیں دے گا یا اپنے ایمان (کی حالت) میں نیک عمل نہیں کئے ہوں گے (تو گناہوں سے توبہ کرنا مفید نہ ہوگا اے پیغمبر ان سے) کہہ دو کہ تم بھی انتظار کرو ہم بھی انتظار کرتے ہیں\qt@no{158}}%
\qt@newcmd\qurantrans@ur@cmxlviii{جن لوگوں نے اپنے دین میں (بہت سے) رستے نکالے اور کئی کئی فرقے ہو گئے ان سے تم کو کچھ کام نہیں ان کا کام خدا کے حوالے پھر جو کچھ وہ کرتے رہے ہیں وہ ان کو (سب) بتائے گا\qt@no{159}}%
\qt@newcmd\qurantrans@ur@cmxlix{اور جو کوئی (خدا کے حضور) نیکی لے کر آئے گا اس کو ویسی دس نیکیاں ملیں گی اور جو برائی لائے گا اسے سزا ویسے ہی ملے گی اور ان پر ظلم نہیں کیا جائے گا\qt@no{160}}%
\qt@newcmd\qurantrans@ur@cml{کہہ دو کہ مجھے میرے پروردگار نے سیدھا رستہ دکھا دیا ہے (یعنی دین صحیح) مذہب ابراہیم کا جو ایک (خدا) ہی کی طرف کے تھے اور مشرکوں میں سے نہ تھے\qt@no{161}}%
\qt@newcmd\qurantrans@ur@cmli{یہ بھی) کہہ دو کہ میری نماز اور میری عبادت اور میرا جینا اور میرا مرنا سب خدائے رب العالمین ہی کے لیے ہے\qt@no{162}}%
\qt@newcmd\qurantrans@ur@cmlii{جس کا کوئی شریک نہیں اور مجھ کو اسی بات کا حکم ملا ہے اور میں سب سے اول فرمانبردار ہوں\qt@no{163}}%
\qt@newcmd\qurantrans@ur@cmliii{کہو کیا میں خدا کے سوا اور پروردگار تلاش کروں اور وہی تو ہر چیز کا مالک ہے اور جو کوئی (برا) کام کرتا ہے تو اس کا ضرر اسی کو ہوتا ہے اور کوئی شخص کسی (کے گناہ) کا بوجھ نہیں اٹھائے گا پھر تم سب کو اپنے پروردگار کی طرف لوٹ کا جانا ہے تو جن جن باتوں میں تم اختلاف کیا کرتے تھے وہ تم کو بتائے گا\qt@no{164}}%
\qt@newcmd\qurantrans@ur@cmliv{اور وہی تو ہے جس نے زمین میں تم کو اپنا نائب بنایا اور ایک کے دوسرے پر درجے بلند کئے تاکہ جو کچھ اس نے تمہیں بخشا ہے اس میں تمہاری آزمائش ہے بےشک تمہارا پروردگار جلد عذاب دینے والا ہے اور بےشک وہ بخشنے والا مہربان بھی ہے\qt@no{165}}%
\qt@newcmd\qurantrans@ur@cmlv{\basmalahur المص\qt@no{1}}%
\qt@newcmd\qurantrans@ur@cmlvi{اے محمدﷺ) یہ کتاب (جو) تم پر نازل ہوئی ہے۔ اس سے تمہیں تنگ دل نہیں ہونا چاہیئے، (یہ نازل) اس لیے (ہوئی ہے) کہ تم اس کے ذریعے سے (لوگوں) کو ڈر سناؤ اور (یہ) ایمان والوں کے لیے نصیحت ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@cmlvii{لوگو) جو (کتاب) تم پر تمہارے پروردگار کے ہاں نازل ہوئی ہے اس کی پیروی کرو اور اس کے سوا اور رفیقوں کی پیروی نہ کرو (اور) تم کم ہی نصیحت قبول کرتے ہو\qt@no{3}}%
\qt@newcmd\qurantrans@ur@cmlviii{اور کتنی ہی بستیاں ہیں کہ ہم نے تباہ کر ڈالیں جن پر ہمارا عذاب (یا تو رات کو) آتا تھا جبکہ وہ سوتے تھے یا (دن کو) جب وہ قیلولہ (یعنی دوپہر کو آرام) کرتے تھے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@cmlix{تو جس وقت ان پر عذاب آتا تھا ان کے منہ سے یہی نکلتا تھا کہ (ہائے) ہم (ہائے) ہم (اپنے اوپر) ظلم کرتے رہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@cmlx{تو جن لوگوں کی طرف پیغمبر بھیجے گئے ہم ان سے بھی پرسش کریں گے اور پیغمبروں سے بھی پوچھیں گے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@cmlxi{پھر اپنے علم سے ان کے حالات بیان کریں گے اور ہم کہیں غائب تو نہیں تھے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@cmlxii{اور اس روز (اعمال کا) تلنا برحق ہے تو جن لوگوں کے (عملوں کے) وزن بھاری ہوں گے وہ تو نجات پانے والے ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@cmlxiii{اور جن کے وزن ہلکے ہوں گے تو یہی لوگ ہیں جنہوں نے اپنے تئیں خسارے میں ڈالا اس لیے کہ ہماری آیتوں کے بارے میں بےانصافی کرتے تھے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@cmlxiv{اور ہم ہی نے زمین میں تمہارا ٹھکانہ بنایا اور اس میں تمہارے لیے سامان معشیت پیدا کئے۔ (مگر) تم کم ہی شکر کرتے ہو\qt@no{10}}%
\qt@newcmd\qurantrans@ur@cmlxv{اور ہم ہی نے تم کو (ابتدا میں مٹی سے) پیدا کیا پھر تمہاری صورت شکل بنائی پھر فرشتوں کو حکم دیا آدم کے آگے سجدہ کرو تو (سب نے) سجدہ کیا لیکن ابلیس کہ وہ سجدہ کرنے والوں میں (شامل) نہ ہوا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@cmlxvi{خدا نے) فرمایا جب میں نے تجھ کو حکم دیا تو کس چیز نے تجھے سجدہ کرنے سے باز رکھا۔ اس نے کہا کہ میں اس سے افضل ہوں۔ مجھے تو نے آگ سے پیدا کیا ہے اور اسے مٹی سے بنایا ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@cmlxvii{فرمایا تو (بہشت سے) اتر جا تجھے شایاں نہیں کہ یہاں غرور کرے پس نکل جا۔ تو ذلیل ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@cmlxviii{اس نے کہا کہ مجھے اس دن تک مہلت عطا فرما جس دن لوگ (قبروں سے) اٹھائے جائیں گے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@cmlxix{فرمایا (اچھا) تجھ کو مہلت دی جاتی ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@cmlxx{پھر) شیطان نے کہا مجھے تو تُو نے ملعون کیا ہی ہے میں بھی تیرے سیدھے رستے پر ان (کو گمراہ کرنے) کے لیے بیٹھوں گا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@cmlxxi{پھر ان کے آگے سے اور پیچھے سے دائیں سے اور بائیں سے (غرض ہر طرف سے) آؤں گا (اور ان کی راہ ماروں گا) اور تو ان میں اکثر کو شکر گزار نہیں پائے گا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@cmlxxii{خدا نے) فرمایا، نکل جا۔ یہاں سے پاجی۔ مردود جو لوگ ان میں سے تیری پیروی کریں گے میں (ان کو اور تجھ کو جہنم میں ڈال کر) تم سب سے جہنم کو بھر دوں گا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@cmlxxiii{اور ہم نے آدم (سے کہا کہ) تم اور تمہاری بیوی بہشت میں رہو سہو اور جہاں سے چاہو (اور جو چاہو) نوش جان کرو مگر اس درخت کے پاس نہ جاؤ ورنہ گنہگار ہو جاؤ گے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@cmlxxiv{تو شیطان دونوں کو بہکانے لگا تاکہ ان کی ستر کی چیزیں جو ان سے پوشیدہ تھیں کھول دے اور کہنے لگا کہ تم کو تمہارے پروردگار نے اس درخت سے صرف اس لیے منع کیا ہے کہ کہ تم فرشتے نہ بن جاؤ یا ہمیشہ جیتے نہ رہو\qt@no{20}}%
\qt@newcmd\qurantrans@ur@cmlxxv{اور ان سے قسم کھا کر کہا میں تو تمہارا خیر خواہ ہوں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@cmlxxvi{غرض (مردود نے) دھوکہ دے کر ان کو (معصیت کی طرف) کھینچ ہی لیا جب انہوں نے اس درخت (کے پھل) کو کھا لیا تو ان کی ستر کی چیزیں کھل گئیں اور وہ بہشت کے (درختوں کے) پتے توڑ توڑ کر اپنے اوپر چپکانے لگے اور (ستر چھپانے لگے) تب ان کے پروردگار نے ان کو پکارا کہ کیا میں نے تم کو اس درخت (کے پاس جانے) سے منع نہیں کیا تھا اور جتا نہیں دیا تھا کہ شیطان تمہارا کھلم کھلا دشمن ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@cmlxxvii{دونوں عرض کرنے لگے کہ پروردگار ہم نے اپنی جانوں پر ظلم کیا اور اگر تو ہمیں نہیں بخشے گا اور ہم پر رحم نہیں کرے گا تو ہم تباہ ہو جائیں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@cmlxxviii{خدا نے) فرمایا (تم سب بہشت سے) اتر جاؤ (اب سے) تم ایک دوسرے کے دشمن ہو اور تمہارے لیے ایک وقت (خاص) تک زمین پر ٹھکانہ اور (زندگی کا) سامان (کر دیا گیا) ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@cmlxxix{یعنی) فرمایا کہ اسی میں تمہارا جینا ہوگا اور اسی میں مرنا اور اسی میں سے (قیامت کو زندہ کر کے) نکالے جاؤ گے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@cmlxxx{اے نبی آدم ہم نے تم پر پوشاک اتاری کہ تمہارا ستر ڈھانکے اور (تمہارے بدن کو) زینت (دے) اور (جو) پرہیزگاری کا لباس (ہے) وہ سب سے اچھا ہے۔ یہ خدا کی نشانیاں ہیں تاکہ لوگ نصحیت پکڑ یں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@cmlxxxi{اے نبی آدم (دیکھنا کہیں) شیطان تمہیں بہکا نہ دے جس طرح تمہارے ماں باپ کو (بہکا کر) بہشت سے نکلوا دیا اور ان سے ان کے کپڑے اتروا دیئے تاکہ ان کے ستر ان کو کھول کر دکھا دے۔ وہ اور اس کے بھائی تم کو ایسی جگہ سے دیکھتے رہے ہیں جہاں سے تم ان کو نہیں دیکھ سکتے ہم نے شیطانوں کو انہیں لوگوں کا رفیق کار بنایا ہے جو ایمان نہیں رکھتے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@cmlxxxii{اور جب کوئی بے حیائی کا کام کرتے ہیں تو کہتے ہیں کہ ہم نے اپنے بزرگوں کو اسی طرح کرتے دیکھا ہے اور خدا نے بھی ہم کو یہی حکم دیا ہے۔ کہہ دو خدا بےحیائی کے کام کرنے کا ہرگز حکم نہیں دیتا۔ بھلا تم خدا کی نسبت ایسی بات کیوں کہتے ہو جس کا تمہیں علم نہیں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@cmlxxxiii{کہہ دو کہ میرے پروردگار نے تو انصاف کرنے کا حکم دیا ہے۔ اور یہ کہ ہر نماز کے وقت سیدھا (قبلے کی طرف) رخ کیا کرو اور خاص اسی کی عبادت کرو اور اسی کو پکارو۔ اس نے جس طرح تم کو ابتداء میں پیدا کیا تھا اسی طرح تم پھر پیدا ہوگے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@cmlxxxiv{ایک فریق کو تو اس نے ہدایت دی اور ایک فریق پر گمراہی ثابت ہوچکی۔ ان لوگوں نے خدا کو چھوڑ کر شیطانوں کو رفیق بنا لیا اور سمجھتے (یہ) ہیں کہ ہدایت یاب ہیں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@cmlxxxv{اے نبی آدم! ہر نماز کے وقت اپنے تئیں مزّین کیا کرو اور کھاؤ اور پیؤ اور بےجا نہ اڑاؤ کہ خدا بےجا اڑانے والوں کو دوست نہیں رکھتا\qt@no{31}}%
\qt@newcmd\qurantrans@ur@cmlxxxvi{پوچھو تو کہ جو زینت (وآرائش) اور کھانے (پینے) کی پاکیزہ چیزیں خدا نے اپنے بندوں کے لیے پیدا کی ہیں ان کو حرام کس نے کیا ہے؟ کہہ دو کہ یہ چیزیں دنیا کی زندگی میں ایمان والوں کے لیے ہیں اور قیامت کے دن خاص ان ہی کا حصہ ہوں گی۔ اسی طرح خدا اپنی آیتیں سمجھنے والوں کے لیے کھول کھول کر بیان فرماتا ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@cmlxxxvii{کہہ دو کہ میرے پروردگار نے تو بےحیائی کی باتوں کو ظاہر ہوں یا پوشیدہ اور گناہ کو اور ناحق زیادتی کرنے کو حرام کیا ہے۔ اور اس کو بھی کہ تم کسی کو خدا کا شریک بناؤ جس کی اس نے کوئی سند نازل نہیں کی اور اس کو بھی کہ خدا کے بارے میں ایسی باتیں کہو جن کا تمہیں کچھ علم نہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@cmlxxxviii{اور ہر ایک فرقے کے لیے (موت کا) ایک وقت مقرر ہے۔ جب وہ آ جاتا ہے تو نہ تو ایک گھڑی دیر کرسکتے ہیں نہ جلدی\qt@no{34}}%
\qt@newcmd\qurantrans@ur@cmlxxxix{اے نبی آدم! (ہم تم کو یہ نصیحت ہمیشہ کرتے رہے ہیں کہ) جب ہمارے پیغمبر تمہارے پاس آیا کریں اور ہماری آیتیں تم کو سنایا کریں (تو ان پر ایمان لایا کرو) کہ جو شخص (ان پر ایمان لا کر خدا سے) ڈرتا رہے گا اور اپنی حالت درست رکھے گا تو ایسے لوگوں کو نہ کچھ خوف ہوگا اور نہ وہ غمناک ہوں گے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@cmxc{اور جنہوں نے ہماری آیتوں کو جھٹلایا اور ان سے سرتابی کی وہی دوزخی ہیں کہ ہمیشہ اس میں (جلتے) رہیں گے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@cmxci{تو اس سے زیادہ ظالم کون ہے جو خدا پر جھوٹ باندھے یا اس کی آیتوں کو جھٹلائے۔ ان کو ان کے نصیب کا لکھا ملتا ہی رہے گا یہاں تک کہ جب ان کے پاس ہمارے بھیجے ہوئے (فرشتے) جان نکالنے آئیں گے تو کہیں گے کہ جن کو تم خدا کے سوا پکارا کرتے تھے وہ (اب) کہاں ہیں؟ وہ کہیں گے (معلوم نہیں) کہ وہ ہم سے (کہاں) غائب ہوگئے اور اقرار کریں گے کہ بےشک وہ کافر تھے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@cmxcii{تو خدا فرمائے گا کہ جنّوں اور انسانوں کی جو جماعتیں تم سے پہلے ہو گزری ہیں ان کے ساتھ تم بھی داخل جہنم ہو جاؤ۔ جب ایک جماعت (وہاں) جا داخل ہو گئی تو اپنی (مذہبی) بہن (یعنی اپنے جیسی دوسری جماعت) پر لعنت کرے گی۔ یہاں تک کہ جب سب اس میں داخل ہو جائیں گے تو پچھلی جماعت پہلی کی نسبت کہے گی کہ اے پروردگار! ان ہی لوگوں نے ہم کو گمراہ کیا تھا تو ان کو آتش جہنم کا دگنا عذاب دے۔ خدا فرمائے گا کہ (تم) سب کو دگنا (عذاب دیا جائے گا) مگر تم نہیں جانتے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@cmxciii{اور پہلی جماعت پچھلی جماعت سے کہے گی کہ تم کو ہم پر کچھ بھی فضیلت نہ ہوئی تو جو (عمل) تم کیا کرتے تھے اس کے بدلے میں عذاب کے مزے چکھو\qt@no{39}}%
\qt@newcmd\qurantrans@ur@cmxciv{جن لوگوں نے ہماری آیتوں کو جھٹلایا اور ان سے سرتابی کی۔ ان کے لیے نہ آسمان کے دروازے کھولے جائیں گے اور نہ وہ بہشت میں داخل ہوں گے۔ یہاں تک کہ اونٹ سوئی کے ناکے میں سے نہ نکل جائے اور گنہگاروں کو ہم ایسی ہی سزا دیا کرتے ہیں\qt@no{40}}%
\qt@newcmd\qurantrans@ur@cmxcv{ایسے لوگوں کے لیے (نیچے) بچھونا بھی (آتش) جہنم کا ہوگا اور اوپر سے اوڑھنا بھی (اسی کا) اور ظالموں کو ہم ایسی ہی سزا دیا کرتے ہیں\qt@no{41}}%
\qt@newcmd\qurantrans@ur@cmxcvi{اور جو لوگ ایمان لائے اور عمل نیک کرتے رہے اور ہم (عملوں کے لیے) کسی شخص کو اس کی طاقت سے زیادہ تکلیف نہیں دیتے۔ ایسے ہی لوگ اہل بہشت ہیں (کہ) اس میں ہمیشہ رہیں گے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@cmxcvii{اور جو کینے ان کے دلوں میں ہوں گے ہم سب نکال ڈالیں گے۔ ان کے محلوں کے نیچے نہریں بہہ رہی ہوں گی اور کہیں گے کہ خدا کا شکر ہے جس نے ہم کو یہاں کا راستہ دکھایا اور اگر خدا ہم کو رستہ نہ دکھاتا تو ہم رستہ نہ پا سکتے۔ بےشک ہمارا پروردگار کے رسول حق بات لے کر آئے تھے اور (اس روز) منادی کر دی جائے گی کہ تم ان اعمال کے صلے میں جو دنیا میں کرتے تھے اس بہشت کے وارث بنا دیئے گئے ہو\qt@no{43}}%
\qt@newcmd\qurantrans@ur@cmxcviii{اور اہل بہشت دوزخیوں سے پکار کر کہیں گے کہ جو وعدہ ہمارے پروردگار نے ہم سے کیا تھا ہم نے تو اسے سچا پالیا۔ بھلا جو وعدہ تمہارے پروردگار نے تم سے کیا تھا تم نے بھی اسے سچا پایا؟ وہ کہیں گے ہاں تو (اس وقت) ان میں ایک پکارنے والا پکارے گا کہ بےانصافوں پر خدا کی لعنت\qt@no{44}}%
\qt@newcmd\qurantrans@ur@cmxcix{جو خدا کی راہ سے روکتے اور اس میں کجی ڈھونڈتے اور آخرت سے انکار کرتے تھے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@m{ان دونوں (یعنی بہشت اور دوزخ) کے درمیان (اعراف نام) ایک دیوار ہو گی اور اعراف پر کچھ آدمی ہوں گے جو سب کو ان کی صورتوں سے پہچان لیں گے۔ تو وہ اہل بہشت کو پکار کر کہیں گے کہ تم پر سلامتی ہو۔ یہ لوگ بھی بہشت میں داخل تو نہیں ہوں گے مگر امید رکھتے ہوں گے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mi{اور جب ان کی نگاہیں پلٹ کر اہل دوزخ کی طرف جائیں گی تو عرض کریں گے کہ اے ہمارے پروردگار ہم کو ظالم لوگوں کے ساتھ شامل نہ کیجیو\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mii{اور اہل اعراف (کافر) لوگوں کو جنہیں ان کی صورتوں سے شناخت کرتے ہوں گے پکاریں گے اور کہیں گے (کہ آج) نہ تو تمہاری جماعت ہی تمہارے کچھ کام آئی اور نہ تمہارا تکبّر (ہی سودمند ہوا)\qt@no{48}}%
\qt@newcmd\qurantrans@ur@miii{پھر مومنوں کی طرف اشارہ کر کے کہیں گے) کیا یہ وہی لوگ ہیں جن کے بارے میں تم قسمیں کھایا کرتے تھے کہ خدا اپنی رحمت سے ان کی دستگیری نہیں کرے گا (تو مومنو) تم بہشت میں داخل ہو جاؤ تمہیں کچھ خوف نہیں اور نہ تم کو کچھ رنج واندوہ ہوگا\qt@no{49}}%
\qt@newcmd\qurantrans@ur@miv{اور وہ دوزخی بہشتیوں سے (گڑگڑا کر) کہیں گے کہ کسی قدر ہم پر پانی بہاؤ یا جو رزق خدا نے تمہیں عنایت فرمایا ہے ان میں سے (کچھ ہمیں بھی دو) وہ جواب دیں گے کہ خدا نے بہشت کا پانی اور رزق کافروں پر حرام کر دیا ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mv{جنہوں نے اپنے دین کو تماشا اور کھیل بنا رکھا تھا اور دنیا کی زندگی نے ان کو دھوکے میں ڈال رکھا تھا۔ تو جس طرح یہ لوگ اس دن کے آنے کو بھولے ہوئے اور ہماری آیتوں سے منکر ہو رہے تھے۔ اسی طرح آج ہم بھی انہیں بھلا دیں گے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mvi{اور ہم نے ان کے پاس کتاب پہنچا دی ہے جس کو علم ودانش کے ساتھ کھول کھول کر بیان کر دیا ہے (اور) وہ مومن لوگوں کے لیے ہدایت اور رحمت ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mvii{کیا یہ لوگ اس کے وعدہٴ عذاب کے منتظر ہیں۔ جس دن وہ وعدہ آجائے گا تو جو لوگ اس کو پہلے سے بھولے ہوئے ہوں گے وہ بول اٹھیں گے کہ بےشک ہمارے پروردگار کے رسول حق لے کر آئے تھے۔ بھلا (آج) ہمارا کوئی سفارشی ہیں کہ ہماری سفارش کریں یا ہم (دنیا میں) پھر لوٹا دیئے جائیں کہ جو عمل (بد) ہم (پہلے) کرتے تھے (وہ نہ کریں بلکہ) ان کے سوا اور (نیک) عمل کریں۔ بےشک ان لوگوں نے اپنا نقصان کیا اور جو کچھ یہ افتراء کیا کرتے تھے ان سے سب جاتا رہا\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mviii{کچھ شک نہیں کہ تمہارا پروردگار خدا ہی ہے جس نے آسمانوں اور زمین کو چھ دن میں پیدا کیا پھر عرش پر جا ٹھہرا۔ وہی رات کو دن کا لباس پہناتا ہے کہ وہ اس کے پیچھے دوڑتا چلا آتا ہے۔ اور اسی نے سورج اور چاند ستاروں کو پیدا کیا سب اس کے حکم کے مطابق کام میں لگے ہوئے ہیں۔ دیکھو سب مخلوق بھی اسی کی ہے اور حکم بھی (اسی کا ہے) ۔ یہ خدا رب العالمین بڑی برکت والا ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mix{لوگو) اپنے پروردگار سے عاجزی سے اور چپکے چپکے دعائیں مانگا کرو۔ وہ حد سے بڑھنے والوں کو دوست نہیں رکھتا\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mx{اور ملک میں اصلاح کے بعد خرابی نہ کرنا اور خدا سے خوف کرتے ہوئے اور امید رکھ کر دعائیں مانگتے رہنا۔ کچھ شک نہیں کہ خدا کی رحمت نیکی کرنے والوں سے قریب ہے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mxi{اور وہی تو ہے جو اپنی رحمت (یعنی مینھ) سے پہلے ہواؤں کو خوشخبری (بنا کر) بھیجتا ہے۔ یہاں تک کہ جب وہ بھاری بھاری بادلوں کو اٹھا لاتی ہے تو ہم اس کو ایک مری ہوئی بستی کی طرف ہانک دیتے ہیں۔ پھر بادل سے مینھ برساتے ہیں۔ پھر مینھ سے ہر طرح کے پھل پیدا کرتے ہیں۔ اسی طرح ہم مردوں کو (زمین سے) زندہ کرکے باہر نکال لیں گے۔ (یہ آیات اس لیے بیان کی جاتی ہیں) تاکہ تم نصیحت پکڑو\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mxii{جو زمین پاکیزہ (ہے) اس میں سے سبزہ بھی پروردگار کے حکم سے (نفیس ہی) نکلتا ہے اور جو خراب ہے اس میں جو کچھ ہے ناقص ہوتا ہے۔ اسی طرح ہم آیتوں کو شکرگزار لوگوں کے لئے پھیر پھیر کر بیان کرتے ہیں\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mxiii{ہم نے نوح کو ان کی قوم کی طرف بھیجا تو انہوں نے (ان سے کہا) اے میری برادری کے لوگو خدا کی عبادت کرو اس کے سوا تمہارا کوئی معبود نہیں۔ مجھے تمہارے بارے میں بڑے دن کے عذاب کا (بہت ہی) ڈر ہے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mxiv{تو جو ان کی قوم میں سردار تھے وہ کہنے لگے کہ ہم تمہیں صریح گمراہی میں (مبتلا) دیکھتے ہیں\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mxv{انہوں نے کہا اے قوم مجھ میں کسی طرح کی گمراہی نہیں ہے بلکہ میں پروردگار عالم کا پیغمبر ہوں\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mxvi{تمہیں اپنے پروردگار کے پیغام پہنچاتا ہوں اور تمہاری خیرخواہی کرتا ہوں اور مجھ کو خدا کی طرف سے ایسی باتیں معلوم ہیں جن سے تم بےخبر ہو\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mxvii{کیا تم کو اس بات سے تعجب ہوا ہے کہ تم میں سے ایک شخص کے ہاتھ تمہارے پروردگار کی طرف سے تمہارے پاس نصیحت آئی تاکہ وہ تم کو ڈرائے اور تاکہ تم پرہیزگار بنو اور تاکہ تم پر رحم کیا جائے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mxviii{مگر ان لوگوں نے ان کی تکذیب کی۔ تو ہم نے نوح کو اور جو ان کے ساتھ کشتی میں سوار تھے ان کو تو بچا لیا اور جن لوگوں نے ہماری آیتوں کو جھٹلایا تھا انہیں غرق کر دیا۔ کچھ شک نہیں کہ وہ اندھے لوگ تھے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mxix{اور (اسی طرح) قوم عاد کی طرف ان کے بھائی ہود کو بھیجا۔ انہوں نے کہا کہ بھائیو خدا ہی کی عبادت کرو۔ اس کے سوا تمہارا کوئی معبود نہیں۔ کیا تم ڈرتے نہیں؟\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mxx{تو ان کی قوم کے سردار جو کافر تھے کہنے لگے کہ تم ہمیں احمق نظر آتے ہو اور ہم تمہیں جھوٹا خیال کرتے ہیں\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mxxi{انہوں نے کہا کہ بھائیو مجھ میں حماقت کی کوئی بات نہیں ہے بلکہ میں رب العالمین کا پیغمبر ہوں\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mxxii{میں تمہیں خدا کے پیغام پہنچاتا ہوں اور تمہارا امانت دار خیرخواہ ہوں\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mxxiii{کیا تم کو اس بات سے تعجب ہوا ہے کہ تم میں سے ایک شخص کے ہاتھ تمہارے پروردگار کی طرف سے تمہارے پاس نصیحت آئی تاکہ وہ تمہیں ڈرائے اور یاد کرو تو کرو جب اس نے تم کو قوم نوح کے بعد سردار بنایا۔ اور تم کو پھیلاؤ زیادہ دیا۔ پس خدا کی نعمتوں کو یاد کرو۔ تاکہ نجات حاصل کرو\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mxxiv{وہ کہنے لگے کہ تم ہمارے پاس اس لیے آئے ہو کہ ہم اکیلے خدا ہی کی عبادت کریں۔ اور جن کو ہمارے باپ دادا پوجتے چلے آئے ہیں ان کو چھوڑ دیں؟ تو اگر سچے ہو تو جس چیز سے ہمیں ڈراتے ہو اسے لے آؤ\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mxxv{ہود نے کہا تمہارے پروردگار کی طرف سے تم پر عذاب اور غضب کا (نازل ہونا) مقرر ہو چکا ہے۔ کیا تم مجھ سے ایسے ناموں کے بارے میں جھگڑتے ہو جو تم نے اور تمہارے باپ دادا نے (اپنی طرف سے) رکھ لئے ہیں۔ جن کی خدا نے کوئی سند نازل نہیں کی۔ تو تم بھی انتظار کرو میں بھی تمہارے ساتھ انتظار کرتا ہوں\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mxxvi{پھر ہم نے ہود کو اور جو لوگ ان کے ساتھ تھے ان کو نجات بخشی اور جنہوں نے ہماری آیتوں کو جھٹلایا تھا ان کی جڑ کاٹ دی اور وہ ایمان لانے والے تھے ہی نہیں\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mxxvii{اور قوم ثمود کی طرف ان کے بھائی صالح کو بھیجا۔ (تو) صالح نے کہا کہ اے قوم! خدا ہی کی عبادت کرو اس کے سوا تمہارا کوئی معبود نہیں۔ تمہارے پاس تمہارے پروردگار کی طرف سے ایک معجزہ آ چکا ہے۔ (یعنی) یہی خدا کی اونٹنی تمہارے لیے معجزہ ہے۔ تو اسے (آزاد) چھوڑ دو کہ خدا کی زمین میں چرتی پھرے اور تم اسے بری نیت سے ہاتھ بھی نہ لگانا۔ ورنہ عذابِ الیم میں تمہیں پکڑ لے گا\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mxxviii{اور یاد تو کرو جب اس نے تم کو قوم عاد کے بعد سردار بنایا اور زمین پر آباد کیا کہ نرم زمین سے (مٹی لے لے کر) محل تعمیر کرتے ہو اور پہاڑوں کو تراش تراش کر گھر بناتے ہو۔ پس خدا کی نعمتوں کو یاد کرو اور زمین میں فساد نہ کرتے پھرو\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mxxix{تو ان کی قوم میں سردار لوگ جو غرور رکھتے تھے غریب لوگوں سے جو ان میں سے ایمان لے آئے تھے کہنے لگے بھلا تم یقین کرتے ہو کہ صالح اپنے پروردگار کی طرف بھیجے گئے ہیں؟ انہوں نے کہا ہاں جو چیز دے کر وہ بھیجے گئے ہیں ہم اس پر بلاشبہ ایمان رکھتے ہیں\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mxxx{تو (سرداران) مغرور کہنے لگے کہ جس چیز پر تم ایمان لائے ہو ہم تو اس کو نہیں مانتے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mxxxi{آخر انہوں نے اونٹی (کی کونچوں) کو کاٹ ڈالا اور اپنے پروردگار کے حکم سے سرکشی کی اور کہنے لگے کہ صالح! جس چیز سے تم ہمیں ڈراتے تھے اگر تم (خدا کے) پیغمبر ہو تو اسے ہم پر لے آؤ\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mxxxii{تو ان کو بھونچال نے آ پکڑا اور وہ اپنے گھروں میں اوندھے پڑے رہ گئے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mxxxiii{پھر صالح ان سے (ناامید ہو کر) پھرے اور کہا کہ میری قوم! میں نے تم کو خدا کا پیغام پہنچا دیا اور تمہاری خیر خواہی کی مگر تم (ایسے ہو کہ) خیر خواہوں کو دوست ہی نہیں رکھتے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mxxxiv{اور اسی طرح جب ہم نے لوط کو (پیغمبر بنا کر بھیجا تو) اس وقت انہوں نے اپنی قوم سے کہا کہ تم ایسی بےحیائی کا کام کیوں کرتے ہو کہ تم سے اہل عالم میں سے کسی نے اس طرح کا کام نہیں کیا\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mxxxv{یعنی خواہش نفسانی پورا کرنے کے لیے عورتوں کو چھوڑ کر لونڈوں پر گرتے ہو۔ حقیقت یہ ہے کہ تم لوگ حد سے نکل جانے والے ہو\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mxxxvi{تو ان سے اس کا جواب کچھ نہ بن پڑا اور بولے تو یہ بولے کہ ان لوگوں (یعنی لوط اور اس کے گھر والوں) کو اپنے گاؤں سے نکال دو (کہ) یہ لوگ پاک بننا چاہتے ہیں\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mxxxvii{تو ہم نے ان کو اور ان کے گھر والوں کو بچا لیا مگر ان کی بی بی (نہ بچی) کہ وہ پیچھے رہنے والوں میں تھی\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mxxxviii{اور ہم نے ان پر (پتھروں کا) مینھ برسایا۔ سو دیکھ لو کہ گنہگاروں کا کیسا انجام ہوا\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mxxxix{اور مَدین کی طرف ان کے بھائی شعیب کو بھیجا۔ (تو) انہوں نے کہا کہ قوم! خدا ہی کی عبادت کرو اس کے سوا تمہارا کوئی معبود نہیں۔ تمہارے پاس تمہارے پروردگار کی طرف سے نشانی آچکی ہے تو تم ناپ تول پوری کیا کرو اور لوگوں کو چیزیں کم نہ دیا کرو۔ اور زمین میں اصلاح کے بعد خرابی نہ کرو۔ اگر تم صاحب ایمان ہو تو سمجھ لو کہ یہ بات تمہارے حق میں بہتر ہے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mxl{اور ہر رستے پر مت بیٹھا کرو کہ جو شخص خدا پر ایمان نہیں لاتا ہے اسے تم ڈراتے اور راہ خدا سے روکتے اور اس میں کجی ڈھونڈتے ہو اور (اس وقت کو) یاد کرو جب تم تھوڑے سے تھے تو خدا نے تم کو جماعت کثیر کر دیا اور دیکھ لو کہ خرابی کرنے والوں کا انجام کیسا ہوا\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mxli{اور اگر تم میں سے ایک جماعت میری رسالت پر ایمان لے آئی ہے اور ایک جماعت ایمان نہیں لائی ہے۔ اور ایک جماعت ایمان نہیں لائی۔ تو صبر کیے رہو یہاں تک کہ خدا ہمارے تمہارے درمیان فیصلہ کر دے اور وہ سب سے بہتر فیصلہ کرنے والا ہے\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mxlii{تو) ان کی قوم میں جو لوگ سردار اور بڑے آدمی تھے، وہ کہنے لگے کہ شعیب! (یا تو) ہم تم کو اور جو لوگ تمہارے ساتھ ایمان لائے ہیں، ان کو اپنے شہر سے نکال دیں گے۔ یا تم ہمارے مذہب میں آجاؤ۔ انہوں نے کہا خواہ ہم (تمہارے دین سے) بیزار ہی ہوں (تو بھی؟)\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mxliii{اگر ہم اس کے بعد کہ خدا ہمیں اس سے نجات بخش چکا ہے تمہارے مذہب میں لوٹ جائیں تو بےشک ہم نے خدا پر جھوٹ افتراء باندھا۔ اور ہمیں شایاں نہیں کہ ہم اس میں لوٹ جائیں ہاں خدا جو ہمارا پروردگار ہے وہ چاہے تو (ہم مجبور ہیں) ۔ ہمارے پروردگار کا علم ہر چیز پر احاطہ کیے ہوئے ہے۔ ہمارا خدا ہی پر بھروسہ ہے۔ اے پروردگار ہم میں اور ہماری قوم میں انصاف کے ساتھ فیصلہ کردے اور تو سب سے بہتر فیصلہ کرنے والا ہے\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mxliv{اور ان کی قوم میں سے سردار لوگ جو کافر تھے، کہنے لگے (بھائیو) اگر تم نے شعیب کی پیروی کی تو بےشک تم خسارے میں پڑگئے\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mxlv{تو ان کو بھونچال نے آپکڑا اور وہ اپنے گھروں میں اوندھے پڑے رہ گئے\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mxlvi{یہ لوگ) جنہوں نے شعیب کی تکذیب کی تھی ایسے برباد ہوئے تھے کہ گویا وہ ان میں کبھی آباد ہی نہیں ہوئے تھے (غرض) جنہوں نے شعیب کو جھٹلایا وہ خسارے میں پڑگئے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mxlvii{تو شعیب ان میں سے نکل آئے اور کہا کہ بھائیو میں نے تم کو اپنے پروردگار کے پیغام پہنچا دیئے ہیں اور تمہاری خیرخواہی کی تھی۔ تو میں کافروں پر (عذاب نازل ہونے سے) رنج وغم کیوں کروں\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mxlviii{اور ہم نے کسی شہر میں کوئی پیغمبر نہیں بھیجا مگر وہاں کے رہنے والوں کو (جو ایمان نہ لائے) دکھوں اور مصیبتوں میں مبتلا کیا تاکہ وہ عاجزی اور زاری کریں\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mxlix{پھر ہم نے تکلیف کو آسودگی سے بدل دیا یہاں تک کہ (مال واولاد میں) زیادہ ہوگئے تو کہنے لگے کہ اس طرح کا رنج وراحت ہمارے بڑوں کو بھی پہنچتا رہا ہے تو ہم نے ان کو ناگہاں پکڑلیا اور وہ (اپنے حال میں) بےخبر تھے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@ml{اگر ان بستیوں کے لوگ ایمان لے آتے اور پرہیزگار ہوجاتے۔ تو ہم ان پر آسمان اور زمین کی برکات (کے دروازے) کھول دیتے مگر انہوں نے تو تکذیب کی۔ سو ان کے اعمال کی سزا میں ہم نے ان کو پکڑ لیا\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mli{کیا بستیوں کے رہنے والے اس سے بےخوف ہیں کہ ان پر ہمارا عذاب رات کو واقع ہو اور وہ (بےخبر) سو رہے ہوں\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mlii{اور کیا اہلِ شہر اس سے نڈر ہیں کہ ان پر ہمارا عذاب دن چڑھے آ نازل ہو اور وہ کھیل رہے ہوں\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mliii{کیا یہ لوگ خدا کے داؤ کا ڈر نہیں رکھتے (سن لو کہ) خدا کے داؤ سے وہی لوگ نڈر ہوتے ہیں جو خسارہ پانے والے ہیں\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mliv{کیا ان لوگوں کو جو اہلِ زمین کے (مرجانے کے) بعد زمین کے مالک ہوتے ہیں، یہ امر موجب ہدایت نہیں ہوا کہ اگر ہم چاہیں تو ان کے گناہوں کے سبب ان پر مصیبت ڈال دیں۔ اور ان کے دلوں پر مہر لگادیں کہ کچھ سن ہی نہ سکیں\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mlv{یہ بستیاں ہیں جن کے کچھ حالات ہم تم کو سناتے ہیں۔ اور ان کے پاس ان کے پیغمبر نشانیاں لے کر آئے۔ مگر وہ ایسے نہیں تھے کہ جس چیز کو پہلے جھٹلا چکے ہوں اسے مان لیں اسی طرح خدا کافروں کے دلوں پر مہر لگا دیتا ہے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mlvi{اور ہم نے ان میں سے اکثروں میں (عہد کا نباہ) نہیں دیکھا۔ اور ان میں اکثروں کو (دیکھا تو) بدکار ہی دیکھا\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mlvii{پھر ان (پیغمبروں) کے بعد ہم نے موسیٰ کو نشانیاں دے کر فرعون اور اس کے اعیانِ سلطنت کے پاس بھیجا تو انہوں نے ان کے ساتھ کفر کیا۔ سو دیکھ لو کہ خرابی کرنے والوں کا انجام کیا ہوا\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mlviii{اور موسیٰ نے کہا کہ اے فرعون میں رب العالمین کا پیغمبر ہوں\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mlix{مجھ پر واجب ہے کہ خدا کی طرف سے جو کچھ کہوں سچ ہی کہوں۔ میں تمہارے پاس تمہارے پروردگار کی طرف سے نشانی لے کر آیا ہوں۔ سو بنی اسرائیل کو میرے ساتھ جانے کی رخصت دے دیجیے\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mlx{فرعون نے کہا اگر تم نشانی لے کر آئے ہو تو اگر سچے ہو تو لاؤ (دکھاؤ)\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mlxi{موسیٰ نے اپنی لاٹھی (زمین پر) ڈال دی تو وہ اسی وقت صریح اژدھا (ہوگیا)\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mlxii{اور اپنا ہاتھ باہر نکالا تو اسی دم دیکھنے والوں کی نگاہوں میں سفید براق (تھا)\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mlxiii{تو قوم فرعون میں جو سردار تھے وہ کہنے لگے کہ یہ بڑا علامہ جادوگر ہے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mlxiv{اس کا ارادہ یہ ہے کہ تم کو تمہارے ملک سے نکال دے۔ بھلا تمہاری کیا صلاح ہے؟\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mlxv{انہوں نے (فرعون سے) کہا کہ فی الحال موسیٰ اور اس کے بھائی کے معاملے کو معاف رکھیے اور شہروں میں نقیب روانہ کر دیجیے\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mlxvi{کہ تمام ماہر جادوگروں کو آپ کے پاس لے آئیں\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mlxvii{چنانچہ ایسا ہی کیا گیا) اور جادوگر فرعون کے پاس آپہنچے اور کہنے لگے کہ اگر ہم جیت گئے تو ہمیں صلہ عطا کیا جائے\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mlxviii{فرعون نے) کہا ہاں (ضرور) اور (اس کے علاوہ) تم مقربوں میں داخل کرلیے جاؤ گے\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mlxix{جب فریقین روزِ مقررہ پر جمع ہوئے تو) جادوگروں نے کہا کہ موسیٰ یا تو تم (جادو کی چیز) ڈالو یا ہم ڈالتے ہیں\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mlxx{موسیٰ نے) کہا تم ہی ڈالو۔ جب انہوں نے (جادو کی چیزیں) ڈالیں تو لوگوں کی آنکھوں پر جادو کردیا (یعنی نظربندی کردی) اور (لاٹھیوں اور رسیوں کے سانپ بنا بنا کر) انہیں ڈرا دیا اور بہت بڑا جادو دکھایا\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mlxxi{اس وقت) ہم نے موسیٰ کی طرف وحی بھیجی کہ تم بھی اپنی لاٹھی ڈال دو۔ وہ فوراً (سانپ بن کر) جادوگروں کے بنائے ہوئے سانپوں کو (ایک ایک کرکے) نگل جائے گی\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mlxxii{پھر) تو حق ثابت ہوگیا اور جو کچھ فرعونی کرتے تھے، باطل ہوگیا\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mlxxiii{اور وہ مغلوب ہوگئے اور ذلیل ہوکر رہ گئے\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mlxxiv{یہ کیفیت دیکھ کر) جادوگر سجدے میں گر پڑے\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mlxxv{اور کہنے لگے کہ ہم جہان کے پروردگار پر ایمان لائے\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mlxxvi{یعنی موسیٰ اور ہارون کے پروردگار پر\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mlxxvii{فرعون نے کہا کہ پیشتر اس کے کہ میں تمہیں اجازت دوں تم اس پر ایمان لے آئے؟ بےشک یہ فریب ہے جو تم نے مل کر شہر میں کیا ہے تاکہ اہلِ شہر کو یہاں سے نکال دو۔ سو عنقریب (اس کا نتیجہ) معلوم کرلو گے\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mlxxviii{میں (پہلے تو) تمہارے ایک طرف کے ہاتھ اور دوسری طرف کے پاؤں کٹوا دوں گا پھر تم سب کو سولی چڑھوا دوں گا\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mlxxix{وہ بولے کہ ہم تو اپنے پروردگار کی طرف لوٹ کر جانے والے ہیں\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mlxxx{اور اس کے سوا تجھ کو ہماری کون سی بات بری لگی ہے کہ جب ہمارے پروردگار کی نشانیاں ہمارے پاس آگئیں تو ہم ان پر ایمان لے آئے۔ اے پروردگار ہم پر صبرواستقامت کے دہانے کھول دے اور ہمیں (ماریو تو) مسلمان ہی ماریو\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mlxxxi{اور قومِ فرعون میں جو سردار تھے کہنے لگے کہ کیا آپ موسیٰ اور اس کی قوم کو چھوڑ دیجیے گا کہ ملک میں خرابی کریں اور آپ سے اور آپ کے معبودوں سے دست کش ہوجائیں۔ وہ بولے کہ ہم ان کے لڑکوں کو قتل کرڈالیں گے اور لڑکیوں کو زندہ رہنے دیں گے اور بےشک ہم ان پر غالب ہیں\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mlxxxii{موسیٰ نے اپنی قوم سے کہا کہ خدا سے مدد مانگو اور ثابت قدم رہو۔ زمین تو خدا کی ہے۔ وہ اپنے بندوں میں سے جسے چاہتا ہے اس کا مالک بناتا ہے۔ اور آخر بھلا تو ڈرنے والوں کا ہے\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mlxxxiii{وہ بولے کہ تمہارے آنے سے پہلے بھی ہم کو اذیتیں پہنچتی رہیں اور آنے کے بعد بھی۔ موسیٰ نے کہا کہ قریب ہے کہ تمہارا پروردگار تمہارے دشمن کو ہلاک کردے اور اس کی جگہ تمہیں زمین میں خلیفہ بنائے پھر دیکھے کہ تم کیسے عمل کرتے ہو\qt@no{129}}%
\qt@newcmd\qurantrans@ur@mlxxxiv{اور ہم نے فرعونیوں کو قحطوں اور میووں کے نقصان میں پکڑا تاکہ نصیحت حاصل کریں\qt@no{130}}%
\qt@newcmd\qurantrans@ur@mlxxxv{تو جب ان کو آسائش حاصل ہوتی تو کہتے کہ ہم اس کے مستحق ہیں۔ اور اگر سختی پہنچتی تو موسیٰ اور ان کے رفیقوں کی بدشگونی بتاتے۔ دیکھو ان کی بدشگونی خدا کے ہاں مقرر ہے لیکن ان میں اکثر نہیں جانتے\qt@no{131}}%
\qt@newcmd\qurantrans@ur@mlxxxvi{اور کہنے لگے کہ تم ہمارے پاس (خواہ) کوئی ہی نشانی لاؤ تاکہ اس سے ہم پر جادو کرو۔ مگر ہم تم پر ایمان لانے والے نہیں ہیں\qt@no{132}}%
\qt@newcmd\qurantrans@ur@mlxxxvii{تو ہم نے ان پر طوفان اور ٹڈیاں اور جوئیں اور مینڈک اور خون کتنی کھلی ہوئی نشانیاں بھیجیں۔ مگر وہ تکبر ہی کرتے رہے اور وہ لوگ تھے ہی گنہگار\qt@no{133}}%
\qt@newcmd\qurantrans@ur@mlxxxviii{اور جب ان پر عذاب واقع ہوتا تو کہتے کہ موسیٰ ہمارے لیے اپنے پروردگار سے دعا کرو۔ جیسا اس نے تم سے عہد کر رکھا ہے۔ اگر تم ہم سے عذاب کو ٹال دو گے تو ہم تم پر ایمان بھی لے آئیں گے اور بنی اسرائیل کو بھی تمہارے ساتھ جانے (کی اجازت) دیں گے\qt@no{134}}%
\qt@newcmd\qurantrans@ur@mlxxxix{پھر جب ہم ایک مدت کے لیے جس تک ان کو پہنچنا تھا ان سے عذاب دور کردیتے تو وہ عہد کو توڑ ڈالتے\qt@no{135}}%
\qt@newcmd\qurantrans@ur@mxc{تو ہم نے ان سے بدلہ لے کر ہی چھوڑا کہ ان کو دریا میں ڈبو دیا اس لیے کہ وہ ہماری آیتوں کو جھٹلاتے اور ان سے بےپروائی کرتے تھے\qt@no{136}}%
\qt@newcmd\qurantrans@ur@mxci{اور جو لوگ کمزور سمجھے جاتے تھے ان کو زمین (شام) کے مشرق ومغرب کا جس میں ہم نے برکت دی تھی وارث کردیا اور بنی اسرائیل کے بارے میں ان کے صبر کی وجہ سے تمہارے پروردگار کا وعدہٴ نیک پورا ہوا اور فرعون اور قوم فرعون جو (محل) بناتے اور (انگور کے باغ) جو چھتریوں پر چڑھاتے تھے سب کو ہم نے تباہ کردیا\qt@no{137}}%
\qt@newcmd\qurantrans@ur@mxcii{اور ہم نے بنی اسرائیل کو دریا کے پار اتارا تو وہ ایسے لوگوں کے پاس جا پہنچے جو اپنے بتوں (کی عبادت) کے لیے بیٹھے رہتے تھے۔ (بنی اسرائیل) کہنے لگے کہ موسیٰ جیسے ان لوگوں کے معبود ہیں۔ ہمارے لیے بھی ایک معبود بنا دو۔ موسیٰ نے کہا کہ تم بڑے ہی جاہل لوگ ہو\qt@no{138}}%
\qt@newcmd\qurantrans@ur@mxciii{یہ لوگ جس (شغل) میں (پھنسے ہوئے) ہیں وہ برباد ہونے والا ہے اور جو کام یہ کرتے ہیں سب بیہودہ ہیں\qt@no{139}}%
\qt@newcmd\qurantrans@ur@mxciv{اور یہ بھی) کہا کہ بھلا میں خدا کے سوا تمہارے لیے کوئی اور معبود تلاش کروں حالانکہ اس نے تم کو تمام اہل عالم پر فضیلت بخشی ہے\qt@no{140}}%
\qt@newcmd\qurantrans@ur@mxcv{اور ہمارے ان احسانوں کو یاد کرو) جب ہم نے تم کو فرعونیوں (کے ہاتھ) سے نجات بخشی وہ لوگ تم کو بڑا دکھ دیتے تھے۔ تمہارے بیٹوں کو قتل کر ڈالتے تھے اور بیٹیوں کو زندہ رہنے دیتے تھے۔ اور اس میں تمہارے پروردگار کی طرف سے سخت آزمائش تھی\qt@no{141}}%
\qt@newcmd\qurantrans@ur@mxcvi{اور ہم نے موسیٰ سے تیس رات کی میعاد مقرر کی۔ اور اس دس (راتیں) اور ملا کر اسے پورا (چلّہ) کردیا تو اس کے پروردگار کی چالیس رات کی میعاد پوری ہوگئی۔ اور موسیٰ نے اپنے بھائی ہارون سے کہا کہ میرے (کوہِٰ طور پر جانے کے) بعد تم میری قوم میں میرے جانشین ہو (ان کی) اصلاح کرتے رہنا ٹھیک اور شریروں کے رستے نہ چلنا\qt@no{142}}%
\qt@newcmd\qurantrans@ur@mxcvii{اور جب موسیٰ ہمارے مقرر کیے ہوئے وقت پر (کوہ طور) پر پہنچے اور ان کے پروردگار نے ان سے کلام کیا تو کہنے لگے کہ اے پروردگار مجھے (جلوہ) دکھا کہ میں تیرا دیدار (بھی) دیکھوں۔ پروردگار نے کہا کہ تم مجھے ہرگز نہ دیکھ سکو گے۔ ہاں پہاڑ کی طرف دیکھتے رہو اگر یہ اپنی جگہ قائم رہا تو تم مجھے دیکھ سکو گے۔ جب ان کا پروردگار پہاڑ پر نمودار ہوا تو (تجلی انوارِ ربانی) نے اس کو ریزہ ریزہ کردیا اور موسیٰ بےہوش ہو کر گر پڑے۔ جب ہوش میں آئے تو کہنے لگے کہ تیری ذات پاک ہے اور میں تیرے حضور توبہ کرتا ہوں اور جو ایمان لانے والے ہیں ان میں سب سے اول ہوں\qt@no{143}}%
\qt@newcmd\qurantrans@ur@mxcviii{خدا نے) فرمایا موسیٰ میں نے تم کو اپنے پیغام اور اپنے کلام سے لوگوں سے ممتاز کیا ہے۔ تو جو میں نے تم کو عطا کیا ہے اسے پکڑ رکھو اور (میرا) شکر بجالاؤ\qt@no{144}}%
\qt@newcmd\qurantrans@ur@mxcix{اور ہم نے (تورات) کی تختیوں میں ان کے لیے ہر قسم کی نصیحت اور ہر چیز کی تفصیل لکھ دی پھر (ارشاد فرمایا کہ) اسے زور سے پکڑے رہو اور اپنی قوم سے بھی کہہ دو کہ ان باتوں کو جو اس میں (مندرج ہیں اور) بہت بہتر ہیں پکڑے رہیں۔ میں عنقریب تم کو نافرمان لوگوں کا گھر دکھاؤں گا\qt@no{145}}%
\qt@newcmd\qurantrans@ur@mc{جو لوگ زمین میں ناحق غرور کرتے ہیں ان کو اپنی آیتوں سے پھیر دوں گا۔ اگر یہ سب نشانیاں بھی دیکھ لیں تب بھی ان پر ایمان نہ لائیں اور اگر راستی کا رستہ دیکھیں تو اسے (اپنا) رستہ نہ بنائیں۔ اور اگر گمراہی کی راہ دیکھیں تو اسے رستہ بنالیں۔ یہ اس لیے کہ انہوں نے ہماری آیات کو جھٹلایا اور ان سے غفلت کرتے رہے\qt@no{146}}%
\qt@newcmd\qurantrans@ur@mci{اور جن لوگوں نے ہماری آیتوں اور آخرت کے آنے کو جھٹلایا ان کے اعمال ضائع ہوجائیں گے۔ یہ جیسے عمل کرتے ہیں ویسا ہی ان کو بدلہ ملے گا\qt@no{147}}%
\qt@newcmd\qurantrans@ur@mcii{اور قوم موسیٰ نے موسیٰ کے بعد اپنے زیور کا ایک بچھڑا بنا لیا (وہ) ایک جسم (تھا) جس میں سے بیل کی آواز نکلتی تھی۔ ان لوگوں نے یہ نہ دیکھا کہ وہ نہ ان سے بات کرسکتا ہے اور نہ ان کو راستہ دکھا سکتا ہے۔ اس کو انہوں نے (معبود) بنالیا اور (اپنے حق میں) ظلم کیا\qt@no{148}}%
\qt@newcmd\qurantrans@ur@mciii{اور جب وہ نادم ہوئے اور دیکھا کہ گمراہ ہوگئے ہیں تو کہنے لگے کہ اگر ہمارا پروردگار ہم پر رحم نہیں کرے گا اور ہم کو معاف نہیں فرمائے گا تو ہم برباد ہوجائیں گے\qt@no{149}}%
\qt@newcmd\qurantrans@ur@mciv{اور جب موسیٰ اپنی قوم میں نہایت غصے اور افسوس کی حالت میں واپس آئے۔ تو کہنے لگے کہ تم نے میرے بعد بہت ہی بداطواری کی۔ کیا تم نے اپنے پروردگار کا حکم (یعنی میرا اپنے پاس آنا) جلد چاہا (یہ کہا) اور (شدت غضب سے تورات کی) تختیاں ڈال دیں اور اپنے بھائی کے سر (کے بالوں) کو پکڑ کر اپنی طرف کھینچنے لگے۔ انہوں نے کہا کہ بھائی جان لوگ تو مجھے کمزور سمجھتے تھے اور قریب تھا کہ قتل کردیں۔ تو ایسا کام نہ کیجیے کہ دشمن مجھ پر ہنسیں اور مجھے ظالم لوگوں میں مت ملایئے\qt@no{150}}%
\qt@newcmd\qurantrans@ur@mcv{تب انہوں نے دعا کی کہ اے میرے پروردگار مجھے اور میرے بھائی کو معاف فرما اور ہمیں اپنی رحمت میں داخل کر تو سب سے بڑھ کر رحم کرنے والا ہے\qt@no{151}}%
\qt@newcmd\qurantrans@ur@mcvi{خدا نے فرمایا کہ) جن لوگوں نے بچھڑے کو (معبود) بنا لیا تھا ان پر پروردگار کا غضب واقع ہوگا اور دنیا کی زندگی میں ذلت (نصیب ہوگی) اور ہم افتراء پردازوں کو ایسا ہی بدلہ دیا کرتے ہیں\qt@no{152}}%
\qt@newcmd\qurantrans@ur@mcvii{اور جنہوں نے برے کام کیے پھر اس کے بعد توبہ کرلی اور ایمان لے آئے تو کچھ شک نہیں کہ تمہارا پروردگار اس کے بعد (بخش دے گا کہ وہ) بخشنے والا مہربان ہے\qt@no{153}}%
\qt@newcmd\qurantrans@ur@mcviii{اور جب موسیٰ کا غصہ فرو ہوا تو (تورات) کی تختیاں اٹھالیں اور جو کچھ ان میں لکھا تھا وہ ان لوگوں کے لیے جو اپنے پروردگار سے ڈرتے ہیں۔ ہدایت اور رحمت تھی\qt@no{154}}%
\qt@newcmd\qurantrans@ur@mcix{اور موسیٰ نے اس میعاد پر جو ہم نے مقرر کی تھی اپنی قوم کے ستر آدمی منتخب (کرکے کوہ طور پر حاضر) ٹل کیے۔ جب ان کو زلزلے نے پکڑا تو موسیٰ نے کہا کہ اے پروردگار تو چاہتا تو ان کو اور مجھ کو پہلے ہی سے ہلاک کر دیتا۔ کیا تو اس فعل کی سزا میں جو ہم میں سے بےعقل لوگوں نے کیا ہے ہمیں ہلاک کردے گا۔ یہ تو تیری آزمائش ہے۔ اس سے تو جس کو چاہے گمراہ کرے اور جس کو چاہے ہدایت بخشے۔ تو ہی ہمارا کارساز ہے تو ہمیں (ہمارے گناہ) بخش دے اور ہم پر رحم فرما اور تو سب سے بہتر بخشنے والا ہے\qt@no{155}}%
\qt@newcmd\qurantrans@ur@mcx{اور ہمارے لیے اس دنیا میں بھی بھلائی لکھ دے اور آخرت میں بھی۔ ہم تیری طرف رجوع ہوچکے۔ فرمایا کہ جو میرا عذاب ہے اسے تو جس پر چاہتا ہوں نازل کرتا ہوں اور جو میری رحمت ہے وہ ہر چیز کو شامل ہے۔ میں اس کو ان لوگوں کے لیے لکھ دوں گا جو پرہیزگاری کرتے اور زکوٰة دیتے اور ہماری آیتوں پر ایمان رکھتے ہیں\qt@no{156}}%
\qt@newcmd\qurantrans@ur@mcxi{وہ جو (محمدﷺ) رسول (الله) کی جو نبی اُمی ہیں پیروی کرتے ہیں جن (کے اوصاف) کو وہ اپنے ہاں تورات اور انجیل میں لکھا ہوا پاتے ہیں۔ وہ انہیں نیک کام کا حکم دیتے ہیں اور برے کام سے روکتے ہیں۔ اور پاک چیزوں کو ان کے لیے حلال کرتے ہیں اور ناپاک چیزوں کو ان پر حرام ٹہراتے ہیں اور ان پر سے بوجھ اور طوق جو ان (کے سر) پر (اور گلے میں) تھے اتارتے ہیں۔ تو جو لوگ ان پر ایمان لائے اور ان کی رفاقت کی اور انہیں مدد دی۔ اور جو نور ان کے ساتھ نازل ہوا ہے اس کی پیروی کی۔ وہی مراد پانے والے ہیں\qt@no{157}}%
\qt@newcmd\qurantrans@ur@mcxii{اے محمدﷺ) کہہ دو کہ لوگو میں تم سب کی طرف خدا کا بھیجا ہوا (یعنی اس کا رسول) ہوں۔ (وہ) جو آسمانوں اور زمین کا بادشاہ ہے۔ اس کے سوا کوئی معبود نہیں وہی زندگانی بخشتا ہے اور وہی موت دیتا ہے۔ تو خدا پر اور اس کے رسول پیغمبر اُمی پر جو خدا پر اور اس کے تمام کلام پر ایمان رکھتے ہیں ایمان لاؤ اور ان کی پیروی کرو تاکہ ہدایت پاؤ\qt@no{158}}%
\qt@newcmd\qurantrans@ur@mcxiii{اور قوم موسیٰ میں کچھ لوگ ایسے بھی ہیں جو حق کا راستہ بتاتے اور اسی کے ساتھ انصاف کرتے ہیں\qt@no{159}}%
\qt@newcmd\qurantrans@ur@mcxiv{اور ہم نے ان کو (یعنی بنی اسرائیل کو) الگ الگ کرکے بارہ قبیلے (اور) بڑی بڑی جماعتیں بنا دیا۔ اور جب موسیٰ سے ان کی قوم نے پانی طلب کیا تو ہم نے ان کی طرف وحی بھیجی کہ اپنی لاٹھی پتھر پر مار دو۔ تو اس میں سے بارہ چشمے پھوٹ نکلے۔ اور سب لوگوں نے اپنا اپنا گھاٹ معلوم کرلیا۔ اور ہم نے ان (کے سروں) پر بادل کو سائبان بنائے رکھا اور ان پر من وسلویٰ اتارتے رہے۔ اور (ان سے کہا کہ) جو پاکیزہ چیزیں ہم تمہیں دیتے ہیں انہیں کھاؤ۔ اور ان لوگوں نے ہمارا کچھ نقصان نہیں کیا بلکہ (جو) نقصان کیا اپنا ہی کیا\qt@no{160}}%
\qt@newcmd\qurantrans@ur@mcxv{اور (یاد کرو) جب ان سے کہا گیا کہ اس شہر میں سکونت اختیار کرلو اور اس میں جہاں سے جی چاہے کھانا (پینا) اور (ہاں شہر میں جانا تو) حِطّتہٌ کہنا اور دروازے میں داخل ہونا تو سجدہ کرنا۔ ہم تمہارے گناہ معاف کردیں گے۔ اور نیکی کرنے والوں کو اور زیادہ دیں گے\qt@no{161}}%
\qt@newcmd\qurantrans@ur@mcxvi{مگر جو ان میں ظالم تھے انہوں نے اس لفظ کو جس کا ان کو حکم دیا گیا تھا بدل کر اس کی جگہ اور لفظ کہنا شروع کیا تو ہم نے ان پر آسمان سے عذاب بھیجا اس لیے کہ ظلم کرتے تھے\qt@no{162}}%
\qt@newcmd\qurantrans@ur@mcxvii{اور ان سے اس گاؤں کا حال تو پوچھو جب لب دریا واقع تھا۔ جب یہ لوگ ہفتے کے دن کے بارے میں حد سے تجاوز کرنے لگے (یعنی) اس وقت کہ ان کے ہفتے کے دن مچھلیاں ان کے سامنے پانی کے اوپر آتیں اور جب ہفتے کا دن نہ ہوتا تو نہ آتیں۔ اسی طرح ہم ان لوگوں کو ان کی نافرمانیوں کے سبب آزمائش میں ڈالنے لگے\qt@no{163}}%
\qt@newcmd\qurantrans@ur@mcxviii{اور جب ان میں سے ایک جماعت نے کہا کہ تم ایسے لوگوں کو کیوں نصیحت کرتے ہو جن کو الله ہلاک کرنے والا یا سخت عذاب دینے والا ہے تو انہوں نے کہا اس لیے کہ تمہارے پروردگار کے سامنے معذرت کرسکیں اور عجب نہیں کہ وہ پرہیزگاری اختیار کریں\qt@no{164}}%
\qt@newcmd\qurantrans@ur@mcxix{جب انہوں نے ان باتوں کو فراموش کردیا جن کی ان کو نصیحت کی گئی تھی تو جو لوگ برائی سے منع کرتے تھے ان کو ہم نے نجات دی اور جو ظلم کرتے تھے ان کو برے عذاب میں پکڑ لیا کہ نافرمانی کئے جاتے تھے\qt@no{165}}%
\qt@newcmd\qurantrans@ur@mcxx{غرض جن اعمال (بد) سے ان کو منع کیا گیا تھا جب وہ ان (پراصرار اور ہمارے حکم سے) گردن کشی کرنے لگے تو ہم نے ان کو حکم دیا کہ ذلیل بندر ہوجاؤ\qt@no{166}}%
\qt@newcmd\qurantrans@ur@mcxxi{اور اس وقت کو یاد کرو) جب تمہارے پروردگار نے (یہود کو) آگاہ کردیا تھا کہ وہ ان پر قیامت تک ایسے شخص کو مسلط رکھے گا جو انہیں بری بری تکلیفیں دیتا رہے۔ بےشک تمہارا پروردگار جلد عذاب کرنے والا ہے اور وہ بخشنے والا مہربان بھی ہے\qt@no{167}}%
\qt@newcmd\qurantrans@ur@mcxxii{اور ہم نے ان کو جماعت جماعت کرکے ملک میں منتشر کر دیا۔ بعض ان میں سے نیکوکار ہیں اور بعض اور طرح کے (یعنی بدکار) اور ہم آسائشوں، تکلیفوں (دونوں) سے ان کی آزمائش کرتے رہے تاکہ (ہماری طرف) رجوع کریں\qt@no{168}}%
\qt@newcmd\qurantrans@ur@mcxxiii{پھر ان کے بعد ناخلف ان کے قائم مقام ہوئے جو کتاب کے وارث بنے۔ یہ (بےتامل) اس دنیائے دنی کا مال ومتاع لے لیتے ہیں اور کہتے ہیں کہ ہم بخش دیئے جائیں گے۔ اور (لوگ ایسوں پر طعن کرتے ہیں) اگر ان کے سامنے بھی ویسا ہی مال آجاتا ہے تو وہ بھی اسے لے لیتے ہیں۔ کیا ان سے کتاب کی نسبت عہد نہیں لیا گیا کہ خدا پر سچ کے سوا اور کچھ نہیں کہیں گے۔ اور جو کچھ اس (کتاب) میں ہے اس کو انہوں نے پڑھ بھی لیا ہے۔ اور آخرت کا گھر پرہیزگاروں کے لیے بہتر ہے کیا تم سمجھتے نہیں\qt@no{169}}%
\qt@newcmd\qurantrans@ur@mcxxiv{اور جو لوگ کتاب کو مضبوط پکڑے ہوئے ہیں اور نماز کا التزام رکھتے ہیں (ان کو ہم اجر دیں گے کہ) ہم نیکوکاروں کا اجر ضائع نہیں کرتے\qt@no{170}}%
\qt@newcmd\qurantrans@ur@mcxxv{اور جب ہم نے ان (کے سروں) پر پہاڑ اٹھا کھڑا کیا گویا وہ سائبان تھا اور انہوں نے خیال کیا کہ وہ ان پر گرتا ہے تو (ہم نے کہا کہ) جو ہم نے تمہیں دیا ہے اسے زور سے پکڑے رہو۔ اور جو اس میں لکھا ہے اس پر عمل کرو تاکہ بچ جاؤ\qt@no{171}}%
\qt@newcmd\qurantrans@ur@mcxxvi{اور جب تمہارے پروردگار نے بنی آدم سے یعنی ان کی پیٹھوں سے ان کی اولاد نکالی تو ان سے خود ان کے مقابلے میں اقرار کرا لیا (یعنی ان سے پوچھا کہ) کیا تمہارا پروردگار نہیں ہوں۔ وہ کہنے لگے کیوں نہیں ہم گواہ ہیں (کہ تو ہمارا پروردگار ہے) ۔ یہ اقرار اس لیے کرایا تھا کہ قیامت کے دن (کہیں یوں نہ) کہنے لگو کہ ہم کو تو اس کی خبر ہی نہ تھی\qt@no{172}}%
\qt@newcmd\qurantrans@ur@mcxxvii{یا یہ (نہ) کہو کہ شرک تو پہلے ہمارے بڑوں نے کیا تھا۔ اور ہم تو ان کی اولاد تھے (جو) ان کے بعد (پیدا ہوئے) ۔ تو کیا جو کام اہل باطل کرتے رہے اس کے بدلے تو ہمیں ہلاک کرتا ہے\qt@no{173}}%
\qt@newcmd\qurantrans@ur@mcxxviii{اور اسی طرح ہم (اپنی) آیتیں کھول کھول کر بیان کرتے ہیں تاکہ یہ رجوع کریں\qt@no{174}}%
\qt@newcmd\qurantrans@ur@mcxxix{اور ان کو اس شخص کا حال پڑھ کر سنا دو جس کو ہم نے اپنی آیتیں عطا فرمائیں (اور ہفت پارچہٴ علم شرائع سے مزین کیا) تو اس نے ان کو اتار دیا پھر شیطان اس کے پیچھے لگا تو وہ گمراہوں میں ہوگیا\qt@no{175}}%
\qt@newcmd\qurantrans@ur@mcxxx{اور اگر ہم چاہتے تو ان آیتوں سے اس (کے درجے) کو بلند کر دیتے مگر وہ تو پستی کی طرف مائل ہوگیا اور اپنی خواہش کے پیچھے چل پڑا۔ تو اس کی مثال کتے کی سی ہوگئی کہ اگر سختی کرو تو زبان نکالے رہے اور یونہی چھوڑ دو تو بھی زبان نکالے رہے۔ یہی مثال ان لوگوں کی ہے جنہوں نے ہماری آیتوں کو جھٹلایا تو ان سے یہ قصہ بیان کردو۔ تاکہ وہ فکر کریں\qt@no{176}}%
\qt@newcmd\qurantrans@ur@mcxxxi{جن لوگوں نے ہماری آیتوں کی تکذیب کی ان کی مثال بری ہے اور انہوں نے نقصان (کیا تو) اپنا ہی کیا\qt@no{177}}%
\qt@newcmd\qurantrans@ur@mcxxxii{جس کو خدا ہدایت دے وہی راہ یاب ہے اور جس کو گمراہ کرے تو ایسے ہی لوگ نقصان اٹھانے والے ہیں\qt@no{178}}%
\qt@newcmd\qurantrans@ur@mcxxxiii{اور ہم نے بہت سے جن اور انسان دوزخ کے لیے پیدا کیے ہیں۔ ان کے دل ہیں لیکن ان سے سمجھتے نہیں اور ان کی آنکھیں ہیں مگر ان سے دیکھتے نہیں اور ان کے کان ہیں پر ان سے سنتے نہیں۔ یہ لوگ بالکل چارپایوں کی طرح ہیں بلکہ ان سے بھی بھٹکے ہوئے۔ یہی وہ ہیں جو غفلت میں پڑے ہوئے ہیں\qt@no{179}}%
\qt@newcmd\qurantrans@ur@mcxxxiv{اور خدا کے سب نام اچھے ہی اچھے ہیں۔ تو اس کو اس کے ناموں سے پکارا کرو اور جو لوگ اس کے ناموں میں کجی اختیار کرتے ہیں ان کو چھوڑ دو۔ وہ جو کچھ کر رہے ہیں عنقریب اس کی سزا پائیں گے\qt@no{180}}%
\qt@newcmd\qurantrans@ur@mcxxxv{اور ہماری مخلوقات میں سے ایک وہ لوگ ہیں جو حق کا رستہ بتاتے ہیں اور اسی کے ساتھ انصاف کرتے ہیں\qt@no{181}}%
\qt@newcmd\qurantrans@ur@mcxxxvi{اور جن لوگوں نے ہماری آیتوں کو جھٹلایا ان کو بتدریج اس طریق سے پکڑیں گے کہ ان کو معلوم ہی نہ ہوگا\qt@no{182}}%
\qt@newcmd\qurantrans@ur@mcxxxvii{اور میں ان کو مہلت دیئے جاتا ہوں میری تدبیر (بڑی) مضبوط ہے\qt@no{183}}%
\qt@newcmd\qurantrans@ur@mcxxxviii{کیا انہوں نے غور نہیں کیا کہ ان کے رفیق محمد (ﷺ) کو (کسی طرح کا بھی) جنون نہیں ہے۔ وہ تو ظاہر ظہور ڈر سنانے والے ہیں\qt@no{184}}%
\qt@newcmd\qurantrans@ur@mcxxxix{کیا انہوں نے آسمان اور زمین کی بادشاہت میں جو چیزیں خدا نے پیدا کی ہیں ان پر نظر نہیں کی اور اس بات پر (خیال نہیں کیا) کہ عجب نہیں ان (کی موت) کا وقت نزدیک پہنچ گیا ہو۔ تو اس کے بعد وہ اور کس بات پر ایمان لائیں گے\qt@no{185}}%
\qt@newcmd\qurantrans@ur@mcxl{جس شخص کو خدا گمراہ کرے اس کو کوئی ہدایت دینے والا نہیں اور وہ ان (گمراہوں) کو چھوڑے رکھتا ہے کہ اپنی سرکشی میں پڑے بہکتے رہیں\qt@no{186}}%
\qt@newcmd\qurantrans@ur@mcxli{یہ لوگ) تم سے قیامت کے بارے میں پوچھتے ہیں کہ اس کے واقع ہونے کا وقت کب ہے۔ کہہ دو کہ اس کا علم تو میرے پروردگار ہی کو ہے۔ وہی اسے اس کے وقت پر ظاہر کردےگا۔ وہ آسمان وزمین میں ایک بھاری بات ہوگی اور ناگہاں تم پر آجائے گی۔ یہ تم سے اس طرح دریافت کرتے ہیں کہ گویا تم اس سے بخوبی واقف ہو۔ کہو کہ اس کا علم تو خدا ہی کو ہے لیکن اکثر لوگ یہ نہیں جانتے\qt@no{187}}%
\qt@newcmd\qurantrans@ur@mcxlii{کہہ دو کہ میں اپنے فائدے اور نقصان کا کچھ بھی اختیار نہیں رکھتا مگر جو الله چاہے اور اگر میں غیب کی باتیں جانتا ہوتا تو بہت سے فائدے جمع کرلیتا اور مجھ کو کوئی تکلیف نہ پہنچتی۔ میں تو مومنوں کو ڈر اور خوشخبری سنانے والا ہوں\qt@no{188}}%
\qt@newcmd\qurantrans@ur@mcxliii{وہ خدا ہی تو ہے جس نے تم کو ایک شخص سے پیدا کیا اور اس سے اس کا جوڑا بنایا تاکہ اس سے راحت حاصل کرے۔ سو جب وہ اس کے پاس جاتا ہے تو اسے ہلکا سا حمل رہ جاتا ہے اور وہ اس کے ساتھ چلتی پھرتی ہے۔ پھر جب کچھ بوجھ معلوم کرتی یعنی بچہ پیٹ میں بڑا ہوتا ہے تو دونوں میاں بیوی اپنے پروردگار خدائے عزوجل سے التجا کرتے ہیں کہ اگر تو ہمیں صحیح وسالم (بچہ) دے گا تو ہم تیرے شکر گذار ہوں گے\qt@no{189}}%
\qt@newcmd\qurantrans@ur@mcxliv{جب وہ ان کو صحیح و سالم (بچہ) دیتا ہے تو اس (بچے) میں جو وہ ان کو دیتا ہے اس کا شریک مقرر کرتے ہیں۔ جو وہ شرک کرتے ہیں (خدا کا رتبہ) اس سے بلند ہے\qt@no{190}}%
\qt@newcmd\qurantrans@ur@mcxlv{کیا وہ ایسوں کو شریک بناتے ہیں جو کچھ بھی پیدا نہیں کرسکتے اور خود پیدا کیے جاتے ہیں\qt@no{191}}%
\qt@newcmd\qurantrans@ur@mcxlvi{اور نہ ان کی مدد کی طاقت رکھتے ہیں اور نہ اپنی ہی مدد کرسکتے ہیں\qt@no{192}}%
\qt@newcmd\qurantrans@ur@mcxlvii{اگر تم ان کو سیدھے رستے کی طرف بلاؤ تو تمہارا کہا نہ مانیں۔ تمہارے لیے برابر ہے کہ تم ان کو بلاؤ یا چپکے ہو رہو\qt@no{193}}%
\qt@newcmd\qurantrans@ur@mcxlviii{مشرکو) جن کو تم خدا کے سوا پکارتے ہو وہ تمہاری طرح کے بندے ہی ہیں (اچھا) تم ان کو پکارو اگر سچے ہو تو چاہیئے کہ وہ تم کو جواب بھی دیں\qt@no{194}}%
\qt@newcmd\qurantrans@ur@mcxlix{بھلا ان کے پاؤں ہیں جن سے چلیں یا ہاتھ ہیں جن سے پکڑیں یا آنکھیں ہیں جن سے دیکھیں یا کان ہیں جن سے سنیں؟ کہہ دو کہ اپنے شریکوں کو بلالو اور میرے بارے میں (جو) تدبیر (کرنی ہو) کرلو اور مجھے کچھ مہلت بھی نہ دو (پھر دیکھو کہ وہ میرا کیا کرسکتے ہیں)\qt@no{195}}%
\qt@newcmd\qurantrans@ur@mcl{میرا مددگار تو خدا ہی ہے جس نے کتاب (برحق) نازل کی۔ اور نیک لوگوں کا وہی دوستدار ہے\qt@no{196}}%
\qt@newcmd\qurantrans@ur@mcli{اور جن کو تم خدا کے سوا پکارتے ہو وہ نہ تمہاری ہی مدد کی طاقت رکھتے ہیں اور نہ خود ہی اپنی مدد کرسکتے ہیں\qt@no{197}}%
\qt@newcmd\qurantrans@ur@mclii{اور اگر تم ان کو سیدھے رستے کی طرف بلاؤ تو سن نہ سکیں اور تم انہیں دیکھتے ہو کہ (بہ ظاہر) آنکھیں کھولے تمہاری طرف دیکھ رہے ہیں مگر (فی الواقع) کچھ نہیں دیکھتے\qt@no{198}}%
\qt@newcmd\qurantrans@ur@mcliii{اے محمدﷺ) عفو اختیار کرو اور نیک کام کرنے کا حکم دو اور جاہلوں سے کنارہ کرلو\qt@no{199}}%
\qt@newcmd\qurantrans@ur@mcliv{اور اگر شیطان کی طرف سے تمہارے دل میں کسی طرح کا وسوسہ پیدا ہو تو خدا سے پناہ مانگو۔ بےشک وہ سننے والا (اور) سب کچھ جاننے والا ہے\qt@no{200}}%
\qt@newcmd\qurantrans@ur@mclv{جو لوگ پرہیزگار ہیں جب ان کو شیطان کی طرف سے کوئی وسوسہ پیدا ہوتا ہے تو چونک پڑتے ہیں اور (دل کی آنکھیں کھول کر) دیکھنے لگتے ہیں\qt@no{201}}%
\qt@newcmd\qurantrans@ur@mclvi{اور ان (کفار) کے بھائی انہیں گمراہی میں کھینچے جاتے ہیں پھر (اس میں کسی طرح کی) کوتاہی نہیں کرتے\qt@no{202}}%
\qt@newcmd\qurantrans@ur@mclvii{اور جب تم ان کے پاس (کچھ دنوں تک) کوئی آیت نہیں لاتے تو کہتے ہیں کہ تم نے (اپنی طرف سے) کیوں نہیں بنالی۔ کہہ دو کہ میں تو اسی کی پیروی کرتا ہوں جو میرے پروردگار کی طرف سے میرے پاس آتا ہے۔ یہ قرآن تمہارے پروردگار کی جانب سے دانش وبصیرت اور مومنوں کے لیے ہدایت اور رحمت ہے\qt@no{203}}%
\qt@newcmd\qurantrans@ur@mclviii{اور جب قرآن پڑھا جائے تو توجہ سے سنا کرو اور خاموش رہا کرو تاکہ تم پر رحم کیا جائے\qt@no{204}}%
\qt@newcmd\qurantrans@ur@mclix{اور اپنے پروردگار کو دل ہی دل میں عاجزی اور خوف سے اور پست آواز سے صبح وشام یاد کرتے رہو اور (دیکھنا) غافل نہ ہونا\qt@no{205}}%
\qt@newcmd\qurantrans@ur@mclx{جو لوگ تمہارے پروردگار کے پاس ہیں وہ اس کی عبادت سے گردن کشی نہیں کرتے اور اس پاک ذات کو یاد کرتے اور اس کے آگے سجدے کرتے رہتے ہیں\qt@no{206}}%
\qt@newcmd\qurantrans@ur@mclxi{\basmalahur (اے محمد! مجاہد لوگ) تم سے غنیمت کے مال کے بارے میں دریافت کرتے ہیں کہ (کیا حکم ہے) کہہ دو کہ غنیمت خدا اور اس کے رسول کا مال ہے۔ تو خدا سے ڈرو اور آپس میں صلح رکھو اور اگر ایمان رکھتے ہو تو خدا اور اس کے رسول کے حکم پر چلو\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mclxii{مومن تو وہ ہیں کہ جب خدا کا ذکر کیا جاتا ہے کہ ان کے دل ڈر جاتے ہیں اور جب انہیں اس کی آیتیں پڑھ کر سنائی جاتی ہیں تو ان کا ایمان اور بڑھ جاتا ہے۔ اور وہ اپنے پروردگار پر بھروسہ رکھتے ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mclxiii{اور) وہ جو نماز پڑھتے ہیں اور جو مال ہم نے ان کو دیا ہے اس میں سے (نیک کاموں میں) خرچ کرتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mclxiv{یہی سچے مومن ہیں اور ان کے لیے پروردگار کے ہاں (بڑے بڑے درجے) اور بخشش اور عزت کی روزی ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mclxv{ان لوگوں کو اپنے گھروں سے اسی طرح نکلنا چاہیئے تھا) جس طرح تمہارے پروردگار نے تم کو تدبیر کے ساتھ اپنے گھر سے نکالا اور (اس وقت) مومنوں ایک جماعت ناخوش تھی\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mclxvi{وہ لوگ حق بات میں اس کے ظاہر ہوئے پیچھے تم سے جھگڑنے لگے گویا موت کی طرف دھکیلے جاتے ہیں اور اسے دیکھ رہے ہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mclxvii{اور (اس وقت کو یاد کرو) جب خدا تم سے وعدہ کرتا تھا کہ (ابوسفیان اور ابوجہل کے) دو گروہوں میں سے ایک گروہ تمہارا (مسخر) ہوجائے گا۔ اور تم چاہتے تھے کہ جو قافلہ بے (شان و) شوکت (یعنی بے ہتھیار ہے) وہ تمہارے ہاتھ آجائے اور خدا چاہتا تھا کہ اپنے فرمان سے حق کو قائم رکھے اور کافروں کی جڑ کاٹ کر (پھینک) دے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mclxviii{تاکہ سچ کو سچ اور جھوٹ کو جھوٹ کردے۔ گو مشرک ناخوش ہی ہوں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mclxix{جب تم اپنے پروردگار سے فریاد کرتے تھے تو اس نے تمہاری دعا قبول کرلی (اور فرمایا) کہ (تسلی رکھو) ہم ہزار فرشتوں سے جو ایک دوسرے کے پیچھے آتے جائیں گے تمہاری مدد کریں گے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mclxx{اور اس مدد کو خدا نے محض بشارت بنایا تھا کہ تمہارے دل سے اطمینان حاصل کریں۔ اور مدد تو الله ہی کی طرف سے ہے۔ بےشک خدا غالب حکمت والا ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mclxxi{جب اس نے (تمہاری) تسکین کے لیے اپنی طرف سے تمہیں نیند (کی چادر) اُڑھا دی اور تم پر آسمان سے پانی برسادیا تاکہ تم کو اس سے (نہلا کر) پاک کر دے اور شیطانی نجاست کو تم سے دور کردے۔ اور اس لیے بھی کہ تمہارے دلوں کو مضبوط کردے اور اس سے تمہارے پاؤں جمائے رکھے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mclxxii{جب تمہارا پروردگار فرشتوں کو ارشاد فرماتا تھا کہ میں تمہارے ساتھ ہوں تم مومنوں کو تسلی دو کہ ثابت قدم رہیں۔ میں ابھی ابھی کافروں کے دلوں میں رعب وہیبت ڈالے دیتا ہوں تو ان کے سر مار (کر) اڑا دو اور ان کا پور پور مار (کر توڑ) دو\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mclxxiii{یہ (سزا) اس لیے دی گئی کہ انہوں نے خدا اور اس کے رسول کی مخالفت کی۔ اور جو شخص خدا اور اس کے رسول کی مخالفت کرتا ہے تو خدا بھی سخت عذاب دینے والا ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mclxxiv{یہ (مزہ تو یہاں) چکھو اور یہ (جانے رہو) کہ کافروں کے لیے (آخرت میں) دوزخ کا عذاب (بھی تیار) ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mclxxv{اے اہل ایمان جب میدان جنگ میں کفار سے تمہار مقابلہ ہو تو ان سے پیٹھ نہ پھیرنا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mclxxvi{اور جو شخص جنگ کے روز اس صورت کے سوا کہ لڑائی کے لیے کنارے کنارے چلے (یعنی حکمت عملی سے دشمن کو مارے) یا اپنی فوج میں جا ملنا چاہے۔ ان سے پیٹھ پھیرے گا تو (سمجھو کہ) وہ خدا کے غضب میں گرفتار ہوگیا اور اس کا ٹھکانا دوزخ ہے۔ اور وہ بہت ہی بری جگہ ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mclxxvii{تم لوگوں نے ان (کفار) کو قتل نہیں کیا بلکہ خدا نے انہیں قتل کیا۔ اور (اے محمدﷺ) جس وقت تم نے کنکریاں پھینکی تھیں تو وہ تم نے نہیں پھینکی تھیں بلکہ الله نے پھینکی تھیں۔ اس سے یہ غرض تھی کہ مومنوں کو اپنے (احسانوں) سے اچھی طرح آزمالے۔ بےشک خدا سنتا جانتا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mclxxviii{بات) یہ (ہے) کچھ شک نہیں کہ خدا کافروں کی تدبیر کو کمزور کر دینے والا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mclxxix{کافرو) اگر تم (محمد صلی الله علیہ وآلہ وسلم پر) فتح چاہتے ہو تو تمہارے پاس فتح آچکی۔ (دیکھو) اگر تم (اپنے افعال سے) باز آجاؤ تو تمہارے حق میں بہتر ہے۔ اور اگر پھر (نافرمانی) کرو گے تو ہم بھی پھر تمہیں عذاب کریں گے اور تمہاری جماعت خواہ کتنی ہی کثیر ہو تمہارے کچھ بھی کام نہ آئے گی۔ اور خدا تو مومنوں کے ساتھ ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mclxxx{اے ایمان والو! خدا اور اس کے رسول کے حکم پر چلو اور اس سے روگردانی نہ کرو اور تم سنتے ہو\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mclxxxi{اور ان لوگوں جیسے نہ ہونا جو کہتے ہیں کہ ہم نے حکم (خدا) سن لیا مگر (حقیقت میں) نہیں سنتے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mclxxxii{کچھ شک نہیں کہ خدا کے نزدیک تمام جانداروں سے بدتر بہرے گونگے ہیں جو کچھ نہیں سمجھتے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mclxxxiii{اور اگر خدا ان میں نیکی (کا مادہ) دیکھتا تو ان کو سننے کی توفیق بخشتا۔ اور اگر (بغیر صلاحیت ہدایت کے) سماعت دیتا تو وہ منہ پھیر کر بھاگ جاتے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mclxxxiv{مومنو! خدا اور اس کے رسول کا حکم قبول کرو جب کہ رسول خدا تمہیں ایسے کام کے لیے بلاتے ہیں جو تم کو زندگی (جاوداں) بخشتا ہے۔ اور جان رکھو کہ خدا آدمی اور اس کے دل کے درمیان حامل ہوجاتا ہے اور یہ بھی کہ تم سب اس کے روبرو جمع کیے جاؤ گے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mclxxxv{اور اس فتنے سے ڈرو جو خصوصیت کے ساتھ انہیں لوگوں پر واقع نہ ہوگا جو تم میں گنہگار ہیں۔ اور جان رکھو کہ خدا سخت عذاب دینے والا ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mclxxxvi{اور اس وقت کو یاد کرو جب تم زمین (مکہ) میں قلیل اور ضعیف سمجھے جاتے تھے اور ڈرتے رہتے تھے کہ لوگ تمہیں اُڑا (نہ) لے جائیں (یعنی بےخان وماں نہ کردیں) تو اس نے تم کو جگہ دی اور اپنی مدد سے تم کو تقویت بخشی اور پاکیزہ چیزیں کھانے کو دیں تاکہ (اس کا) شکر کرو\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mclxxxvii{اے ایمان والو! نہ تو خدا اور رسول کی امانت میں خیانت کرو اور نہ اپنی امانتوں میں خیانت کرو اور تم (ان باتوں کو) جانتے ہو\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mclxxxviii{اور جان رکھو کہ تمہارا مال اور اولاد بڑی آزمائش ہے اور یہ کہ خدا کے پاس (نیکیوں کا) بڑا ثواب ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mclxxxix{مومنو! اگر تم خدا سے ڈرو گے تو وہ تمہارے لیے امر فارق پیدا کردے گا (یعنی تم کو ممتاز کردے گا) تو وہ تمہارے گناہ مٹادے گا اور تمہیں بخش دے گا۔ اور خدا بڑا فضل والا ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mcxc{اور (اے محمدﷺ اس وقت کو یاد کرو) جب کافر لوگ تمہارے بارے میں چال چل رہے تھے کہ تم کو قید کر دیں یا جان سے مار ڈالیں یا (وطن سے) نکال دیں تو (ادھر تو) وہ چال چل رہے تھے اور (اُدھر) خدا چال چل رہا تھا۔ اور خدا سب سے بہتر چال چلنے والا ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mcxci{اور جب ان کو ہماری آیتیں پڑھ کر سنائی جاتی ہیں تو کہتے ہیں (یہ کلام) ہم نے سن لیا ہے اگر ہم چاہیں تو اسی طرح کا (کلام) ہم بھی کہہ دیں اور یہ ہے ہی کیا صرف اگلے لوگوں کی حکایتیں ہیں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mcxcii{اور جب انہوں نے کہا کہ اے خدا اگر یہ (قرآن) تیری طرف سے برحق ہے تو ہم پر آسمان سے پتھر برسا یا کوئی اور تکلیف دینے والا عذاب بھیج\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mcxciii{اور خدا ایسا نہ تھا کہ جب تک تم ان میں سے تھے انہیں عذاب دیتا۔ اور ایسا نہ تھا کہ وہ بخششیں مانگیں اور انہیں عذاب دے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mcxciv{اور (اب) ان کے لیے کون سی وجہ ہے کہ وہ انہیں عذاب نہ دے جب کہ وہ مسجد محترم (میں نماز پڑھنے) سے روکتے ہیں اور وہ اس مسجد کے متولی بھی نہیں۔ اس کے متولی تو صرف پرہیزگار ہیں۔ لیکن ان میں اکثر نہیں جانتے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mcxcv{اور ان لوگوں کی نماز خانہٴ کعبہ کے پاس سیٹیاں اور تالیاں بجانے کے سوا کچھ نہ تھی۔ تو تم جو کفر کرتے تھے اب اس کے بدلے عذاب (کا مزہ) چکھو\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mcxcvi{جو لوگ کافر ہیں اپنا مال خرچ کرتے ہیں کہ (لوگوں کو) خدا کے رستے سے روکیں۔ سو ابھی اور خرچ کریں گے مگر آخر وہ (خرچ کرنا) ان کے لیے (موجب) افسوس ہوگا اور وہ مغلوب ہوجائیں گے۔ اور کافر لوگ دوزخ کی طرف ہانکے جائیں گے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mcxcvii{تاکہ خدا ناپاک کو پاک سے الگ کر دے اور ناپاک کو ایک دوسرے پر رکھ کر ایک ڈھیر بنا دے۔ پھر اس کو دوزخ میں ڈال دے۔ یہی لوگ خسارہ پانے والے ہیں\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mcxcviii{اے پیغمبر) کفار سے کہہ دو کہ اگر وہ اپنے افعال سے باز آجائیں تو جو ہوچکا وہ انہیں معاف کردیا جائے گا۔ اور اگر پھر (وہی حرکات) کرنے لگیں گے تو اگلے لوگوں کا (جو) طریق جاری ہوچکا ہے (وہی ان کے حق میں برتا جائے گا)\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mcxcix{اور ان لوگوں سے لڑتے رہو یہاں تک کہ فتنہ (یعنی کفر کا فساد) باقی نہ رہے اور دین سب خدا ہی کا ہوجائے اور اگر باز آجائیں تو خدا ان کے کاموں کو دیکھ رہا ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mcc{اور اگر روگردانی کریں تو جان رکھو کہ خدا تمہارا حمایتی ہے۔ (اور) وہ خوب حمایتی اور خوب مددگار ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mcci{اور جان رکھو کہ جو چیز تم (کفار سے) لوٹ کر لاؤ اس میں سے پانچواں حصہ خدا کا اور اس کے رسول کا اور اہل قرابت کا اور یتیموں کا اور محتاجوں کا اور مسافروں کا ہے۔ اگر تم خدا پر اور اس (نصرت) پر ایمان رکھتے ہو جو (حق وباطل میں) فرق کرنے کے دن (یعنی جنگ بدر میں) جس دن دونوں فوجوں میں مڈھ بھیڑ ہوگئی۔ اپنے بندے (محمدﷺ) پر نازل فرمائی۔ اور خدا ہر چیز پر قادر ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mccii{جس وقت تم (مدینے سے) قریب کے ناکے پر تھے اور کافر بعید کے ناکے پر اور قافلہ تم سے نیچے (اتر گیا) تھا۔ اور اگر تم (جنگ کے لیے) آپس میں قرارداد کرلیتے تو وقت معین (پر جمع ہونے) میں تقدیم وتاخیر ہو جاتی۔ لیکن خدا کو منظور تھا کہ جو کام ہو کر رہنے والا تھا اسے کر ہی ڈالے تاکہ جو مرے بصیرت پر (یعنی یقین جان کر) مرے اور جو جیتا رہے وہ بھی بصیرت پر (یعنی حق پہچان کر) جیتا رہے۔ اور کچھ شک نہیں کہ خدا سنتا جانتا ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mcciii{اس وقت خدا نے تمہیں خواب میں کافروں کو تھوڑی تعداد میں دکھایا۔ اور اگر بہت کر کے دکھاتا تو تم لوگ جی چھوڑ دیتے اور (جو) کام (درپیش تھا اس) میں جھگڑنے لگتے لیکن خدا نے (تمہیں اس سے) بچا لیا۔ بےشک وہ سینوں کی باتوں تک سے واقف ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mcciv{اور اس وقت جب تم ایک دوسرے کے مقابل ہوئے تو کافروں کو تمہاری نظروں میں تھوڑا کر کے دکھاتا تھا اور تم کو ان کی نگاہوں میں تھوڑا کر کے دکھاتا تھا تاکہ خدا کو جو کام منظور کرنا تھا اسے کر ڈالے۔ اور سب کاموں کا رجوع خدا کی طرف ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mccv{مومنو! جب (کفار کی) کسی جماعت سے تمہارا مقابلہ ہو تو ثابت قدم رہو اور خدا کو بہت یاد کرو تاکہ مراد حاصل کرو\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mccvi{اور خدا اور اس کے رسول کے حکم پر چلو اور آپس میں جھگڑا نہ کرنا کہ (ایسا کرو گے تو) تم بزدل ہو جاؤ گے اور تمہارا اقبال جاتا رہے گا اور صبر سے کام لو۔ کہ خدا صبر کرنے والوں کا مددگار ہے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mccvii{اور ان لوگوں جیسے نہ ہونا جو اِتراتے ہوئے (یعنی حق کا مقابلہ کرنے کے لیے) اور لوگوں کو دکھانے کے لیے گھروں سے نکل آئے اور لوگوں کو خدا کی راہ سے روکتے ہیں۔ اور جو اعمال یہ کرتے ہیں خدا ان پر احاطہ کئے ہوئے ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mccviii{اور جب شیطانوں نے ان کے اعمال ان کو آراستہ کر کے دکھائے اور کہا کہ آج کے دن لوگوں میں کوئی تم پر غالب نہ ہوگا اور میں تمہارا رفیق ہوں (لیکن) جب دونوں فوجیں ایک دوسرے کے مقابل صف آراء ہوئیں تو پسپا ہو کر چل دیا اور کہنے لگا کہ مجھے تم سے کوئی واسطہ نہیں۔ میں تو ایسی چیزیں دیکھ رہا ہوں جو تم نہیں دیکھ سکتے۔ مجھے تو خدا سے ڈر لگتا ہے۔ اور خدا سخت عذاب کرنے والا ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mccix{اس وقت منافق اور (کافر) جن کے دلوں میں مرض تھا کہتے تھے کہ ان لوگوں کو ان کے دین نے مغرور کر رکھا ہے اور جو شخص خدا پر بھروسہ رکھتا ہے تو خدا غالب حکمت والا ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mccx{اور کاش تم اس وقت (کی کیفیت) دیکھو۔ جب فرشتے کافروں کی جانیں نکالتے ہیں ان کے مونہوں اور پیٹھوں پر (کوڑے اور ہتھوڑے وغیرہ) مارتے (ہیں اور کہتے ہیں) کہ (اب) عذاب آتش (کا مزہ) چکھو\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mccxi{یہ ان (اعمال) کی سزا ہے جو تمہارے ہاتھوں نے آگے بھیجے ہیں۔ اور یہ (جان رکھو) کہ خدا بندوں پر ظلم نہیں کرتا\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mccxii{جیسا حال فرعوینوں اور ان سے پہلے لوگوں کا (ہوا تھا ویسا ہی ان کا ہوا کہ) انہوں نے خدا کی آیتوں سے کفر کیا تو خدا نےان کے گناہوں کی سزا میں ان کو پکڑ لیا۔ بےشک خدا زبردست اور سخت عذاب دینے والا ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mccxiii{یہ اس لیے کہ جو نعمت خدا کسی قوم کو دیا کرتا ہے جب تک وہ خود اپنے دلوں کی حالت نہ بدل ڈالیں خدا اسے نہیں بدلا کرتا۔ اور اس لیے کہ خدا سنتا جانتا ہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mccxiv{جیسا حال فرعونیوں اور ان سے پہلے لوگوں کا (ہوا تھا ویسا ہی ان کا ہوا) انہوں نے اپنے پروردگار کی آیتوں کو جھٹلایا تو ہم نے ان کو ان کے گناہوں کے سبب ہلاک کر ڈالا اور فرعونیوں کو ڈبو دیا۔ اور وہ سب ظالم تھے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mccxv{جانداروں میں سب سے بدتر خدا کے نزدیک وہ لوگ ہیں جو کافر ہیں سو وہ ایمان نہیں لاتے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mccxvi{جن لوگوں سے تم نے (صلح کا) عہد کیا ہے پھر وہ ہر بار اپنے عہد کو توڑ ڈالتے ہیں اور (خدا سے) نہیں ڈرتے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mccxvii{اگر تم ان کو لڑائی میں پاؤ تو انہیں ایسی سزا دو کہ جو لوگ ان کے پس پشت ہیں وہ ان کو دیکھ کر بھاگ جائیں عجب نہیں کہ ان کو (اس سے) عبرت ہو\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mccxviii{اور اگر تم کو کسی قوم سے دغا بازی کا خوف ہو تو (ان کا عہد) انہیں کی طرف پھینک دو (اور) برابر (کا جواب دو) کچھ شک نہیں کہ خدا دغابازوں کو دوست نہیں رکھتا\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mccxix{اور کافر یہ نہ خیال کریں کہ وہ بھاگ نکلے ہیں۔ وہ (اپنی چالوں سے ہم کو) ہرگز عاجز نہیں کرسکتے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mccxx{اور جہاں تک ہوسکے (فوج کی جمعیت کے) زور سے اور گھوڑوں کے تیار رکھنے سے ان کے (مقابلے کے) لیے مستعد رہو کہ اس سے خدا کے دشمنوں اور تمہارے دشمنوں اور ان کے سوا اور لوگوں پر جن کو تم نہیں جانتے اور خدا جانتا ہے ہیبت بیٹھی رہے گی۔ اور تم جو کچھ راہ خدا میں خرچ کرو گے اس کا ثواب تم کو پورا پورا دیا جائے گا اور تمہارا ذرا نقصان نہیں کیا جائے گا\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mccxxi{اور اگر یہ لوگ صلح کی طرف مائل ہوں تو تم بھی اس کی طرف مائل ہو جاؤ اور خدا پر بھروسہ رکھو۔ کچھ شک نہیں کہ وہ سب کچھ سنتا (اور) جانتا ہے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mccxxii{اور اگر یہ چاہیں کہ تم کو فریب دیں تو خدا تمہیں کفایت کرے گا۔ وہی تو ہے جس نے تم کو اپنی مدد سے اور مسلمانوں (کی جمعیت) سے تقویت بخشی\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mccxxiii{اور ان کے دلوں میں الفت پیدا کردی۔ اور اگر تم دنیا بھر کی دولت خرچ کرتے تب بھی ان کے دلوں میں الفت نہ پیدا کرسکتے۔ مگر خدا ہی نے ان میں الفت ڈال دی۔ بےشک وہ زبردست (اور) حکمت والا ہے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mccxxiv{اے نبی! خدا تم کو اور مومنوں کو جو تمہارے پیرو ہیں کافی ہے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mccxxv{اے نبی! مسلمانوں کو جہاد کی ترغیب دو۔ اور اگر تم بیس آدمی ثابت قدم رہنے والے ہوں گے تو دو سو کافروں پر غالب رہیں گے۔ اور اگر سو (ایسے) ہوں گے تو ہزار پر غالب رہیں گے۔ اس لیے کہ کافر ایسے لوگ ہیں کہ کچھ بھی سمجھ نہیں رکھتے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mccxxvi{اب خدا نے تم پر سے بوجھ ہلکا کر دیا اور معلوم کرلیا کہ (ابھی) تم میں کسی قدر کمزوری ہے۔ پس اگر تم میں ایک سو ثابت قدم رہنے والے ہوں گے تو دو سو پر غالب رہیں گے۔ اور اگر ایک ہزار ہوں گے تو خدا کے حکم سے دو ہزار پر غالب رہیں گے۔ اور خدا ثابت قدم رہنے والوں کا مدد گار ہے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mccxxvii{پیغمبر کو شایان نہیں کہ اس کے قبضے میں قیدی رہیں جب تک (کافروں کو قتل کر کے) زمین میں کثرت سے خون (نہ) بہا دے۔ تم لوگ دنیا کے مال کے طالب ہو۔ اور خدا آخرت (کی بھلائی) چاہتا ہے۔ اور خدا غالب حکمت والا ہے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mccxxviii{اگر خدا کا حکم پہلے نہ ہوچکا ہوتا تو جو (فدیہ) تم نے لیا ہے اس کے بدلے تم پر بڑا عذاب نازل ہوتا\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mccxxix{تو جو مالِ غنیمت تمہیں ملا ہے اسے کھاؤ (کہ وہ تمہارے لیے) حلال طیب رہے اور خدا سے ڈرتے رہو۔ بےشک خدا بخشنے والا مہربان ہے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mccxxx{اے پیغمبر جو قیدی تمہارے ہاتھ میں (گرفتار) ہیں ان سے کہہ دو کہ اگر خدا تمہارے دلوں میں نیکی معلوم کرے گا تو جو (مال) تم سے چھن گیا ہے اس سے بہتر تمہیں عنایت فرمائے گا اور تمہارے گناہ بھی معاف کر دے گا اور خدا بخشنے والا مہربان ہے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mccxxxi{اور اگر یہ لوگ تم سے دغا کرنا چاہیں گے تو یہ پہلے ہی خدا سے دغا کرچکے ہیں تو اس نے ان کو (تمہارے) قبضے میں کر دیا۔ اور خدا دانا حکمت والا ہے\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mccxxxii{جو لوگ ایمان لائے اور وطن سے ہجرت کر گئے اور خدا کی راہ میں اپنے مال اور جان سے لڑے وہ اور جنہوں نے (ہجرت کرنے والوں کو) جگہ دی اور ان کی مدد کی وہ آپس میں ایک دوسرے کے رفیق ہیں۔ اور جو لوگ ایمان تو لے آئے لیکن ہجرت نہیں کی تو جب تک وہ ہجرت نہ کریں تم کو ان کی رفاقت سے کچھ سروکار نہیں۔ اور اگر وہ تم سے دین (کے معاملات) میں مدد طلب کریں تو تم کو مدد کرنی لازم ہوگی۔ مگر ان لوگوں کے مقابلے میں کہ تم میں اور ان میں (صلح کا) عہد ہو (مدد نہیں کرنی چاہیئے) اور خدا تمہارے سب کاموں کو دیکھ رہا ہے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mccxxxiii{اور جو لوگ کافر ہیں (وہ بھی) ایک دوسرے کے رفیق ہیں۔ تو (مومنو) اگر تم یہ (کام) نہ کرو گے تو ملک میں فتنہ برپا ہو جائے گا اور بڑا فساد مچے گا\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mccxxxiv{اور جو لوگ ایمان لائے اور وطن سے ہجرت کر گئے اور خدا کی راہ میں لڑائیاں کرتے رہے اور جنہوں نے (ہجرت کرنے والوں کو) جگہ دی اور ان کی مدد کی۔ یہی لوگ سچے مسلمان ہیں۔ ان کے لیے (خدا کے ہاں) بخشش اور عزت کی روزی ہے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mccxxxv{اور جو لوگ بعد میں ایمان لائے اور وطن سے ہجرت کرگئے اور تمہارے ساتھ ہو کر جہاد کرتے رہے وہ بھی تم ہی میں سے ہیں۔ اور رشتہ دار خدا کے حکم کی رو سے ایک دوسرے کے زیادہ حقدار ہیں۔ کچھ شک نہیں کہ خدا ہر چیز سے واقف ہے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mccxxxvi{\basmalahur (اے اہل اسلام اب) خدا اور اس کے رسول کی طرف سے مشرکوں سے جن سے تم نے عہد کر رکھا تھا بیزاری (اور جنگ کی تیاری) ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mccxxxvii{تو (مشرکو تم) زمین میں چار مہینے چل پھر لو اور جان رکھو کہ تم خدا کو عاجز نہ کرسکو گے۔ اور یہ بھی کہ خدا کافروں کو رسوا کرنے والا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mccxxxviii{اور حج اکبر کے دن خدا اور اس کے رسول کی طرف سے لوگوں کو آگاہ کیا جاتا ہے کہ خدا مشرکوں سے بیزار ہے اور اس کا رسول بھی (ان سے دستبردار ہے) ۔ پس اگر تم توبہ کرلو تو تمھارے حق میں بہتر ہے۔ اور اگر نہ مانو (اور خدا سے مقابلہ کرو) تو جان رکھو کہ تم خدا کو ہرا نہیں سکو گے اور (اے پیغمبر) کافروں کو دکھ دینے والے عذاب کی خبر سنا دو\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mccxxxix{البتہ جن مشرکوں کے ساتھ تم نے عہد کیا ہو اور انہوں نے تمہارا کسی طرح کا قصور نہ کیا ہو اور نہ تمہارے مقابلے میں کسی کی مدد کی ہو تو جس مدت تک ان کے ساتھ عہد کیا ہو اسے پورا کرو۔ (کہ) خدا پرہیزگاروں کو دوست رکھتا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mccxl{جب عزت کے مہینے گزر جائیں تو مشرکوں کو جہاں پاؤ قتل کر دو اور پکڑلو اور گھیرلو اور ہر گھات کی جگہ ان کی تاک میں بیٹھے رہو۔ پھر اگر وہ توبہ کرلیں اور نماز پڑھنے اور زکوٰة دینے لگیں تو ان کی راہ چھوڑ دو۔ بےشک خدا بخشنے والا مہربان ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mccxli{اور اگر کوئی مشرک تم سے پناہ کا خواستگار ہو تو اس کو پناہ دو یہاں تک کہ کلام خدا سننے لگے پھر اس کو امن کی جگہ واپس پہنچادو۔ اس لیے کہ یہ بےخبر لوگ ہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mccxlii{بھلا مشرکوں کے لیے (جنہوں نے عہد توڑ ڈالا) خدا اور اس کے رسول کے نزدیک عہد کیونکر (قائم) رہ سکتا ہے ہاں جن لوگوں کے ساتھ تم نے مسجد محترم (یعنی خانہ کعبہ) کے نزدیک عہد کیا ہے اگر وہ (اپنے عہد پر) قائم رہیں تو تم بھی اپنے قول وقرار (پر) قائم رہو۔ بےشک خدا پرہیز گاروں کو دوست رکھتا ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mccxliii{بھلا ان سے عہد) کیونکر (پورا کیا جائے جب ان کا یہ حال ہے) کہ اگر تم پر غلبہ پالیں تو نہ قرابت کا لحاظ کریں نہ عہد کا۔ یہ منہ سے تو تمہیں خوش کر دیتے ہیں لیکن ان کے دل (ان باتوں کو) قبول نہیں کرتے۔ اور ان میں اکثر نافرمان ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mccxliv{یہ خدا کی آیتوں کے عوض تھوڑا سا فائدہ حاصل کرتے اور لوگوں کو خدا کے رستے سے روکتے ہیں۔ کچھ شک نہیں کہ جو کام یہ کرتے ہیں برے ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mccxlv{یہ لوگ کسی مومن کے حق میں نہ تو رشتہ داری کا پاس کرتے ہیں نہ عہد کا۔ اور یہ حد سے تجاوز کرنے والے ہیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mccxlvi{اگر یہ توبہ کرلیں اور نماز پڑھنے اور زکوٰة دینے لگیں تو دین میں تمہارے بھائی ہیں۔ اور سمجھنے والے لوگوں کے لیے ہم اپنی آیتیں کھول کھول کر بیان کرتے ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mccxlvii{اور اگر عہد کرنے کے بعد اپنی قسموں کو توڑ ڈالیں اور تمہارے دین میں طعنے کرنے لگیں تو ان کفر کے پیشواؤں سے جنگ کرو (یہ یہ بےایمان لوگ ہیں اور) ان کی قسموں کا کچھ اعتبار نہیں ہے۔ عجب نہیں کہ (اپنی حرکات سے) باز آجائیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mccxlviii{بھلا تم ایسے لوگوں سے کیوں نہ لڑو جنہوں نے اپنی قسموں کو توڑ ڈالا اور پیغمبر (خدا) کے جلا وطن کرنے کا عزم مصمم کر لیا اور انہوں نے تم سے (عہد شکنی کی) ابتدا کی۔ کیا تم ایسے لوگوں سے ڈرتے ہو حالانکہ ڈرنے کے لائق خدا ہے بشرطیکہ ایمان رکھتے ہو\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mccxlix{ان سے (خوب) لڑو۔ خدا ان کو تمہارے ہاتھوں سے عذاب میں ڈالے گا اور رسوا کرے گا اور تم کو ان پر غلبہ دے گا اور مومن لوگوں کے سینوں کو شفا بخشے گا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mccl{اور ان کے دلوں سے غصہ دور کرے گا اور جس پر چاہے گا رحمت کرے گا۔ اور خدا سب کچھ جانتا (اور) حکمت والا ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mccli{کیا تم لوگ یہ خیال کرتے ہو کہ (بےآزمائش) چھوڑ دیئے جاؤ گے اور ابھی خدا نے ایسے لوگوں کو متمیز کیا ہی نہیں جنہوں نے تم میں سے جہاد کئے اور خدا اور اس کے رسول اور مومنوں کے سوا کسی کو دلی دوست نہیں بنایا۔ اور خدا تمہارے سب کاموں سے واقف ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mcclii{مشرکوں کی زیبا نہیں کہ خدا کی مسجدوں کو آباد کریں جب کہ وہ اپنے آپ پر کفر کی گواہی دے رہے ہیں۔ ان لوگوں کے سب اعمال بےکار ہیں اور یہ ہمیشہ دوزخ میں رہیں گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mccliii{خدا کی مسجدوں کو تو وہ لوگ آباد کرتے ہیں جو خدا پر اور روز قیامت پر ایمان لاتے ہیں اور نماز پڑھتے اور زکواة دیتے ہیں اور خدا کے سوا کسی سے نہیں ڈرتے۔ یہی لوگ امید ہے کہ ہدایت یافتہ لوگوں میں (داخل) ہوں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mccliv{کیا تم نے حاجیوں کو پانی پلانا اور مسجد محترم یعنی (خانہٴ کعبہ) کو آباد کرنا اس شخص کے اعمال جیسا خیال کیا ہے جو خدا اور روز آخرت پر ایمان رکھتا ہے اور خدا کی راہ میں جہاد کرتا ہے۔ یہ لوگ خدا کے نزدیک برابر نہیں ہیں۔ اور خدا ظالم لوگوں کو ہدایت نہیں دیا کرتا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mcclv{جو لوگ ایمان لائے اور وطن چھوڑ گئے اور خدا کی راہ میں مال اور جان سے جہاد کرتے رہے۔ خدا کے ہاں ان کے درجے بہت بڑے ہیں۔ اور وہی مراد کو پہنچنے والے ہیں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mcclvi{ان کا پروردگار ان کو اپنی رحمت کی اور خوشنودی کی اور بہشتوں کی خوشخبری دیتا ہے جن میں ان کے لیے نعمت ہائے جاودانی ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mcclvii{اور وہ) ان میں ابدالاآباد رہیں گے۔ کچھ شک نہیں کہ خدا کے ہاں بڑا صلہ (تیار) ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mcclviii{اے اہل ایمان! اگر تمہارے (ماں) باپ اور (بہن) بھائی ایمان کے مقابل کفر کو پسند کریں تو ان سے دوستی نہ رکھو۔ اور جو ان سے دوستی رکھیں گے وہ ظالم ہیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mcclix{کہہ دو کہ اگر تمہارے باپ اور بیٹے اور بھائی اور عورتیں اور خاندان کے آدمی اور مال جو تم کماتے ہو اور تجارت جس کے بند ہونے سے ڈرتے ہو اور مکانات جن کو پسند کرتے ہو خدا اور اس کے رسول سے اور خدا کی راہ میں جہاد کرنے سے تمہیں زیادہ عزیز ہوں تو ٹھہرے رہو یہاں تک کہ خدا اپنا حکم (یعنی عذاب) بھیجے۔ اور خدا نافرمان لوگوں کو ہدایت نہیں دیا کرتا\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mcclx{خدا نے بہت سے موقعوں پر تم کو مدد دی ہے اور (جنگ) حنین کے دن۔ جب تم کو اپنی (جماعت کی) کثرت پر غرّہ تھا تو وہ تمہارے کچھ بھی کام نہ آئی۔ اور زمین باوجود (اتنی بڑی) فراخی کے تم پر تنگ ہوگئی پھر تم پیٹھ پھیر کر پھر گئے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mcclxi{پھر خدا نے اپنے پیغمبر پر اور مومنوں پر اپنی طرف سے تسکین نازل فرمائی (اور تمہاری مدد کو فرشتوں کے) لشکر جو تمہیں نظر نہیں آتے تھے (آسمان سے) اُتارے اور کافروں کو عذاب دیا۔ اور کفر کرنے والوں کی یہی سزا ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mcclxii{پھر خدا اس کے بعد جس پر چاہے مہربانی سے توجہ فرمائے اور خدا بخشنے والا مہربان ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mcclxiii{مومنو! مشرک تو پلید ہیں تو اس برس کے بعد وہ خانہٴ کعبہ کا پاس نہ جانے پائیں اور اگر تم کو مفلسی کا خوف ہو تو خدا چاہے گا تو تم کو اپنے فضل سے غنی کر دے گا۔ بےشک خدا سب کچھ جانتا (اور) حکمت والا ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mcclxiv{جو اہل کتاب میں سے خدا پر ایمان نہیں لاتے اور نہ روز آخرت پر (یقین رکھتے ہیں) اور نہ ان چیزوں کو حرام سمجھتے ہیں جو خدا اور اس کے رسول نے حرام کی ہیں اور نہ دین حق کو قبول کرتے ہیں ان سے جنگ کرو یہاں تک کہ ذلیل ہوکر اپنے ہاتھ سے جزیہ دیں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mcclxv{اور یہود کہتے ہیں کہ عُزیر خدا کے بیٹے ہیں اور عیسائی کہتے ہیں کہ مسیح خدا کے بیٹے ہیں۔ یہ ان کے منہ کی باتیں ہیں پہلے کافر بھی اسی طرح کی باتیں کہا کرتے تھے یہ بھی انہیں کی ریس کرنے میں لگے ہیں۔ خدا ان کو ہلاک کرے۔ یہ کہاں بہکے پھرتے ہیں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mcclxvi{انہوں نے اپنے علماء اور مشائخ اور مسیح ابن مریم کو الله کے سوا خدا بنا لیا حالانکہ اُن کو یہ حکم دیا گیا تھا کہ خدائے واحد کے سوا کسی کی عبادت نہ کریں۔ اس کے سوا کوئی معبود نہیں۔ اور وہ ان لوگوں کے شریک مقرر کرنے سے پاک ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mcclxvii{یہ چاہتے ہیں کہ خدا کے نور کو اپنے منہ سے (پھونک مار کر) بجھا دیں اور خدا اپنے نور کو پورا کئے بغیر رہنے کا نہیں۔ اگرچہ کافروں کو برا ہی لگے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mcclxviii{وہی تو ہے جس نے اپنے پیغمبر کو ہدایت اور دین حق دے کر بھیجا تاکہ اس (دین) کو (دنیا کے) تمام دینوں پر غالب کرے۔ اگرچہ کافر ناخوش ہی ہوں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mcclxix{مومنو! (اہل کتاب کے) بہت سے عالم اور مشائخ لوگوں کا مال ناحق کھاتے اور (ان کو) راہ خدا سے روکتے ہیں۔ اور جو لوگ سونا اور چاندی جمع کرتے ہیں اور اس کو خدا کے رستے میں خرچ نہیں کرتے۔ ان کو اس دن عذاب الیم کی خبر سنادو\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mcclxx{جس دن وہ مال دوزخ کی آگ میں (خوب) گرم کیا جائے گا۔ پھر اس سے ان (بخیلوں) کی پیشانیاں اور پہلو اور پیٹھیں داغی جائیں گی (اور کہا جائے گا) کہ یہ وہی ہے جو تم نے اپنے لیے جمع کیا تھا سو جو تم جمع کرتے تھے (اب) اس کا مزہ چکھو\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mcclxxi{خدا کے نزدیک مہینے گنتی میں (بارہ ہیں یعنی) اس روز (سے) کہ اس نے آسمانوں اور زمین کو پیدا کیا۔ کتاب خدا میں (برس کے) بارہ مہینے (لکھے ہوئے) ہیں۔ ان میں سے چار مہینے ادب کے ہیں۔ یہی دین (کا) سیدھا راستہ ہے۔ تو ان (مہینوں) میں (قتال ناحق سے) اپنے آپ پر ظلم نہ کرنا۔ اور تم سب کے سب مشرکوں سے لڑو جیسے وہ سب کے سب تم سے لڑتے ہیں۔ اور جان رکھو کہ خدا پرہیز گاروں کے ساتھ ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mcclxxii{امن کے کس مہینے کو ہٹا کر آگے پیچھے کر دینا کفر میں اضافہ کرتا ہے اس سے کافر گمراہی میں پڑے رہتے ہیں۔ ایک سال تو اس کو حلال سمجھ لیتے ہیں اور دوسرے سال حرام۔ تاکہ ادب کے مہینوں کو جو خدا نے مقرر کئے ہیں گنتی پوری کر لیں۔ اور جو خدا نے منع کیا ہے اس کو جائز کر لیں۔ ان کے برے اعمال ان کے بھلے دکھائی دیتے ہیں۔ اور خدا کافر لوگوں کو ہدایت نہیں دیا کرتا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mcclxxiii{مومنو! تمہیں کیا ہوا ہے کہ جب تم سے کہا جاتا ہے کہ خدا کی راہ میں (جہاد کے لیے) نکلو تو تم (کاہلی کے سبب سے) زمین پر گرے جاتے ہو (یعنی گھروں سے نکلنا نہیں چاہتے) کیا تم آخرت (کی نعمتوں) کو چھوڑ کر دینا کی زندگی پر خوش ہو بیٹھے ہو۔ دنیا کی زندگی کے فائدے تو آخرت کے مقابل بہت ہی کم ہیں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mcclxxiv{اور اگر تم نہ نکلو گے تو خدا تم کو بڑی تکلیف کا عذاب دے گا۔ اور تمہاری جگہ اور لوگ پیدا کر دے گا (جو خدا کے پورے فرمانبردار ہوں گے) اور تم اس کو کچھ نقصان نہ پہنچا سکو گے اور خدا ہر چیز پر قدرت رکھتا ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mcclxxv{اگر تم پیغمبر کی مدد نہ کرو گے تو خدا اُن کا مددگار ہے (وہ وقت تم کو یاد ہوگا) جب ان کو کافروں نے گھر سے نکال دیا۔ (اس وقت) دو (ہی ایسے شخص تھے جن) میں (ایک ابوبکرؓ تھے) اور دوسرے (خود رسول الله) جب وہ دونوں غار (ثور) میں تھے اس وقت پیغمبر اپنے رفیق کو تسلی دیتے تھے کہ غم نہ کرو خدا ہمارے ساتھ ہے۔ تو خدا نے ان پر تسکین نازل فرمائی اور ان کو ایسے لشکروں سے مدد دی جو تم کو نظر نہیں آتے تھے اور کافروں کی بات کو پست کر دیا۔ اور بات تو خدا ہی کی بلند ہے۔ اور خدا زبردست (اور) حکمت والا ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mcclxxvi{تم سبکبار ہو یا گراں بار (یعنی مال و اسباب تھوڑا رکھتے ہو یا بہت، گھروں سے) نکل آؤ۔ اور خدا کے رستے میں مال اور جان سے لڑو۔ یہی تمہارے حق میں اچھا ہے بشرطیکہ سمجھو\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mcclxxvii{اگر مالِ غنیمت سہل الحصول اور سفر بھی ہلکا سا ہوتا تو تمہارے ساتھ (شوق سے) چل دیتے۔ لیکن مسافت ان کو دور (دراز) نظر آئی (تو عذر کریں گے) ۔ اور خدا کی قسمیں کھائیں گے کہ اگر ہم طاقت رکھتے تو آپ کے ساتھ ضرور نکل کھڑے ہوتے یہ (ایسے عذروں سے) اپنے تئیں ہلاک کر رہے ہیں۔ اور خدا جانتا ہے کہ جھوٹے ہیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mcclxxviii{خدا تمہیں معاف کرے۔ تم نے پیشتر اس کے کہ تم پر وہ لوگ بھی ظاہر ہو جاتے ہیں جو سچے ہیں اور وہ بھی تمہیں معلوم ہو جاتے جو جھوٹے ہیں اُن کو اجازت کیوں دی\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mcclxxix{جو لوگ خدا پر اور روز آخرت پر ایمان رکھتے ہیں وہ تو تم سے اجازت نہیں مانگتے (کہ پیچھے رہ جائیں بلکہ چاہتے ہیں کہ) اپنے مال اور جان سے جہاد کریں۔ اور خدا ڈرنے والوں سے واقف ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mcclxxx{اجازت وہی لوگ مانگتے ہیں جو خدا پر اور پچھلے دن پر ایمان نہیں رکھتے اور ان کے دل شک میں پڑے ہوئے ہیں۔ سو وہ اپنے شک میں ڈانواں ڈول ہو رہے ہیں\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mcclxxxi{اور اگر وہ نکلنے کا ارادہ کرتے ہیں تو اس کے لیے سامان تیار کرتے لیکن خدا نے ان کا اُٹھنا (اور نکلنا) پسند نہ کیا تو ان کو ہلنے جلنے ہی نہ دیا اور (ان سے) کہہ دیا گیا کہ جہاں (معذور) بیٹھے ہیں تم بھی ان کے ساتھ بیٹھے رہو\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mcclxxxii{اگر وہ تم میں (شامل ہوکر) نکل بھی کھڑے ہوتے تو تمہارے حق میں شرارت کرتے اور تم میں فساد ڈلوانے کی غرض سے دوڑے دوڑے پھرتے اور تم میں ان کے جاسوس بھی ہیں اور خدا ظالموں کو خوب جانتا ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mcclxxxiii{یہ پہلے بھی طالب فساد رہے ہیں اور بہت سی باتوں میں تمہارے لیے الٹ پھیر کرتے رہے ہیں۔ یہاں تک کہ حق آپہنچا اور خدا کا حکم غالب ہوا اور وہ برا مانتے ہی رہ گئے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mcclxxxiv{اور ان میں کوئی ایسا بھی ہے جو کہتا ہے کہ مجھے تو اجازت ہی دیجئے اور آفت میں نہ ڈالئے۔ دیکھو یہ آفت میں پڑگئے ہیں اور دوزخ سب کافروں کو گھیرے ہوئے ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mcclxxxv{اے پیغمبر) اگر تم کو آسائش حاصل ہوتی ہے تو ان کو بری لگتی ہے۔ اور کوئی مشکل پڑتی ہے تو کہتے کہ ہم نے اپنا کام پہلے ہیں (درست) کر لیا تھا اور خوشیاں مناتے لوٹ جاتے ہیں\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mcclxxxvi{کہہ دو کہ ہم کو کوئی مصیبت نہیں پہنچ سکتی بجز اس کے جو خدا نے ہمارے لیے لکھ دی ہو وہی ہمارا کارساز ہے۔ اور مومنوں کو خدا ہی کا بھروسہ رکھنا چاہیئے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mcclxxxvii{کہہ دو کہ تم ہمارے حق میں دو بھلائیوں میں سے ایک کے منتظر ہو اور ہم تمہارے حق میں اس بات کے منتظر ہیں کہ خدا (یا تو) اپنے پاس سے تم پر کوئی عذاب نازل کرے یا ہمارے ہاتھوں سے (عذاب دلوائے) تو تم بھی انتظار کرو ہم بھی تمہارے ساتھ انتظار کرتے ہیں\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mcclxxxviii{کہہ دو کہ تم (مال) خوشی سے خرچ کرو یا ناخوشی سے تم سے ہرگز قبول نہیں کیا جائے گا تم نافرمان لوگ ہو\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mcclxxxix{اور ان کے خرچ (موال) کے قبول ہونے سے کوئی چیز مانع نہیں ہوئی سوا اس کے انہوں نے خدا سے اور اس کے رسول سے کفر کیا اور نماز کو آتے ہیں تو سست کاہل ہوکر اور خرچ کرتے ہیں تو ناخوشی سے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mccxc{تم ان کے مال اور اولاد سے تعجب نہ کرنا۔ خدا چاہتا ہے کہ ان چیزوں سے دنیا کی زندگی میں ان کو عذاب دے اور (جب) ان کی جان نکلے تو (اس وقت بھی) وہ کافر ہی ہوں\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mccxci{اور خدا کی قسمیں کھاتے ہیں کہ وہ تم ہی میں سے ہیں حالانکہ ہو تم میں سے نہیں ہیں۔ اصل یہ ہے کہ یہ ڈرپوک لوگ ہیں\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mccxcii{اگر ان کی کوئی بچاؤ کی جگہ (جیسے قلعہ) یا غار ومغاک یا (زمین کے اندر) گھسنے کی جگہ مل جائے تو اسی طرف رسیاں تڑاتے ہوئے بھاگ جائیں\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mccxciii{اور ان میں سے بعض اسے بھی ہیں کہ (تقسیم) صدقات میں تم پر طعنہ زنی کرتے ہیں۔ اگر ان کو اس میں سے (خاطر خواہ) مل جائے تو خوش رہیں اور اگر (اس قدر) نہ ملے تو جھٹ خفا ہو جائیں\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mccxciv{اور اگر وہ اس پر خوش رہتے جو خدا اور اس کے رسول نے ان کو دیا تھا۔ اور کہتے کہ ہمیں خدا کافی ہے اور خدا اپنے فضل سے اور اس کے پیغمبر (اپنی مہربانی سے) ہمیں (پھر) دیں گے۔ اور ہمیں تو خدا ہی کی خواہش ہے (تو ان کے حق میں بہتر ہوتا)\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mccxcv{صدقات (یعنی زکوٰة وخیرات) تو مفلسوں اور محتاجوں اور کارکنان صدقات کا حق ہے اور ان لوگوں کا جن کی تالیف قلوب منظور ہے اور غلاموں کے آزاد کرانے میں اور قرضداروں (کے قرض ادا کرنے میں) اور خدا کی راہ میں اور مسافروں (کی مدد) میں (بھی یہ مال خرچ کرنا چاہیئے یہ حقوق) خدا کی طرف سے مقرر کر دیئے گئے ہیں اور خدا جاننے والا (اور) حکمت والا ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mccxcvi{اور ان میں بعض ایسے ہیں جو پیغمبر کو ایذا دیتے ہیں اور کہتے ہیں کہ یہ شخص نرا کان ہے۔ (ان سے) کہہ دو کہ (وہ) کان (ہے تو) تمہاری بھلائی کے لیے۔ وہ خدا کا اور مومنوں (کی بات) کا یقین رکھتا ہے اور جو لوگ تم میں سے ایمان لائے ہیں ان کے لیے رحمت ہے۔ اور جو لوگ رسول خدا کو رنج پہنچاتے ہیں ان کے لیے عذاب الیم (تیار) ہے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mccxcvii{مومنو! یہ لوگ تمہارے سامنے خدا کی قسمیں کھاتے ہیں تاکہ تم کو خوش کر دیں۔ حالانکہ اگر یہ (دل سے) مومن ہوتے تو خدا اور اس کے پیغمبر خوش کرنے کے زیادہ مستحق ہیں\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mccxcviii{کیا ان لوگوں کو معلوم نہیں کہ جو شخص خدا اور اس کے رسول سے مقابلہ کرتا ہے تو اس کے لیے جہنم کی آگ (تیار) ہے جس میں وہ ہمیشہ (جلتا) رہے گا۔ یہ بڑی رسوائی ہے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mccxcix{منافق ڈرتے رہتے ہیں کہ ان (کے پیغمبر) پر کہیں کوئی ایسی سورت (نہ) اُتر آئے کہ ان کے دل کی باتوں کو ان (مسلمانوں) پر ظاہر کر دے۔ کہہ دو کہ ہنسی کئے جاؤ۔ جس بات سے تم ڈرتے ہو خدا اس کو ضرور ظاہر کردے گا\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mccc{اور اگر تم ان سے (اس بارے میں) دریافت کرو تو کہیں گے ہم تو یوں ہی بات چیت اور دل لگی کرتے تھے۔ کہو کیا تم خدا اور اس کی آیتوں اور اس کے رسول سے ہنسی کرتے تھے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mccci{بہانے مت بناؤ تم ایمان لانے کے بعد کافر ہو چکے ہو۔ اگر ہم تم میں سے ایک جماعت کو معاف کردیں تو دوسری جماعت کو سزا بھی دیں گے کیونکہ وہ گناہ کرتے رہے ہیں\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mcccii{منافق مرد اور منافق عورتیں ایک دوسرے کے ہم جنس (یعنی ایک طرح کے) ہیں کہ برے کام کرنے کو کہتے اور نیک کاموں سے منع کرتے اور (خرچ کرنے سے) ہاتھ بند کئے رہتے ہیں۔ انہوں نے خدا کو بھلا دیا تو خدا نے ان کو بھلا دیا۔ بےشک منافق نافرمان ہیں\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mccciii{الله نے منافق مردوں اور منافق عورتوں اور کافروں سے آتش جہنم کا وعدہ کیا ہے جس میں ہمیشہ (جلتے) رہیں گے۔ وہی ان کے لائق ہے۔ اور خدا نے ان پر لعنت کر دی ہے۔ اور ان کے لیے ہمیشہ کا عذاب (تیار) ہے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mccciv{تم منافق لوگ) ان لوگوں کی طرح ہو، جو تم سے پہلے ہوچکے ہیں۔ وہ تم سے بہت زیادہ طاقتور اور مال و اولاد میں کہیں زیادہ تھے تو وہ اپنے حصے سے بہرہ یاب ہوچکے۔ سو جس طرح تم سے پہلے لوگ اپنے حصے سے فائدہ اٹھا چکے ہیں۔ اسی طرح تم نے اپنے حصے سے فائدہ اٹھا لیا۔ اور جس طرح وہ باطل میں ڈوبے رہے اسی طرح تم باطل میں ڈوبے رہے یہ وہ لوگ ہیں جن کے اعمال دنیا اور آخرت میں ضائع ہوگئے۔ اور یہی نقصان اٹھانے والے ہیں\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mcccv{کیا ان کو ان لوگوں (کے حالات) کی خبر نہیں پہنچی جو ان سے پہلے تھے (یعنی) نوح اور عاد اور ثمود کی قوم۔ اور ابراہیم کی قوم اور مدین والے اور الٹی ہوئی بستیوں والے۔ ان کے پاس پیغمبر نشانیاں لے لے کر آئے۔ اور خدا تو ایسا نہ تھا کہ ان پر ظلم کرتا لیکن وہی اپنے آپ پر ظلم کرتے تھے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mcccvi{اور مومن مرد اور مومن عورتیں ایک دوسرے کے دوست ہیں کہ اچھے کام کرنے کو کہتے ہیں اور بری باتوں سے منع کرتے اور نماز پڑھتے اور زکوٰة دیتے اور خدا اور اس کے رسول کی اطاعت کرتے ہیں۔ یہی لوگ ہیں جن پر خدا رحم کرے گا۔ بےشک خدا غالب حکمت والا ہے\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mcccvii{خدا نے مومن مردوں اور مومن عورتوں سے بہشتوں کا وعدہ کیا ہے جن کے نیچے نہریں بہہ رہی ہیں (وہ) ان میں ہمیشہ رہیں گے اور بہشت ہائے جاودانی میں نفیس مکانات کا (وعدہ کیا ہے) اور خدا کی رضا مندی تو سب سے بڑھ کر نعمت ہے یہی بڑی کامیابی ہے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mcccviii{اے پیغمبر! کافروں اور منافقوں سے لڑو۔ اور ان پر سختی کرو۔ اور ان کا ٹھکانہ دورخ ہے اور وہ بری جگہ ہے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mcccix{یہ خدا کی قسمیں کھاتے ہیں کہ انہوں نے (تو کچھ) نہیں کہا حالانکہ انہوں نے کفر کا کلمہ کہا ہے اور یہ اسلام لانے کے بعد کافر ہوگئے ہیں اور ایسی بات کا قصد کرچکے ہیں جس پر قدرت نہیں پاسکے۔ اور انہوں نے (مسلمانوں میں) عیب ہی کون سا دیکھا ہے سوا اس کے کہ خدا نے اپنے فضل سے اور اس کے پیغمبر نے (اپنی مہربانی سے) ان کو دولت مند کر دیا ہے۔ تو اگر یہ لوگ توبہ کرلیں تو ان کے حق میں بہتر ہوگا۔ اور اگر منہ پھیر لیں تو ان کو دنیا اور آخرت میں دکھ دینے والا عذاب دے گا اور زمین میں ان کا کوئی دوست اور مددگار نہ ہوگا\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mcccx{اور ان میں سے بعض ایسے ہیں جنہوں نے خدا سے عہد کیا تھا کہ اگر وہ ہم کو اپنی مہربانی سے (مال) عطا فرمائے گا تو ہم ضرور خیرات کیا کریں گے اور نیک کاروں میں ہو جائیں گے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mcccxi{لیکن جب خدا نے ان کو اپنے فضل سے (مال) دیا تو اس میں بخل کرنے لگے اور (اپنے عہد سے) روگردانی کرکے پھر بیٹھے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mcccxii{تو خدا نے اس کا انجام یہ کیا کہ اس روز تک کے لیے جس میں وہ خدا کے روبرو حاضر ہوں گے ان کے دلوں میں نفاق ڈال دیا اس لیے کہ انہوں نے خدا سے جو وعدہ کیا تھا اس کے خلاف کیا اور اس لیے کہ وہ جھوٹ بولتے تھے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mcccxiii{کیا ان کو معلوم نہیں کہ خدا ان کے بھیدوں اور مشوروں تک سے واقف ہے اور یہ کہ وہ غیب کی باتیں جاننے والا ہے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mcccxiv{جو (ذی استطاعت) مسلمان دل کھول کر خیرات کرتے ہیں اور جو (بےچارے غریب صرف اتنا ہی کما سکتے ہیں جتنی مزدوری کرتے (اور تھوڑی سی کمائی میں سے خرچ بھی کرتے) ہیں ان پر جو (منافق) طعن کرتے ہیں اور ہنستے ہیں۔ خدا ان پر ہنستا ہے اور ان کے لیے تکلیف دینے والا عذاب (تیار) ہے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mcccxv{تم ان کے لیے بخشش مانگو یا نہ مانگو۔ (بات ایک ہے) ۔ اگر ان کے لیے ستّر دفعہ بھی بخشش مانگو گے تو بھی خدا ان کو نہیں بخشے گا۔ یہ اس لیے کہ انہوں نے خدا اور اس کے رسول سے کفر کیا۔ اور خدا نافرمان لوگوں کو ہدایت نہیں دیتا\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mcccxvi{جو لوگ (غزوہٴ تبوک میں) پیچھے رہ گئے وہ پیغمبر خدا (کی مرضی) کے خلاف بیٹھے رہنے سے خوش ہوئے اور اس بات کو ناپسند کیا کہ خدا کی راہ میں اپنے مال اور جان سے جہاد کریں۔ اور (اوروں سے بھی) کہنے لگے کہ گرمی میں مت نکلنا۔ (ان سے) کہہ دو کہ دوزخ کی آگ اس سے کہیں زیادہ گرم ہے۔ کاش یہ (اس بات) کو سمجھتے\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mcccxvii{یہ (دنیا میں) تھوڑا سا ہنس لیں اور (آخرت میں) ان کو ان اعمال کے بدلے جو کرتے رہے ہیں بہت سا رونا ہوگا\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mcccxviii{پھر اگر خدا تم کو ان میں سے کسی گروہ کی طرف لے جائے اور وہ تم سے نکلنے کی اجازت طلب کریں تو کہہ دینا کہ تم میرے ساتھ ہرگز نہیں نکلو گے اور نہ میرے ساتھ (مددگار ہوکر) دشمن سے لڑائی کرو گے۔ تم پہلی دفعہ بیٹھ رہنے سے خوش ہوئے تو اب بھی پیچھے رہنے والوں کے ساتھ بیٹھے رہو\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mcccxix{اور (اے پیغمبر) ان میں سے کوئی مر جائے تو کبھی اس (کے جنازے) پر نماز نہ پڑھنا اور نہ اس کی قبر پر (جا کر) کھڑے ہونا۔ یہ خدا اور اس کے رسول کے ساتھ کفر کرتے رہے اور مرے بھی نافرمان (ہی مرے)\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mcccxx{ان کے اولاد اور مال سے تعجب نہ کرنا۔ ان چیزوں سے خدا یہ چاہتا ہے کہ ان کو دنیا میں عذاب کرے اور (جب) ان کی جان نکلے تو (اس وقت بھی) یہ کافر ہی ہوں\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mcccxxi{اور جب کوئی سورت نازل ہوتی ہے کہ خدا پر ایمان لاؤ اور اس کے رسول کے ساتھ ہو کر لڑائی کرو تو جو ان میں دولت مند ہیں وہ تم سے اجازت طلب کرتے ہیں اور کہتے ہیں کہ ہمیں تو رہنے ہی دیجیئے کہ جو لوگ گھروں میں رہیں گے ہم بھی ان کے ساتھ رہیں\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mcccxxii{یہ اس بات سے خوش ہیں کہ عورتوں کے ساتھ جو پیچھے رہ جاتی ہیں۔ (گھروں میں بیٹھ) رہیں ان کے دلوں پر مہر لگا دی گئی ہے تو یہ سمجھتے ہی نہیں\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mcccxxiii{لیکن پیغمبر اور جو لوگ ان کے ساتھ ایمان لائے سب اپنے مال اور جان سے لڑے۔ انہیں لوگوں کے لیے بھلائیاں ہیں۔ اور یہی مراد پانے والے ہیں\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mcccxxiv{خدا نے ان کے لیے باغات تیار کر رکھے ہیں جن کے نیچے نہریں بہہ رہی ہیں ہمیشہ ان میں رہی گے۔ یہ بڑی کامیابی ہے\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mcccxxv{اور صحرا نشینوں میں سے بھی کچھ لوگ عذر کرتے ہوئے (تمہارے پاس) آئے کہ ان کو بھی اجازت دی جائے اور جنہوں نے خدا اور اس کے رسول سے جھوٹ بولا وہ (گھر میں) بیٹھ رہے سو جو لوگ ان میں سے کافر ہوئے ہیں ان کو دکھ دینے والا عذاب پہنچے گا\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mcccxxvi{نہ تو ضعیفوں پر کچھ گناہ ہے اور نہ بیماروں پر نہ ان پر جن کے پاس خرچ موجود نہیں (کہ شریک جہاد نہ ہوں یعنی) جب کہ خدا اور اس کے رسول کے خیراندیش (اور دل سے ان کے ساتھ) ہوں۔ نیکو کاروں پر کسی طرح کا الزام نہیں ہے۔ اور خدا بخشنے والا مہربان ہے\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mcccxxvii{اور نہ ان (بےسروسامان) لوگوں پر (الزام) ہے کہ تمہارے پاس آئے کہ ان کو سواری دو اور تم نے کہا کہ میرے پاس کوئی ایسی چیز نہیں جس پر تم کو سوار کروں تو وہ لوٹ گئے اور اس غم سے کہ ان کے پاس خرچ موجود نہ تھا، ان کی آنکھوں سے آنسو بہہ رہے تھے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mcccxxviii{الزام تو ان لوگوں پر ہے۔ جو دولت مند ہیں اور (پھر) تم سے اجازت طلب کرتے ہیں (یعنی) اس بات سے خوش ہیں کہ عورتوں کے ساتھ جو پیچھے رہ جاتی ہیں (گھروں میں بیٹھ) رہیں۔ خدا نے ان کے دلوں پر مہر کردی ہے پس وہ سمجھتے ہی نہیں\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mcccxxix{جب تم ان کے پاس واپس جاؤ گے تو تم سے عذر کریں گے تم کہنا کہ مت عذر کرو ہم ہرگز تمہاری بات نہیں مانیں گے خدا نے ہم کو تمہارے سب حالات بتا دیئے ہیں۔ اور ابھی خدا اور اس کا رسول تمہارے عملوں کو (اور) دیکھیں گے پھر تم غائب وحاضر کے جاننے والے (خدائے واحد) کی طرف لوٹائے جاؤ گے اور جو عمل تم کرتے رہے ہو وہ سب تمہیں بتائے گا\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mcccxxx{جب تم ان کے پاس لوٹ کر جاؤ گے تو تمہارے روبرو خدا کی قسمیں کھائیں گے تاکہ تم ان سے درگزر کرو سو اُن کی طرف التفات نہ کرنا۔ یہ ناپاک ہیں اور جو یہ کام کرتے رہے ہیں اس کے بدلہ ان کا ٹھکانہ دوزخ ہے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mcccxxxi{یہ تمہارے آگے قسمیں کھائیں گے تاکہ تم ان سے خوش ہو جاؤ لیکن اگر تم اُن سے خوش ہو جاؤ گے تو خدا تو نافرمان لوگوں سے خوش نہیں ہوتا\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mcccxxxii{دیہاتی لوگ سخت کافر اور سخت منافق ہیں اور اس قابل ہیں کہ جو احکام (شریعت) خدا نے اپنے رسول پر نازل فرمائے ہیں ان سے واقف (ہی) نہ ہوں۔ اور خدا جاننے والا (اور) حکمت والا ہے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mcccxxxiii{اور بعض دیہاتی ایسے ہیں کہ جو خرچ کرتے ہیں اسے تاوان سمجھتے ہیں اور تمہارے حق میں مصیبتوں کے منتظر ہیں۔ ان ہی پر بری مصیبت (واقع) ہو۔ اور خدا سننے والا (اور) جاننے والا ہے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mcccxxxiv{اور بعض دیہاتی ایسے ہیں کہ خدا پر اور روز آخرت پر ایمان رکھتے ہیں اور جو کچھ خرچ کرتے ہیں اس کو خدا کی قُربت اور پیغمبر کی دعاؤں کا ذریعہ سمجھتے ہیں۔ دیکھو وہ بےشبہ ان کے لیے (موجب) قربت ہے خدا ان کو عنقریب اپنی رحمت میں داخل کرے گا۔ بےشک خدا بخشنے والا مہربان ہے\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mcccxxxv{جن لوگوں نے سبقت کی (یعنی سب سے) پہلے (ایمان لائے) مہاجرین میں سے بھی اور انصار میں سے بھی۔ اور جنہوں نے نیکو کاری کے ساتھ ان کی پیروی کی خدا ان سے خوش ہے اور وہ خدا سے خوش ہیں اور اس نے ان کے لیے باغات تیار کئے ہیں جن کے نیچے نہریں بہہ رہی ہیں اور ہمیشہ ان میں رہیں گے۔ یہ بڑی کامیابی ہے\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mcccxxxvi{اور تمہارے گرد و نواح کے بعض دیہاتی منافق ہیں اور بعض مدینے والے بھی نفاق پر اڑے ہوئے ہیں تم انہیں نہیں جانتے۔ ہم جانتے ہیں۔ ہم ان کو دوہرا عذاب دیں گے پھر وہ بڑے عذاب کی طرف لوٹائے جائیں گے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mcccxxxvii{اور کچھ اور لوگ ہیں کہ اپنے گناہوں کا (صاف) اقرار کرتے ہیں انہوں نے اچھے برے عملوں کو ملا جلا دیا تھا۔ قریب ہے کہ خدا ان پر مہربانی سے توجہ فرمائے۔ بےشک خدا بخشنے والا مہربان ہے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mcccxxxviii{ان کے مال میں سے زکوٰة قبول کر لو کہ اس سے تم ان کو (ظاہر میں بھی) پاک اور (باطن میں بھی) پاکیزہ کرتے ہو اور ان کے حق میں دعائے خیر کرو کہ تمہاری دعا ان کے لیے موجب تسکین ہے اور خدا سننے والا اور جاننے والا ہے\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mcccxxxix{کیا یہ لوگ نہیں جانتے کہ خدا ہی اپنے بندوں سے توبہ قبول فرماتا ہے اور صدقات (وخیرات) لیتا ہے اور بےشک خدا ہی توبہ قبول کرنے والا مہربان ہے\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mcccxl{اور ان سے کہہ دو کہ عمل کئے جاؤ۔ خدا اور اس کا رسول اور مومن (سب) تمہارے عملوں کو دیکھ لیں گے۔ اور تم غائب وحاضر کے جاننے والے (خدائے واحد) کی طرف لوٹائے جاؤ گے پھر جو کچھ تم کرتے رہے ہو وہ سب تم کو بتا دے گا\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mcccxli{اور کچھ اور لوگ ہیں جن کا کام خدا کے حکم پر موقوف ہے۔ چاہے ان کو عذاب دے اور چاہے ان کو معاف کر دے۔ اور خدا جاننے والا اور حکمت والا ہے\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mcccxlii{اور (ان میں سے ایسے بھی ہیں) جنہوں نے اس غرض سے مسجد بنوائی کہ ضرر پہنچائیں اور کفر کریں اور مومنوں میں تفرقہ ڈالیں اور جو لوگ خدا اور اس کے رسول سے پہلے جنگ کرچکے ہیں ان کے لیے گھات کی جگہ بنائیں۔ اور قسمیں کھائیں گے کہ ہمارا مقصود تو صرف بھلائی تھی۔ مگر خدا گواہی دیتا ہے کہ یہ جھوٹے ہیں\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mcccxliii{تم اس (مسجد) میں کبھی (جاکر) کھڑے بھی نہ ہونا۔ البتہ وہ مسجد جس کی بنیاد پہلے دن سے تقویٰ پر رکھی گئی ہے اس قابل ہے کہ اس میں جایا (اور نماز پڑھایا) کرو۔ اس میں ایسے لوگ ہیں جو کہ پاک رہنے کو پسند کرتے ہیں۔ اور خدا پاک رہنے والوں کو ہی پسند کرتا ہے\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mcccxliv{بھلا جس شخص نے اپنی عمارت کی بنیاد خدا کے خوف اور اس کی رضامندی پر رکھی وہ اچھا ہے یا وہ جس نے اپنی عمارت کی بنیاد گر جانے والی کھائی کے کنارے پر رکھی کہ وہ اس کو دوزخ کی آگ میں لے گری اور خدا ظالموں کو ہدایت نہیں دیتا\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mcccxlv{یہ عمارت جو انہوں نے بنائی ہے ہمیشہ ان کے دلوں میں (موجب) خلجان رہے گی (اور ان کو متردد رکھے گی) مگر یہ کہ ان کے دل پاش پاش ہو جائیں اور خدا جاننے والا اور حکمت والا ہے\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mcccxlvi{خدا نے مومنوں سے ان کی جانیں اور ان کے مال خرید لیے ہیں (اور اس کے) عوض ان کے لیے بہشت (تیار کی) ہے۔ یہ لوگ خدا کی راہ میں لڑتے ہیں تو مارتے بھی ہیں اور مارے بھی جاتے ہیں بھی ہیں۔ یہ تورات اور انجیل اور قرآن میں سچا وعدہ ہے۔ جس کا پورا کرنا اسے ضرور ہے اور خدا سے زیادہ وعدہ پورا کرنے والا کون ہے تو جو سودا تم نے اس سے کیا ہے اس سے خوش رہو۔ اور یہی بڑی کامیابی ہے\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mcccxlvii{توبہ کرنے والے، عبادت کرنے والے، حمد کرنے والے، روزہ رکھنے والے، رکوع کرنے والے، سجدہ کرنے والے، نیک کاموں کا امر کرنے والے، بری باتوں سے منع کرنے والے، خدا کی حدوں کی حفاظت کرنے والے، (یہی مومن لوگ ہیں) اور اے پیغمبر مومنوں کو (بہشت کی) خوش خبری سنادو\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mcccxlviii{پیغمبر اور مسلمانوں کو شایاں نہیں کہ جب ان پر ظاہر ہوگیا کہ مشرک اہل دوزخ ہیں۔ تو ان کے لیے بخشش مانگیں گو وہ ان کے قرابت دار ہی ہوں\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mcccxlix{اور ابراہیم کا اپنے باپ کے لیے بخشش مانگنا تو ایک وعدے کا سبب تھا جو وہ اس سے کر چکے تھے۔ لیکن جب ان کو معلوم ہوگیا کہ وہ خدا کا دشمن ہے تو اس سے بیزار ہوگئے۔ کچھ شک نہیں کہ ابراہیم بڑے نرم دل اور متحمل تھے\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mcccl{اور خدا ایسا نہیں کہ کسی قوم کو ہدایت دینے کے بعد گمراہ کر دے جب تک کہ ان کو وہ چیز نہ بتا دے جس سے وہ پرہیز کریں۔ بےشک خدا ہر چیز سے واقف ہے\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mcccli{خدا ہی ہے جس کے لیے آسمانوں اور زمینوں کی بادشاہت ہے۔ وہی زندگانی بخشتا ہے (وہی) موت دیتا ہے اور خدا کے سوا تمہارا کوئی دوست اور مددگار نہیں ہے\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mccclii{بےشک خدا نے پیغمبر پر مہربانی کی اور مہاجرین اور انصار پر جو باوجود اس کے کہ ان میں سے بعضوں کے دل جلد پھر جانے کو تھے۔ مشکل کی گھڑی میں پیغمبر کے ساتھ رہے۔ پھر خدا نے ان پر مہربانی فرمائی۔ بےشک وہ ان پر نہایت شفقت کرنے والا (اور) مہربان ہے\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mcccliii{اور ان تینوں پر بھی جن کا معاملہ ملتوی کیا گیا تھا۔ یہاں تک کہ جب اُنہیں زمین باوجود فراخی کے ان پر تنگ ہوگئی اور ان کے جانیں بھی ان پر دوبھر ہوگئیں۔ اور انہوں نے جان لیا کہ خدا (کے ہاتھ) سے خود اس کے سوا کوئی پناہ نہیں۔ پھر خدا نے ان پر مہربانی کی تاکہ توبہ کریں۔ بےشک خدا توبہ قبول کرنے والا مہربان ہے\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mcccliv{اے اہل ایمان! خدا سے ڈرتے رہو اور راست بازوں کے ساتھ رہو\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mccclv{اہل مدینہ کو اور جو ان کے آس پاس دیہاتی رہتے ہیں ان کو شایاں نہ تھا کہ پیغمبر خدا سے پیچھے رہ جائیں اور نہ یہ کہ اپنی جانوں کو ان کی جان سے زیادہ عزیز رکھیں۔ یہ اس لیے کہ انہیں خدا کی راہ میں تکلیف پہنچتی ہے پیاس کی، محنت کی یا بھوک کی یا وہ ایسی جگہ چلتے ہیں کہ کافروں کو غصہ آئے یا دشمنوں سے کوئی چیز لیتے ہیں تو ہر بات پر ان کے لیے عمل نیک لکھا جاتا ہے۔ کچھ شک نہیں کہ خدا نیکو کاروں کا اجر ضائع نہیں کرتا\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mccclvi{اور (اسی طرح) جو وہ خرچ کرتے ہیں تھوڑا یا بہت یا کوئی میدان طے کرتے ہیں تو یہ سب کچھ ان کے لیے (اعمال صالحہ) میں لکھ لیا جاتا ہے تاکہ خدا ان کو ان کے اعمال کا بہت اچھا بدلہ دے\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mccclvii{اور یہ تو ہو نہیں سکتا کہ مومن سب کے سب نکل آئیں۔ تو یوں کیوں نہ کیا کہ ہر ایک جماعت میں سے چند اشخاص نکل جاتے تاکہ دین کا (علم سیکھتے اور اس) میں سمجھ پیدا کرتے اور جب اپنی قوم کی طرف واپس آتے تو ان کو ڈر سناتے تاکہ وہ حذر کرتے\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mccclviii{اے اہلِ ایمان! اپنے نزدیک کے (رہنے والے) کافروں سے جنگ کرو اور چاہیئے کہ وہ تم میں سختی (یعنی محنت وقوت جنگ) معلوم کریں۔ اور جان رکھو کہ خدا پرہیز گاروں کے ساتھ ہے\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mccclix{اور جب کوئی سورت نازل ہوتی ہے تو بعض منافق (استہزاء کرتے اور) پوچھتے کہ اس سورت نے تم میں سے کس کا ایمان زیادہ کیا ہے۔ سو جو ایمان والے ہیں ان کا ایمان تو زیادہ کیا اور وہ خوش ہوتے ہیں\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mccclx{اور جن کے دلوں میں مرض ہے، ان کے حق میں خبث پر خبث زیادہ کیا اور وہ مرے بھی تو کافر کے کافر\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mccclxi{کیا یہ دیکھتے نہیں کہ یہ ہر سال ایک یا دو بار بلا میں پھنسا دیئے جاتے ہیں پھر بھی توبہ نہیں کرتے اور نہ نصیحت پکڑتے ہیں\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mccclxii{اور جب کوئی سورت نازل ہوتی ہے ایک دوسرے کی جانب دیکھنے لگتے ہیں (اور پوچھتے ہیں کہ) بھلا تمہیں کوئی دیکھتا ہے پھر پھر جاتے ہیں۔ خدا نے ان کے دلوں کو پھیر رکھا ہے کیونکہ یہ ایسے لوگ ہیں کہ سمجھ سے کام نہیں لیتے\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mccclxiii{لوگو) تمہارے پاس تم ہی میں سے ایک پیغمبر آئے ہیں۔ تمہاری تکلیف ان کو گراں معلوم ہوتی ہے اور تمہاری بھلائی کے خواہش مند ہیں اور مومنوں پر نہایت شفقت کرنے والے (اور) مہربان ہیں\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mccclxiv{پھر اگر یہ لوگ پھر جائیں (اور نہ مانیں) تو کہہ دو کہ خدا مجھے کفایت کرتا ہے اس کے سوا کوئی معبود نہیں اسی پر میرا بھروسہ ہے اور وہی عرش عظیم کا مالک ہے\qt@no{129}}%
\qt@newcmd\qurantrans@ur@mccclxv{\basmalahur آلرا ۔ یہ بڑی دانائی کی کتاب کی آیتیں ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mccclxvi{کیا لوگوں کو تعجب ہوا کہ ہم نے ان ہی میں سے ایک مرد کو حکم بھیجا کہ لوگوں کو ڈر سنا دو۔ اور ایمان لانے والوں کو خوشخبری دے دو کہ ان کے پروردگار کے ہاں ان کا سچا درجہ ہے۔ (ایسے شخص کی نسبت) کافر کہتے ہیں کہ یہ صریح جادوگر ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mccclxvii{تمہارا پروردگار تو خدا ہی ہے جس نے آسمان اور زمین چھ دن میں بنائے پھر عرش (تخت شاہی) پر قائم ہوا وہی ہر ایک کا انتظام کرتا ہے۔ کوئی (اس کے پاس) اس کا اذن حاصل کیے بغیر کسی کی سفارش نہیں کرسکتا، یہی خدا تمہارا پروردگار ہے تو اسی کی عبادت کرو۔ بھلا تم غور کیوں نہیں کرتے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mccclxviii{اسی کے پاس تم سب کو لوٹ کر جانا ہے۔ خدا کا وعدہ سچا ہے۔ وہی خلقت کو پہلی بار پیدا کرتا ہے۔ پھر وہی اس کو دوبارہ پیدا کرے گا تاکہ ایمان والوں اور نیک کام کرنے والوں کو انصاف کے ساتھ بدلہ دے۔ اور جو کافر ہیں ان کے لیے پینے کو نہایت گرم پانی اور درد دینے والا عذاب ہوگا کیوں کہ (خدا سے) انکار کرتے تھے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mccclxix{وہی تو ہے جس نے سورج کو روشن اور چاند کو منور بنایا اور چاند کی منزلیں مقرر کیں تاکہ تم برسوں کا شمار اور (کاموں کا) حساب معلوم کرو۔ یہ (سب کچھ) خدا نے تدبیر سے پیدا کیا ہے۔ سمجھنے والوں کے لیے وہ اپنی آیاتیں کھول کھول کر بیان فرماتا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mccclxx{رات اور دن کے (ایک دوسرے کے پیچھے) آنے جانے میں اور جو چیزیں خدا نے آسمان اور زمین میں پیدا کی ہیں (سب میں) ڈرنے والوں کے لیے نشانیاں ہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mccclxxi{جن لوگوں کو ہم سے ملنے کی توقع نہیں اور دنیا کی زندگی سے خوش اور اسی پر مطئمن ہو بیٹھے اور ہماری نشانیوں سے غافل ہو رہے ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mccclxxii{ان کا ٹھکانہ ان (اعمال) کے سبب جو وہ کرتے ہیں دوزخ ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mccclxxiii{اور جو لوگ ایمان لائے اور نیک کام کرتے رہے ان کو پروردگار ان کے ایمان کی وجہ سے (ایسے محلوں کی) راہ دکھائے گا (کہ) ان کے نیچے نعمت کے باغوں میں نہریں بہہ رہی ہوں گی\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mccclxxiv{جب وہ) ان میں (ان نعمتوں کو دیکھوں گے تو بےساختہ) کہیں گے سبحان الله۔ اور آپس میں ان کی دعا سلامٌ علیکم ہوگی اور ان کا آخری قول یہ (ہوگا) کہ خدائے رب العالمین کی حمد (اور اس کا شکر) ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mccclxxv{اور اگر خدا لوگوں کی برائی میں جلدی کرتا جس طرح وہ طلب خیر میں جلدی کرتے ہیں۔ تو ان کی (عمر کی) میعاد پوری ہوچکی ہوتی سو جن لوگوں کو ہم سے ملنے کی توقع نہیں انہیں ہم چھوڑے رکھتے ہیں کہ اپنی سرکشی میں بہکتے رہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mccclxxvi{اور جب انسان کو تکلیف پہنچتی ہے تو لیٹا اور بیٹھا اور کھڑا (ہر حال میں) ہمیں پکارتا ہے۔ پھر جب ہم اس تکلیف کو اس سے دور کر دیتے ہیں تو (بےلحاظ ہو جاتا ہے اور) اس طرح گزر جاتا ہے گویا کسی تکلیف پہنچنے پر ہمیں کبھی پکارا ہی نہ تھا۔ اسی طرح حد سے نکل جانے والوں کو ان کے اعمال آراستہ کرکے دکھائے گئے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mccclxxvii{اور تم سے پہلے ہم کئی امتوں کو جب انہوں نے ظلم کا راستہ اختیار کیا ہلاک کرچکے ہیں۔ اور ان کے پاس پیغمبر کھلی نشانیاں لے کر آئے مگر وہ ایسے نہ تھے کہ ایمان لاتے۔ ہم گنہگار لوگوں کو اسی طرح بدلہ دیا کرتے ہیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mccclxxviii{پھر ہم نے ان کے بعد تم لوگوں کو ملک میں خلیفہ بنایا تاکہ دیکھیں تم کیسے کام کرتے ہو\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mccclxxix{اور جب ان کو ہماری آیتیں پڑھ کر سنائی جاتی ہیں تو جن لوگوں کو ہم سے ملنے کی امید نہیں وہ کہتے ہیں کہ (یا تو) اس کے سوا کوئی اور قرآن (بنا) لاؤ یا اس کو بدل دو۔ کہہ دو کہ مجھ کو اختیار نہیں ہے کہ اسے اپنی طرف سے بدل دو۔ میں تو اسی حکم کا تابع ہوں جو میری طرف آتا ہے۔ اگر میں اپنے پروردگار کی نافرمانی کروں تو مجھے بڑے (سخت) دن کے عذاب سے خوف آتا ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mccclxxx{یہ بھی) کہہ دو کہ اگر خدا چاہتا تو (نہ تو) میں ہی یہ (کتاب) تم کو پڑھ کر سناتا اور نہ وہی تمہیں اس سے واقف کرتا۔ میں اس سے پہلے تم میں ایک عمر رہا ہوں (اور کبھی ایک کلمہ بھی اس طرح کا نہیں کہا) بھلا تم سمجھتے نہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mccclxxxi{تو اس سے بڑھ کر ظالم کون جو خدا پر جھوٹ افترا کرے اور اس کی آیتوں کو جھٹلائے۔ بےشک گنہگار فلاح نہیں پائیں گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mccclxxxii{اور یہ (لوگ) خدا کے سوا ایسی چیزوں کی پرستش کرتے ہیں جو نہ ان کا کچھ بگاڑ ہی سکتی ہیں اور نہ کچھ بھلا ہی کر سکتی ہیں اور کہتے ہیں کہ یہ خدا کے پاس ہماری سفارش کرنے والے ہیں۔ کہہ دو کہ کیا تم خدا کو ایسی چیز بتاتے ہو جس کا وجود اسے نہ آسمانوں میں معلوم ہوتا ہے اور نہ زمین میں۔ وہ پاک ہے اور (اس کی شان) ان کے شرک کرنے سے بہت بلند ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mccclxxxiii{اور (سب) لوگ (پہلے) ایک ہی اُمت (یعنی ایک ہی ملت پر) تھے۔ پھر جدا جدا ہوگئے۔ اور اگر ایک بات جو تمہارے پروردگار کی طرف سے پہلے ہوچکی ہے نہ ہوتی تو جن باتوں میں وہ اختلاف کرتے ہیں ان میں فیصلہ کر دیا جاتا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mccclxxxiv{اور کہتے ہیں کہ اس پر اس کے پروردگار کی طرف سے کوئی نشانی کیوں نازل نہیں ہوئی۔ کہہ دو کہ غیب (کا علم) تو خدا کو ہے سو تم انتظار کرو۔ میں بھی تمہارے ساتھ انتظار کرتا ہوں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mccclxxxv{اور جب ہم لوگوں کو تکلیف پہنچنے کے بعد (اپنی) رحمت (سے آسائش) کا مزہ چکھاتے ہیں تو وہ ہماری آیتوں میں حیلے کرنے لگتے ہیں۔ کہہ دو کہ خدا بہت جلد حیلہ کرنے والا ہے۔ اور جو حیلے تم کرتے ہو ہمارے فرشتے ان کو لکھتے جاتے ہیں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mccclxxxvi{وہی تو ہے جو تم کو جنگل اور دریا میں چلنے پھرنے اور سیر کرنے کی توفیق دیتا ہے۔ یہاں تک کہ جب تم کشتیوں میں (سوار) ہوتے اور کشتیاں پاکیزہ ہوا (کے نرم نرم جھونکوں) سے سواروں کو لے کر چلنے لگتی ہیں اور وہ ان سے خوش ہوتے ہیں تو ناگہاں زناٹے کی ہوا چل پڑتی ہے اور لہریں ہر طرف سے ان پر (جوش مارتی ہوئی) آنے لگتی ہیں اور وہ خیال کرتے ہیں کہ (اب تو) لہروں میں گھر گئے تو اس وقت خالص خدا ہی کی عبادت کرکے اس سے دعا مانگنے لگتے ہیں کہ (اے خدا) اگر تو ہم کو اس سے نجات بخشے تو ہم (تیرے) بہت ہی شکر گزار ہوں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mccclxxxvii{لیکن جب وہ ان کو نجات دے دیتا ہے تو ملک میں ناحق شرارت کرنے لگتے ہیں۔ لوگو! تمہاری شرارت کا وبال تمہاری ہی جانوں پر ہوگا تم دنیا کی زندگی کے فائدے اُٹھا لو۔ پھر تم کو ہمارے پاس لوٹ کر آنا ہے۔ اس وقت ہم تم کو بتائیں گے جو کچھ تم کیا کرتے تھے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mccclxxxviii{دنیا کی زندگی کی مثال مینھہ کی سی ہے کہ ہم نے اس کو آسمان سے برسایا۔ پھر اس کے ساتھ سبزہ جسے آدمی اور جانور کھاتے ہیں مل کر نکلا یہاں تک کہ زمین سبزے سے خوشنما اور آراستہ ہوگئی اور زمین والوں نے خیال کیا کہ وہ اس پر پوری دسترس رکھتے ہیں ناگہاں رات کو یا دن کو ہمارا حکم (عذاب) آپہنچا تو ہم نے اس کو کاٹ (کر ایسا کر) ڈالا کہ گویا کل وہاں کچھ تھا ہی نہیں۔ جو لوگ غور کرنے والے ہیں۔ ان کے لیے ہم (اپنی قدرت کی) نشانیاں اسی طرح کھول کھول کر بیان کرتے ہیں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mccclxxxix{اور خدا سلامتی کے گھر کی طرف بلاتا ہے۔ اور جس کو چاہتا ہے سیدھا راستہ دکھاتا ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mcccxc{جن لوگوں نے نیکو کاری کی ان کے لیے بھلائی ہے اور (مزید برآں) اور بھی اور ان کے مونہوں پر نہ تو سیاہی چھائے گی اور نہ رسوائی۔ یہی جنتی ہیں کہ اس میں ہمیشہ رہیں گے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mcccxci{اور جنہوں نے برے کام کئے تو برائی کا بدلہ ویسا ہی ہوگا۔ اور ان کے مونہوں پر ذلت چھا جائے گی۔ اور کوئی ان کو خدا سے بچانے والا نہ ہوگا۔ ان کے مونہوں (کی سیاہی کا یہ عالم ہوگا کہ ان) پر گویا اندھیری رات کے ٹکڑے اُڑھا دیئے گئے ہیں۔ یہی دوزخی ہیں کہ ہمیشہ اس میں رہیں گے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mcccxcii{اور جس دن ہم ان سب کو جمع کریں گے پھر مشرکوں سے کہیں گے کہ تم اور تمہارے شریک اپنی اپنی جگہ ٹھہرے رہو۔ تو ہم ان میں تفرقہ ڈال دیں گے اور ان کے شریک (ان سے) کہیں گے کہ تم ہم کو نہیں پوجا کرتے تھے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mcccxciii{ہمارے اور تمہارے درمیان خدا ہی گواہ کافی ہے۔ ہم تمہاری پرستش سے بالکل بےخبر تھے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mcccxciv{وہاں ہر شخص (اپنے اعمال کی) جو اس نے آگے بھیجے ہوں گے آزمائش کرلے گا اور وہ اپنے سچے مالک کی طرف لوٹائے جائیں گے اور جو کچھ وہ بہتان باندھا کرتے تھے سب ان سے جاتا رہے گا\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mcccxcv{ان سے) پوچھو کہ تم کو آسمان اور زمین میں رزق کون دیتا ہے یا (تمہارے) کانوں اور آنکھوں کا مالک کون ہے اور بےجان سے جاندار کون پیدا کرتا ہے اور دنیا کے کاموں کا انتظام کون کرتا ہے۔ جھٹ کہہ دیں گے کہ خدا۔ تو کہو کہ پھر تم (خدا سے) ڈرتے کیوں نہیں؟\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mcccxcvi{یہی خدا تو تمہارا پروردگار برحق ہے۔ اور حق بات کے ظاہر ہونے کے بعد گمراہی کے سوا ہے ہی کیا؟ تو تم کہاں پھرے جاتے ہو\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mcccxcvii{اسی طرح خدا کا ارشاد ان نافرمانوں کے حق میں ثابت ہو کر رہا کہ یہ ایمان نہیں لائیں گے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mcccxcviii{ان سے) پوچھو کہ بھلا تمھارے شریکوں میں سے کوئی ایسا ہے کہ مخلوق کو ابتداً پیدا کرے (اور) پھر اس کو دوبارہ بنائے؟ کہہ دو کہ خدا ہی پہلی بار پیدا کرتا ہے پھر وہی اس کو دوبارہ پیدا کرے گا تو تم کہاں اُکسے جارہے ہو\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mcccxcix{پوچھو کہ بھلا تمہارے شریکوں میں کون ایسا ہے کہ حق کا رستہ دکھائے۔ کہہ دو کہ خدا ہی حق کا رستہ دکھاتا ہے۔ بھلا جو حق کا رستہ دکھائے وہ اس قابل ہے کہ اُس کی پیروی کی جائے یا وہ کہ جب تک کوئی اسے رستہ نہ بتائے رستہ نہ پائے۔ تو تم کو کیا ہوا ہے کیسا انصاف کرتے ہو؟\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mcd{اور ان میں سے اکثر صرف ظن کی پیروی کرتے ہیں۔ اور کچھ شک نہیں کہ ظن حق کے مقابلے میں کچھ بھی کارآمد نہیں ہوسکتا۔ بےشک خدا تمہارے (سب) افعال سے واقف ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mcdi{اور یہ قرآن ایسا نہیں کہ خدا کے سوا کوئی اس کو اپنی طرف سے بنا لائے۔ ہاں (ہاں یہ خدا کا کلام ہے) جو (کتابیں) اس سے پہلے (کی) ہیں۔ ان کی تصدیق کرتا ہے اور ان ہی کتابوں کی (اس میں) تفصیل ہے اس میں کچھ شک نہیں (کہ) یہ رب العالمین کی طرف سے (نازل ہوا) ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mcdii{کیا یہ لوگ کہتے ہیں کہ پیغمبر نے اس کو اپنی طرف سے بنا لیا ہے کہہ دو کہ اگر سچے ہو تو تم بھی اس طرح کی ایک سورت بنا لاؤ اور خدا کے سوا جن کو تم بلا سکو بلا بھی لو\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mcdiii{حقیقت یہ ہے کہ جس چیز کے علم پر یہ قابو نہیں پاسکے اس کو (نادانی سے) جھٹلا دیا اور ابھی اس کی حقیقت ان پر کھلی ہی نہیں۔ اسی طرح جو لوگ ان سے پہلے تھے انہوں نے تکذیب کی تھی سو دیکھ لو ظالموں کا انجام کیسا ہوا\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mcdiv{اور ان میں سے کچھ تو ایسے ہیں کہ اس پر ایمان لے آتے ہیں اور کچھ ایسے ہیں کہ ایمان نہیں لاتے۔ اور تمھارا پروردگار شریروں سے خوب واقف ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mcdv{اور اگر یہ تمہاری تکذیب کریں تو کہہ دو کہ مجھ کو میرے اعمال (کا بدلہ ملے گا) اور تم کو تمہارے اعمال (کا) تم میرے عملوں کا جواب دہ نہیں ہو اور میں تمہارے عملوں کا جوابدہ نہیں ہوں\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mcdvi{اور ان میں سے بعض ایسے ہیں کہ تمہاری طرف کان لگاتے ہیں تو کیا تم بہروں کو سناؤ گے اگرچہ کچھ بھی (سنتے) سمجھتے نہ ہوں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mcdvii{اور بعض ایسے ہیں کہ تمھاری طرف دیکھتے ہیں۔ تو کیا تم اندھوں کو راستہ دکھاؤ گے اگرچہ کچھ بھی دیکھتے (بھالتے) نہ ہوں\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mcdviii{خدا تو لوگوں پر کچھ ظلم نہیں کرتا لیکن لوگ ہی اپنے آپ پر ظلم کرتے ہیں\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mcdix{اور جس دن خدا ان کو جمع کرے گا (تو وہ دنیا کی نسبت ایسا خیال کریں گے کہ) گویا (وہاں) گھڑی بھر دن سے زیادہ رہے ہی نہیں تھے (اور) آپس میں ایک دوسرے کو شناخت بھی کریں گے۔ جن لوگوں نے خدا کے روبرو حاضر ہونے کو جھٹلایا وہ خسارے میں پڑ گئے اور راہ یاب نہ ہوئے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mcdx{اور اگر ہم کوئی عذاب جس کا ان لوگوں سے وعدہ کرتے ہیں تمہاری آنکھوں کے سامنے (نازل) کریں یا (اس وقت جب) تمہاری مدت حیات پوری کردیں تو ان کو ہمارے ہی پاس لوٹ کر آنا ہے پھر جو کچھ یہ کر رہے ہیں خدا اس کو دیکھ رہا ہے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mcdxi{اور ہر ایک اُمت کی طرف سے پیغمبر بھیجا گیا۔ جب ان کا پیغمبر آتا ہے تو اُن میں انصاف کے ساتھ فیصلہ کر دیا جاتا ہے اور ان پر کچھ ظلم نہیں کیا جاتا\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mcdxii{اور یہ کہتے ہیں کہ اگر تم سچے ہو تو (جس عذاب کا) یہ وعدہ (ہے وہ آئے گا) کب؟\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mcdxiii{کہہ دو کہ میں اپنے نقصان اور فائدے کا بھی کچھ اختیار نہیں رکھتا۔ مگر جو خدا چاہے۔ ہر ایک امت کے لیے (موت کا) ایک وقت مقرر ہے۔ جب وہ وقت آجاتا ہے تو ایک گھڑی بھی دیر نہیں کرسکتے اور نہ جلدی کرسکتے ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mcdxiv{کہہ دو کہ بھلا دیکھو تو اگر اس کا عذاب تم پر (ناگہاں) آجائے رات کو یا دن کو تو پھر گنہگار کس بات کی جلدی کریں گے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mcdxv{کیا جب وہ آ واقع ہوگا تب اس پر ایمان لاؤ گے (اس وقت کہا جائے گا کہ) اور اب (ایمان لائے؟) اس کے لیے تو تم جلدی مچایا کرتے تھے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mcdxvi{پھر ظالم لوگوں سے کہا جائے گا کہ عذاب دائمی کا مزہ چکھو۔ (اب) تم انہیں (اعمال) کا بدلہ پاؤ گے جو (دنیا میں) کرتے رہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mcdxvii{اور تم سے دریافت کرتے ہیں کہ آیا یہ سچ ہے۔ کہہ دو ہاں خدا کی قسم سچ ہے اور تم (بھاگ کر خدا کو) عاجز نہیں کرسکو گے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mcdxviii{اور اگر ہر ایک نافرمان شخص کے پاس روئے زمین کی تمام چیزیں ہوں تو (عذاب سے بچنے کے) بدلے میں (سب) دے ڈالے اور جب وہ عذاب کو دیکھیں گے تو (پچھتائیں گے اور) ندامت کو چھپائیں گے۔ اور ان میں انصاف کے ساتھ فیصلہ کر دیا جائے گا اور (کسی طرح کا) ان پر ظلم نہیں ہوگا\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mcdxix{سن رکھو جو کچھ آسمانوں اور زمینوں میں ہے سب خدا ہی کا ہے۔ اور یہ بھی سن رکھو کہ خدا کا وعدہ سچا ہے لیکن اکثر لوگ نہیں جانتے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mcdxx{وہی جان بخشتا اور (وہی) موت دیتا ہے اور تم لوگ اسی کی طرف لوٹ کر جاؤ گے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mcdxxi{لوگو تمہارے پروردگار کی طرف سے نصیحت اور دلوں کی بیماریوں کی شفا۔ اور مومنوں کے لیے ہدایت اور رحمت آپہنچی ہے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mcdxxii{کہہ دو کہ (یہ کتاب) خدا کے فضل اور اس کی مہربانی سے (نازل ہوئی ہے) تو چاہیئے کہ لوگ اس سے خوش ہوں۔ یہ اس سے کہیں بہتر ہے جو وہ جمع کرتے ہیں\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mcdxxiii{کہو کہ بھلا دیکھو تو خدا نے تمھارے لئے جو رزق نازل فرمایا تو تم نے اس میں سے (بعض کو) حرام ٹھہرایا اور (بعض کو) حلال (ان سے) پوچھو کیا خدا نے تم کو اس کا حکم دیا ہے یا تم خدا پر افتراء کرتے ہو\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mcdxxiv{اور جو لوگ خدا پر افتراء کرتے ہیں وہ قیامت کے دن کی نسبت کیا خیال رکھتے ہیں؟ بےشک خدا لوگوں پر مہربان ہے لیکن اکثر لوگ شکر نہیں کرتے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mcdxxv{اور تم جس حال میں ہوتے ہو یا قرآن میں کچھ پڑھتے ہو یا تم لوگ کوئی (اور) کام کرتے ہو جب اس میں مصروف ہوتے ہو ہم تمہارے سامنے ہوتے ہیں اور تمہارے پروردگار سے ذرہ برابر بھی کوئی چیز پوشیدہ نہیں ہے نہ زمین میں نہ آسمان میں اور نہ کوئی چیز اس سے چھوٹی ہے یا بڑی مگر کتاب روشن میں (لکھی ہوئی) ہے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mcdxxvi{سن رکھو کہ جو خدا کے دوست ہیں ان کو نہ کچھ خوف ہوگا اور نہ وہ غمناک ہوں گے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mcdxxvii{یعنی) جو لوگ ایمان لائے اور پرہیزگار رہے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mcdxxviii{ان کے لیے دنیا کی زندگی میں بھی بشارت ہے اور آخرت میں بھی۔ خدا کی باتیں بدلتی نہیں۔ یہی تو بڑی کامیابی ہے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mcdxxix{اور (اے پیغمبر) ان لوگوں کی باتوں سے آزردہ نہ ہونا (کیونکہ) عزت سب خدا ہی کی ہے وہ (سب کچھ) سنتا (اور) جانتا ہے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mcdxxx{سن رکھو کہ جو مخلوق آسمانوں میں ہے اور جو زمین میں ہے سب خدا کے (بندے اور اس کے مملوک) ہیں۔ اور یہ جو خدا کے سوا (اپنے بنائے ہوئے) شریکوں کو پکارتے ہیں۔ وہ (کسی اور چیز کے) پیچھے نہیں چلتے۔ صرف ظن کے پیچھے چلتے ہیں اور محض اٹکلیں دوڑا رہے ہیں\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mcdxxxi{وہی تو ہے جس نے تمہارے لیے رات بنائی تاکہ اس میں آرام کرو اور روز روشن بنایا (تاکہ اس میں کام کرو) جو لوگ (مادہٴ) سماعت رکھتے ہیں ان کے لیے ان میں نشانیاں ہیں\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mcdxxxii{بعض لوگ) کہتے ہیں کہ خدا نے بیٹا بنا لیا ہے۔ اس کی ذات (اولاد سے) پاک ہے (اور) وہ بےنیاز ہے۔ جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے وہ سب اسی کا ہے (اے افتراء پردازو) تمہارے پاس اس (قول باطل) کی کوئی دلیل نہیں ہے۔ تم خدا کی نسبت ایسی بات کیوں کہتے ہو جو جانتے نہیں\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mcdxxxiii{کہہ دو جو لوگ خدا پر جھوٹ بہتان باندھتے ہیں فلاح نہیں پائیں گے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mcdxxxiv{ان کے لیے جو) فائدے ہیں دنیا میں (ہیں) پھر ان کو ہماری ہی طرف لوٹ کر آنا ہے۔ اس وقت ہم ان کو شدید عذاب (کے مزے) چکھائیں گے کیونکہ کفر (کی باتیں) کیا کرتے تھے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mcdxxxv{اور ان کو نوح کا قصہ پڑھ کر سنادو۔ جب انہوں نے اپنی قوم سے کہا کہ اے قوم! اگر تم کو میرا تم میں رہنا اور خدا کی آیتوں سے نصیحت کرنا ناگوار ہو تو میں خدا پر بھروسہ رکھتا ہوں۔ تم اپنے شریکوں کے ساتھ مل کر ایک کام (جو میرے بارے میں کرنا چاہو) مقرر کرلو اور وہ تمہاری تمام جماعت (کو معلوم ہوجائے اور کسی) سے پوشیدہ نہ رہے اور پھر وہ کام میرے حق میں کر گزرو اور مجھے مہلت نہ دو\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mcdxxxvi{اور اگر تم نے منہ پھیر لیا تو (تم جانتے ہو کہ) میں نے تم سے کچھ معاوضہ نہیں مانگا۔ میرا معاوضہ تو خدا کے ذمے ہے۔ اور مجھے حکم ہوا ہے کہ میں فرمانبرداروں میں رہوں\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mcdxxxvii{لیکن ان لوگوں نے ان کی تکذیب کی تو ہم نے ان کو اور جو لوگ ان کے ساتھ کشتی میں سوار تھے سب کو (طوفان سے) بچا لیا اور انہیں (زمین میں) خلیفہ بنادیا اور جن لوگوں نے ہماری آیتوں کو جھٹلایا ان کو غرق کر دیا تو دیکھ لو کہ جو لوگ ڈرائے گئے تھے ان کا کیا انجام ہوا\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mcdxxxviii{پھر نوح کے بعد ہم نے اور پیغمبر اپنی اپنی قوم کی طرف بھیجے۔ تو وہ ان کے پاس کھلی نشانیاں لے کر آئے۔ مگر وہ لوگ ایسے نہ تھے کہ جس چیز کی پہلے تکذیب کرچکے تھے اس پر ایمان لے آتے۔ اسی طرح ہم زیادتی کرنے والوں کے دلوں پر مہر لگا دیتے ہیں\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mcdxxxix{پھر ان کے بعد ہم نے موسیٰ اور ہارون کو اپنی نشانیاں دے کر فرعون اور اس کے سرداروں کے پاس بھیجا تو انہوں نے تکبر کیا اور وہ گنہگار لوگ تھے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mcdxl{تو جب ان کے پاس ہمارے ہاں سے حق آیا تو کہنے لگے کہ یہ تو صریح جادو ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mcdxli{موسیٰ نے کہا کیا تم حق کے بارے میں جب وہ تمہارے پاس آیا یہ کہتے ہو کہ یہ جادو ہے۔ حالانکہ جادوگر فلاح نہیں پانے کے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mcdxlii{وہ بولے کیا تم ہمارے پاس اس لئے آئے ہو کہ جس (راہ) پر ہم اپنے باپ دادا کو پاتے رہے ہیں اس سے ہم کو پھیردو۔ اور (اس) ملک میں تم دونوں کی ہی سرداری ہوجائے اور ہم تم پر ایمان لانے والے نہیں ہیں\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mcdxliii{اور فرعون نے حکم دیا کہ سب کامل فن جادوگروں کو ہمارے پاس لے آؤ\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mcdxliv{جب جادوگر آئے تو موسیٰ نے ان سے کہا تم کو جو ڈالنا ہے ڈالو\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mcdxlv{جب انہوں نے (اپنی رسیوں اور لاٹھیوں کو) ڈالا تو موسیٰ نے کہا کہ جو چیزیں تم (بنا کر) لائے ہو جادو ہے خدا اس کو بھی نیست ونابود کردے گا۔ خدا شریروں کے کام سنوارا نہیں کرتا\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mcdxlvi{اور خدا اپنے حکم سے سچ کو سچ ہی کردے گا اگرچہ گنہگار برا ہی مانیں\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mcdxlvii{تو موسیٰ پر کوئی ایمان نہ لایا۔ مگر اس کی قوم میں سے چند لڑکے (اور وہ بھی) فرعون اور اس کے اہل دربار سے ڈرتے ڈرتے کہ کہیں وہ ان کو آفت میں نہ پھنسا دے۔ اور فرعون ملک میں متکبر ومتغلب اور (کبر وکفر) میں حد سے بڑھا ہوا تھا\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mcdxlviii{اور موسیٰ نے کہا کہ بھائیو! اگر تم خدا پر ایمان لائے ہو تو اگر (دل سے) فرمانبردار ہو تو اسی پر بھروسہ رکھو\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mcdxlix{تو وہ بولے کہ ہم خدا ہی پر بھروسہ رکھتے ہیں۔ اے ہمارے پروردگار ہم کو ظالم لوگوں کے ہاتھ سے آزمائش میں نہ ڈال\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mcdl{اور اپنی رحمت سے قوم کفار سے نجات بخش\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mcdli{اور ہم نے موسیٰ اور اس کے بھائی کی طرف وحی بھیجی کہ اپنے لوگوں کے لیے مصر میں گھر بناؤ اور اپنے گھروں کو قبلہ (یعنی مسجدیں) ٹھہراؤ اور نماز پڑھو۔ اور مومنوں کو خوشخبری سنادو\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mcdlii{اور موسیٰ نے کہا اے ہمارے پروردگار تو نے فرعون اور اس کے سرداروں کو دنیا کی زندگی میں (بہت سا) سازو برگ اور مال وزر دے رکھا ہے۔ اے پروردگار ان کا مال یہ ہے کہ تیرے رستے سے گمراہ کردیں۔ اے پروردگار ان کے مال کو برباد کردے اور ان کے دلوں کو سخت کردے کہ ایمان نہ لائیں جب تک عذاب الیم نہ دیکھ لیں\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mcdliii{خدا نے فرمایا کہ تمہاری دعا قبول کرلی گئی تو تم ثابت قدم رہنا اور بےعقلوں کے رستے نہ چلنا\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mcdliv{اور ہم نے بنی اسرائیل کو دریا سے پار کردیا تو فرعون اور اس کے لشکر نے سرکشی اور تعدی سے ان کا تعاقب کیا۔ یہاں تک کہ جب اس کو غرق (کے عذاب) نے آپکڑا تو کہنے لگا کہ میں ایمان لایا کہ جس (خدا) پر بنی اسرائیل ایمان لائے ہیں اس کے سوا کوئی معبود نہیں اور میں فرمانبرداروں میں ہوں\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mcdlv{جواب ملا کہ) اب (ایمان لاتا ہے) حالانکہ تو پہلے نافرمانی کرتا رہا اور مفسد بنا رہا\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mcdlvi{تو آج ہم تیرے بدن کو (دریا سے) نکال لیں گے تاکہ تو پچھلوں کے لئے عبرت ہو۔ اور بہت سے لوگ ہماری نشانیوں سے بےخبر ہیں\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mcdlvii{اور ہم نے بنی اسرائیل کو رہنے کو عمدہ جگہ دی اور کھانے کو پاکیزہ چیزیں عطا کیں لیکن وہ باوجود علم ہونے کے اختلاف کرتے رہے۔ بےشک جن باتوں میں وہ اختلاف کرتے رہے ہیں تمہارا پروردگار قیامت کے دن ان میں ان باتوں کا فیصلہ کردے گا\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mcdlviii{اگر تم کو اس (کتاب کے) بارے میں جو ہم نے تم پر نازل کی ہے کچھ شک ہو تو جو لوگ تم سے پہلے کی (اُتری ہوئی) کتابیں پڑھتے ہیں ان سے پوچھ لو۔ تمہارے پروردگار کی طرف سے تمہارے پاس حق آچکا ہے تو تم ہرگز شک کرنے والوں میں نہ ہونا\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mcdlix{اور نہ ان لوگوں میں ہونا جو خدا کی آیتوں کی تکذیب کرتے ہیں نہیں تو نقصان اٹھاؤ گے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mcdlx{جن لوگوں کے بارے میں خدا کا حکم (عذاب) قرار پاچکا ہے وہ ایمان نہیں لانے کے\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mcdlxi{جب تک کہ عذاب الیم نہ دیکھ لیں خواہ ان کے پاس ہر (طرح کی) نشانی آجائے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mcdlxii{تو کوئی بستی ایسی کیوں نہ ہوئی کہ ایمان لاتی تو اس کا ایمان اسے نفع دیتا ہاں یونس کی قوم۔ جب ایمان لائی تو ہم نے دنیا کی زندگی میں ان سے ذلت کا عذاب دور کردیا اور ایک مدت تک (فوائد دنیاوی سے) ان کو بہرہ مند رکھا\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mcdlxiii{اور اگر تمہارا پروردگار چاہتا تو جتنے لوگ زمین پر ہیں سب کے سب ایمان لے آتے۔ تو کیا تم لوگوں پر زبردستی کرنا چاہتے ہو کہ وہ مومن ہوجائیں\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mcdlxiv{حالانکہ کسی شخص کو قدرت نہیں ہے کہ خدا کے حکم کے بغیر ایمان لائے۔ اور جو لوگ بےعقل ہیں ان پر وہ (کفر وذلت کی) نجاست ڈالتا ہے\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mcdlxv{ان کفار سے) کہو دیکھو تو زمین اور آسمانوں میں کیا کچھ ہے۔ مگر جو لوگ ایمان نہیں رکھتے ان کی نشانیاں اور ڈرواے کچھ کام نہیں آتے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mcdlxvi{سو جیسے (برے) دن ان سے پہلے لوگوں پر گزر چکے ہیں اسی طرح کے (دنوں کے) یہ منتظر ہیں۔ کہہ دو کہ تم بھی انتظار کرو۔ میں بھی تمہارے ساتھ انتظار کرتا ہوں\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mcdlxvii{اور ہم اپنے پیغمبروں کو اور مومنوں کو نجات دیتے رہے ہیں۔ اسی طرح ہمارا ذمہ ہے کہ مسلمانوں کو نجات دیں\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mcdlxviii{اے پیغمبر) کہہ دو کہ لوگو اگر تم کو میرے دین میں کسی طرح کا شک ہو تو (سن رکھو کہ) جن لوگوں کی تم خدا کے سوا عبادت کرتے ہو میں ان کی عبادت نہیں کرتا۔ بلکہ میں خدا کی عبادت کرتا ہوں جو تمھاری روحیں قبض کرلیتا ہے اور مجھ کو یہی حکم ہوا ہے کہ ایمان لانے والوں میں ہوں\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mcdlxix{اور یہ کہ (اے محمد سب سے) یکسو ہو کر دین (اسلام) کی پیروی کئے جاؤ۔ اور مشرکوں میں ہرگز نہ ہونا\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mcdlxx{اور خدا کو چھوڑ کر ایسی چیز کو نہ پکارنا جو نہ تمہارا کچھ بھلا کرسکے اور نہ کچھ بگاڑ سکے۔ اگر ایسا کرو گے تو ظالموں میں ہوجاؤ گے\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mcdlxxi{اور اگر خدا تم کو کوئی تکلیف پہنچائے تو اس کے سوا اس کا کوئی دور کرنے والا نہیں اور اگر تم سے بھلائی کرنی چاہے تو اس کے فضل کو کوئی روکنے والا نہیں۔ وہ اپنے بندوں میں سے جسے چاہتا ہے فائدہ پہنچاتا ہے اور وہ بخشنے والا مہربان ہے\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mcdlxxii{کہہ دو کہ لوگو تمہارے پروردگار کے ہاں سے تمہارے پاس حق آچکا ہے تو جو کوئی ہدایت حاصل کرتا ہے تو ہدایت سے اپنے ہی حق میں بھلائی کرتا ہے۔ اور جو گمراہی اختیار کرتا ہے تو گمراہی سے اپنا ہی نقصان کرتا ہے۔ اور میں تمہارا وکیل نہیں ہوں\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mcdlxxiii{اور (اے پیغمبر) تم کو جو حکم بھیجا جاتا ہے اس کی پیروی کئے جاؤ اور (تکلیفوں پر) صبر کرو یہاں تک کہ خدا فیصلہ کردے۔ اور وہ سب سے بہتر فیصلہ کرنے والا ہے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mcdlxxiv{\basmalahur الٓرا۔ یہ وہ کتاب ہے جس کی آیتیں مستحکم ہیں اور خدائے حکیم وخبیر کی طرف سے بہ تفصیل بیان کردی گئی ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mcdlxxv{وہ یہ) کہ خدا کے سوا کسی کی عبادت نہ کرو اور میں اس کی طرف سے تم کو ڈر سنانے والا اور خوشخبری دینے والا ہوں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mcdlxxvi{اور یہ کہ اپنے پروردگار سے بخشش مانگو اور اس کے آگے توبہ کرو وہ تو تم کو ایک وقت مقررہ تک متاع نیک سے بہرہ مند کرے گا اور ہر صاحب بزرگ کو اس کی بزرگی (کی داد) دے گا۔ اور اگر روگردانی کرو گے تو مجھے تمہارے بارے میں (قیامت کے) بڑے دن کے عذاب کا ڈر ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mcdlxxvii{تم (سب) کو خدا کی طرف لوٹ کر جانا ہے اور وہ ہر چیز پر قادر ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mcdlxxviii{دیکھو یہ اپنے سینوں کو دوھرا کرتے ہیں تاکہ خدا سے پردہ کریں۔ سن رکھو جس وقت یہ کپڑوں میں لپٹ کر پڑتے ہیں (تب بھی) وہ ان کی چھپی اور کھلی باتوں کو جانتا ہے۔ وہ تو دلوں تک کی باتوں سے آگاہ ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mcdlxxix{اور زمین پر کوئی چلنے پھرنے والا نہیں مگر اس کا رزق خدا کے ذمے ہے وہ جہاں رہتا ہے، اسے بھی جانتا ہے اور جہاں سونپا جاتا ہے اسے بھی۔ یہ سب کچھ کتاب روشن میں (لکھا ہوا) ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mcdlxxx{اور وہی تو ہے جس نے آسمانوں اور زمین کو چھ دن میں بنایا اور (اس وقت) اس کا عرش پانی پر تھا۔ (تمہارے پیدا کرنے سے) مقصود یہ ہے کہ وہ تم کو آزمائے کہ تم میں عمل کے لحاظ سے کون بہتر ہے اور اگر تم کہو کہ تم لوگ مرنے کے بعد (زندہ کرکے) اٹھائے جاؤ گے تو کافر کہہ دیں گے کہ یہ تو کھلا جادو ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mcdlxxxi{اور اگر ایک مدت معین تک ہم ان سے عذاب روک دیں تو کہیں گے کہ کون سی چیز عذاب روکے ہوئے ہے۔ دیکھو جس روز وہ ان پر واقع ہوگا (پھر) ٹلنے کا نہیں اور جس چیز کے ساتھ یہ استہزاء کیا کرتے ہیں وہ ان کو گھیر لے گی\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mcdlxxxii{اور اگر ہم انسان کو اپنے پاس سے نعمت بخشیں پھر اس سے اس کو چھین لیں تو ناامید (اور) ناشکرا (ہوجاتا) ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiii{اور اگر تکلیف پہنچنے کے بعد آسائش کا مزہ چکھائیں تو (خوش ہو کر) کہتا ہے کہ (آہا) سب سختیاں مجھ سے دور ہوگئیں۔ بےشک وہ خوشیاں منانے والا (اور) فخر کرنے والا ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mcdlxxxiv{ہاں جنہوں نے صبر کیا اور عمل نیک کئے۔ یہی ہیں جن کے لیے بخشش اور اجرعظیم ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mcdlxxxv{شاید تم کچھ چیز وحی میں سے جو تمہارے پاس آتی ہے چھوڑ دو اور اس (خیال) سے کہ تمہارا دل تنگ ہو کہ (کافر) یہ کہنے لگیں کہ اس پر کوئی خزانہ کیوں نہ نازل ہوا یا اس کے ساتھ کوئی فرشتہ کیوں نہیں آیا۔ اے محمدﷺ! تم تو صرف نصیحت کرنے والے ہو۔ اور خدا ہر چیز کا نگہبان ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvi{یہ کیا کہتے ہیں کہ اس نے قرآن ازخود بنا لیا ہے؟ کہہ دو کہ اگر سچے ہو تو تم بھی ایسی دس سورتیں بنا لاؤ اور خدا کے سوا جس جس کو بلاسکتے ہو، بلا بھی لو\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mcdlxxxvii{اگر وہ تمہاری بات قبول نہ کریں تو جان لو کہ وہ خدا کے علم سے اُترا ہے اور یہ کہ اس کے سوا کوئی معبود نہیں تو تمہیں بھی اسلام لے آنا چاہئیے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mcdlxxxviii{جو لوگ دنیا کی زندگی اور اس کی زیب و زینت کے طالب ہوں ہم ان کے اعمال کا بدلہ انہیں دنیا میں ہی دے دیتے ہیں اور اس میں ان کی حق تلفی نہیں کی جاتی\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mcdlxxxix{یہ وہ لوگ ہیں جن کے لیے آخرت میں آتش (جہنم) کے سوا کوئی چیز نہیں اور جو عمل انہوں نے دنیا میں کئے سب برباد اور جو کچھ وہ کرتے رہے، سب ضائع\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mcdxc{بھلا جو لوگ اپنے پروردگار کی طرف سے (روشن) دلیل رکھتے ہوں اور ان کے ساتھ ایک (آسمانی) گواہ بھی اس کی جانب سے ہو اور اس سے پہلے موسیٰ کی کتاب ہو جو پیشوا اور رحمت ہے (تو کیا وہ قرآن پر ایمان نہیں لائیں گے) یہی لوگ اس پر ایمان لاتے ہیں اور جو کوئی اور فرقوں میں سے اس سے منکر ہو تو اس کا ٹھکانہ آگ ہے۔ تو تم اس (قرآن) سے شک میں نہ ہونا۔ یہ تمہارے پروردگار کی طرف سے حق ہے لیکن اکثر لوگ ایمان نہیں لاتے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mcdxci{اور اس سے بڑھ کر ظالم کون ہوگا جو خدا پر جھوٹ افتراء کرے ایسے لوگ خدا کے سامنے پیش کئے جائیں گے اور گواہ کہیں گے کہ یہی لوگ ہیں جنہوں نے اپنے پروردگار پر جھوٹ بولا تھا۔ سن رکھو کہ ظالموں پر الله کی لعنت ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mcdxcii{جو خدا کے رستے سے روکتے ہیں اور اس میں کجی چاہتے ہیں اور وہ آخرت سے بھی انکار کرتے ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mcdxciii{یہ لوگ زمین میں (کہیں بھاگ کر خدا کو) نہیں ہرا سکتے اور نہ خدا کے سوا کوئی ان کا حمایتی ہے۔ (اے پیغمبر) ان کو دگنا عذاب دیا جائے گا کیونکہ یہ (شدت کفر سے تمہاری بات) نہیں سن سکتے تھے اور نہ (تم کو) دیکھ سکتے تھے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mcdxciv{یہی ہیں جنہوں نے اپنے تئیں خسارے میں ڈالا اور جو کچھ وہ افتراء کیا کرتے تھے ان سے جاتا رہا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mcdxcv{بلاشبہ یہ لوگ آخرت میں سب سے زیادہ نقصان پانے والے ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mcdxcvi{جو لوگ ایمان لائے اور عمل نیک کئے اور اپنے پروردگار کے آگے عاجزی کی۔ یہی صاحب جنت ہیں اور ہمیشہ اس میں رہیں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mcdxcvii{دونوں فرقوں (یعنی کافرومومن) کی مثال ایسی ہے جیسے ایک اندھا بہرا ہو اور ایک دیکھتا سنتا۔ بھلا دونوں کا حال یکساں ہوسکتا ہے؟ پھر تم سوچتے کیوں نہیں؟\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mcdxcviii{اور ہم نے نوح کو ان کی قوم کی طرف بھیجا (تو انہوں نے ان سے کہا) کہ میں تم کو کھول کھول کر ڈر سنانے اور پیغام پہنچانے آیا ہوں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mcdxcix{کہ خدا کے سوا کسی کی عبادت نہ کرو۔ مجھے تمہاری نسبت عذاب الیم کا خوف ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@md{تو ان کی قوم کے سردار جو کافر تھے کہنے لگے کہ ہم تم کو اپنے ہی جیسا ایک آدمی دیکھتے ہیں اور یہ بھی دیکھتے ہیں کہ تمہارے پیرو وہی لوگ ہوئے ہیں جو ہم میں ادنیٰ درجے کے ہیں۔ اور وہ بھی رائے ظاہر سے (نہ غوروتعمق سے) اور ہم تم میں اپنے اوپر کسی طرح کی فضیلت نہیں دیکھتے بلکہ تمہیں جھوٹا خیال کرتے ہیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mdi{انہوں نے کہا کہ اے قوم! دیکھو تو اگر میں اپنے پروردگار کی طرف سے دلیل (روشن) رکھتا ہوں اور اس نے مجھے اپنے ہاں سے رحمت بخشی ہو جس کی حقیقت تم سے پوشیدہ رکھی گئی ہے۔ تو کیا ہم اس کے لیے تمہیں مجبور کرسکتے ہیں اور تم ہو کہ اس سے ناخوش ہو رہے ہو\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mdii{اور اے قوم! میں اس (نصیحت) کے بدلے تم سے مال وزر کا خواہاں نہیں ہوں، میرا صلہ تو خدا کے ذمے ہے اور جو لوگ ایمان لائے ہیں، میں ان کو نکالنے والا بھی نہیں ہوں۔ وہ تو اپنے پروردگار سے ملنے والے ہیں لیکن میں دیکھتا ہوں کہ تم لوگ نادانی کر رہے ہو\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mdiii{اور برادران ملت! اگر میں ان کو نکال دوں تو (عذاب) خدا سے (بچانے کے لیے) کون میری مدد کرسکتا ہے۔ بھلا تم غور کیوں نہیں کرتے؟\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mdiv{میں نہ تم سے یہ کہتا ہوں کہ میرے پاس خدا کے خزانے ہیں اور نہ یہ کہ میں غیب جانتا ہوں اور نہ یہ کہتا ہوں کہ میں فرشتہ ہوں اور نہ ان لوگوں کی نسبت جن کو تم حقارت کی نظر سے دیکھتے ہو یہ کہتا ہوں کہ خدا ان کو بھلائی (یعنی اعمال کی جزائے نیک) نہیں دے گا جو ان کے دلوں میں ہے اسے خدا خوب جانتا ہے۔ اگر میں ایسا کہوں تو بےانصافوں میں ہوں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mdv{انہوں نے کہا کہ نوح تم نے ہم سے جھگڑا تو کیا اور جھگڑا بھی بہت کیا۔ لیکن اگر سچے ہو تو جس چیز سے ہمیں ڈراتے ہو وہ ہم پر لا نازل کرو\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mdvi{نوح نے کہا کہ اس کو خدا ہی چاہے گا تو نازل کرے گا۔ اور تم (اُس کو کسی طرح) ہرا نہیں سکتے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mdvii{اور اگر میں یہ چاہوں کہ تمہاری خیرخواہی کروں اور خدا یہ چاہے وہ تمہیں گمراہ کرے تو میری خیرخواہی تم کو کچھ فائدہ نہیں دے سکتی۔ وہی تمہارا پروردگار ہے اور تمہیں اس کی طرف لوٹ کر جانا ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mdviii{کیا یہ کہتے ہیں کہ اس (پیغمبر) نے یہ قرآن اپنے دل سے بنا لیا ہے۔ کہہ دو کہ اگر میں نے دل سے بنالیا ہے تو میرے گناہ کا وبال مجھ پر اور جو گناہ تم کرتے ہو اس سے میں بری الذمہ ہوں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mdix{اور نوح کی طرف وحی کی گئی کہ تمہاری قوم میں جو لوگ ایمان (لاچکے)، ان کے سوا کوئی اور ایمان نہیں لائے گا تو جو کام یہ کر رہے ہیں ان کی وجہ سے غم نہ کھاؤ\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mdx{اور ایک کشتی ہمارے حکم سے ہمارے روبرو بناؤ۔ اور جو لوگ ظالم ہیں ان کے بارے میں ہم سے کچھ نہ کہنا کیونکہ وہ ضرور غرق کردیئے جائیں گے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mdxi{تو نوح نے کشتی بنانی شروع کردی۔ اور جب ان کی قوم کے سردار ان کے پاس سے گزرتے تو ان سے تمسخر کرتے۔ وہ کہتے کہ اگر تم ہم سے تمسخر کرتے ہو تو جس طرح تم ہم سے تمسخر کرتے ہو اس طرح (ایک وقت) ہم بھی تم سے تمسخر کریں گے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mdxii{اور تم کو جلد معلوم ہوجائے گا کہ کس پر عذاب آتا ہے اور جو اسے رسوا کرے گا اور کس پر ہمیشہ کا عذاب نازل ہوتا ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mdxiii{یہاں تک کہ جب ہمارا حکم آپہنچا اور تنور جوش مارنے لگا تو ہم نے نوح کو حکم دیا کہ ہر قسم (کے جانداروں) میں سے جوڑا جوڑا (یعنی) دو (دو جانور۔ ایک ایک نر اور ایک ایک مادہ) لے لو اور جس شخص کی نسبت حکم ہوچکا ہے (کہ ہلاک ہوجائے گا) اس کو چھوڑ کر اپنے گھر والوں کو جو ایمان لایا ہو اس کو کشتی میں سوار کر لو اور ان کے ساتھ ایمان بہت ہی کم لوگ لائے تھے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mdxiv{نوح نے) کہا کہ خدا کا نام لے کر (کہ اسی کے ہاتھ میں اس کا) چلنا اور ٹھہرنا (ہے) اس میں سوار ہوجاؤ۔ بےشک میرا پروردگار بخشنے والا مہربان ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mdxv{اور وہ ان کو لے کر (طوفان کی) لہروں میں چلنے لگی۔ (لہریں کیا تھیں) گویا پہاڑ (تھے) اس وقت نوح نے اپنے بیٹے کو کہ جو (کشتی سے) الگ تھا، پکارا کہ بیٹا ہمارے ساتھ سوار ہوجا اور کافروں میں شامل نہ ہو\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mdxvi{اس نے کہا کہ میں (ابھی) پہاڑ سے جا لگوں گا، وہ مجھے پانی سے بچالے گا۔ انہوں نے کہا کہ آج خدا کے عذاب سے کوئی بچانے والا نہیں (اور نہ کوئی بچ سکتا ہے) مگر جس پر خدا رحم کرے۔ اتنے میں دونوں کے درمیان لہر آحائل ہوئی اور وہ ڈوب کر رہ گیا\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mdxvii{اور حکم دیا گیا کہ اے زمین اپنا پانی نگل جا اور اے آسمان تھم جا۔ تو پانی خشک ہوگیا اور کام تمام کردیا گیا اور کشی کوہ جودی پر جا ٹھہری۔ اور کہہ دیا گیا کہ بےانصاف لوگوں پر لعنت\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mdxviii{اور نوح نے اپنے پروردگار کو پکارا اور کہا کہ پروردگار میرا بیٹا بھی میرے گھر والوں میں ہے (تو اس کو بھی نجات دے) تیرا وعدہ سچا ہے اور تو سب سے بہتر حاکم ہے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mdxix{خدا نے فرمایا کہ نوح وہ تیرے گھر والوں میں نہیں ہے وہ تو ناشائستہ افعال ہے تو جس چیز کی تم کو حقیقت معلوم نہیں ہے اس کے بارے میں مجھ سے سوال ہی نہ کرو۔ اور میں تم کو نصیحت کرتا ہوں کہ نادان نہ بنو\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mdxx{نوح نے کہا پروردگار میں تجھ سے پناہ مانگتا ہوں کہ ایسی چیز کا تجھ سے سوال کروں جس کی حقیقت مجھے معلوم نہیں۔ اور اگر تو مجھے نہیں بخشے گا اور مجھ پر رحم نہیں کرے گا تو میں تباہ ہوجاؤں گا\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mdxxi{حکم ہوا کہ نوح ہماری طرف سے سلامتی اور برکتوں کے ساتھ (جو) تم پر اور تمہارے ساتھ کی جماعتوں پر (نازل کی گئی ہیں) اتر آؤ۔ اور کچھ اور جماعتیں ہوں گی جن کو ہم (دنیا کے فوائد سے) محظوظ کریں گے پھر ان کو ہماری طرف سے عذاب الیم پہنچے گا\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mdxxii{یہ (حالات) منجملہ غیب کی خبروں کے ہیں جو ہم تمہاری طرف بھیجتے ہیں۔ اور اس سے پہلے نہ تم ہی ان کو جانتے تھے اور نہ تمہاری قوم (ہی ان سے واقف تھی) تو صبر کرو کہ انجام پرہیزگاروں ہی کا (بھلا) ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mdxxiii{اور ہم نے عاد کی طرف ان کے بھائی ہود (کو بھیجا) انہوں نے کہا کہ میری قوم! خدا ہی کی عبادت کرو، اس کے سوا تمہارا کوئی معبود نہیں۔ تم (شرک کرکے خدا پر) محض بہتان باندھتے ہو\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mdxxiv{میری قوم! میں اس (وعظ و نصیحت) کا تم سے کچھ صلہ نہیں مانگتا۔ میرا صلہ تو اس کے ذمّے ہے جس نے مجھے پیدا کیا۔ بھلا تم سمجھتے کیوں نہیں؟\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mdxxv{اور اے قوم! اپنے پروردگار سے بخشش مانگو پھر اس کے آگے توبہ کرو۔ وہ تم پر آسمان سے موسلادھار مینہ برسائے گا اور تمہاری طاقت پر طاقت بڑھائے گا اور (دیکھو) گنہگار بن کر روگردانی نہ کرو\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mdxxvi{وہ بولے ہود تم ہمارے پاس کوئی دلیل ظاہر نہیں لائے اور ہم (صرف) تمہارے کہنے سے نہ اپنے معبودوں کو چھوڑنے والے ہیں اور نہ تم پر ایمان لانے والے ہیں\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mdxxvii{ہم تو یہ سمجھتے ہیں کہ ہمارے کسی معبود نے تمہیں آسیب پہنچا کر (دیوانہ کر) دیا ہے۔ انہوں نے کہا کہ میں خدا کو گواہ کرتا ہوں اور تم بھی گواہ رہو کہ جن کو تم (خدا کا) شریک بناتے ہو میں اس سے بیزار ہوں\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mdxxviii{یعنی جن کی) خدا کے سوا (عبادت کرتے ہو تو) تم سب مل کر میرے بارے میں جو تدبیر (کرنی چاہو) کرلو اور مجھے مہلت نہ دو\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mdxxix{میں خدا پر جو میرا اور تمہارا (سب کا) پروردگار ہے، بھروسہ رکھتا ہوں (زمین پر) جو چلنے پھرنے والا ہے وہ اس کو چوٹی سے پکڑے ہوئے ہے۔ بےشک میرا پروردگار سیدھے رستے پر ہے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mdxxx{اگر تم روگردانی کرو گے تو جو پیغام میرے ہاتھ تمہاری طرف بھیجا گیا ہے، وہ میں نے تمہیں پہنچا دیا ہے۔ اور میرا پروردگار تمہاری جگہ اور لوگوں کو لابسائے گا۔ اور تم خدا کا کچھ بھی نقصان نہیں کرسکتے۔ میرا پروردگار تو ہر چیز پر نگہبان ہے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mdxxxi{اور جب ہمارا حکم عذاب آپہنچا تو ہم نے ہود کو اور جو لوگ ان کے ساتھ ایمان لائے تھے ان کو اپنی مہربانی سے بچا لیا۔ اور ان کو عذاب شدید سے نجات دی\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mdxxxii{یہ (وہی) عاد ہیں جنہوں نے خدا کی نشانیوں سے انکار کیا اور اس کے پیغمبروں کی نافرمانی کی اور ہر متکبر وسرکش کا کہا مانا\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mdxxxiii{تو اس دنیا میں بھی لعنت ان کے پیچھے لگی رہے گی اور قیامت کے دن بھی (لگی رہے گی) دیکھو عاد نے اپنے پروردگار سے کفر کیا۔ (اور) سن رکھو ہود کی قوم عاد پر پھٹکار ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mdxxxiv{اور ثمود کی طرف ان کے بھائی صالح کو (بھیجا) تو انہوں نے کہا کہ قوم! خدا ہی کی عبادت کرو اس کے سوا تمہارا کوئی معبود نہیں۔ اسی نے تم کو زمین سے پیدا کیا اور اس میں آباد کیا تو اس سے مغفرت مانگو اور اس کے آگے توبہ کرو۔ بےشک میرا پروردگار نزدیک (بھی ہے اور دعا کا) قبول کرنے والا (بھی) ہے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mdxxxv{انہوں نے کہا کہ صالح اس سے پہلے ہم تم سے (کئی طرح کی) امیدیں رکھتے تھے (اب وہ منقطع ہوگئیں) کیا تم ہم کو ان چیزوں کے پوجنے سے منع کرتے ہو جن کو ہمارے بزرگ پوجتے آئے ہیں؟ اور جس بات کی طرف تم ہمیں بلاتے ہو، اس میں ہمیں قوی شبہ ہے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mdxxxvi{صالح نے کہا اے قوم! بھلا دیکھو تو اگر میں اپنے پروردگار کی طرف سے کھلی دلیل پر ہوں اور اس نے مجھے اپنے ہاں سے (نبوت کی) نعمت بخشی ہو تو اگر میں خدا کی نافرمانی کروں تو اس کے سامنے میری کون مدد کرے گا؟ تم تو (کفر کی باتوں سے) میرا نقصان کرتے ہو\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mdxxxvii{اور یہ بھی کہا کہ اے قوم! یہ خدا کی اونٹنی تمہارے لیے ایک نشانی (یعنی معجزہ) ہے تو اس کو چھوڑ دو کہ خدا کی زمین میں (جہاں چاہے) چرے اور اس کو کسی طرح کی تکلیف نہ دینا ورنہ تمہیں جلد عذاب آپکڑے گا\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mdxxxviii{مگر انہوں نے اس کی کانچیں کاٹ ڈالیں۔ تو (صالح نے) کہا کہ اپنے گھروں میں تم تین دن (اور) فائدہ اٹھا لو۔ یہ وعدہ ہے کہ جھوٹا نہ ہوگا\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mdxxxix{جب ہمارا حکم آگیا تو ہم نے صالح کو اور جو لوگ ان کے ساتھ ایمان لائے تھے ان کو اپنی مہربانی سے بچالیا۔ اور اس دن کی رسوائی سے (محفوظ رکھا) ۔ بےشک تمہارا پروردگار طاقتور اور زبردست ہے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mdxl{اور جن لوگوں نے ظلم کیا تھا ان کو چنگھاڑ (کی صورت میں عذاب) نے آپکڑا تو وہ اپنے گھروں میں اوندھے پڑے رہ گئے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mdxli{گویا کبھی ان میں بسے ہی نہ تھے۔ سن رکھو کہ ثمود نے اپنے پروردگار سے کفر کیا۔ اور سن رکھو ثمود پر پھٹکار ہے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mdxlii{اور ہمارے فرشتے ابراہیم کے پاس بشارت لے کر آئے تو سلام کہا۔ انہوں نے بھی (جواب میں) سلام کہا۔ ابھی کچھ وقفہ نہیں ہوا تھا کہ (ابراہیم) ایک بھنا ہوا بچھڑا لے آئے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mdxliii{جب دیکھا کہ ان کے ہاتھ کھانے کی طرف نہیں جاتے (یعنی وہ کھانا نہیں کھاتے) تو ان کو اجنبی سمجھ کر دل میں خوف کیا۔ (فرشتوں نے) کہا کہ خوف نہ کیجیے، ہم قوم لوط کی طرف (ان کے ہلاک کرنے کو) بھیجے گئے ہیں\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mdxliv{اور ابراہیم کی بیوی (جو پاس) کھڑی تھی، ہنس پڑی تو ہم نے اس کو اسحاق کی اور اسحاق کے بعد یعقوب کی خوشخبری دی\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mdxlv{اس نے کہا اے ہے میرے بچہ ہوگا؟ میں تو بڑھیا ہوں اور میرے میاں بھی بوڑھے ہیں۔ یہ تو بڑی عجیب بات ہے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mdxlvi{انہوں نے کہا کیا تم خدا کی قدرت سے تعجب کرتی ہو؟ اے اہل بیت تم پر خدا کی رحمت اور اس کی برکتیں ہیں۔ وہ سزاوار تعریف اور بزرگوار ہے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mdxlvii{جب ابراہیم سے خوف جاتا رہا اور ان کو خوشخبری بھی مل گئی تو قوم لوط کے بارے میں لگے ہم سے بحث کرنے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mdxlviii{بےشک ابراہیم بڑے تحمل والے، نرم دل اور رجوع کرنے والے تھے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mdxlix{اے ابراہیم اس بات کو جانے دو۔ تمہارے پروردگار کا حکم آپہنچا ہے۔ اور ان لوگوں پر عذاب آنے والا ہے جو کبھی نہیں ٹلنے کا\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mdl{اور جب ہمارے فرشتے لوط کے پاس آئے تو وہ ان (کے آنے) سے غمناک اور تنگ دل ہوئے اور کہنے لگے کہ آج کا دن بڑی مشکل کا دن ہے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mdli{اور لوط کی قوم کے لوگ ان کے پاس بےتحاشا دوڑتے ہوئے آئے اور یہ لوگ پہلے ہی سے فعل شنیع کیا کرتے تھے۔ لوط نے کہا کہ اے قوم! یہ (جو) میری (قوم کی) لڑکیاں ہیں، یہ تمہارے لیے (جائز اور) پاک ہیں۔ تو خدا سے ڈرو اور میرے مہمانوں کے (بارے) میں میری آبرو نہ کھوؤ۔ کیا تم میں کوئی بھی شائستہ آدمی نہیں\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mdlii{وہ بولے تم کو معلوم ہے کہ تمہاری (قوم کی) بیٹیوں کی ہمیں کچھ حاجت نہیں۔ اور جو ہماری غرض ہے اسے تم (خوب) جانتے ہو\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mdliii{لوط نے کہا اے کاش مجھ میں تمہارے مقابلے کی طاقت ہوتی یا کسی مضبوط قلعے میں پناہ پکڑ سکتا\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mdliv{فرشتوں نے کہا کہ لوط ہم تمہارے پروردگار کے فرشتے ہیں۔ یہ لوگ ہرگز تم تک نہیں پہنچ سکیں گے تو کچھ رات رہے سے اپنے گھر والوں کو لے کر چل دو اور تم میں سے کوئی شخص پیچھے پھر کر نہ دیکھے۔ مگر تمہاری بیوی کہ جو آفت ان پر پڑنے والی ہے وہی اس پر پڑے گی۔ ان کے (عذاب کے) وعدے کا وقت صبح ہے۔ اور کیا صبح کچھ دور ہے؟\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mdlv{تو جب ہمارا حکم آیا ہم نے اس (بستی) کو (اُلٹ کر) نیچے اوپر کردیا اور ان پر پتھر کی تہہ بہ تہہ (یعنی پےدرپے) کنکریاں برسائیں\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mdlvi{جن پر تمہارے پروردگار کے ہاں سے نشان کئے ہوئے تھے اور وہ بستی ان ظالموں سے کچھ دور نہیں\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mdlvii{اور مدین کی طرف ان کے بھائی شعیب کو (بھیجا) تو اُنہوں نے کہا کہ اے قوم! خدا ہی کی عبادت کرو کہ اس کے سوا تمہارا کوئی معبود نہیں۔ اور ناپ تول میں کمی نہ کیا کرو۔ میں تو تم کو آسودہ حال دیکھتا ہوں اور (اگر تم ایمان نہ لاؤ گے تو) مجھے تمہارے بارے میں ایک ایسے دن کے عذاب کا خوف ہے جو تم کو گھیر کر رہے گا\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mdlviii{اور قوم! ماپ اور تول انصاف کے ساتھ پوری پوری کیا کرو اور لوگوں کو ان کی چیزیں کم نہ دیا کرو اور زمین میں خرابی کرتے نہ پھرو\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mdlix{اگر تم کو (میرے کہنے کا) یقین ہو تو خدا کا دیا ہوا نفع ہی تمہارے لیے بہتر ہے اور میں تمہارا نگہبان نہیں ہوں\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mdlx{انہوں نے کہا شعیب کیا تمہاری نماز تمہیں یہ سکھاتی ہے کہ جن کو ہمارے باپ دادا پوجتے آئے ہیں ہم ان کو ترک کر دیں یا اپنے مال میں تصرف کرنا چاہیں تو نہ کریں۔ تم تو بڑے نرم دل اور راست باز ہو\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mdlxi{انہوں نے کہا کہ اے قوم! دیکھو تو اگر میں اپنے پروردگار کی طرف سے دلیل روشن پر ہوں اور اس نے اپنے ہاں سے مجھے نیک روزی دی ہو (تو کیا میں ان کے خلاف کروں گا؟) اور میں نہیں چاہتا کہ جس امر سے میں تمہیں منع کروں خود اس کو کرنے لگوں۔ میں تو جہاں تک مجھ سے ہوسکے (تمہارے معاملات کی) اصلاح چاہتا ہوں اور (اس بارے میں) مجھے توفیق کا ملنا خدا ہی (کے فضل) سے ہے۔ میں اسی پر بھروسہ رکھتا ہوں اور اس کی طرف رجوع کرتا ہوں\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mdlxii{اور اے قوم! میری مخالفت تم سے کوئی ایسا کام نہ کرادے کہ جیسی مصیبت نوح کی قوم یا ہود کی قوم یا صالح کی قوم پر واقع ہوئی تھی ویسی ہی مصیبت تم پر واقع ہو۔ اور لوط کی قوم (کا زمانہ تو) تم سے کچھ دور نہیں\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mdlxiii{اور اپنے پروردگار سے بخشش مانگو اور اس کے آگے توبہ کرو۔ بےشک میرا پروردگار رحم والا (اور) محبت والا ہے\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mdlxiv{اُنہوں نے کہا کہ شعیب تمہاری بہت سی باتیں ہماری سمجھ میں نہیں آتیں اور ہم دیکھتے ہیں کہ تم ہم میں کمزور بھی ہو اور اگر تمہارے بھائی نہ ہوتے تو ہم تم کو سنگسار کر دیتے اور تم ہم پر (کسی طرح بھی) غالب نہیں ہو\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mdlxv{انہوں نے کہا کہ قوم! کیا میرے بھائی بندوں کا دباؤ تم پر خدا سے زیادہ ہے۔ اور اس کو تم نے پیٹھ پیچھے ڈال رکھا ہے۔ میرا پروردگار تو تمہارے سب اعمال پر احاطہ کیے ہوئے ہے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mdlxvi{اور برادران ملت! تم اپنی جگہ کام کیے جاؤ میں (اپنی جگہ) کام کیے جاتا ہوں۔ تم کو عنقریب معلوم ہوجائے گا کہ رسوا کرنے والا عذاب کس پر آتا ہے اور جھوٹا کون ہے اور تم بھی انتظار کرو، میں بھی تمہارے ساتھ انتظار کرتا ہوں\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mdlxvii{اور جب ہمارا حکم آپہنچا تو ہم نے شعیب کو اور جو لوگ ان کے ساتھ ایمان لائے تھے ان کو تو اپنی رحمت سے بچا لیا۔ اور جو لوگ ظالم تھے، ان کو چنگھاڑ نے آدبوچا تو وہ اپنے گھروں میں اوندھے پڑے رہ گئے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mdlxviii{گویا ان میں کبھی بسے ہی نہ تھے۔ سن رکھو کہ مدین پر (ویسی ہی) پھٹکار ہے جیسی ثمود پر پھٹکار تھی\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mdlxix{اور ہم نے موسیٰ کو اپنی نشانیاں اور دلیل روشن دے کر بھیجا\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mdlxx{یعنی) فرعون اور اس کے سرداروں کی طرف۔ تو وہ فرعون ہی کے حکم پر چلے۔ اور فرعون کا حکم درست نہیں تھا\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mdlxxi{وہ قیامت کے دن اپنی قوم کے آگے آگے چلے گا اور ان کو دوزخ میں جا اُتارے گا اور جس مقام پر وہ اُتارے جائیں گے وہ برا ہے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mdlxxii{اور اس جہان میں بھی لعنت ان کے پیچھے لگا دی گئی اور قیامت کے دن بھی (پیچھے لگی رہے گی) ۔ جو انعام ان کو ملا ہے برا ہے\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mdlxxiii{یہ (پرانی) بستیوں کے تھوڑے سے حالات ہیں جو ہم تم سے بیان کرتے ہیں۔ ان میں سے بعض تو باقی ہیں اور بعض کا تہس نہس ہوگیا\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mdlxxiv{اور ہم نے ان لوگوں پر ظلم نہیں کیا بلکہ انہوں نے خود اپنے اُوپر ظلم کیا۔ غرض جب تمہارے پروردگار کا حکم آپہنچا تو جن معبودوں کو وہ خدا کے سوا پکارا کرتے تھے وہ ان کے کچھ بھی کام نہ آئے۔ اور تباہ کرنے کے سوا ان کے حق میں اور کچھ نہ کرسکے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mdlxxv{اور تمہارا پروردگار جب نافرمان بستیوں کو پکڑا کرتا ہے تو اس کی پکڑ اسی طرح کی ہوتی ہے۔ بےشک اس کی پکڑ دکھ دینے والی اور سخت ہے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mdlxxvi{ان (قصوں) میں اس شخص کے لیے جو عذاب آخرت سے ڈرے عبرت ہے۔ یہ وہ دن ہوگا جس میں سب لوگ اکٹھے کیے جائیں گے اور یہی وہ دن ہوگا جس میں سب (خدا کے روبرو) حاضر کیے جائیں گے\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mdlxxvii{اور ہم اس کے لانے میں ایک وقت معین تک تاخیر کر رہے ہیں\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mdlxxviii{جس روز وہ آجائے گا تو کوئی متنفس خدا کے حکم کے بغیر بول بھی نہیں سکے گا۔ پھر ان میں سے کچھ بدبخت ہوں گے اور کچھ نیک بخت\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mdlxxix{تو جو بدبخت ہوں گے وہ دوزخ میں (ڈال دیئے جائیں گے) اس میں ان کا چلانا اور دھاڑنا ہوگا\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mdlxxx{اور) جب تک آسمان اور زمین ہیں، اسی میں رہیں گے مگر جتنا تمہارا پروردگار چاہے۔ بےشک تمہارا پروردگار جو چاہتا ہے کردیتا ہے\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mdlxxxi{اور جو نیک بخت ہوں گے، وہ بہشت میں داخل کیے جائیں گے اور جب تک آسمان اور زمین ہیں ہمیشہ اسی میں رہیں گے مگر جتنا تمہارا پروردگار چاہے۔ بےشک تمہارا پروردگار جو چاہتا ہے کردیتا ہے۔ اور جو نیک بخت ہوں گے وہ بہشت میں داخل کئے جائیں گے (اور) جب تک آسمان اور زمین ہیں ہمیشہ اسی میں رہیں گے۔ مگر جتنا تمہارا پروردگار چاہے۔ یہ (خدا کی) بخشش ہے جو کبھی منقطع نہیں ہوگی\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mdlxxxii{تو یہ لوگ جو (غیر خدا کی) پرستش کرتے ہیں۔ اس سے تم خلجان میں نہ پڑنا۔ یہ اسی طرح پرستش کرتے ہیں جس طرح پہلے سے ان کے باپ دادا پرستش کرتے آئے ہیں۔ اور ہم ان کو ان کا حصہ پورا پورا بلا کم وکاست دینے والے ہیں\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mdlxxxiii{اور ہم نے موسیٰ کو کتاب دی تو اس میں اختلاف کیا گیا اور اگر تمہارے پروردگار کی طرف سے ایک بات پہلے نہ ہوچکی ہوتی تو ان میں فیصلہ کردیا جاتا۔ اور وہ تو اس سے قوی شبہے میں (پڑے ہوئے) ہیں\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mdlxxxiv{اور تمہارا پروردگار ان سب کو (قیامت کے دن) ان کے اعمال کا پورا پورا بدلہ دے گا۔ بےشک جو عمل یہ کرتے ہیں وہ اس سے واقف ہے\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mdlxxxv{سو (اے پیغمبر) جیسا تم کو حکم ہوتا ہے (اس پر) تم اور جو لوگ تمہارے ساتھ تائب ہوئے ہیں قائم رہو۔ اور حد سے تجاوز نہ کرنا۔ وہ تمہارے سب اعمال کو دیکھ رہا ہے\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mdlxxxvi{اور جو لوگ ظالم ہیں، ان کی طرف مائل نہ ہونا، نہیں تو تمہیں (دوزخ کی) آگ آلپٹے گی اور خدا کے سوا تمہارے اور دوست نہیں ہیں۔ اگر تم ظالموں کی طرف مائل ہوگئے تو پھر تم کو (کہیں سے) مدد نہ مل سکے گی\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mdlxxxvii{اور دن کے دونوں سروں (یعنی صبح اور شام کے اوقات میں) اور رات کی چند (پہلی) ساعات میں نماز پڑھا کرو۔ کچھ شک نہیں کہ نیکیاں گناہوں کو دور کر دیتی ہیں۔ یہ ان کے لیے نصیحت ہے جو نصیحت قبول کرنے والے ہیں\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mdlxxxviii{اور صبر کیے رہو کہ خدا نیکوکاروں کا اجر ضائع نہیں کرتا\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mdlxxxix{تو جو اُمتیں تم سے پہلے گزر چکی ہیں، ان میں ایسے ہوش مند کیوں نہ ہوئے جو ملک میں خرابی کرنے سے روکتے ہاں (ایسے) تھوڑے سے (تھے) جن کو ہم نے ان میں سے مخلصی بخشی۔ اور جو ظالم تھے وہ ان ہی باتوں کے پیچھے لگے رہے جس میں عیش وآرام تھا اور وہ گناہوں میں ڈوبے ہوئے تھے\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mdxc{اور تمہارا پروردگار ایسا نہیں ہے کہ بستیوں کو جب کہ وہاں کے باشندے نیکوکار ہوں ازراہِ ظلم تباہ کردے\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mdxci{اور اگر تمہارا پروردگار چاہتا تو تمام لوگوں کو ایک ہی جماعت کردیتا لیکن وہ ہمیشہ اختلاف کرتے رہیں گے\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mdxcii{مگر جن پر تمہارا پروردگار رحم کرے۔ اور اسی لیے اس نے ان کو پیدا کیا ہے اور تمہارے پروردگار کا قول پورا ہوگیا کہ میں دوزخ کو جنوں اور انسانوں سب سے بھر دوں گا\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mdxciii{اے محمدﷺ) اور پیغمبروں کے وہ سب حالات جو ہم تم سے بیان کرتے ہیں ان سے ہم تمہارے دل کو قائم رکھتے ہیں۔ اور ان (قصص) میں تمہارے پاس حق پہنچ گیا اور یہ مومنوں کے لیے نصیحت اور عبرت ہے\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mdxciv{اور جو لوگ ایمان نہیں لائے ان سے کہہ دو کہ تم اپنی جگہ عمل کیے جاؤ۔ ہم اپنی جگہ عمل کیے جاتے ہیں\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mdxcv{اور (نتیجہٴ اعمال کا) تم بھی انتظار کرو، ہم بھی انتظار کرتے ہیں\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mdxcvi{اور آسمانوں اور زمین کی چھپی چیزوں کا علم خدا ہی کو ہے اور تمام امور کا رجوع اسی کی طرف ہے۔ تو اسی کی عبادت کرو اور اسی پر بھروسہ رکھو۔ اور جو کچھ تم کررہے ہو تمہارا پروردگار اس سے بےخبر نہیں\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mdxcvii{\basmalahur الٓرا۔ یہ کتاب روشن کی آیتیں ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mdxcviii{ہم نے اس قرآن کو عربی میں نازل کیا ہے تاکہ تم سمجھ سکو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mdxcix{اے پیغمبر) ہم اس قرآن کے ذریعے سے جو ہم نے تمہاری طرف بھیجا ہے تمہیں ایک نہایت اچھا قصہ سناتے ہیں اور تم اس سے پہلے بےخبر تھے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mdc{جب یوسف نے اپنے والد سے کہا کہ ابا میں نے (خواب میں) گیارہ ستاروں اور سورج اور چاند کو دیکھا ہے۔ دیکھتا (کیا) ہوں کہ وہ مجھے سجدہ کر رہے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mdci{انہوں نے کہا کہ بیٹا اپنے خواب کا ذکر اپنے بھائیوں سے نہ کرنا نہیں تو وہ تمہارے حق میں کوئی فریب کی چال چلیں گے۔ کچھ شک نہیں کہ شیطان انسان کا کھلا دشمن ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mdcii{اور اسی طرح خدا تمہیں برگزیدہ (وممتاز) کرے گا اور (خواب کی) باتوں کی تعبیر کا علم سکھائے گا۔ اور جس طرح اس نے اپنی نعمت پہلے تمہارے دادا، پردادا ابراہیم اور اسحاق پر پوری کی تھی اسی طرح تم پر اور اولاد یعقوب پر پوری کرے گا۔ بےشک تمہارا پروردگار (سب کچھ) جاننے والا (اور) حکمت والا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mdciii{ہاں یوسف اور ان کے بھائیوں (کے قصے) میں پوچھنے والوں کے لیے (بہت سی) نشانیاں ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mdciv{جب انہوں نے (آپس میں) تذکرہ کیا کہ یوسف اور اس کا بھائی ابا کو ہم سے زیادہ پیارے ہیں حالانکہ ہم جماعت (کی جماعت) ہیں۔ کچھ شک نہیں کہ ابا صریح غلطی پر ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mdcv{تو یوسف کو (یا تو جان سے) مار ڈالو یا کسی ملک میں پھینک آؤ۔ پھر ابا کی توجہ صرف تمہاری طرف ہوجائے گی۔ اور اس کے بعد تم اچھی حالت میں ہوجاؤ گے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mdcvi{ان میں سے ایک کہنے والے نے کہا کہ یوسف کو جان سے نہ مارو کسی گہرے کنویں میں ڈال دو کہ کوئی راہگیر نکال (کر اور ملک میں) لے جائے گا۔ اگر تم کو کرنا ہے (تو یوں کرو)\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mdcvii{یہ مشورہ کر کے وہ یعقوب سے) کہنے لگے کہ اباجان کیا سبب ہے کہ آپ یوسف کے بارے میں ہمارا اعتبار نہیں کرتے حالانکہ ہم اس کے خیرخواہ ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mdcviii{کل اسے ہمارے ساتھ بھیج دیجیئے کہ خوب میوے کھائے اور کھیلے کودے۔ ہم اس کے نگہبان ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mdcix{انہوں نے کہا کہ یہ امر مجھے غمناک کئے دیتا ہے کہ تم اسے لے جاؤ (یعنی وہ مجھ سے جدا ہوجائے) اور مجھے یہ خوف بھی ہے کہ تم (کھیل میں) اس سے غافل ہوجاؤ اور اسے بھیڑیا کھا جائے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mdcx{وہ کہنے لگے کہ اگر ہماری موجودگی میں کہ ہم ایک طاقتور جماعت ہیں، اسے بھیڑیا کھا گیا تو ہم بڑے نقصان میں پڑگئے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mdcxi{غرض جب وہ اس کو لے گئے اور اس بات پر اتفاق کرلیا کہ اس کو گہرے کنویں میں ڈال دیں۔ تو ہم نے یوسف کی طرف وحی بھیجی کہ (ایک وقت ایسا آئے گا کہ) تم ان کے اس سلوک سے آگاہ کرو گے اور ان کو (اس وحی کی) کچھ خبر نہ ہوگی\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mdcxii{یہ حرکت کرکے) وہ رات کے وقت باپ کے پاس روتے ہوئے آئے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mdcxiii{اور) کہنے لگے کہ اباجان ہم تو دوڑنے اور ایک دوسرے سے آگے نکلنے میں مصروف ہوگئے اور یوسف کو اپنے اسباب کے پاس چھوڑ گئے تو اسے بھیڑیا کھا گیا۔ اور آپ ہماری بات کو گو ہم سچ ہی کہتے ہوں باور نہیں کریں گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mdcxiv{اور ان کے کرتے پر جھوٹ موٹ کا لہو بھی لگا لائے۔ یعقوب نے کہا (کہ حقیقت حال یوں نہیں ہے) بلکہ تم اپنے دل سے (یہ) بات بنا لائے ہو۔ اچھا صبر (کہ وہی) خوب (ہے) اور جو تم بیان کرتے ہو اس کے بارے میں خدا ہی سے مدد مطلوب ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mdcxv{اب خدا کی شان دیکھو کہ اس کنویں کے قریب) ایک قافلہ آوارد ہوا اور انہوں نے (پانی کے لیے) اپنا سقا بھیجا۔ اس نے کنویں میں ڈول لٹکایا (تو یوسف اس سے لٹک گئے) وہ بولا زہے قسمت یہ تو (نہایت حسین) لڑکا ہے۔ اور اس کو قیمتی سرمایہ سمجھ کر چھپا لیا اور جو کچھ وہ کرتے تھے خدا کو سب معلوم تھا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mdcxvi{اور اس کو تھوڑی سی قیمت (یعنی) معدودے چند درہموں پر بیچ ڈالا۔ اور انہیں ان (کے بارے) میں کچھ لالچ نہ تھا\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mdcxvii{اور مصر میں جس شخص نے اس کو خریدا اس نے اپنی بیوی سے (جس کا نام زلیخا تھا) کہا کہ اس کو عزت واکرام سے رکھو عجب نہیں کہ یہ ہمیں فائدہ دے یا ہم اسے بیٹا بنالیں۔ اس طرح ہم نے یوسف کو سرزمین (مصر) میں جگہ دی اور غرض یہ تھی کہ ہم ان کو (خواب کی) باتوں کی تعبیر سکھائیں اور خدا اپنے کام پر غالب ہے لیکن اکثر لوگ نہیں جانتے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mdcxviii{اور جب وہ اپنی جوانی کو پہنچے تو ہم نے ان کو دانائی اور علم بخشا۔ اور نیکوکاروں کو ہم اسی طرح بدلہ دیا کرتے ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mdcxix{تو جس عورت کے گھر میں وہ رہتے تھے اس نے ان کو اپنی طرف مائل کرنا چاہا اور دروازے بند کرکے کہنے لگی (یوسف) جلدی آؤ۔ انہوں نے کہا کہ خدا پناہ میں رکھے (وہ یعنی تمہارے میاں) تو میرے آقا ہیں انہوں نے مجھے اچھی طرح سے رکھا ہے (میں ایسا ظلم نہیں کرسکتا) بےشک ظالم لوگ فلاح نہیں پائیں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mdcxx{اور اس عورت نے ان کا قصد کیا اور انہوں نے اس کا قصد کیا۔ اگر وہ اپنے پروردگار کی نشانی نہ دیکھتے (تو جو ہوتا ہوتا) یوں اس لیے (کیا گیا) کہ ہم ان سے برائی اور بےحیائی کو روک دیں۔ بےشک وہ ہمارے خالص بندوں میں سے تھے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mdcxxi{اور دونوں دروازے کی طرف بھاگے (آگے یوسف اور پیچھے زلیخا) اور عورت نے ان کا کرتا پیچھے سے (پکڑ کر جو کھینچا تو) پھاڑ ڈالا اور دونوں کو دروازے کے پاس عورت کا خاوند مل گیا تو عورت بولی کہ جو شخص تمہاری بیوی کے ساتھ برا ارادہ کرے اس کی اس کے سوا کیا سزا ہے کہ یا تو قید کیا جائے یا دکھ کا عذاب دیا جائے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mdcxxii{یوسف نے کہا اسی نے مجھ کو اپنی طرف مائل کرنا چاہا تھا۔ اس کے قبیلے میں سے ایک فیصلہ کرنے والے نے فیصلہ کیا کہ اگر اس کا کرتا آگے سے پھٹا تو یہ سچی اور یوسف جھوٹا\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mdcxxiii{اور اگر کرتا پیچھے سے پھٹا ہو تو یہ جھوٹی اور وہ سچا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mdcxxiv{اور جب اس کا کرتا دیکھا (تو) پیچھے سے پھٹا تھا (تب اس نے زلیخا سے کہا) کہ یہ تمہارا ہی فریب ہے۔ اور کچھ شک نہیں کہ تم عورتوں کے فریب بڑے (بھاری) ہوتے ہیں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mdcxxv{یوسف اس بات کا خیال نہ کر۔ اور (زلیخا) تو اپنے گناہوں کی بخشش مانگ، بےشک خطا تیری ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mdcxxvi{اور شہر میں عورتیں گفتگوئیں کرنے لگیں کہ عزیز کی بیوی اپنے غلام کو اپنی طرف مائل کرنا چاہتی ہے۔ اور اس کی محبت اس کے دل میں گھر کرگئی ہے۔ ہم دیکھتی ہیں کہ وہ صریح گمراہی میں ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mdcxxvii{جب زلیخا نے ان عورتوں کی (گفتگو جو حقیقت میں دیدار یوسف کے لیے ایک) چال (تھی) سنی تو ان کے پاس (دعوت کا) پیغام بھیجا اور ان کے لیے ایک محفل مرتب کی۔ اور (پھل تراشنے کے لیے) ہر ایک کو ایک چھری دی اور (یوسف سے) کہا کہ ان کے سامنے باہر آؤ۔ جب عورتوں نے ان کو دیکھا تو ان کا رعب (حسن) ان پر (ایسا) چھا گیا کہ (پھل تراشتے تراشتے) اپنے ہاتھ کاٹ لیے اور بےساختہ بول اٹھیں کہ سبحان الله (یہ حسن) یہ آدمی نہیں کوئی بزرگ فرشتہ ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mdcxxviii{تب زلیخا نے کہا یہ وہی ہے جس کے بارے میں تم مجھے طعنے دیتی تھیں۔ اور بےشک میں نے اس کو اپنی طرف مائل کرنا چاہا مگر یہ بچا رہا۔ اور اگر یہ وہ کام نہ کرے گا جو میں اسے کہتی ہوں تو قید کردیا جائے گا اور ذلیل ہوگا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mdcxxix{یوسف نے دعا کی کہ پروردگار جس کام کی طرف یہ مجھے بلاتی ہیں اس کی نسبت مجھے قید پسند ہے۔ اور اگر تو مجھ سے ان کے فریب کو نہ ہٹائے گا تو میں ان کی طرف مائل ہوجاؤں گا اور نادانوں میں داخل ہوجاؤں گا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mdcxxx{تو خدا نے ان کی دعا قبول کرلی اور ان سے عورتوں کا مکر دفع کر دیا۔ بےشک وہ سننے (اور) جاننے والا ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mdcxxxi{پھر باوجود اس کے کہ وہ لوگ نشان دیکھ چکے تھے ان کی رائے یہی ٹھہری کہ کچھ عرصہ کے لیے ان کو قید ہی کردیں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mdcxxxii{اور ان کے ساتھ دو اور جوان بھی داخل زندان ہوئے۔ ایک نے ان میں سے کہا کہ (میں نے خواب دیکھا ہے) دیکھتا (کیا) ہوں کہ شراب (کے لیے انگور) نچوڑ رہا ہوں۔ دوسرے نے کہا کہ (میں نے بھی خواب دیکھا ہے) میں یہ دیکھتا ہوں کہ اپنے سر پر روٹیاں اٹھائے ہوئے ہوں اور جانور ان میں سے کھا رہے (ہیں تو) ہمیں ان کی تعبیر بتا دیجیئے کہ ہم تمہیں نیکوکار دیکھتے ہیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mdcxxxiii{یوسف نے کہا کہ جو کھانا تم کو ملنے والا ہے وہ آنے نہیں پائے گا کہ میں اس سے پہلے تم کو اس کی تعبیر بتادوں گا۔ یہ ان (باتوں) میں سے ہے جو میرے پروردگار نے مجھے سکھائی ہیں جو لوگ خدا پر ایمان نہیں لاتے اور روز آخرت سے انکار کرتے ہیں میں ان کا مذہب چھوڑے ہوئے ہوں\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mdcxxxiv{اور اپنے باپ دادا ابراہیم اور اسحاق اور یعقوب کے مذہب پر چلتا ہوں۔ ہمیں شایاں نہیں ہے کہ کسی چیز کو خدا کے ساتھ شریک بنائیں۔ یہ خدا کا فضل ہے ہم پر بھی اور لوگوں پر بھی ہے لیکن اکثر لوگ شکر نہیں کرتے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mdcxxxv{میرے جیل خانے کے رفیقو! بھلا کئی جدا جدا آقا اچھے یا (ایک) خدائے یکتا وغالب؟\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mdcxxxvi{جن چیزوں کی تم خدا کے سوا پرستش کرتے ہو وہ صرف نام ہی نام ہیں جو تم نے اور تمہارے باپ دادا نے رکھ لیے ہیں۔ خدا نے ان کی کوئی سند نازل نہیں کی۔ (سن رکھو کہ) خدا کے سوا کسی کی حکومت نہیں ہے۔ اس نے ارشاد فرمایا ہے کہ اس کے سوا کسی کی عبادت نہ کرو۔ یہی سیدھا دین ہے لیکن اکثر لوگ نہیں جانتے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mdcxxxvii{میرے جیل خانے کے رفیقو! تم میں سے ایک (جو پہلا خواب بیان کرنے والا ہے وہ) تو اپنے آقا کو شراب پلایا کرے گا اور جو دوسرا ہے وہ سولی دیا جائے گا اور جانور اس کا سر کھا جائیں گے۔ جو امر تم مجھ سے پوچھتے تھے وہ فیصلہ ہوچکا ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mdcxxxviii{اور دونوں شخصوں میں سے جس کی نسبت (یوسف نے) خیال کیا کہ وہ رہائی پا جائے گا اس سے کہا کہ اپنے آقا سے میرا ذکر بھی کرنا لیکن شیطان نے ان کا اپنے آقا سے ذکر کرنا بھلا دیا اور یوسف کئی برس جیل خانے میں رہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mdcxxxix{اور بادشاہ نے کہا کہ میں (نے خواب دیکھا ہے) دیکھتا (کیا) ہوں کہ سات موٹی گائیں ہیں جن کو سات دبلی گائیں کھا رہی ہیں اور سات خوشے سبز ہیں اور (سات) خشک۔ اے سردارو! اگر تم خوابوں کی تعبیر دے سکتے ہو تو مجھے میرے خواب کی تعبیر بتاؤ\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mdcxl{انہوں نے کہا یہ تو پریشان سے خواب ہیں۔ اور ہمیں ایسے خوابوں کی تعبیر نہیں آتی\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mdcxli{اب وہ شخص جو دونوں قیدیوں میں سے رہائی پا گیا تھا اور جسے مدت کے بعد وہ بات یاد آگئی بول اٹھا کہ میں آپ کو اس کی تعبیر (لا) بتاتا ہوں مجھے (جیل خانے) جانے کی اجازت دے دیجیئے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mdcxlii{غرض وہ یوسف کے پاس آیا اور کہنے لگا) یوسف اے بڑے سچے (یوسف) ہمیں اس خواب کی تعبیر بتایئے کہ سات موٹی گائیوں کو سات دبلی گائیں کھا رہی ہیں۔ اور سات خوشے سبز ہیں اور سات سوکھے تاکہ میں لوگوں کے پاس واپس جا (کر تعبیر بتاؤں) ۔ عجب نہیں کہ وہ (تمہاری قدر) جانیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mdcxliii{انہوں نے کہا کہ تم لوگ سات سال متواتر کھیتی کرتے رہوگے تو جو (غلّہ) کاٹو تو تھوڑے سے غلّے کے سوا جو کھانے میں آئے اسے خوشوں میں ہی رہنے دینا\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mdcxliv{پھر اس کے بعد (خشک سالی کے) سات سخت (سال) آئیں گے کہ جو (غلّہ) تم نے جمع کر رکھا ہوگا وہ اس سب کو کھا جائیں گے۔ صرف وہی تھوڑا سا رہ جائے گا جو تم احتیاط سے رکھ چھوڑو گے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mdcxlv{پھر اس کے بعد ایک سال آئے گا کہ خوب مینہ برسے گا اور لوگ اس میں رس نچوڑیں گے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mdcxlvi{یہ تعبیر سن کر) بادشاہ نے حکم دیا کہ یوسف کو میرے پاس لے آؤ۔ جب قاصد ان کے پاس گیا تو انہوں نے کہا کہ اپنے آقا کے پاس واپس جاؤ اور ان سے پوچھو کہ ان عورتوں کا کیا حال ہے جنہوں نے اپنے ہاتھ کاٹ لیے تھے۔ بےشک میرا پروردگار ان کے مکروں سے خوب واقف ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mdcxlvii{بادشاہ نے عورتوں سے پوچھا کہ بھلا اس وقت کیا ہوا تھا جب تم نے یوسف کو اپنی طرف مائل کرنا چاہا۔ سب بول اٹھیں کہ حاش َللهِ ہم نے اس میں کوئی برائی معلوم نہیں کی۔ عزیز کی عورت نے کہا اب سچی بات تو ظاہر ہو ہی گئی ہے۔ (اصل یہ ہے کہ) میں نے اس کو اپنی طرف مائل کرنا چاہا تھا اور بےشک وہ سچا ہے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mdcxlviii{یوسف نے کہا کہ میں نے) یہ بات اس لیے (پوچھی ہے) کہ عزیز کو یقین ہوجائے کہ میں نے اس کی پیٹھ پیچھے اس کی (امانت میں خیانت نہیں کی) اور خدا خیانت کرنے والوں کے مکروں کو روبراہ نہیں کرتا\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mdcxlix{اور میں اپنے تئیں پاک صاف نہیں کہتا کیونکہ نفس امارہ (انسان کو) برائی سکھاتا رہتا ہے۔ مگر یہ کہ میرا پروردگار رحم کرے گا۔ بےشک میرا پروردگار بخشنے والا مہربان ہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mdcl{بادشاہ نے حکم دیا کہ اسے میرے پاس لاؤ میں اسے اپنا مصاحب خاص بناؤں گا۔ پھر جب ان سے گفتگو کی تو کہا کہ آج سے تم ہمارے ہاں صاحب منزلت اور صاحبِ اعتبار ہو\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mdcli{یوسف نے) کہا مجھے اس ملک کے خزانوں پر مقرر کر دیجیئے کیونکہ میں حفاظت بھی کرسکتا ہوں اور اس کام سے واقف ہوں\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mdclii{اس طرح ہم نے یوسف کو ملک (مصر) میں جگہ دی اور وہ اس ملک میں جہاں چاہتے تھے رہتے تھے۔ ہم اپنی رحمت جس پر چاہتے ہیں کرتے ہیں اور نیکوکاروں کے اجر کو ضائع نہیں کرتے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mdcliii{اور جو لوگ ایمان لائے اور ڈرتے رہے ان کے لیے آخرت کا اجر بہت بہتر ہے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mdcliv{اور یوسف کے بھائی (کنعان سے مصر میں غلّہ خریدنے کے لیے) آئے تو یوسف کے پاس گئے تو یوسف نے ان کو پہچان لیا اور وہ ان کو نہ پہچان سکے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mdclv{جب یوسف نے ان کے لیے ان کا سامان تیار کر دیا تو کہا کہ (پھر آنا تو) جو باپ کی طرف سے تمہارا ایک اور بھائی ہے اسے بھی میرے پاس لیتے آنا۔ کیا تم نہیں دیکھتے کہ میں ناپ بھی پوری پوری دیتا ہوں اور مہمانداری بھی خوب کرتا ہوں\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mdclvi{اور اگر تم اسے میرے پاس نہ لاؤ گے تو نہ تمہیں میرے ہاں سے غلّہ ملے گا اور نہ تم میرے پاس ہی آسکو گے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mdclvii{انہوں نے کہا کہ ہم اس کے بارے میں اس کے والد سے تذکرہ کریں گے اور ہم (یہ کام) کرکے رہیں گے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mdclviii{اور یوسف نے) اپنے خدام سے کہا کہ ان کا سرمایہ (یعنی غلّے کی قیمت) ان کے شلیتوں میں رکھ دو عجب نہیں کہ جب یہ اپنے اہل وعیال میں جائیں تو اسے پہچان لیں (اور) عجب نہیں کہ پھر یہاں آئیں\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mdclix{جب وہ اپنے باپ کے پاس واپس گئے تو کہنے لگے کہ ابّا (جب تک ہم بنیامین کو ساتھ نہ لے جائیں) ہمارے لیے غلّے کی بندش کر دی گئی ہے تو ہمارے ساتھ ہمارے بھائی کو بھیج دے تاکہ ہم پھر غلّہ لائیں اور ہم اس کے نگہبان ہیں\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mdclx{یعقوب نے) کہا کہ میں اس کے بارے میں تمہارا اعتبار نہیں کرتا مگر ویسا ہی جیسا اس کے بھائی کے بارے میں کیا تھا۔ سو خدا ہی بہتر نگہبان ہے۔ اور وہ سب سے زیادہ رحم کرنے والا ہے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mdclxi{اور جب انہوں نے اپنا اسباب کھولا تو دیکھا کہ ان کا سرمایہ واپس کر دیا گیا ہے۔ کہنے لگے ابّا ہمیں (اور) کیا چاہیئے (دیکھیے) یہ ہماری پونجی بھی ہمیں واپس کر دی گئی ہے۔ اب ہم اپنے اہل وعیال کے لیے پھر غلّہ لائیں گے اور اپنے بھائی کی نگہبانی کریں گے اور ایک بار شتر زیادہ لائیں گے (کہ) یہ غلّہ جو ہم لائے ہیں تھوڑا ہے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mdclxii{یعقوب نے) کہا جب تک تم خدا کا عہد نہ دو کہ اس کو میرے پاس (صحیح سالم) لے آؤ گے میں اسے ہرگز تمہارے ساتھ نہیں بھیجنے کا۔ مگر یہ کہ تم گھیر لیے جاؤ (یعنی بےبس ہوجاؤ تو مجبوری ہے) جب انہوں نے ان سے عہد کرلیا تو (یعقوب نے) کہا کہ جو قول وقرار ہم کر رہے ہیں اس کا خدا ضامن ہے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mdclxiii{اور ہدایت کی کہ بیٹا ایک ہی دروازے سے داخل نہ ہونا بلکہ جدا جدا دروازوں سے داخل ہونا۔ اور میں خدا کی تقدیر کو تم سے نہیں روک سکتا۔ بےشک حکم اسی کا ہے میں اسی پر بھروسہ رکھتا ہوں۔ اور اہلِ توکل کو اسی پر بھروسہ رکھنا چاہیئے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mdclxiv{اور جب وہ ان ان مقامات سے داخل ہوئے جہاں جہاں سے (داخل ہونے کے لیے) باپ نے ان سے کہا تھا تو وہ تدبیر خدا کے حکم کو ذرا بھی نہیں ٹال سکتی تھی ہاں وہ یعقوب کے دل کی خواہش تھی جو انہوں نے پوری کی تھی۔ اور بےشک وہ صاحبِ علم تھے کیونکہ ہم نے ان کو علم سکھایا تھا لیکن اکثر لوگ نہیں جانتے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mdclxv{اور جب وہ لوگ یوسف کے پاس پہنچے تو یوسف نے اپنے حقیقی بھائی کو اپنے پاس جگہ دی اور کہا کہ میں تمہارا بھائی ہوں تو جو سلوک یہ (ہمارے ساتھ) کرتے رہے ہیں اس پر افسوس نہ کرنا\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mdclxvi{جب ان کا اسباب تیار کر دیا تو اپنے بھائی کے شلیتے میں گلاس رکھ دیا اور پھر (جب وہ آبادی سے باہر نکل گئے تو) ایک پکارنے والے نے آواز دی کہ قافلے والو تم تو چور ہو\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mdclxvii{وہ ان کی طرف متوجہ ہو کر کہنے لگے تمہاری کیا چیز کھوئی گئی ہے\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mdclxviii{وہ بولے کہ بادشاہ (کے پانی پینے) کا گلاس کھویا گیا ہے اور جو شخص اس کو لے آئے اس کے لیے ایک بار شتر (انعام) اور میں اس کا ضامن ہوں\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mdclxix{وہ کہنے لگے کہ خدا کی قسم تم کو معلوم ہے کہ ہم (اس) ملک میں اس لیے نہیں آئے کہ خرابی کریں اور نہ ہم چوری کیا کرتے ہیں\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mdclxx{بولے کہ اگر تم جھوٹے نکلے (یعنی چوری ثابت ہوئی) تو اس کی سزا کیا\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mdclxxi{انہوں نے کہا کہ اس کی سزا یہ ہے کہ جس کے شلیتے میں وہ دستیاب ہو وہی اس کا بدل قرار دیا جائے ہم ظالموں کو یہی سزا دیا کرتے ہیں\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mdclxxii{پھر یوسف نے اپنے بھائی کے شلیتے سے پہلے ان کے شلیتوں کو دیکھنا شروع کیا پھر اپنے بھائی کے شلیتے میں سے اس کو نکال لیا۔ اس طرح ہم نے یوسف کے لیے تدبیر کی (ورنہ) بادشاہ کے قانون کے مطابق وہ مشیتِ خدا کے سوا اپنے بھائی کو لے نہیں سکتے تھے۔ ہم جس کے لیے چاہتے ہیں درجے بلند کرتے ہیں۔ اور ہر علم والے سے دوسرا علم والا بڑھ کر ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mdclxxiii{برادران یوسف نے) کہا کہ اگر اس نے چوری کی ہو تو (کچھ عجب نہیں کہ) اس کے ایک بھائی نے بھی پہلے چوری کی تھی یوسف نے اس بات کو اپنے دل میں مخفی رکھا اور ان پر ظاہر نہ ہونے دیا (اور) کہا کہ تم بڑے بدقماش ہو۔ اور جو تم بیان کرتے ہو خدا اسے خوب جانتا ہے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mdclxxiv{وہ کہنے لگے کہ اے عزیز اس کے والد بہت بوڑھے ہیں (اور اس سے بہت محبت رکھتے ہیں) تو (اس کو چھوڑ دیجیےاور) اس کی جگہ ہم میں سے کسی کو رکھ لیجیئے۔ ہم دیکھتے ہیں کہ آپ احسان کرنے والے ہیں\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mdclxxv{یوسف نے) کہا کہ خدا پناہ میں رکھے کہ جس شخص کے پاس ہم نے اپنی چیز پائی ہے اس کے سوا کسی اور کو پکڑ لیں ایسا کریں تو ہم (بڑے) بےانصاف ہیں\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mdclxxvi{جب وہ اس سے ناامید ہوگئے تو الگ ہو کر صلاح کرنے لگے۔ سب سے بڑے نے کہا کیا تم نہیں جانتے کہ تمہارے والد نے تم سے خدا کا عہد لیا ہے اور اس سے پہلے بھی تم یوسف کے بارے میں قصور کر چکے ہو تو جب تک والد صاحب مجھے حکم نہ دیں میں تو اس جگہ سے ہلنے کا نہیں یا خدا میرے لیے کوئی اور تدبیر کرے۔ اور وہ سب سے بہتر فیصلہ کرنے والا ہے\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mdclxxvii{تم سب والد صاحب کے پاس واپس جاؤ اور کہو کہ ابا آپ کے صاحبزادے نے (وہاں جا کر) چوری کی۔ اور ہم نے اپنی دانست کے مطابق آپ سے (اس کے لے آنے کا) عہد کیا تھا مگر ہم غیب کی باتوں کو جاننے اور یاد رکھنے والے تو نہیں تھے\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mdclxxviii{اور جس بستی میں ہم (ٹھہرے) تھے وہاں سے (یعنی اہل مصر سے) اور جس قافلے میں آئے ہیں اس سے دریافت کر لیجیئے اور ہم اس بیان میں بالکل سچے ہیں\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mdclxxix{جب انہوں نے یہ بات یعقوب سے آ کر کہی تو) انہوں نے کہا کہ (حقیقت یوں نہیں ہے) بلکہ یہ بات تم نے اپنے دل سے بنالی ہے تو صبر ہی بہتر ہے۔ عجب نہیں کہ خدا ان سب کو میرے پاس لے آئے۔ بےشک وہ دانا (اور) حکمت والا ہے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mdclxxx{پھر ان کے پاس سے چلے گئے اور کہنے لگے ہائے افسوس یوسف (ہائے افسوس) اور رنج والم میں (اس قدر روئے کہ) ان کی آنکھیں سفید ہوگئیں اور ان کا دل غم سے بھر رہا تھا\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mdclxxxi{بیٹے کہنے لگے کہ والله اگر آپ یوسف کو اسی طرح یاد ہی کرتے رہیں گے تو یا تو بیمار ہوجائیں گے یا جان ہی دے دیں گے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mdclxxxii{انہوں نے کہا کہ میں اپنے غم واندوہ کا اظہار خدا سے کرتا ہوں۔ اور خدا کی طرف سے وہ باتیں جانتا ہوں جو تم نہیں جانتے\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mdclxxxiii{بیٹا (یوں کرو کہ ایک دفعہ پھر) جاؤ اور یوسف اور اس کے بھائی کو تلاش کرو اور خدا کی رحمت سے ناامید نہ ہو۔ کہ خدا کی رحمت سے بےایمان لوگ ناامید ہوا کرتے ہیں\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mdclxxxiv{جب وہ یوسف کے پاس گئے تو کہنے لگے کہ عزیز ہمیں اور ہمارے اہل وعیال کو بڑی تکلیف ہو رہی ہے اور ہم تھوڑا سا سرمایہ لائے ہیں آپ ہمیں (اس کے عوض) پورا غلّہ دے دیجیئے اور خیرات کیجیئے۔ کہ خدا خیرات کرنے والوں کو ثواب دیتا ہے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mdclxxxv{یوسف نے) کہا تمہیں معلوم ہے جب تم نادانی میں پھنسے ہوئے تھے تو تم نے یوسف اور اس کے بھائی کے ساتھ کیا کیا تھا\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mdclxxxvi{وہ بولے کیا تم ہی یوسف ہو؟ انہوں نے کہا ہاں میں ہی یوسف ہوں۔ اور (بنیامین کی طرف اشارہ کرکے کہنے لگے) یہ میرا بھائی ہے خدا نے ہم پر بڑا احسان کیا ہے۔ جو شخص خدا سے ڈرتا اور صبر کرتا ہے تو خدا نیکوکاروں کا اجر ضائع نہیں کرتا\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mdclxxxvii{وہ بولے خدا کی قسم خدا نے تم کو ہم پر فضیلت بخشی ہے اور بےشک ہم خطاکار تھے\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mdclxxxviii{یوسف نے) کہا کہ آج کے دن سے تم پر کچھ عتاب (وملامت) نہیں ہے۔ خدا تم کو معاف کرے۔ اور وہ بہت رحم کرنے والا ہے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mdclxxxix{یہ میرا کرتہ لے جاؤ اور اسے والد صاحب کے منہ پر ڈال دو۔ وہ بینا ہو جائیں گے۔ اور اپنے تمام اہل وعیال کو میرے پاس لے آؤ\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mdcxc{اور جب قافلہ (مصر سے) روانہ ہوا تو ان کے والد کہنے لگے کہ اگر مجھ کو یہ نہ کہو کہ (بوڑھا) بہک گیا ہے تو مجھے تو یوسف کی بو آ رہی ہے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mdcxci{وہ بولے کہ والله آپ اسی قدیم غلطی میں (مبتلا) ہیں\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mdcxcii{جب خوشخبری دینے والا آ پہنچا تو کرتہ یعقوب کے منہ پر ڈال دیا اور وہ بینا ہو گئے (اور بیٹوں سے) کہنے لگے کیا میں نے تم سے نہیں کہا تھا کہ میں خدا کی طرف سے وہ باتیں جانتا ہوں جو تم نہیں جانتے\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mdcxciii{بیٹوں نے کہا کہ ابا ہمارے لیے ہمارے گناہ کی مغفرت مانگیئے۔ بےشک ہم خطاکار تھے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mdcxciv{انہوں نے کہا کہ میں اپنے پروردگار سے تمہارے لیے بخشش مانگوں گا۔ بےشک وہ بخشنے والا مہربان ہے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mdcxcv{جب یہ (سب لوگ) یوسف کے پاس پہنچے تو یوسف نے اپنے والدین کو اپنے پاس بٹھایا اور کہا مصر میں داخل ہو جائیے خدا نے چاہا تو جمع خاطر سے رہیئے گا\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mdcxcvi{اور اپنے والدین کو تخت پر بٹھایا اور سب یوسفؑ کے آگے سجدہ میں گر پڑے اور (اس وقت) یوسف نے کہا ابا جان یہ میرے اس خواب کی تعبیر ہے جو میں نے پہلے (بچپن میں) دیکھا تھا۔ میرے پروردگار نے اسے سچ کر دکھایا اور اس نے مجھ پر (بہت سے) احسان کئے ہیں کہ مجھ کو جیل خانے سے نکالا۔ اور اس کے بعد کہ شیطان نے مجھ میں اور میرے بھائیوں میں فساد ڈال دیا تھا۔ آپ کو گاؤں سے یہاں لایا۔ بےشک میرا پروردگار جو چاہتا ہے تدبیر سے کرتا ہے۔ وہ دانا (اور) حکمت والا ہے\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mdcxcvii{جب یہ سب باتیں ہولیں تو یوسف نے خدا سے دعا کی کہ) اے میرے پروردگار تو نے مجھ کو حکومت سے بہرہ دیا اور خوابوں کی تعبیر کا علم بخشا۔ اے آسمانوں اور زمین کے پیدا کرنے والے تو ہی دنیا اور آخرت میں میرا کارساز ہے۔ تو مجھے (دنیا سے) اپنی اطاعت (کی حالت) میں اٹھائیو اور (آخرت میں) اپنے نیک بندوں میں داخل کیجیو\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mdcxcviii{اے پیغمبر) یہ اخبار غیب میں سے ہیں جو ہم تمہاری طرف بھیجتے ہیں اور جب برادران یوسف نے اپنی بات پر اتفاق کیا تھا اور وہ فریب کر رہے تھے تو تم ان کے پاس تو نہ تھے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mdcxcix{اور بہت سے آدمی گو تم (کتنی ہی) خواہش کرو ایمان لانے والے نہیں ہیں\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mdcc{اور تم ان سے اس (خیر خواہی) کا کچھ صلا بھی تو نہیں مانگتے۔ یہ قرآن اور کچھ نہیں تمام عالم کے لیے نصیحت ہے\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mdcci{اور آسمان و زمین میں بہت سی نشانیاں ہیں جن پر یہ گزرتے ہیں اور ان سے اعراض کرتے ہیں\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mdccii{اور یہ اکثر خدا پر ایمان نہیں رکھتے۔ مگر (اس کے ساتھ) شرک کرتے ہیں\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mdcciii{کیا یہ اس (بات) سے بےخوف ہیں کہ ان پر خدا کا عذاب نازل ہو کر ان کو ڈھانپ لے یا ان پر ناگہاں قیامت آجائے اور انہیں خبر بھی نہ ہو\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mdcciv{کہہ دو میرا رستہ تو یہ ہے میں خدا کی طرف بلاتا ہوں (از روئے یقین وبرہان) سمجھ بوجھ کر میں بھی (لوگوں کو خدا کی طرف بلاتا ہوں) اور میرے پیرو بھی۔ اور خدا پاک ہے۔ اور میں شرک کرنے والوں میں سے نہیں ہوں\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mdccv{اور ہم نے تم سے پہلے بستیوں کے رہنے والوں میں سے مرد ہی بھیجے تھے جن کی طرف ہم وحی بھیجتے تھے۔ کیا ان لوگوں نے ملک میں سیر (وسیاحت) نہیں کی کہ دیکھ لیتے کہ جو لوگ ان سے پہلے تھے ان کا انجام کیا ہوا۔ اور متّقیوں کے لیے آخرت کا گھر بہت اچھا ہے۔ کیا تم سمجھتے نہیں؟\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mdccvi{یہاں تک کہ جب پیغمبر ناامید ہوگئے اور انہوں نے خیال کیا کہ اپنی نصرت کے بارے میں جو بات انہوں نے کہی تھی (اس میں) وہ سچے نہ نکلے تو ان کے پاس ہماری مدد آ پہنچی۔ پھر جسے ہم نے چاہا بچا دیا۔ اور ہمارا عذاب (اتر کر) گنہگار لوگوں سے پھرا نہیں کرتا\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mdccvii{ان کے قصے میں عقلمندوں کے لیے عبرت ہے۔ یہ (قرآن) ایسی بات نہیں ہے جو (اپنے دل سے) بنائی گئی ہو بلکہ جو (کتابیں) اس سے پہلے نازل ہوئی ہیں ان کی تصدیق (کرنے والا) ہے اور مومنوں کے لیے ہدایت اور رحمت ہے\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mdccviii{\basmalahur الٓمرا۔ (اے محمد) یہ کتاب (الہیٰ) کی آیتیں ہیں۔ اور جو تمہارے پروردگار کی طرف سے تم پر نازل ہوا ہے حق ہے لیکن اکثر لوگ ایمان نہیں لاتے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mdccix{خدا وہی تو ہے جس نے ستونوں کے بغیر آسمان جیسا کہ تم دیکھتے ہو (اتنے) اونچے بنائے۔ پھر عرش پر جا ٹھہرا اور سورج اور چاند کو کام میں لگا دیا۔ ہر ایک ایک میعاد معین تک گردش کر رہا ہے۔ وہی (دنیا کے) کاموں کا انتظام کرتا ہے (اس طرح) وہ اپنی آیتیں کھول کھول کر بیان کرتا ہے کہ تم اپنے پروردگار کے روبرو جانے کا یقین کرو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mdccx{اور وہ وہی ہے جس نے زمین کو پھیلایا اور اس میں پہاڑ اور دریا پیدا کئے اور ہر طرح کے میوؤں کی دو دو قسمیں بنائیں۔ وہی رات کو دن کا لباس پہناتا ہے۔ غور کرنے والوں کے لیے اس میں بہت سی نشانیاں ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mdccxi{اور زمین میں کئی طرح کے قطعات ہیں۔ ایک دوسرے سے ملے ہوئے اور انگور کے باغ اور کھیتی اور کھجور کے درخت۔ بعض کی بہت سی شاخیں ہوتی ہیں اور بعض کی اتنی نہیں ہوتیں (باوجود یہ کہ) پانی سب کو ایک ہی ملتا ہے۔ اور ہم بعض میوؤں کو بعض پر لذت میں فضیلت دیتے ہیں۔ اس میں سمجھنے والوں کے لیے بہت سی نشانیاں ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mdccxii{اگر تم عجیب بات سننی چاہو تو کافروں کا یہ کہنا عجیب ہے کہ جب ہم (مر کر) مٹی ہو جائیں گے تو کیا ازسرنو پیدا ہوں گے؟ یہی لوگ ہیں جو اپنے پروردگار سے منکر ہوئے ہیں۔ اور یہی ہیں جن کی گردنوں میں طوق ہوں گے اور یہی اہل دوزخ ہیں کہ ہمیشہ اس میں (جلتے) رہیں گے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mdccxiii{اور یہ لوگ بھلائی سے پہلے تم سے برائی کے جلد خواستگار یعنی (طالب عذاب) ہیں حالانکہ ان سے پہلے عذاب (واقع) ہوچکے ہیں اور تمہارا پروردگار لوگوں کو باوجود ان کی بےانصافیوں کے معاف کرنے والا ہے۔ اور بےشک تمہارا پروردگار سخت عذاب دینے والا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mdccxiv{اور کافر لوگ کہتے ہیں کہ اس (پیغمبر) پر اس کے پروردگار کی طرف سے کوئی نشانی نازل نہیں ہوئی۔ سو (اے محمدﷺ) تم تو صرف ہدایت کرنے والے ہو اور ہر ایک قوم کے لیے رہنما ہوا کرتا ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mdccxv{خدا ہی اس بچے سے واقف ہے جو عورت کے پیٹ میں ہوتا ہے اور پیٹ کے سکڑنے اور بڑھنے سے بھی (واقف ہے) ۔ اور ہر چیز کا اس کے ہاں ایک اندازہ مقرر ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mdccxvi{وہ دانائے نہاں وآشکار ہے سب سے بزرگ (اور) عالی رتبہ ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mdccxvii{کوئی تم میں سے چپکے سے بات کہے یا پکار کر یا رات کو کہیں چھپ جائے یا دن کی روشنی میں کھلم کھلا چلے پھرے (اس کے نزدیک) برابر ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mdccxviii{اس کے آگے اور پیچھے خدا کے چوکیدار ہیں جو خدا کے حکم سے اس کی حفاظت کرتے ہیں۔ خدا اس (نعمت) کو جو کسی قوم کو (حاصل) ہے نہیں بدلتا جب تک کہ وہ اپنی حالت کو نہ بدلے۔ اور جب خدا کسی قوم کے ساتھ برائی کا ارادہ کرتا ہے تو پھر وہ پھر نہیں سکتی۔ اور خدا کے سوا ان کا کوئی مددگار نہیں ہوتا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mdccxix{اور وہی تو ہے جو تم کو ڈرانے اور امید دلانے کے لیے بجلی دکھاتا اور بھاری بھاری بادل پیدا کرتا ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mdccxx{اور رعد اور فرشتے سب اس کے خوف سے اس کی تسبیح و تحمید کرتے رہتے ہیں اور وہی بجلیاں بھیجتا ہے پھر جس پر چاہتا ہے گرا بھی دیتا ہے اور وہ خدا کے بارے میں جھگڑتے ہیں۔ اور وہ بڑی قوت والا ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mdccxxi{سودمند پکارنا تو اسی کا ہے اور جن کو یہ لوگ اس کے سوا پکارتے ہیں وہ ان کی پکار کو کسی طرح قبول نہیں کرتے مگر اس شخص کی طرح جو اپنے دونوں ہاتھ پانی کی طرف پھیلا دے تاکہ (دور ہی سے) اس کے منہ تک آ پہنچے حالانکہ وہ (اس تک کبھی بھی) نہیں آسکتا اور (اسی طرح) کافروں کی پکار بیکار ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mdccxxii{اور جتنی مخلوقات آسمانوں اور زمین میں ہے خوشی سے یا زبردستی سے خدا کے آگے سجدہ کرتی ہے اور ان کے سائے بھی صبح وشام (سجدے کرتے ہیں)\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mdccxxiii{ان سے پوچھو کہ آسمانوں اور زمین کا پروردگار کون ہے؟ (تم ہی ان کی طرف سے) کہہ دو کہ خدا۔ پھر (ان سے) کہو کہ تم نے خدا کو چھوڑ کر ایسے لوگوں کو کیوں کارساز بنایا ہے جو خود اپنے نفع ونقصان کا بھی اختیار نہیں رکھتے (یہ بھی) پوچھو کیا اندھا اور آنکھوں والا برابر ہیں؟ یا اندھیرا اور اُجالا برابر ہوسکتا ہے؟ بھلا ان لوگوں نے جن کو خدا کا شریک مقرر کیا ہے۔ کیا انہوں نے خدا کی سی مخلوقات پیدا کی ہے جس کے سبب ان کو مخلوقات مشتبہ ہوگئی ہے۔ کہہ دو کہ خدا ہی ہر چیز کا پیدا کرنے والا ہے اور وہ یکتا (اور) زبردست ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mdccxxiv{اسی نے آسمان سے مینہ برسایا پھر اس سے اپنے اپنے اندازے کے مطابق نالے بہہ نکلے پھر نالے پر پھولا ہوا جھاگ آگیا۔ اور جس چیز کو زیور یا کوئی اور سامان بنانے کے لیے آگ میں تپاتے ہیں اس میں بھی ایسا ہی جھاگ ہوتا ہے۔ اس طرح خدا حق اور باطل کی مثال بیان فرماتا ہے۔ سو جھاگ تو سوکھ کر زائل ہو جاتا ہے۔ اور (پانی) جو لوگوں کو فائدہ پہنچاتا ہے وہ زمین میں ٹھہرا رہتا ہے۔ اس طرح خدا (صحیح اور غلط کی) مثالیں بیان فرماتا ہے (تاکہ تم سمجھو)\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mdccxxv{جن لوگوں نے خدا کے حکم کو قبول کیا ان کی حالت بہت بہتر ہوگی۔ اور جنہوں نے اس کو قبول نہ کیا اگر روئے زمین کے سب خزانے ان کے اختیار میں ہوں تو وہ سب کے سب اور ان کے ساتھ اتنے ہی اور (نجات کے) بدلے میں صرف کرڈالیں (مگر نجات کہاں؟) ایسے لوگوں کا حساب بھی برا ہوگا۔ اور ان کا ٹھکانا بھی دوزخ ہے۔ اور وہ بری جگہ ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mdccxxvi{بھلا جو شخص یہ جانتا ہے کہ جو کچھ تمہارے پروردگار کی طرف سے تم پر نازل ہوا ہے حق ہے وہ اس شخص کی طرح ہے جو اندھا ہے اور سمجھتے تو وہی ہیں جو عقلمند ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mdccxxvii{جو خدا کے عہد کو پورا کرتے ہیں اور اقرار کو نہیں توڑتے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mdccxxviii{اور جن (رشتہ ہائے قرابت) کے جوڑے رکھنے کا خدا نے حکم دیا ہے ان کو جوڑے رکھتے اور اپنے پروردگار سے ڈرتے رہتے اور برے حساب سے خوف رکھتے ہیں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mdccxxix{اور جو پروردگار کی خوشنودی حاصل کرنے کے لیے (مصائب پر) صبر کرتے ہیں اور نماز پڑھتے ہیں اور جو (مال) ہم نے ان کو دیا ہے اس میں سے پوشیدہ اور ظاہر خرچ کرتے ہیں اور نیکی سے برائی دور کرتے ہیں یہی لوگ ہیں جن کے لیے عاقبت کا گھر ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mdccxxx{یعنی) ہمیشہ رہنے کے باغات جن میں وہ داخل ہوں گے اور ان کے باپ دادا اور بیبیوں اور اولاد میں سے جو نیکوکار ہوں گے وہ بھی (بہشت میں جائیں گے) اور فرشتے (بہشت کے) ہر ایک دروازے سے ان کے پاس آئیں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mdccxxxi{اور کہیں گے) تم پر رحمت ہو (یہ) تمہاری ثابت قدمی کا بدلہ ہے اور عاقبت کا گھر خوب (گھر) ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mdccxxxii{اور جو لوگ خدا سے عہد واثق کر کے اس کو توڑ ڈالتے اور (رشتہ ہائے قرابت) کے جوڑے رکھنے کا خدا نے حکم دیا ہے ان کو قطع کر دیتے ہیں اور ملک میں فساد کرتے ہیں۔ ایسوں پر لعنت ہے اور ان کے لیے گھر بھی برا ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mdccxxxiii{خدا جس کا چاہتا ہے رزق فراخ کر دیتا ہے اور (جس کا چاہتا ہے) تنگ کر دیتا ہے۔ اور کافر لوگ دنیا کی زندگی پر خوش ہو رہے ہیں اور دنیا کی زندگی آخرت (کے مقابلے) میں (بہت) تھوڑا فائدہ ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mdccxxxiv{اور کافر کہتے ہیں کہ اس (پیغمبر) پر اس کے پروردگار کی طرف سے کوئی نشانی کیوں نازل نہیں ہوئی۔ کہہ دو کہ خدا جسے چاہتا ہے گمراہ کرتا ہے اور جو (اس کی طرف) رجوع ہوتا ہے اس کو اپنی طرف کا رستہ دکھاتا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mdccxxxv{یعنی) جو لوگ ایمان لاتے اور جن کے دل یادِ خدا سے آرام پاتے ہیں (ان کو) اور سن رکھو کہ خدا کی یاد سے دل آرام پاتے ہیں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mdccxxxvi{جو لوگ ایمان لائے اور عمل نیک کئے ان کے لیے خوشحالی اور عمدہ ٹھکانہ ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mdccxxxvii{جس طرح ہم اور پیغمبر بھیجتے رہے ہیں) اسی طرح (اے محمدﷺ) ہم نے تم کو اس امت میں جس سے پہلے بہت سی امتیں گزر چکی ہیں بھیجا ہے تاکہ تم ان کو وہ (کتاب) جو ہم نے تمہاری طرف بھیجی ہے پڑھ کر سنا دو اور یہ لوگ رحمٰن کو نہیں مانتے۔ کہہ دو وہی تو میرا پروردگار ہے اس کے سوا کوئی معبود نہیں۔ میں اسی پر بھروسہ رکھتا ہوں اور اسی کی طرف رجوع کرتا ہوں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mdccxxxviii{اور اگر کوئی قرآن ایسا ہوتا کہ اس (کی تاثیر) سے پہاڑ چل پڑتے یا زمین پھٹ جاتی یا مردوں سے کلام کرسکتے۔ (تو یہی قرآن ان اوصاف سے متصف ہوتا مگر) بات یہ ہے کہ سب باتیں خدا کے اختیار میں ہیں تو کیا مومنوں کو اس سے اطمینان نہیں ہوا کہ اگر خدا چاہتا تو سب لوگوں کو ہدایت کے رستے پر چلا دیتا۔ اور کافروں پر ہمیشہ ان کے اعمال کے بدلے بلا آتی رہے گی یا ان کے مکانات کے قریب نازل ہوتی رہے گی یہاں تک کہ خدا کا وعدہ آپہنچے۔ بےشک خدا وعدہ خلاف نہیں کرتا\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mdccxxxix{اور تم سے پہلے بھی رسولوں کے ساتھ تمسخر ہوتے رہے ہیں تو ہم نے کافروں کو مہلت دی پھر پکڑ لیا۔ سو (دیکھ لو کہ) ہمارا عذاب کیسا تھا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mdccxl{تو کیا جو (خدا) ہر متنفس کے اعمال کا نگراں (ونگہباں) ہے (وہ بتوں کی طرح بےعلم وبےخبر ہوسکتا ہے) اور ان لوگوں نے خدا کے شریک مقرر کر رکھے ہیں۔ ان سے کہو کہ (ذرا) ان کے نام تو لو۔ کیا تم اسے ایسی چیزیں بتاتے ہو جس کو وہ زمین میں (کہیں بھی) معلوم نہیں کرتا یا (محض) ظاہری (باطل اور جھوٹی) بات کی (تقلید کرتے ہو) اصل یہ ہے کہ کافروں کو ان کے فریب خوبصورت معلوم ہوتے ہیں۔ اور وہ (ہدایت کے) رستے سے روک لیے گئے ہیں۔ اور جسے خدا گمراہ کرے اسے کوئی ہدایت کرنے والا نہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mdccxli{ان کو دنیا کی زندگی میں بھی عذاب ہے اور آخرت کا عذاب تو بہت ہی سخت ہے۔ اور ان کو خدا (کے عذاب سے) کوئی بھی بچانے والا نہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mdccxlii{جس باغ کا متقیوں سے وعدہ کیا گیا ہے اس کے اوصاف یہ ہیں کہ اس کے نیچے نہریں بہہ رہی ہیں۔ اس کے پھل ہمیشہ (قائم رہنے والے) ہیں اور اس کے سائے بھی۔ یہ ان لوگوں کا انجام ہے جو متقی ہیں۔ اور کافروں کا انجام دوزخ ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mdccxliii{اور جن لوگوں کو ہم نے کتاب دی ہے وہ اس (کتاب) سے جو تم پر نازل ہوئی ہے خوش ہوتے ہیں اور بعض فرقے اس کی بعض باتیں نہیں بھی مانتے۔ کہہ دو کہ مجھ کو یہی حکم ہوا ہے کہ خدا ہی کی عبادت کروں اور اس کے ساتھ کسی کو شریک نہ بناؤں۔ میں اسی کی طرف بلاتا ہوں اور اسی کی طرف مجھے لوٹنا ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mdccxliv{اور اسی طرح ہم نے اس قرآن کو عربی زبان کا فرمان نازل کیا ہے۔ اور اگر تم علم (ودانش) آنے کے بعد ان لوگوں کی خواہشوں کے پیچھے چلو گے تو خدا کے سامنے کوئی نہ تمہارا مددگار ہوگا اور نہ کوئی بچانے والا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mdccxlv{اور (اے محمدﷺ) ہم نے تم سے پہلے بھی پیغمبر بھیجے تھے۔ اور ان کو بیبیاں اور اولاد بھی دی تھی ۔اور کسی پیغمبر کے اختیار کی بات نہ تھی کہ خدا کے حکم کے بغیر کوئی نشانی لائے۔ ہر (حکم) قضا (کتاب میں) مرقوم ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mdccxlvi{خدا جس کو چاہتا ہے مٹا دیتا ہے اور (جس کو چاہتا ہے) قائم رکھتا ہے اور اسی کے پاس اصل کتاب ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mdccxlvii{اور اگر ہم کوئی عذاب جس کا ان لوگوں سے وعدہ کرتے ہیں تمہیں دکھائیں (یعنی تمہارے روبرو ان پر نازل کریں) یا تمہاری مدت حیات پوری کر دیں (یعنی تمہارے انتقال کے بعد عذاب بھیجیں) تو تمہارا کام (ہمارے احکام کا) پہنچا دینا ہے اور ہمارا کام حساب لینا ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mdccxlviii{کیا انہوں نے نہیں دیکھا کہ ہم زمین کو اس کے کناروں سے گھٹاتے چلے آتے ہیں۔ اور خدا (جیسا چاہتا ہے) حکم کرتا ہے کوئی اس کے حکم کا رد کرنے والا نہیں۔ اور وہ جلد حساب لینے والا ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mdccxlix{جو لوگ ان سے پہلے تھے وہ بھی (بہتری) چالیں چلتے رہے ہیں سو چال تو سب الله ہی کی ہے ہر متنفس جو کچھ کر رہا ہے وہ اسے جانتا ہے۔ اور کافر جلد معلوم کریں گے کہ عاقبت کا گھر (یعنی انجام محمود) کس کے لیے ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mdccl{اور کافر لوگ کہتے ہیں کہ تم (خدا کے) رسول نہیں ہو۔ کہہ دو کہ میرے اور تمہارے درمیان خدا اور وہ شخص جس کے پاس کتاب (آسمانی) کا علم ہے گواہ کافی ہیں\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mdccli{\basmalahur الٓرٰ۔ (یہ) ایک (پُرنور) کتاب (ہے) اس کو ہم نے تم پر اس لیے نازل کیا ہے کہ لوگوں کو اندھیرے سے نکال کر روشنی کی طرف لے جاؤ (یعنی) ان کے پروردگار کے حکم سے غالب اور قابل تعریف (خدا) کے رستے کی طرف\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mdcclii{وہ خدا کہ جو کچھ آسمانوں اور زمین میں ہے سب اسی کا ہے۔ اور کافروں کے لیے عذاب سخت (کی وجہ) سے خرابی ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mdccliii{جو آخرت کی نسبت دنیا کو پسند کرتے اور (لوگوں کو) خدا کے رستے سے روکتے اور اس میں کجی چاہتے ہیں۔ یہ لوگ پرلے سرے کی گمراہی میں ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mdccliv{اور ہم نے کوئی پیغمبر نہیں بھیجا مگر اپنی قوم کی زبان بولتا تھا تاکہ انہیں (احکام خدا) کھول کھول کر بتا دے۔ پھر خدا جسے چاہتا ہے گمراہ کرتا ہے اور جسے چاہتا ہے ہدایت دیتا ہے اور وہ غالب (اور) حکمت والا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mdcclv{اور ہم نے موسیٰ کو اپنی نشانیاں دے کر بھیجا کہ اپنی قوم کو تاریکی سے نکال کر روشنی میں لے جاؤ۔ اور ان کو خدا کے دن یاد دلاؤ اس میں ان لوگوں کے لیے جو صابر وشاکر ہیں (قدرت خدا کی) نشانیاں ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mdcclvi{اور جب موسیٰ نے اپنی قوم سے کہا کہ خدا نے جو تم پر مہربانیاں کی ہیں ان کو یاد کرو جب کہ تم کو فرعون کی قوم (کے ہاتھ) سے مخلصی دی وہ لوگ تمہیں بُرے عذاب دیتے تھے اور تمہارے بیٹوں کو مار ڈالتے تھے اور عورت ذات یعنی تمہاری لڑکیوں کو زندہ رہنے دیتے تھے اور اس میں تمہارے پروردگار کی طرف سے بڑی (سخت) آزمائش تھی\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mdcclvii{اور جب تمہارے پروردگار نے (تم کو) آگاہ کیا کہ اگر شکر کرو گے تو میں تمہیں زیادہ دوں گا اور اگر ناشکری کرو گے تو (یاد رکھو کہ) میرا عذاب بھی سخت ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mdcclviii{اور موسیٰ نے (صاف صاف) کہہ دیا کہ اگر تم اور جتنے اور لوگ زمین میں ہیں سب کے سب ناشکری کرو تو خدا بھی بےنیاز (اور) قابل تعریف ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mdcclix{بھلا تم کو ان لوگوں (کے حالات) کی خبر نہیں پہنچی جو تم سے پہلے تھے (یعنی) نوح اور عاد اور ثمود کی قوم۔ اور جو ان کے بعد تھے۔ جن کا علم خدا کے سوا کسی کو نہیں (جب) ان کے پاس پیغمبر نشانیاں لے کر آئے تو انہوں نے اپنے ہاتھ ان کے مونہوں پر رکھ دیئے (کہ خاموش رہو) اور کہنے لگے کہ ہم تو تمہاری رسالت کو تسلیم نہیں کرتے اور جس چیز کی طرف تم ہمیں بلاتے ہو ہم اس سے قوی شک میں ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mdcclx{ان کے پیغمبروں نے کہا کیا (تم کو) خدا (کے بارے) میں شک ہے جو آسمانوں اور زمین کا پیدا کرنے والا ہے۔ وہ تمہیں اس لیے بلاتا ہے کہ تمہارے گناہ بخشے اور (فائدہ پہنچانے کے لیے) ایک مدت مقرر تک تم کو مہلت دے۔ وہ بولے کہ تم تو ہمارے ہی جیسے آدمی ہو۔ تمہارا یہ منشاء ہے کہ جن چیزوں کو ہمارے بڑے پوجتے رہے ہیں ان (کے پوجنے) سے ہم کو بند کر دو تو (اچھا) کوئی کھلی دلیل لاؤ (یعنی معجزہ دکھاؤ)\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mdcclxi{پیغمبروں نے ان سے کہا کہ ہاں ہم تمہارے ہی جیسے آدمی ہیں۔ لیکن خدا اپنے بندوں میں سے جس کو چاہتا ہے (نبوت کا) احسان کرتا ہے اور ہمارے اختیار کی بات نہیں کہ ہم خدا کے حکم کے بغیر تم کو (تمہاری فرمائش کے مطابق) معجزہ دکھائیں اور خدا ہی پر مومنوں کو بھروسہ رکھنا چاہیئے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mdcclxii{اور ہم کیونکر خدا پر بھروسہ نہ رکھیں حالانکہ اس نے ہم کو ہمارے (دین کے سیدھے) رستے بتائے ہیں۔ جو تکلیفیں تم ہم کو دیتے ہو اس پر صبر کریں گے۔ اور اہل توکل کو خدا ہی پر بھروسہ رکھنا چاہیئے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mdcclxiii{اور جو کافر تھے انہوں نے اپنے پیغمبروں سے کہا کہ (یا تو) ہم تم کو اپنے ملک سے باہر نکال دیں گے یا ہمارے مذہب میں داخل ہو جاؤ۔ تو پروردگار نے ان کی طرف وحی بھیجی کہ ہم ظالموں کو ہلاک کر دیں گے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mdcclxiv{اور ان کے بعد تم کو اس زمین میں آباد کریں گے۔ یہ اس شخص کے لیے ہے جو (قیامت کے روز) میرے سامنے کھڑے ہونے سے ڈرے اور میرے عذاب سے خوف کرے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mdcclxv{اور پیغمبروں نے (خدا سے اپنی) فتح چاہی تو ہر سرکش ضدی نامراد رہ گیا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mdcclxvi{اس کے پیچھے دوزخ ہے اور اسے پیپ کا پانی پلایا جائے گا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mdcclxvii{وہ اس کو گھونٹ گھونٹ پیئے گا اور گلے سے نہیں اتار سکے گا اور ہر طرف سے اسے موت آرہی ہوگی مگر وہ مرنے میں نہیں آئے گا۔ اور اس کے پیچھے سخت عذاب ہوگا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mdcclxviii{جن لوگوں نے اپنے پروردگار سے کفر کیا ان کے اعمال کی مثال راکھ کی سی ہے کہ آندھی کے دن اس پر زور کی ہوا چلے (اور) اسے اڑا لے جائے (اس طرح) جو کام وہ کرتے رہے ان پر ان کو کچھ دسترس نہ ہوگی۔ یہی تو پرلے سرے کی گمراہی ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mdcclxix{کیا تم نے نہیں دیکھا کہ خدا نے آسمانوں اور زمین کو تدبیر سے پیدا کیا ہے۔ اگر وہ چاہے تو تم کو نابود کر دے اور (تمہاری جگہ) نئی مخلوق پیدا کر دے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mdcclxx{اور یہ خدا کو کچھ بھی مشکل نہیں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mdcclxxi{اور (قیامت کے دن) سب لوگ خدا کے سامنے کھڑے ہوں گے تو ضعیف (العقل متبع اپنے رؤسائے) متکبرین سے کہیں گے کہ ہم تو تمہارے پیرو تھے۔ کیا تم خدا کا کچھ عذاب ہم پر سے دفع کرسکتے ہو۔ وہ کہیں گے کہ اگر خدا ہم کو ہدایت کرتا تو ہم تم کو ہدایت کرتے۔ اب ہم گھبرائیں یا ضد کریں ہمارے حق میں برابر ہے۔ کوئی جگہ (گریز اور) رہائی کی ہمارے لیے نہیں ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mdcclxxii{جب (حساب کتاب کا) کام فیصلہ ہوچکے گا تو شیطان کہے گا (جو) وعدہ خدا نے تم سے کیا تھا (وہ تو) سچا (تھا) اور (جو) وعدہ میں نے تم سے کیا تھا وہ جھوٹا تھا۔ اور میرا تم پر کسی طرح کا زور نہیں تھا۔ ہاں میں نے تم کو (گمراہی اور باطل کی طرف) بلایا تو تم نے (جلدی سے اور بےدلیل) میرا کہا مان لیا۔ تو (آج) مجھے ملامت نہ کرو۔ اپنے آپ ہی کو ملامت کرو۔ نہ میں تمہاری فریاد رسی کرسکتا ہوں اور نہ تم میری فریاد رسی کرسکتے ہو۔ میں اس بات سے انکار کرتا ہوں کہ تم پہلے مجھے شریک بناتے تھے۔ بےشک جو ظالم ہیں ان کے لیے درد دینے والا عذاب ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mdcclxxiii{اور جو ایمان لائے اور عمل نیک کیے وہ بہشتوں میں داخل کیے جائیں گے جن کے نیچے نہریں بہہ رہی ہیں اپنے پروردگار کے حکم سے ہمیشہ ان میں رہیں گے۔ وہاں ان کی صاحب سلامت سلام ہوگا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mdcclxxiv{کیا تم نے نہیں دیکھا کہ خدا نے پاک بات کی کیسی مثال بیان فرمائی ہے (وہ ایسی ہے) جیسے پاکیزہ درخت جس کی جڑ مضبوط (یعنی زمین کو پکڑے ہوئے) ہو اور شاخیں آسمان میں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mdcclxxv{اپنے پروردگار کے حکم سے ہر وقت پھل لاتا (اور میوے دیتا) ہو۔ اور خدا لوگوں کے لیے مثالیں بیان فرماتا ہے تاکہ وہ نصیحت پکڑیں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mdcclxxvi{اور ناپاک بات کی مثال ناپاک درخت کی سی ہے (نہ جڑ مستحکم نہ شاخیں بلند) زمین کے اوپر ہی سے اکھیڑ کر پھینک دیا جائے گا اس کو ذرا بھی قرار (وثبات) نہیں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mdcclxxvii{خدا مومنوں (کے دلوں) کو (صحیح اور) پکی بات سے دنیا کی زندگی میں بھی مضبوط رکھتا ہے اور آخرت میں بھی (رکھے گا) اور خدا بےانصافوں کو گمراہ کر دیتا ہے اور خدا جو چاہتا ہے کرتا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mdcclxxviii{کیا تم نے ان لوگوں کو نہیں دیکھا جنہوں نے خدا کے احسان کو ناشکری سے بدل دیا۔ اور اپنی قوم کو تباہی کے گھر میں اتارا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mdcclxxix{وہ گھر) دوزخ ہے۔ (سب ناشکرے) اس میں داخل ہوں گے۔ اور وہ برا ٹھکانہ ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mdcclxxx{اور ان لوگوں نے خدا کے شریک مقرر کئے کہ (لوگوں کو) اس کے رستے سے گمراہ کریں۔ کہہ دو کہ (چند روز) فائدے اٹھا لو آخرکار تم کو دوزخ کی طرف لوٹ کر جانا ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mdcclxxxi{اے پیغمبر) میرے مومن بندوں سے کہہ دو کہ نماز پڑھا کریں اور اس دن کے آنے سے پیشتر جس میں نہ (اعمال کا) سودا ہوگا اور نہ دوستی (کام آئے گی) ہمارے دیئے ہوئے مال میں سے درپردہ اور ظاہر خرچ کرتے رہیں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mdcclxxxii{خدا ہی تو ہے جس نے آسمانوں اور زمین کو پیدا کیا اور آسمان سے مینہ برسایا پھر اس سے تمہارے کھانے کے لیے پھل پیدا کئے۔ اور کشتیوں (اور جہازوں) کو تمہارے زیر فرمان کیا تاکہ دریا (اور سمندر) میں اس کے حکم سے چلیں۔ اور نہروں کو بھی تمہارے زیر فرمان کیا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiii{اور سورج اور چاند کو تمہارے لیے کام میں لگا دیا کہ دونوں (دن رات) ایک دستور پر چل رہے ہیں۔ اور رات اور دن کو بھی تمہاری خاطر کام میں لگا دیا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mdcclxxxiv{اور جو کچھ تم نے مانگا سب میں سے تم کو عنایت کیا۔ اور اگر خدا کے احسان گننے لگو تو شمار نہ کرسکو۔ (مگر لوگ نعمتوں کا شکر نہیں کرتے) کچھ شک نہیں کہ انسان بڑا بےانصاف اور ناشکرا ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mdcclxxxv{اور جب ابراہیم نے دعا کی کہ میرے پروردگار اس شہر کو (لوگوں کے لیے) امن کی جگہ بنا دے۔ اور مجھے اور میری اولاد کو اس بات سے کہ بتوں کی پرستش کرنے لگیں بچائے رکھ\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvi{اے پروردگار انہوں نے بہت سے لوگوں کو گمراہ کیا ہے۔ سو جس شخص نے میرا کہا مانا وہ میرا ہے۔ اور جس نے میری نافرمانی کی تو تُو بخشنے والا مہربان ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mdcclxxxvii{اے پروردگار میں نے اپنی اولاد کو میدان (مکہ) میں جہاں کھیتی نہیں تیرے عزت (وادب) والے گھر کے پاس لابسائی ہے۔ اے پروردگار تاکہ یہ نماز پڑھیں تو لوگوں کے دلوں کو ایسا کر دے کہ ان کی طرف جھکے رہیں اور ان کو میوؤں سے روزی دے تاکہ (تیرا) شکر کریں\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mdcclxxxviii{اے پروردگار جو بات ہم چھپاتے اور جو ظاہر کرتے ہیں تو سب جانتا ہے۔ اور خدا سے کوئی چیز مخفی نہیں (نہ) زمین میں نہ آسمان میں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mdcclxxxix{خدا کا شکر ہے جس نے مجھ کو بڑی عمر میں اسماعیل اور اسحاق بخشے۔ بےشک میرا پروردگار سننے والا ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mdccxc{اے پروردگار مجھ کو (ایسی توفیق عنایت) کر کہ نماز پڑھتا رہوں اور میری اولاد کو بھی (یہ توفیق بخش) اے پروردگار میری دعا قبول فرما\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mdccxci{اے پروردگار حساب (کتاب) کے دن مجھ کو اور میرے ماں باپ کو اور مومنوں کو مغفرت کیجیو\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mdccxcii{اور (مومنو) مت خیال کرنا کہ یہ ظالم جو عمل کر رہے ہیں خدا ان سے بےخبر ہے۔ وہ ان کو اس دن تک مہلت دے رہا ہے جب کہ (دہشت کے سبب) آنکھیں کھلی کی کھلی رہ جائیں گی\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mdccxciii{اور لوگ) سر اٹھائے ہوئے (میدان قیامت کی طرف) دوڑ رہے ہوں گے ان کی نگاہیں ان کی طرف لوٹ نہ سکیں گی اور ان کے دل (مارے خوف کے) ہوا ہو رہے ہوں گے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mdccxciv{اور لوگوں کو اس دن سے آگاہ کردو جب ان پر عذاب آجائے گا تب ظالم لوگ کہیں گے کہ اے ہمارے پروردگار ہمیں تھوڑی سی مدت مہلت عطا کر۔ تاکہ تیری دعوت (توحید) قبول کریں اور (تیرے) پیغمبروں کے پیچھے چلیں (تو جواب ملے گا) کیا تم پہلے قسمیں نہیں کھایا کرتے تھے کہ تم کو (اس حال سے جس میں تم ہو) زوال (اور قیامت کو حساب اعمال) نہیں ہوگا\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mdccxcv{اور جو لوگ اپنے آپ پر ظلم کرتے تھے تم ان کے مکانوں میں رہتے تھے اور تم پر ظاہر ہوچکا تھا کہ ہم نے ان لوگوں کے ساتھ کس طرح (کا معاملہ) کیا تھا اور تمہارے (سمجھانے) کے لیے مثالیں بیان کر دی تھیں\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mdccxcvi{اور انہوں نے (بڑی بڑی) تدبیریں کیں اور ان کی (سب) تدبیریں خدا کے ہاں (لکھی ہوئی) ہیں گو وہ تدبیریں ایسی (غضب کی) تھیں کہ ان سے پہاڑ بھی ٹل جائیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mdccxcvii{تو ایسا خیال نہ کرنا کہ خدا نے جو اپنے پیغمبروں سے وعدہ کیا ہے اس کے خلاف کرے گا بےشک خدا زبردست (اور) بدلہ لینے والا ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mdccxcviii{جس دن یہ زمین دوسری زمین سے بدل دی جائے گی اور آسمان بھی (بدل دیئے جائیں گے) اور سب لوگ خدائے یگانہ وزبردست کے سامنے نکل کھڑے ہوں گے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mdccxcix{اور اس دن تم گنہگاروں کو دیکھو گے کہ زنجیروں میں جکڑے ہوئے ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mdccc{ان کے کرتے گندھک کے ہوں گے اور ان کے مونہوں کو آگ لپیٹ رہی ہوگی\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mdccci{یہ اس لیے کہ خدا ہر شخص کو اس کے اعمال کا بدلہ دے۔ بےشک خدا جلد حساب لینے والا ہے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mdcccii{یہ قرآن لوگوں کے نام (خدا کا پیغام) ہے تاکہ ان کو اس سے ڈرایا جائے اور تاکہ وہ جان لیں کہ وہی اکیلا معبود ہے اور تاکہ اہل عقل نصیحت پکڑیں\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mdccciii{\basmalahur آلرا۔ یہ خدا کی کتاب اور قرآن روشن کی آیتیں ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mdccciv{کسی وقت کافر لوگ آرزو کریں گے کہ اے کاش وہ مسلمان ہوتے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mdcccv{اے محمد) ان کو اُن کے حال پر رہنے دو کہ کھالیں اور فائدے اُٹھالیں اور (طول) امل ان کو دنیا میں مشغول کئے رہے عنقریب ان کو (اس کا انجام) معلوم ہو جائے گا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mdcccvi{اور ہم نے کوئی بستی ہلاک نہیں کی۔ مگر اس کا وقت مرقوم ومعین تھا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mdcccvii{کوئی جماعت اپنی مدت (وفات) سے نہ آگے نکل سکتی ہے نہ پیچھے رہ سکتی ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mdcccviii{اور کفار کہتے ہیں کہ اے شخص جس پر نصیحت (کی کتاب) نازل ہوئی ہے تُو تو دیوانہ ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mdcccix{اگر تو سچا ہے تو ہمارے پاس فرشتوں کو کیوں نہیں لے آتا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mdcccx{کہہ دو) ہم فرشتوں کو نازل نہیں کیا کرتے مگر حق کے ساتھ اور اس وقت ان کو مہلت نہیں ملتی\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mdcccxi{بےشک یہ (کتاب) نصیحت ہمیں نے اُتاری ہے اور ہم ہی اس کے نگہبان ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mdcccxii{اور ہم نے تم سے پہلے لوگوں میں بھی پیغمبر بھیجے تھے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mdcccxiii{اور اُن کے پاس کوئی پیغمبر نہیں آتا تھا مگر وہ اُس کے ساتھ استہزاء کرتے تھے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mdcccxiv{اسی طرح ہم اس (تکذیب وضلال) کو گنہگاروں کے دلوں میں داخل کر دیتے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mdcccxv{سو وہ اس پر ایمان نہیں لاتے اور پہلوں کی روش بھی یہی رہی ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mdcccxvi{اوراگر ہم آسمان کا کوئی دروازہ اُن پر کھول دیں اور وہ اس میں چڑھنے بھی لگیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mdcccxvii{تو بھی یہی کہیں کہ ہماری آنکھیں مخمور ہوگئی ہیں بلکہ ہم پر جادو کر دیا گیا ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mdcccxviii{اور ہم ہی نے آسمان میں برج بنائے اور دیکھنے والوں کے لیے اُس کو سجا دیا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mdcccxix{اور ہر شیطان راندہٴ درگاہ سے اُسے محفوظ کر دیا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mdcccxx{ہاں اگر کوئی چوری سے سننا چاہے تو چمکتا ہوا انگارہ اس کے پیچھے لپکتا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mdcccxxi{اور زمین کو بھی ہم ہی نے پھیلایا اور اس پر پہاڑ (بنا کر) رکھ دیئے اور اس میں ہر ایک سنجیدہ چیز اُگائی\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mdcccxxii{اور ہم ہی نے تمہارے لیے اور ان لوگوں کے لیے جن کو تم روزی نہیں دیتے اس میں معاش کے سامان پیدا کئے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mdcccxxiii{اور ہمارے ہاں ہر چیز کے خزانے ہیں اور ہم ان کو بمقدار مناسب اُتارتے رہتے ہیں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mdcccxxiv{اور ہم ہی ہوائیں چلاتے ہیں (جو بادلوں کے پانی سے) بھری ہوئی ہوتی ہیں اور ہم ہی آسمان سے مینہ برساتے ہیں اور ہم ہی تم کو اس کا پانی پلاتے ہیں اور تم تو اس کا خرانہ نہیں رکھتے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mdcccxxv{اور ہم ہی حیات بخشتے اور ہم ہی موت دیتے ہیں۔ اور ہم سب کے وارث (مالک) ہیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mdcccxxvi{اور جو لوگ تم میں پہلے گزر چکے ہیں ہم کو معلوم ہیں اور جو پیچھے آنے والے ہیں وہ بھی ہم کو معلوم ہیں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mdcccxxvii{اور تمہارا پروردگار (قیامت کے دن) ان سب کو جمع کرے گا وہ بڑا دانا (اور) خبردار ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mdcccxxviii{اور ہم نے انسان کو کھنکھناتے سڑے ہوئے گارے سے پیدا کیا ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mdcccxxix{اور جنوں کو اس سے بھی پہلے بےدھوئیں کی آگ سے پیدا کیا تھا\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mdcccxxx{اور جب تمہارے پروردگار نے فرشتوں سے فرمایا کہ میں کھنکھناتے سڑے ہوئے گارے سے ایک بشر بنانے والا ہوں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mdcccxxxi{جب اس کو (صورت انسانیہ میں) درست کر لوں اور اس میں اپنی (بےبہا چیز یعنی) روح پھونک دوں تو اس کے آگے سجدے میں گر پڑنا\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mdcccxxxii{تو فرشتے تو سب کے سب سجدے میں گر پڑے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiii{مگر شیطان کہ اس نے سجدہ کرنے والوں کے ساتھ ہونے سے انکار کر دیا\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mdcccxxxiv{خدا نے فرمایا) کہ ابلیس! تجھے کیا ہوا کہ تو سجدہ کرنے والوں میں شامل نہ ہوا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mdcccxxxv{اس نے) کہا کہ میں ایسا نہیں ہوں کہ انسان کو جس کو تو نے کھنکھناتے سڑے ہوئے گارے سے بنایا ہے سجدہ کروں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvi{خدا نے) فرمایا یہاں سے نکل جا۔ تو مردود ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mdcccxxxvii{اور تجھ پر قیامت کے دن تک لعنت (برسے گی)\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mdcccxxxviii{اس نے) کہا کہ پروردگار مجھے اس دن تک مہلت دے جب لوگ (مرنے کے بعد) زندہ کئے جائیں گے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mdcccxxxix{فرمایا کہ تجھے مہلت دی جاتی ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mdcccxl{وقت مقرر (یعنی قیامت) کے دن تک\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mdcccxli{اس نے) کہا کہ پروردگار جیسا تونے مجھے رستے سے الگ کیا ہے میں بھی زمین میں لوگوں کے لیے (گناہوں) کو آراستہ کر دکھاؤں گا اور سب کو بہکاؤں گا\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mdcccxlii{ہاں ان میں جو تیرے مخلص بندے ہیں (ان پر قابو چلنا مشکل ہے)\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mdcccxliii{خدا نے) فرمایا کہ مجھ تک (پہنچنے کا) یہی سیدھا رستہ ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mdcccxliv{جو میرے (مخلص) بندے ہیں ان پر تجھے کچھ قدرت نہیں (کہ ان کو گناہ میں ڈال سکے) ہاں بد راہوں میں سے جو تیرے پیچھے چل پڑے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mdcccxlv{اور ان سب کے وعدے کی جگہ جہنم ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mdcccxlvi{اس کے سات دروازے ہیں۔ ہر ایک دروازے کے لیے ان میں سے جماعتیں تقسیم کردی گئی ہیں\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mdcccxlvii{جو متقی ہیں وہ باغوں اور چشموں میں ہوں گے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mdcccxlviii{ان سے کہا جائے گا کہ) ان میں سلامتی (اور خاطر جمع سے) داخل ہوجاؤ\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mdcccxlix{اور ان کے دلوں میں جو کدورت ہوگی ان کو ہم نکال کر (صاف کر) دیں گے (گویا) بھائی بھائی تختوں پر ایک دوسرے کے سامنے بیٹھے ہوئے ہیں\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mdcccl{نہ ان کو وہاں کوئی تکلیف پہنچے گی اور نہ وہاں سے نکالے جائیں گے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mdcccli{اے پیغمبر) میرے بندوں کو بتادو کہ میں بڑا بخشنے والا (اور) مہربان ہوں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mdccclii{اور یہ کہ میرا عذاب بھی درد دینے والا عذاب ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mdcccliii{اور ان کو ابراہیم کے مہمانوں کا احوال سنادو\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mdcccliv{جب وہ ابراہیم کے پاس آئے تو سلام کہا۔ (انہوں نے) کہا کہ ہمیں تو تم سے ڈر لگتا ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mdccclv{مہمانوں نے) کہا کہ ڈریئے نہیں ہم آپ کو ایک دانشمند لڑکے کی خوشخبری دیتے ہیں\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mdccclvi{بولے کہ جب مجھے بڑھاپے نے آ پکڑا تو تم خوشخبری دینے لگے۔ اب کاہے کی خوشخبری دیتے ہو\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mdccclvii{انہوں نے) کہا ہم آپ کو سچی خوشخبری دیتے ہیں آپ مایوس نہ ہوئیے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mdccclviii{ابراہیم نے) کہا کہ خدا کی رحمت سے (میں مایوس کیوں ہونے لگا اس سے) مایوس ہونا گمراہوں کا کام ہے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mdccclix{پھر کہنے لگے کہ فرشتو! تمہیں (اور) کیا کام ہے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mdccclx{انہوں نے) کہا کہ ہم ایک گنہگار قوم کی طرف بھیجے گئے ہیں (کہ اس کو عذاب کریں)\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mdccclxi{مگر لوط کے گھر والے کہ ان سب کو ہم بچالیں گے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mdccclxii{البتہ ان کی عورت (کہ) اس کے لیے ہم نے ٹھہرا دیا ہے کہ وہ پیچھے رہ جائے گی\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mdccclxiii{پھر جب فرشتے لوط کے گھر گئے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mdccclxiv{تو لوط نے کہا تم تو ناآشنا سے لوگ ہو\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mdccclxv{وہ بولے کہ نہیں بلکہ ہم آپ کے پاس وہ چیز لے کر آئے ہیں جس میں لوگ شک کرتے تھے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mdccclxvi{اور ہم آپ کے پاس یقینی بات لے کر آئے ہیں اور ہم سچ کہتے ہیں\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mdccclxvii{تو آپ کچھ رات رہے سے اپنے گھر والوں کو لے نکلیں اور خود ان کے پیچھے چلیں اور اور آپ میں سے کوئی شخص مڑ کر نہ دیکھے۔ اور جہاں آپ کو حکم ہو وہاں چلے جایئے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mdccclxviii{اور ہم نے لوط کی طرف وحی بھیجی کہ ان لوگوں کی جڑ صبح ہوتے ہوتے کاٹ دی جائے گی\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mdccclxix{اور اہل شہر (لوط کے پاس) خوش خوش (دوڑے) آئے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mdccclxx{لوط نے) کہا کہ یہ میرے مہمان ہیں (کہیں ان کے بارے میں) مجھے رسوا نہ کرنا\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mdccclxxi{اور خدا سے ڈرو۔ اور میری بےآبروئی نہ کیجو\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mdccclxxii{وہ بولے کیا ہم نے تم کو سارے جہان (کی حمایت وطرفداری) سے منع نہیں کیا\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mdccclxxiii{انہوں نے) کہا کہ اگر تمہیں کرنا ہی ہے تو یہ میری (قوم کی) لڑکیاں ہیں (ان سے شادی کرلو)\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mdccclxxiv{اے محمد) تمہاری جان کی قسم وہ اپنی مستی میں مدہوش (ہو رہے) تھے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mdccclxxv{سو ان کو سورج نکلتے نکلتے چنگھاڑ نے آپکڑا\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mdccclxxvi{اور ہم نے اس شہر کو (الٹ کر) نیچے اوپر کردیا۔ اور ان پر کھنگر کی پتھریاں برسائیں\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mdccclxxvii{بےشک اس (قصے) میں اہل فراست کے لیے نشانی ہے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mdccclxxviii{اور وہ (شہر) اب تک سیدھے رستے پر (موجود) ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mdccclxxix{بےشک اس میں ایمان لانے والوں کے لیے نشانی ہے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mdccclxxx{اور بَن کے رہنے والے (یعنی قوم شعیب کے لوگ) بھی گنہگار تھے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mdccclxxxi{تو ہم نے ان سے بھی بدلہ لیا۔ اور یہ دونوں شہر کھلے رستے پر (موجود) ہیں\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mdccclxxxii{اور (وادی) حجر کے رہنے والوں نے بھی پیغمبروں کی تکذیب کی\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiii{ہم نے ان کو اپنی نشانیاں دیں اور وہ ان سے منہ پھرتے رہے\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mdccclxxxiv{اور وہ پہاڑوں کو تراش تراش کر گھر بناتے تھے (کہ) امن (واطمینان) سے رہیں گے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mdccclxxxv{تو چیخ نے ان کو صبح ہوتے ہوتے آپکڑا\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvi{اور جو کام وہ کرتے تھے وہ ان کے کچھ بھی کام نہ آئے\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mdccclxxxvii{اور ہم نے آسمانوں اور زمین کو اور جو (مخلوقات) ان میں ہے اس کو تدبیر کے ساتھ پیدا کیا ہے۔ اور قیامت تو ضرور آکر رہے گی تو تم (ان لوگوں سے) اچھی طرح سے درگزر کرو\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mdccclxxxviii{کچھ شک نہیں کہ تمہارا پروردگار (سب کچھ) پیدا کرنے والا (اور) جاننے والا ہے\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mdccclxxxix{اور ہم نے تم کو سات (آیتیں) جو (نماز میں) دہرا کر پڑھی جاتی ہیں (یعنی سورہٴ الحمد) اور عظمت والا قرآن عطا فرمایا ہے\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mdcccxc{اور ہم نے کفار کی کئی جماعتوں کو جو (فوائد دنیاوی سے) متمتع کیا ہے تم ان کی طرف (رغبت سے) آنکھ اٹھا کر نہ دیکھنا اور نہ ان کے حال پر تاسف کرنا اور مومنوں سے خاطر اور تواضع سے پیش آنا\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mdcccxci{اور کہہ دو کہ میں تو علانیہ ڈر سنانے والا ہوں\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mdcccxcii{اور ہم ان کفار پر اسی طرح عذاب نازل کریں گے) جس طرح ان لوگوں پر نازل کیا جنہوں نے تقسیم کردیا\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mdcccxciii{یعنی قرآن کو (کچھ ماننے اور کچھ نہ ماننے سے) ٹکڑے ٹکڑے کر ڈالا\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mdcccxciv{تمہارے پروردگار کی قسم ہم ان سے ضرور پرسش کریں گے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mdcccxcv{ان کاموں کی جو وہ کرتے رہے\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mdcccxcvi{پس جو حکم تم کو (خدا کی طرف سے) ملا ہے وہ (لوگوں کو) سنا دو اور مشرکوں کا (ذرا) خیال نہ کرو\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mdcccxcvii{ہم تمہیں ان لوگوں (کے شر) سے بچانے کے لیے جو تم سے استہزاء کرتے ہیں کافی ہیں\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mdcccxcviii{جو خدا کے ساتھ معبود قرار دیتے ہیں۔ سو عنقریب ان کو (ان باتوں کا انجام) معلوم ہوجائے گا\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mdcccxcix{اور ہم جانتے ہیں کہ ان باتوں سے تمہارا دل تنگ ہوتا ہے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mcm{تو تم اپنے پروردگار کی تسبیح کہتے اور (اس کی) خوبیاں بیان کرتے رہو اور سجدہ کرنے والوں میں داخل رہو\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mcmi{اور اپنے پروردگار کی عبادت کئے جاؤ یہاں تک کہ تمہاری موت (کا وقت) آجائے\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mcmii{\basmalahur خدا کا حکم (یعنی عذاب گویا) آ ہی پہنچا تو (کافرو) اس کے لیے جلدی مت کرو۔ یہ لوگ جو (خدا کا) شریک بناتے ہیں وہ اس سے پاک اور بالاتر ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mcmiii{وہی فرشتوں کو پیغام دے کر اپنے حکم سے اپنے بندوں میں سے جس کے پاس چاہتا ہے بھیجتا ہے کہ (لوگوں کو) بتادو کہ میرے سوا کوئی معبود نہیں تو مجھی سے ڈرو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mcmiv{اسی نے آسمانوں اور زمین کو مبنی برحکمت پیدا کیا۔ اس کی ذات ان (کافروں) کے شرک سے اونچی ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mcmv{اسی نے انسان کو نطفے سے بنایا مگر وہ اس (خالق) کے بارے میں علانیہ جھگڑنے لگا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mcmvi{اور چارپایوں کو بھی اسی نے پیدا کیا۔ ان میں تمہارے لیے جڑاول اور بہت سے فائدے ہیں اور ان میں سے بعض کو تم کھاتے بھی ہو\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mcmvii{اور جب شام کو انہیں (جنگل سے) لاتے ہو اور جب صبح کو (جنگل) چرانے لے جاتے ہو تو ان سے تمہاری عزت وشان ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mcmviii{اور (دور دراز) شہروں میں جہاں تم زحمتِ شاقّہ کے بغیر پہنچ نہیں سکتے وہ تمہارے بوجھ اٹھا کر لے جاتے ہیں۔ کچھ شک نہیں کہ تمہارا پروردگار نہایت شفقت والا اور مہربان ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mcmix{اور اسی نے گھوڑے اور خچر اور گدھے پیدا کئے تاکہ تم ان پر سوار ہو اور (وہ تمہارے لیے) رونق وزینت (بھی ہیں) اور وہ (اور چیزیں بھی) پیدا کرتا ہے جن کی تم کو خبر نہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mcmx{اور سیدھا رستہ تو خدا تک جا پہنچتا ہے۔ اور بعض رستے ٹیڑھے ہیں (وہ اس تک نہیں پہنچتے) اور اگر وہ چاہتا تو تم سب کو سیدھے رستے پر چلا دیتا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mcmxi{وہی تو ہے جس نے آسمان سے پانی برسایا جسے تم پیتے ہو اور اس سے درخت بھی (شاداب ہوتے ہیں) جن میں تم اپنے چارپایوں کو چراتے ہو\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mcmxii{اسی پانی سے وہ تمہارے لیے کھیتی اور زیتون اور کھجور اور انگور (اور بےشمار درخت) اُگاتا ہے۔ اور ہر طرح کے پھل (پیدا کرتا ہے) غور کرنے والوں کے لیے اس میں (قدرتِ خدا کی بڑی) نشانی ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mcmxiii{اور اسی نے تمہارے لیے رات اور دن اور سورج اور چاند کو کام میں لگایا۔ اور اسی کے حکم سے ستارے بھی کام میں لگے ہوئے ہیں۔ سمجھنے والوں کے لیے اس میں (قدرت خدا کی بہت سی) نشانیاں ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mcmxiv{اور جو طرح طرح کے رنگوں کی چیزیں اس نے زمین میں پیدا کیں (سب تمہارے زیر فرمان کردیں) نصیحت پکڑنے والوں کے لیے اس میں نشانی ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mcmxv{اور وہی تو ہے جس نے دریا کو تمہارے اختیار میں کیا تاکہ اس میں سے تازہ گوشت کھاؤ اور اس سے زیور (موتی وغیرہ) نکالو جسے تم پہنتے ہو۔ اور تم دیکھتے ہو کہ کشتیاں دریا میں پانی کو پھاڑتی چلی جاتی ہیں۔ اور اس لیے بھی (دریا کو تمہارے اختیار میں کیا) کہ تم خدا کے فضل سے (معاش) تلاش کرو تاکہ اس کا شکر کرو\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mcmxvi{اور اسی نے زمین پر پہاڑ (بنا کر) رکھ دیئے کہ تم کو لے کر کہیں جھک نہ جائے اور نہریں اور رستے بنا دیئے تاکہ ایک مقام سے دوسرے مقام تک (آسانی سے) جاسکو\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mcmxvii{اور (راستوں میں) نشانات بنا دیئے اور لوگ ستاروں سے بھی رستے معلوم کرتے ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mcmxviii{تو جو (اتنی مخلوقات) پیدا کرے۔ کیا وہ ویسا ہے جو کچھ بھی پیدا نہ کرسکے تو پھر تم غور کیوں نہیں کرتے؟\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mcmxix{اور اگر تم خدا کی نعمتوں کو شمار کرنا چاہو تو گن نہ سکو۔ بےشک خدا بخشنے والا مہربان ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mcmxx{اور جو کچھ تم چھپاتے اور جو کچھ ظاہر کرتے ہو سب سے خدا واقف ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mcmxxi{اور جن لوگوں کو یہ خدا کے سوا پکارتے ہیں وہ کوئی چیز بھی تو نہیں بناسکتے بلکہ خود ان کو اور بناتے ہیں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mcmxxii{لاشیں ہیں بےجان۔ ان کو یہ بھی تو معلوم نہیں کہ اٹھائے کب جائیں گے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mcmxxiii{تمہارا معبود تو اکیلا خدا ہے۔ تو جو آخرت پر ایمان نہیں رکھتے ان کے دل انکار کر رہے ہیں اور وہ سرکش ہو رہے ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mcmxxiv{یہ جو کچھ چھپاتے ہیں اور جو ظاہر کرتے ہیں خدا اس کو ضرور جانتا ہے۔ وہ سرکشوں کو ہرگز پسند نہیں کرتا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mcmxxv{اور جب ان (کافروں) سے کہا جاتا ہے کہ تمہارے پروردگار نے کیا اتارا ہے تو کہتے ہیں کہ (وہ تو) پہلے لوگوں کی حکایتیں ہیں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mcmxxvi{اے پیغمبر ان کو بکنے دو) یہ قیامت کے دن اپنے (اعمال کے) پورے بوجھ بھی اٹھائیں گے اور جن کو یہ بےتحقیق گمراہ کرتے ہیں ان کے بوجھ بھی اٹھائیں گے۔ سن رکھو کہ جو بوجھ اٹھا رہے ہیں برے ہیں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mcmxxvii{ان سے پہلے لوگوں نے بھی (ایسی ہی) مکاریاں کی تھیں تو خدا (کا حکم) ان کی عمارت کے ستونوں پر آپہنچا اور چھت ان پر ان کے اوپر سے گر پڑی اور (ایسی طرف سے) ان پر عذاب آ واقع ہوا جہاں سے ان کو خیال بھی نہ تھا\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mcmxxviii{پھر وہ ان کو قیامت کے دن بھی ذلیل کرے گا اور کہے گا کہ میرے وہ شریک کہاں ہیں جن کے بارے میں تم جھگڑا کرتے تھے۔ جن لوگوں کو علم دیا گیا تھا وہ کہیں گے کہ آج کافروں کی رسوائی اور برائی ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mcmxxix{ان کا حال یہ ہے کہ) جب فرشتے ان کی روحیں قبض کرنے لگتے ہیں (اور یہ) اپنے ہی حق میں ظلم کرنے والے (ہوتے ہیں) تو مطیع ومنقاد ہوجاتے ہیں (اور کہتے ہیں) کہ ہم کوئی برا کام نہیں کرتے تھے۔ ہاں جو کچھ تم کیا کرتے تھے خدا اسے خوب جانتا ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mcmxxx{سو دوزخ کے دروازوں میں داخل ہوجاؤ۔ ہمیشہ اس میں رہو گے۔ اب تکبر کرنے والوں کا برا ٹھکانا ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mcmxxxi{اور (جب) پرہیزگاروں سے پوچھا جاتا ہے کہ تمہارے پروردگار نے کیا نازل کیا ہے۔ تو کہتے ہیں کہ بہترین (کلام) ۔ جو لوگ نیکوکار ہیں ان کے لیے اس دنیا میں بھلائی ہے۔ اور آخرت کا گھر تو بہت ہی اچھا ہے۔ اور پرہیز گاروں کا گھر بہت خوب ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mcmxxxii{وہ) بہشت جاودانی (ہیں) جن میں وہ داخل ہوں گے ان کے نیچے نہریں بہہ رہی ہیں وہاں جو چاہیں گے ان کے لیے میسر ہوگا۔ خدا پرہیزگاروں کو ایسا ہی بدلہ دیتا ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mcmxxxiii{ان کی کیفیت یہ ہے کہ) جب فرشتے ان کی جانیں نکالنے لگتے ہیں اور یہ (کفر وشرک سے) پاک ہوتے ہیں تو سلام علیکم کہتے ہیں (اور کہتے ہیں کہ) جو عمل تم کیا کرتے تھے ان کے بدلے میں بہشت میں داخل ہوجاؤ\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mcmxxxiv{کیا یہ (کافر) اس بات کے منتظر ہیں کہ فرشتے ان کے پاس (جان نکالنے) آئیں یا تمہارے پروردگار کا حکم (عذاب) آپہنچے۔ اسی طرح اُن لوگوں نے کیا تھا جو اُن سے پہلے تھے اور خدا نے اُن پر ظلم نہیں کیا بلکہ وہ خود اپنے آپ پر ظلم کرتے تھے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mcmxxxv{تو ان کو ان کے اعمال کے برے بدلے ملے اور جس چیز کے ساتھ وہ ٹھٹھے کیا کرتے تھے اس نے ان کو (ہر طرف سے) گھیر لیا\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mcmxxxvi{اور مشرک کہتے ہیں کہ اگر خدا چاہتا تو نہ ہم ہی اس کے سوا کسی چیز کو پوجتے اور نہ ہمارے بڑے ہی (پوجتے) اور نہ اس کے (فرمان کے) بغیر ہم کسی چیز کو حرام ٹھہراتے۔ (اے پیغمبر) اسی طرح ان سے اگلے لوگوں نے کیا تھا۔ تو پیغمبروں کے ذمے (خدا کے احکام کو) کھول کر سنا دینے کے سوا اور کچھ نہیں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mcmxxxvii{اور ہم نے ہر جماعت میں پیغمبر بھیجا کہ خدا ہی کی عبادت کرو اور بتوں (کی پرستش) سے اجتناب کرو۔ تو ان میں بعض ایسے ہیں جن کو خدا نے ہدایت دی اور بعض ایسے ہیں جن پر گمراہی ثابت ہوئی۔ سو زمین پر چل پھر کر دیکھ لو کہ جھٹلانے والوں کا انجام کیسا ہوا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mcmxxxviii{اگر تم ان (کفار) کی ہدایت کے لیے للچاؤ تو جس کو خدا گمراہ کردیتا ہے اس کو وہ ہدایت نہیں دیا کرتا اور ایسے لوگوں کا کوئی مددگار بھی نہیں ہوتا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mcmxxxix{اور یہ خدا کی سخت سخت قسمیں کھاتے ہیں کہ جو مرجاتا ہے خدا اسے (قیامت کے دن قبر سے) نہیں اٹھائے گا۔ ہرگز نہیں۔ یہ (خدا کا) وعدہ سچا ہے اور اس کا پورا کرنا اسے ضرور ہے لیکن اکثر لوگ نہیں جانتے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mcmxl{تاکہ جن باتوں میں یہ اختلاف کرتے ہیں وہ ان پر ظاہر کردے اور اس لیے کہ کافر جان لیں کہ وہ جھوٹے تھے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mcmxli{جب ہم کسی چیز کا ارادہ کرتے ہیں تو ہماری بات یہی ہے کہ اس کو کہہ دیتے ہیں کہ ہوجا تو وہ ہوجاتی ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mcmxlii{اور جن لوگوں نے ظلم سہنے کے بعد خدا کے لیے وطن چھوڑا ہم ان کو دنیا میں اچھا ٹھکانا دیں گے۔ اور آخرت کا اجر تو بہت بڑا ہے۔ کاش وہ (اسے) جانتے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mcmxliii{یعنی وہ لوگ جو صبر کرتے ہیں اور اپنے پروردگار پر بھروسا رکھتے ہیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mcmxliv{اور ہم نے تم سے پہلے مردوں ہی کو پیغمبر بنا کر بھیجا تھا جن کی طرف ہم وحی بھیجا کرتے تھے اگر تم لوگ نہیں جانتے تو اہل کتاب سے پوچھ لو\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mcmxlv{اور ان پیغمبروں کو) دلیلیں اور کتابیں دے کر (بھیجا تھا) اور ہم نے تم پر بھی یہ کتاب نازل کی ہے تاکہ جو (ارشادات) لوگوں پر نازل ہوئے ہیں وہ ان پر ظاہر کردو اور تاکہ وہ غور کریں\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mcmxlvi{کیا جو لوگ بری بری چالیں چلتے ہیں اس بات سے بےخوف ہیں کہ خدا ان کو زمین میں دھنسا دے یا (ایسی طرف سے) ان پر عذاب آجائے جہاں سے ان کو خبر ہی نہ ہو\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mcmxlvii{یا ان کو چلتے پھرتے پکڑ لے وہ (خدا کو) عاجز نہیں کرسکتے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mcmxlviii{یا جب ان کو عذاب کا ڈر پیدا ہوگیا ہو تو ان کو پکڑلے۔ بےشک تمہارا پروردگار بہت شفقت کرنے والا اور مہربان ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mcmxlix{کیا ان لوگوں نے خدا کی مخلوقات میں سے ایسی چیزیں نہیں دیکھیں جن کے سائے دائیں سے (بائیں کو) اور بائیں سے (دائیں کو) لوٹتے رہتے ہیں (یعنی) خدا کے آگے عاجز ہو کر سجدے میں پڑے رہتے ہیں\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mcml{اور تمام جاندار جو آسمانوں میں ہیں اور جو زمین میں ہیں سب خدا کے آگے سجدہ کرتے ہیں اور فرشتے بھی اور وہ ذرا غرور نہیں کرتے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mcmli{اور اپنے پروردگار سے جو ان کے اوپر ہے ڈرتے ہیں اور جو ان کو ارشاد ہوتا ہے اس پر عمل کرتے ہیں\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mcmlii{اور خدا نے فرمایا ہے کہ دو دو معبود نہ بناؤ۔ معبود وہی ایک ہے۔ تو مجھ ہی سے ڈرتے رہو\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mcmliii{اور جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے سب اسی کا ہے اور اسی کی عبادت لازم ہے۔ تو تم خدا کے سوا اوروں سے کیوں ڈرتے ہو\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mcmliv{اور جو نعمتیں تم کو میسر ہیں سب خدا کی طرف سے ہیں۔ پھر جب تم کو کوئی تکلیف پہنچتی ہے تو اسی کے آگے چلاتے ہو\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mcmlv{پھر جب وہ تم سے تکلیف کو دور کردیتا ہے تو کچھ لوگ تم میں سے خدا کے ساتھ شریک کرنے لگتے ہیں\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mcmlvi{تاکہ جو (نعمتیں) ہم نے ان کو عطا فرمائی ہیں ان کی ناشکری کریں تو (مشرکو) دنیا میں فائدے اٹھالو۔ عنقریب تم کو (اس کا انجام) معلوم ہوجائے گا\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mcmlvii{اور ہمارے دیئے ہوئے مال میں سے ایسی چیزوں کا حصہ مقرر کرتے ہیں جن کو جانتے ہی نہیں۔ (کافرو) خدا کی قسم کہ جو تم افتراء کرتے ہو اس کی تم سے ضرور پرسش ہوگی\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mcmlviii{اور یہ لوگ خدا کے لیے تو بیٹیاں تجویز کرتے ہیں۔ (اور) وہ ان سے پاک ہے اور اپنے لیے (بیٹے) جو مرغوب ودلپسند ہیں\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mcmlix{حالانکہ جب ان میں سے کسی کو بیٹی (کے پیدا ہونے) کی خبر ملتی ہے تو اس کا منہ (غم کے سبب) کالا پڑ جاتا ہے اور (اس کے دل کو دیکھو تو) وہ اندوہناک ہوجاتا ہے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mcmlx{اور اس خبر بد سے (جو وہ سنتا ہے) لوگوں سے چھپتا پھرتا ہے (اور سوچتا ہے) کہ آیا ذلت برداشت کرکے لڑکی کو زندہ رہنے دے یا زمین میں گاڑ دے۔ دیکھو یہ جو تجویز کرتے ہیں بہت بری ہے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mcmlxi{جو لوگ آخرت پر ایمان نہیں رکھتے ان ہی کے لیے بری باتیں (شایان) ہیں۔ اور خدا کو صفت اعلیٰ (زیب دیتی ہے) اور وہ غالب حکمت والا ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mcmlxii{اور اگر خدا لوگوں کو ان کے ظلم کے سبب پکڑنے لگے تو ایک جاندار کو زمین پر نہ چھوڑے لیکن ان کو ایک وقت مقرر تک مہلت دیئے جاتا ہے۔ جب وہ وقت آجاتا ہے تو ایک گھڑی نہ پیچھے رہ سکتے ہیں نہ آگے بڑھ سکتے ہیں\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mcmlxiii{اور یہ خدا کے لیے ایسی چیزیں تجویز کرتے ہیں جن کو خود ناپسند کرتے ہیں اور زبان سے جھوٹ بکے جاتے ہیں کہ ان کو (قیامت کے دن) بھلائی (یعنی نجات) ہوگی۔ کچھ شک نہیں کہ ان کے لیے (دوزخ کی) آگ (تیار) ہے اور یہ (دوزخ میں) سب سے آگے بھیجے جائیں گے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mcmlxiv{خدا کی قسم ہم نے تم سے پہلی امتوں کی طرف بھی پیغمبر بھیجے تو شیطان نے ان کے کردار (ناشائستہ) ان کو آراستہ کر دکھائے تو آج بھی وہی ان کا دوست ہے اور ان کے لیے عذاب الیم ہے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mcmlxv{اور ہم نے جو تم پر کتاب نازل کی ہے تو اس کے لیے جس امر میں ان لوگوں کو اختلاف ہے تم اس کا فیصلہ کردو۔ اور (یہ) مومنوں کے لیے ہدایت اور رحمت ہے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mcmlxvi{اور خدا ہی نے آسمان سے پانی برسایا پھر اس سے زمین کو اس کے مرنے کے بعد زندہ کیا۔ بےشک اس میں سننے والوں کے لیے نشانی ہے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mcmlxvii{اور تمہارے لیے چارپایوں میں بھی (مقام) عبرت (وغور) ہے کہ ان کے پیٹوں میں جو گوبر اور لہو ہے اس سے ہم تم کو خالص دودھ پلاتے ہیں جو پینے والوں کے لیے خوشگوار ہے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mcmlxviii{اور کھجور اور انگور کے میووں سے بھی (تم پینے کی چیزیں تیار کرتے ہو کہ ان سے شراب بناتے ہو) اور عمدہ رزق (کھاتے ہو) جو لوگ سمجھ رکھتے ہیں ان کے لیے ان (چیزوں) میں (قدرت خدا کی) نشانی ہے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mcmlxix{اور تمہارے پروردگار نے شہد کی مکھیوں کو ارشاد فرمایا کہ پہاڑوں میں اور درختوں میں اور اونچی اونچی چھتریوں میں جو لوگ بناتے ہیں گھر بنا\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mcmlxx{اور ہر قسم کے میوے کھا۔ اور اپنے پروردگار کے صاف رستوں پر چلی جا۔ اس کے پیٹ سے پینے کی چیز نکلتی ہے جس کے مختلف رنگ ہوتے ہیں اس میں لوگوں (کے کئی امراض) کی شفا ہے۔ بےشک سوچنے والوں کے لیے اس میں بھی نشانی ہے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mcmlxxi{اور خدا ہی نے تم کو پیدا کیا۔ پھر وہی تم کو موت دیتا ہے اور تم میں بعض ایسے ہوتے ہیں کہ نہایت خراب عمر کو پہنچ جاتے ہیں اور (بہت کچھ) جاننے کے بعد ہر چیز سے بےعلم ہوجاتے ہیں۔ بےشک خدا (سب کچھ) جاننے والا (اور) قدرت والا ہے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mcmlxxii{اور خدا نے رزق (ودولت) میں بعض کو بعض پر فضیلت دی ہے تو جن لوگوں کو فضیلت دی ہے وہ اپنا رزق اپنے مملوکوں کو تو دے ڈالنے والے ہیں نہیں کہ سب اس میں برابر ہوجائیں۔ تو کیا یہ لوگ نعمت الہیٰ کے منکر ہیں\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mcmlxxiii{اور خدا ہی نے تم میں سے تمہارے لیے عورتیں پیدا کیں اور عورتوں سے تمہارے بیٹے اور پوتے پیدا کیے اور کھانے کو تمہیں پاکیزہ چیزیں دیں۔ تو کیا بےاصل چیزوں پر اعتقاد رکھتے اور خدا کی نعمتوں سے انکار کرتے ہیں\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mcmlxxiv{اور خدا کے سوا ایسوں کو پوجتے ہیں جو ان کو آسمانوں اور زمین میں روزی دینے کا ذرا بھی اختیار نہیں رکھتے اور نہ کسی اور طرح کا مقدور رکھتے ہیں\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mcmlxxv{تو (لوگو) خدا کے بارے میں (غلط) مثالیں نہ بناؤ۔ (صحیح مثالوں کا طریقہ) خدا ہی جانتا ہے اور تم نہیں جانتے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mcmlxxvi{خدا ایک اور مثال بیان فرماتا ہے کہ ایک غلام ہے جو (بالکل) دوسرے کے اختیار میں ہے اور کسی چیز پر قدرت نہیں رکھتا اور ایک ایسا شخص ہے جس کو ہم نے اپنے ہاں سے (بہت سا) مال طیب عطا فرمایا ہے اور وہ اس میں سے (رات دن) پوشیدہ اور ظاہر خرچ کرتا رہتا ہے تو کیا یہ دونوں شخص برابر ہیں؟ (ہرگز نہیں) الحمدلله لیکن ان میں سے اکثر لوگ نہیں سمجھ رکھتے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mcmlxxvii{اور خدا ایک اور مثال بیان فرماتا ہے کہ دو آدمی ہیں ایک اُن میں سے گونگا (اور دوسرے کی ملک) ہے (بےاختیار وناتوان) کہ کسی چیز پر قدرت نہیں رکھتا۔ اور اپنے مالک کو دوبھر ہو رہا ہے وہ جہاں اُسے بھیجتا ہے (خیر سے کبھی) بھلائی نہیں لاتا۔ کیا ایسا (گونگا بہرا) اور وہ شخص جو (سنتا بولتا اور) لوگوں کو انصاف کرنے کا حکم دیتا ہے اور خود سیدھے راستے پر چل رہا ہے دونوں برابر ہیں؟\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mcmlxxviii{اور آسمانوں اور زمین کا علم خدا ہی کو ہے اور (خدا کے نزدیک) قیامت کا آنا یوں ہے جیسے آنکھ کا جھپکنا بلکہ اس سے بھی جلد تر۔ کچھ شک نہیں کہ خدا ہر چیز پر قادر ہے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mcmlxxix{اور خدا ہی نے تم کو تمہاری ماؤں کے شکم سے پیدا کیا کہ تم کچھ نہیں جانتے تھے۔ اور اس نے تم کو کان اور آنکھیں اور دل (اور اُن کے علاوہ اور) اعضا بخشے تاکہ تم شکر کرو\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mcmlxxx{کیا ان لوگوں نے پرندوں کو نہیں دیکھا کہ آسمان کی ہوا میں گھرے ہوئے (اُڑتے رہتے) ہیں۔ ان کو خدا ہی تھامے رکھتا ہے۔ ایمان والوں کے لیے اس میں (بہت سی) نشانیاں ہیں\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mcmlxxxi{اور خدا ہی نے تمہارے لیے گھروں کو رہنے کی جگہ بنایا اور اُسی نے چوپایوں کی کھالوں سے تمہارے لیے ڈیرے بنائے۔ جن کو تم سبک دیکھ کر سفر اور حضر میں کام میں لاتے ہو اور اُن کی اون، پشم اور بالوں سے تم اسباب اور برتنے کی چیزیں (بناتے ہو جو) مدت تک (کام دیتی ہیں)\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mcmlxxxii{اور خدا ہی نے تمہارے (آرام کے) لیے اپنی پیدا کی ہوئی چیزوں کے سائے بنائے اور پہاڑوں میں غاریں بنائیں اور کُرتے بنائے جو تم کو گرمی سے بچائیں۔ اور (ایسے) کُرتے (بھی) جو تم کو اسلحہ جنگ (کے ضرر) سے محفوظ رکھیں۔ اسی طرح خدا اپنا احسان تم پر پورا کرتا ہے تاکہ تم فرمانبردار بنو\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiii{اور اگر یہ لوگ اعتراض کریں تو (اے پیغمبر) تمہارا کام فقط کھول کر سنا دینا ہے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mcmlxxxiv{یہ خدا کی نعمتوں سے واقف ہیں۔ مگر (واقف ہو کر) اُن سے انکار کرتے ہیں اور یہ اکثر ناشکرے ہیں\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mcmlxxxv{اور جس دن ہم ہر اُمت میں سے گواہ (یعنی پیغمبر) کھڑا کریں گے تو نہ تو کفار کو (بولنے کی) اجازت ملے گی اور نہ اُن کے عذر قبول کئے جائیں گے\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvi{اور جب ظالم لوگ عذاب دیکھ لیں گے تو پھر نہ تو اُن کے عذاب ہی میں تخفیف کی جائے گی اور نہ اُن کو مہلت ہی دی جائے گی\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mcmlxxxvii{اور جب مشرک (اپنے بنائے ہوئے) شریکوں کو دیکھیں گے تو کہیں گے کہ پروردگار یہ وہی ہمارے شریک ہیں جن کو ہم تیرے سوا پُکارا کرتے تھے۔ تو وہ (اُن کے کلام کو مسترد کردیں گے اور) اُن سے کہیں گے کہ تم تو جھوٹے ہو\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mcmlxxxviii{اور اس دن خدا کے سامنے سرنگوں ہو جائیں گے اور جو طوفان وہ باندھا کرتے تھے سب اُن سے جاتا رہے گا\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mcmlxxxix{جن لوگوں نے کفر کیا اور (لوگوں کو) خدا کے رستے سے روکا ہم اُن کو عذاب پر عذاب دیں گے۔ اس لیے کہ شرارت کیا کرتے تھے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mcmxc{اور (اس دن کو یاد کرو) جس دن ہم ہر اُمت میں سے خود اُن پر گواہ کھڑے کریں گے۔ اور (اے پیغمبر) تم کو ان لوگوں پر گواہ لائیں گے۔ اور ہم نے تم پر (ایسی) کتاب نازل کی ہے کہ (اس میں) ہر چیز کا بیان (مفصل) ہے اور مسلمانوں کے لیے ہدایت اور رحمت اور بشارت ہے\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mcmxci{خدا تم کو انصاف اور احسان کرنے اور رشتہ داروں کو (خرچ سے مدد) دینے کا حکم دیتا ہے۔ اور بےحیائی اور نامعقول کاموں سے اور سرکشی سے منع کرتا ہے (اور) تمہیں نصیحت کرتا ہے تاکہ تم یاد رکھو\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mcmxcii{اور جب خدا سے عہد واثق کرو تو اس کو پورا کرو اور جب پکی قسمیں کھاؤ تو اُن کو مت توڑو کہ تم خدا کو اپنا ضامن مقرر کرچکے ہو۔ اور جو کچھ تم کرتے ہو خدا اس کو جانتا ہے\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mcmxciii{اور اُس عورت کی طرح نہ ہونا جس نے محنت سے تو سوت کاتا۔ پھر اس کو توڑ کر ٹکڑے ٹکڑے کر ڈالا۔ کہ تم اپنی قسموں کو آپس میں اس بات کا ذریعہ بنانے لگو کہ ایک گروہ دوسرے گروہ سے زیادہ غالب رہے۔ بات یہ ہے کہ خدا تمہیں اس سے آزماتا ہے۔ اور جن باتوں میں تم اختلاف کرتے ہو قیامت کو اس کی حقیقت تم پر ظاہر کر دے گا\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mcmxciv{اور اگر خدا چاہتا تو تم (سب) کو ایک ہی جماعت بنا دیتا۔ لیکن وہ جسے چاہتا ہے گمراہ کرتا ہے اور جسے چاہتا ہے ہدایت دیتا ہے۔ اور جو عمل تم کرتے ہو (اُس دن) اُن کے بارے میں تم سے ضرور پوچھا جائے گا\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mcmxcv{اور اپنی قسموں کو آپس میں اس بات کا ذریعہ نہ بناؤ کہ (لوگوں کے) قدم جم چکنے کے بعد لڑ کھڑا جائیں اور اس وجہ سے کہ تم نے لوگوں کو خدا کے رستے سے روکا تم کو عقوبت کا مزہ چکھنا پڑے۔ اور بڑا سخت عذاب ملے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mcmxcvi{اور خدا سے جو تم نے عہد کیا ہے (اس کو مت بیچو اور) اس کے بدلے تھوڑی سی قیمت نہ لو۔ (کیونکہ ایفائے عہد کا) جو صلہ خدا کے ہاں مقرر ہے وہ اگر سمجھو تو تمہارے لیے بہتر ہے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mcmxcvii{جو کچھ تمہارے پاس ہے وہ ختم ہو جاتا ہے اور جو خدا کے پاس ہے وہ باقی ہے کہ (کبھی ختم نہیں ہوگا) اور جن لوگوں نے صبر کیا ہم اُن کو ان کے اعمال کا بہت اچھا بدلہ دیں گے\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mcmxcviii{جو شخص نیک اعمال کرے گا مرد ہو یا عورت وہ مومن بھی ہوگا تو ہم اس کو (دنیا میں) پاک (اور آرام کی) زندگی سے زندہ رکھیں گے اور (آخرت میں) اُن کے اعمال کا نہایت اچھا صلہ دیں گے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mcmxcix{اور جب تم قرآن پڑھنے لگو تو شیطان مردود سے پناہ مانگ لیا کرو\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mm{کہ جو مومن ہیں اپنے پروردگار پر بھروسہ رکھتے ہیں اُن پر اس کا کچھ زور نہیں چلتا\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmi{اس کا زور ان ہی لوگوں پر چلتا ہے جو اس کو رفیق بناتے ہیں اور اس کے (وسوسے کے) سبب (خدا کے ساتھ) شریک مقرر کرتے ہیں\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmii{اور جب ہم کوئی آیت کسی آیت کی جگہ بدل دیتے ہیں۔ اور خدا جو کچھ نازل فرماتا ہے اسے خوب جانتا ہے تو (کافر) کہتے ہیں کہ تم یونہی اپنی طرف سے بنا لاتے ہو۔ حقیقت یہ ہے کہ ان میں اکثر نادان ہیں\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmiii{کہہ دو کہ اس کو روح القدس تمہارے پروردگار کی طرف سے سچائی کے ساتھ لے کر نازل ہوئے ہیں تاکہ یہ (قرآن) مومنوں کو ثابت قدم رکھے اور حکم ماننے والوں کے لئے تو (یہ) ہدایت اور بشارت ہے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmiv{اور ہمیں معلوم ہے کہ یہ کہتے ہیں کہ اس (پیغمبر) کو ایک شخص سکھا جاتا ہے۔ مگر جس کی طرف (تعلیم کی) نسبت کرتے ہیں اس کی زبان تو عجمی ہے اور یہ صاف عربی زبان ہے\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmv{یہ لوگ خدا کی آیتوں پر ایمان نہیں لاتے ان کو خدا ہدایت نہیں دیتا اور ان کے لئے عذاب الیم ہے\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmvi{جھوٹ افتراء تو وہی لوگ کیا کرتے ہیں جو خدا کی آیتوں پر ایمان نہیں لاتے۔ اور وہی جھوٹے ہیں\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmvii{جو شخص ایمان لانے کے بعد خدا کے ساتھ کفر کرے وہ نہیں جو (کفر پر زبردستی) مجبور کیا جائے اور اس کا دل ایمان کے ساتھ مطمئن ہو۔ بلکہ وہ جو (دل سے اور) دل کھول کر کفر کرے۔ تو ایسوں پر الله کا غضب ہے۔ اور ان کو بڑا سخت عذاب ہوگا\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmviii{یہ اس لئے کہ انہوں نے دنیا کی زندگی کو آخرت کے مقابلے میں عزیز رکھا۔ اور اس لئے خدا کافر لوگوں کو ہدایت نہیں دیتا\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmix{یہی لوگ ہیں جن کے دلوں پر اور کانوں پر اور آنکھوں پر خدا نے مہر لگا رکھی ہے۔ اور یہی غفلت میں پڑے ہوئے ہیں\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmx{کچھ شک نہیں کہ یہ آخرت میں خسارہ اٹھانے والے ہوں گے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmxi{پھر جن لوگوں نے ایذائیں اٹھانے کے بعد ترک وطن کیا۔ پھر جہاد کئے اور ثابت قدم رہے تمہارا پروردگار ان کو بےشک ان (آزمائشوں) کے بعد بخشنے والا (اور ان پر) رحمت کرنے والا ہے\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmxii{جس دن ہر متنفس اپنی طرف سے جھگڑا کرنے آئے گا۔ اور ہر شخص کو اس کے اعمال کا پورا پورا بدلہ دیا جائے گا۔ اور کسی کا نقصان نہیں کیا جائے گا\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmxiii{اور خدا ایک بستی کی مثال بیان فرماتا ہے کہ (ہر طرح) امن چین سے بستی تھی ہر طرف سے رزق بافراغت چلا آتا تھا۔ مگر ان لوگوں نے خدا کی نعمتوں کی ناشکری کی تو خدا نے ان کے اعمال کے سبب ان کو بھوک اور خوف کا لباس پہنا کر (ناشکری کا) مزہ چکھا دیا\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmxiv{اور ان کے پاس ان ہی میں سے ایک پیغمبر آیا تو انہوں نے اس کو جھٹلایا سو ان کو عذاب نے آپکڑا اور وہ ظالم تھے\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mmxv{پس خدا نے جو تم کو حلال طیّب رزق دیا ہے اسے کھاؤ۔ اور الله کی نعمتوں کا شکر کرو۔ اگر اسی کی عبادت کرتے ہو\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mmxvi{اس نے تم پر مُردار اور لہو اور سور کا گوشت حرام کردیا ہے اور جس چیز پر خدا کے سوا کسی اور کا نام پکارا جائے (اس کو بھی) ہاں اگر کوئی ناچار ہوجائے تو بشرطیکہ گناہ کرنے والا نہ ہو اور نہ حد سے نکلنے والا تو خدا بخشنے والا مہربان ہے\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mmxvii{اور یوں ہی جھوٹ جو تمہاری زبان پر آجائے مت کہہ دیا کرو کہ یہ حلال ہے اور یہ حرام ہے کہ خدا پر جھوٹ بہتان باندھنے لگو۔ جو لوگ خدا پر جھوٹ بہتان باندھتے ہیں ان کا بھلا نہیں ہوگا\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mmxviii{جھوٹ کا) فائدہ تو تھوڑا سا ہے مگر (اس کے بدلے) ان کو عذاب الیم بہت ہوگا\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mmxix{اور چیزیں ہم تم سے پہلے بیان کرچکے ہیں وہ ہم نے یہودیوں پر حرام کردی تھیں۔ اور ہم نے ان پر کچھ ظلم نہیں کیا بلکہ وہی اپنے آپ پر ظلم کرتے تھے\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mmxx{پھر جن لوگوں نے نادانی سے برا کام کیا۔ پھر اس کے بعد توبہ کی اور نیکوکار ہوگئے تو تمہارا پروردگار (ان کو) توبہ کرنے اور نیکوکار ہوجانے کے بعد بخشنے والا اور ان پر رحمت کرنے والا ہے\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mmxxi{بےشک ابراہیم (لوگوں کے) امام اور خدا کے فرمانبردار تھے۔ جو ایک طرف کے ہو رہے تھے اور مشرکوں میں سے نہ تھے\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mmxxii{اس کی نعمتوں کے شکرگزار تھے۔ خدا نے ان کو برگزیدہ کیا تھا اور (اپنی) سیدھی راہ پر چلایا تھا\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mmxxiii{اور ہم نے ان کو دنیا میں بھی خوبی دی تھی۔ اور وہ آخرت میں بھی نیک لوگوں میں ہوں گے\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mmxxiv{پھر ہم نے تمہاری طرف وحی بھیجی کہ دین ابراہیم کی پیروی اختیار کرو جو ایک طرف کے ہو رہے تھے اور مشرکوں میں سے نہ تھے\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mmxxv{ہفتے کا دن تو ان ہی لوگوں کے لئے مقرر کیا گیا تھا۔ جنہوں نے اس میں اختلاف کیا۔ اور تمہارا پروردگار قیامت کے دن ان میں ان باتوں کا فیصلہ کردے گا جن میں وہ اختلاف کرتے تھے\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mmxxvi{اے پیغمبر) لوگوں کو دانش اور نیک نصیحت سے اپنے پروردگار کے رستے کی طرف بلاؤ۔ اور بہت ہی اچھے طریق سے ان سے مناظرہ کرو۔ جو اس کے رستے سے بھٹک گیا تمہارا پروردگار اسے بھی خوب جانتا ہے اور جو رستے پر چلنے والے ہیں ان سے بھی خوب واقف ہے\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mmxxvii{اور اگر تم ان کو تکلیف دینی چاہو تو اتنی ہی دو جتنی تکلیف تم کو ان سے پہنچی۔ اور اگر صبر کرو تو وہ صبر کرنے والوں کے لیے بہت اچھا ہے\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mmxxviii{اور صبر ہی کرو اور تمہارا صبر بھی خدا ہی کی مدد سے ہے اور ان کے بارے میں غم نہ کرو اور جو یہ بداندیشی کرتے ہیں اس سے تنگدل نہ ہو\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mmxxix{کچھ شک نہیں کہ جو پرہیزگار ہیں اور جو نیکوکار ہیں خدا ان کا مددگار ہے\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mmxxx{\basmalahur وہ (ذات) پاک ہے جو ایک رات اپنے بندے کو مسجدالحرام یعنی (خانہٴ کعبہ) سے مسجد اقصیٰ (یعنی بیت المقدس) تک جس کے گردا گرد ہم نے برکتیں رکھی ہیں لے گیا تاکہ ہم اسے اپنی (قدرت کی) نشانیاں دکھائیں۔ بےشک وہ سننے والا (اور) دیکھنے والا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmxxxi{اور ہم نے موسیٰ کو کتاب عنایت کی تھی اور اس کو بنی اسرائیل کے لئے رہنما مقرر کیا تھا کہ میرے سوا کسی کو کارساز نہ ٹھہرانا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmxxxii{اے اُن لوگوں کی اولاد جن کو ہم نے نوح کے ساتھ (کشتی میں) سوار کیا تھا۔ بےشک نوح (ہمارے) شکرگزار بندے تھے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmxxxiii{اور ہم نے کتاب میں بنی اسرائیل سے کہہ دیا تھا کہ زمین میں دو دفعہ فساد مچاؤ گے اور بڑی سرکشی کرو گے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmxxxiv{پس جب پہلے (وعدے) کا وقت آیا تو ہم نے سخت لڑائی لڑنے والے بندے تم پر مسلط کردیئے اور وہ شہروں کے اندر پھیل گئے۔ اور وہ وعدہ پورا ہو کر رہا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmxxxv{پھر ہم نے دوسری بات تم کو اُن پر غلبہ دیا اور مال اور بیٹوں سے تمہاری مدد کی۔ اور تم کو جماعت کثیر بنا دیا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmxxxvi{اگر تم نیکوکاری کرو گے تو اپنی جانوں کے لئے کرو گے۔ اور اگر اعمال بد کرو گے تو (اُن کا) وبال بھی تمہاری ہی جانوں پر ہوگا پھر جب دوسرے (وعدے) کا وقت آیا (تو ہم نے پھر اپنے بندے بھیجے) تاکہ تمہارے چہروں کو بگاڑ دیں اور جس طرح پہلی دفعہ مسجد (بیت المقدس) میں داخل ہوگئے تھے اسی طرح پھر اس میں داخل ہوجائیں اور جس چیز پر غلبہ پائیں اُسے تباہ کردیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmxxxvii{امید ہے کہ تمہارا پروردگار تم پر رحم کرے، اور اگر تم پھر وہی (حرکتیں) کرو گے تو ہم بھی (وہی پہلا سلوک) کریں گے اور ہم نے جہنم کو کافروں کے لئے قید خانہ بنا رکھا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmxxxviii{یہ قرآن وہ رستہ دکھاتا ہے جو سب سے سیدھا ہے اور مومنوں کو جو نیک عمل کرتے ہیں بشارت دیتا ہے کہ اُن کے لئے اجر عظیم ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmxxxix{اور یہ بھی (بتاتا ہے) کہ جو آخرت پر ایمان نہیں رکھتے اُن کے لئے ہم نے دکھ دینے والا عذاب تیار کر رکھا ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmxl{اور انسان جس طرح (جلدی سے) بھلائی مانگتا ہے اسی طرح برائی مانگتا ہے۔ اور انسان جلد باز (پیدا ہوا) ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmxli{اور ہم نے دن اور رات کو دو نشانیاں بنایا ہے رات کی نشانی کو تاریک بنایا اور دن کی نشانی کو روشن۔ تاکہ تم اپنے پروردگار کا فضل (یعنی) روزی تلاش کرو اور برسوں کا شمار اور حساب جانو۔ اور ہم نے ہر چیز کو (بخوبی) تفصیل کردی ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmxlii{اور ہم نے ہر انسان کے اعمال کو (بہ صورت کتاب) اس کے گلے میں لٹکا دیا ہے۔ اور قیامت کے روز (وہ) کتاب اسے نکال دکھائیں گے جسے وہ کھلا ہوا دیکھے گا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmxliii{کہا جائے گا کہ) اپنی کتاب پڑھ لے۔ تو آج اپنا آپ ہی محاسب کافی ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmxliv{جو شخص ہدایت اختیار کرتا ہے تو اپنے لئے اختیار کرتا ہے۔ اور جو گمراہ ہوتا ہے گمراہی کا ضرر بھی اسی کو ہوگا۔ اور کوئی شخص کسی دوسرے کا بوجھ نہیں اٹھائے گا۔ اور جب تک ہم پیغمبر نہ بھیج لیں عذاب نہیں دیا کرتے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmxlv{اور جب ہمارا ارادہ کسی بستی کے ہلاک کرنے کا ہوا تو وہاں کے آسودہ لوگوں کو (فواحش پر) مامور کردیا تو وہ نافرمانیاں کرتے رہے۔ پھر اس پر (عذاب کا) حکم ثابت ہوگیا۔ اور ہم نے اسے ہلاک کر ڈالا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmxlvi{اور ہم نے نوح کے بعد بہت سی اُمتوں کو ہلاک کر ڈالا۔ اور تمہارا پروردگار اپنے بندوں کے گناہوں کو جاننے اور دیکھنے والا کافی ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmxlvii{جو شخص دنیا (کی آسودگی) کا خواہشمند ہو تو ہم اس میں سے جسے چاہتے ہیں اور جتنا چاہتے ہیں جلد دے دیتے ہیں۔ پھر اس کے لئے جہنم کو (ٹھکانا) مقرر کر رکھا ہے۔ جس میں وہ نفرین سن کر اور (درگاہ خدا سے) راندہ ہو کر داخل ہوگا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmxlviii{اور جو شخص آخرت کا خواستگار ہوا اور اس میں اتنی کوشش کرے جتنی اسے لائق ہے اور وہ مومن بھی ہو تو ایسے ہی لوگوں کی کوشش ٹھکانے لگتی ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmxlix{ہم اُن کو اور ان کو سب کو تمہارے پروردگار کی بخشش سے مدد دیتے ہیں۔ اور تمہارے پروردگار کی بخشش (کسی سے) رکی ہوئی نہیں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mml{دیکھو ہم نے کس طرح بعض کو بعض پر فضیلت بخشی ہے۔ اور آخرت درجوں میں (دنیا سے) بہت برتر اور برتری میں کہیں بڑھ کر ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmli{اور خدا کے ساتھ کوئی اور معبود نہ بنانا کہ ملامتیں سن کر اور بےکس ہو کر بیٹھے رہ جاؤ گے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmlii{اور تمہارے پروردگار نے ارشاد فرمایا ہے کہ اس کے سوا کسی کی عبادت نہ کرو اور ماں باپ کے ساتھ بھلائی کرتے رہو۔ اگر ان میں سے ایک یا دونوں تمہارے سامنے بڑھاپے کو پہنچ جائیں تو اُن کو اُف تک نہ کہنا اور نہ انہیں جھڑکنا اور اُن سے بات ادب کے ساتھ کرنا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmliii{اور عجزو نیاز سے ان کے آگے جھکے رہو اور ان کے حق میں دعا کرو کہ اے پروردگار جیسا انہوں نے مجھے بچپن میں (شفقت سے) پرورش کیا ہے تو بھی اُن (کے حال) پر رحمت فرما\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmliv{جو کچھ تمہارے دلوں میں ہے تمہارا پروردگار اس سے بخوبی واقف ہے۔ اگر تم نیک ہوگے تو وہ رجوع لانے والوں کو بخش دینے والا ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmlv{اور رشتہ داروں اور محتاجوں اور مسافروں کو ان کا حق ادا کرو۔ اور فضول خرچی سے مال نہ اُڑاؤ\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmlvi{کہ فضول خرچی کرنے والے تو شیطان کے بھائی ہیں۔ اور شیطان اپنے پروردگار (کی نعمتوں) کا کفر ان کرنے والا (یعنی ناشکرا) ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmlvii{اور اگر تم نے اپنے پروردگار کی رحمت (یعنی فراخ دستی) کے انتظار میں جس کی تمہیں امید ہو ان (مستحقین) کی طرف توجہ نہ کرسکو اُن سے نرمی سے بات کہہ دیا کرو\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmlviii{اور اپنے ہاتھ کو نہ تو گردن سے بندھا ہوا (یعنی بہت تنگ) کرلو (کہ کسی کچھ دو ہی نہیں) اور نہ بالکل کھول ہی دو (کہ سبھی دے ڈالو اور انجام یہ ہو) کہ ملامت زدہ اور درماندہ ہو کر بیٹھ جاؤ\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmlix{بےشک تمہارا پروردگار جس کی روزی چاہتا ہے فراخ کردیتا ہے اور (جس کی روزی چاہتا ہے) تنگ کردیتا ہے وہ اپنے بندوں سے خبردار ہے اور (ان کو) دیکھ رہا ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmlx{اور اپنی اولاد کو مفلسی کے خوف سے قتل نہ کرنا۔ (کیونکہ) ان کو اور تم کو ہم ہی رزق دیتے ہیں۔ کچھ شک نہیں کہ ان کا مار ڈالنا بڑا سخت گناہ ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmlxi{اور زنا کے بھی پاس نہ جانا کہ وہ بےحیائی اور بری راہ ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmlxii{اور جس کا جاندار کا مارنا خدا نے حرام کیا ہے اسے قتل نہ کرنا مگر جائز طور پر (یعنی بفتویٰ شریعت) ۔ اور جو شخص ظلم سے قتل کیا جائے ہم نے اس کے وارث کو اختیار دیا ہے (کہ ظالم قاتل سے بدلہ لے) تو اس کو چاہیئے کہ قتل (کے قصاص) میں زیادتی نہ کرے کہ وہ منصورو فتحیاب ہے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmlxiii{اور یتیم کے مال کے پاس بھی نہ پھٹکنا مگر ایسے طریق سے کہ بہت بہتر ہو یہاں تک کہ ہو جوانی کو پہنچ جائے۔ اور عہد کو پورا کرو کہ عہد کے بارے میں ضرور پرسش ہوگی\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmlxiv{اور جب (کوئی چیز) ناپ کر دینے لگو تو پیمانہ پورا بھرا کرو اور (جب تول کر دو تو) ترازو سیدھی رکھ کر تولا کرو۔ یہ بہت اچھی بات اور انجام کے لحاظ سے بھی بہت بہتر ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmlxv{اور (اے بندے) جس چیز کا تجھے علم نہیں اس کے پیچھے نہ پڑ۔ کہ کان اور آنکھ اور دل ان سب (جوارح) سے ضرور باز پرس ہوگی\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmlxvi{اور زمین پر اکڑ کر (اور تن کر) مت چل کہ تو زمین کو پھاڑ تو نہیں ڈالے گا اور نہ لمبا ہو کر پہاڑوں (کی چوٹی) تک پہنچ جائے گا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmlxvii{ان سب (عادتوں) کی برائی تیرے پروردگار کے نزدیک بہت ناپسند ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmlxviii{اے پیغمبر یہ ان (ہدایتوں) میں سے ہیں جو خدا نے دانائی کی باتیں تمہاری طرف وحی کی ہیں۔ اور خدا کے ساتھ کوئی معبود نہ بنانا کہ (ایسا کرنے سے) ملامت زدہ اور (درگاہ خدا سے) راندہ بنا کر جہنم میں ڈال دیئے جاؤ گے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmlxix{مشرکو!) کیا تمہارے پروردگار نے تم کو لڑکے دیئے اور خود فرشتوں کو بیٹیاں بنایا۔ کچھ شک نہیں کہ (یہ) تم بڑی (نامعقول بات) کہتے ہو\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmlxx{اور ہم نے اس قرآن میں طرح طرح کی باتیں بیان کی ہیں تاکہ لوگ نصیحت پکڑیں گے۔ مگر وہ اس سے اور بدک جاتے ہیں\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmlxxi{کہہ دو کہ اگر خدا کے ساتھ اور معبود ہوتے جیسا کہ یہ کہتے ہیں تو وہ ضرور (خدائے) مالک عرش کی طرف (لڑنے بھڑنے کے لئے) رستہ نکالتے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmlxxii{وہ پاک ہے اور جو کچھ یہ بکواس کرتے ہیں اس سے (اس کا رتبہ) بہت عالی ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmlxxiii{ساتوں آسمان اور زمین اور جو لوگ ان میں ہیں سب اسی کی تسبیح کرتے ہیں۔ اور (مخلوقات میں سے) کوئی چیز نہیں مگر اس کی تعریف کے ساتھ تسبیح کرتی ہے۔ لیکن تم ان کی تسبیح کو نہیں سمجھتے۔ بےشک وہ بردبار (اور) غفار ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmlxxiv{اور جب قرآن پڑھا کرتے ہو تو ہم تم میں اور ان لوگوں میں جو آخرت پر ایمان نہیں رکھتے حجاب پر حجاب کر دیتے ہیں\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmlxxv{اور ان کے دلوں پر پردہ ڈال دیتے ہیں کہ اسے سمجھ نہ سکیں اور ان کے کانوں میں ثقل پیدا کر دیتے ہیں۔ اور جب تم قرآن میں اپنے پروردگار یکتا کا ذکر کرتے ہو تو وہ بدک جاتے اور پیٹھ پھیر کر چل دیتے ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmlxxvi{یہ لوگ جب تمہاری طرف کان لگاتے ہیں تو جس نیت سے یہ سنتے ہیں ہم اسے خوب جانتے ہیں اور جب یہ سرگوشیاں کرتے ہیں (یعنی) جب ظالم کہتے ہیں کہ تم ایک ایسے شخص کی پیروی کرتے ہو جس پر جادو کیا گیا ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmlxxvii{دیکھو انہوں نے کس کس طرح کی تمہارے بارے میں باتیں بنائیں ہیں۔ سو یہ گمراہ ہو رہے ہیں اور رستہ نہیں پاسکتے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmlxxviii{اور کہتے ہیں کہ جب ہم (مر کر بوسیدہ) ہڈیوں اور چُور چُور ہوجائیں گے تو کیا ازسرنو پیدا ہو کر اُٹھیں گے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmlxxix{کہہ دو کہ (خواہ تم) پتھر ہوجاؤ یا لوہا\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmlxxx{یا کوئی اور چیز جو تمہارے نزدیک (پتھر اور لوہے سے بھی) بڑی (سخت) ہو (جھٹ کہیں گے) کہ (بھلا) ہمیں دوبارہ کون جِلائے گا؟ کہہ دو کہ وہی جس نے تم کو پہلی بار پیدا کیا۔ تو (تعجب سے) تمہارے آگے سرہلائیں گے اور پوچھیں گے کہ ایسا کب ہوگا؟ کہہ دو کہ امید ہے جلد ہوگا\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmlxxxi{جس دن وہ تمہیں پکارے گا تو تم اس کی تعریف کے ساتھ جواب دو گے اور خیال کرو گے کہ تم (دنیا میں) بہت کم (مدت) رہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmlxxxii{اور میرے بندوں سے کہہ دو کہ (لوگوں سے) ایسی باتیں کہا کریں جو بہت پسندیدہ ہوں۔ کیونکہ شیطان (بری باتوں سے) ان میں فساد ڈلوا دیتا ہے۔ کچھ شک نہیں کہ شیطان انسان کا کھلا دشمن ہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmlxxxiii{تمہارا پروردگار تم سے خوب واقف ہے۔ اگر چاہے تو تم پر رحم کرے یا اگر چاہے تو تمہیں عذاب دے۔ اور ہم نے تم کو ان پر داروغہ (بنا کر) نہیں بھیجا\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmlxxxiv{اور جو لوگ آسمانوں اور زمین میں ہیں تمہارا پروردگار ان سے خوب واقف ہے۔ اور ہم نے بعض پیغمبروں کو بعض پر فضیلت بخشی اور داؤد کو زبور عنایت کی\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmlxxxv{کہو کہ (مشرکو) جن لوگوں کی نسبت تمہیں (معبود ہونے کا) گمان ہے ان کو بلا کر دیکھو۔ وہ تم سے تکلیف کے دور کرنے یا اس کے بدل دینے کا کچھ بھی اختیار نہیں رکھتے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmlxxxvi{یہ لوگ جن کو (خدا کے سوا) پکارتے ہیں وہ خود اپنے پروردگار کے ہاں ذریعہ (تقرب) تلاش کرتے رہتے ہیں کہ کون ان میں (خدا کا) زیادہ مقرب ہوتا ہے اور اس کی رحمت کے امیدوار رہتے ہیں اور اس کے عذاب سے خوف رکھتے ہیں۔ بےشک تمہارے پروردگار کا عذاب ڈرنے کی چیز ہے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmlxxxvii{اور (کفر کرنے والوں کی) کوئی بستی نہیں مگر قیامت کے دن سے پہلے ہم اسے ہلاک کردیں گے یا سخت عذاب سے معذب کریں گے۔ یہ کتاب (یعنی تقدیر) میں لکھا جاچکا ہے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmlxxxviii{اور ہم نے نشانیاں بھیجنی اس لئے موقوف کردیں کہ اگلے لوگوں نے اس کی تکذیب کی تھی۔ اور ہم نے ثمود کو اونٹنی (نبوت صالح کی کھلی) نشانی دی۔ تو انہوں نے اس پر ظلم کیا اور ہم جو نشانیاں بھیجا کرتے ہیں تو ڈرانے کو\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmlxxxix{جب ہم نے تم سے کہا کہ تمہارا پروردگار لوگوں کو احاطہ کئے ہوئے ہے۔ اور جو نمائش ہم نے تمہیں دکھائی اس کو لوگوں کے لئے آرمائش کیا۔ اور اسی طرح (تھوہر کے) درخت کو جس پر قرآن میں لعنت کی گئی۔ اور ہم انہیں ڈراتے ہیں تو ان کو اس سے بڑی (سخت) سرکشی پیدا ہوتی ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmxc{اور جب ہم نے فرشتوں سے کہا کہ آدم کو سجدہ کرو تو سب نے سجدہ کیا مگر ابلیس نے نہ کیا۔ بولا کہ بھلا میں ایسے شخص کو سجدہ کرو جس کو تو نے مٹی سے پیدا کیا ہے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmxci{اور از راہ طنز) کہنے لگا کہ دیکھ تو یہی وہ ہے جسے تو نے مجھ پر فضیلت دی ہے۔ اگر تو مجھ کو قیامت کے دن تک مہلت دے تو میں تھوڑے سے شخصوں کے سوا اس کی (تمام) اولاد کی جڑ کاٹتا رہوں گا\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmxcii{خدا نے فرمایا (یہاں سے) چلا جا۔ جو شخص ان میں سے تیری پیروی کرے گا تو تم سب کی جزا جہنم ہے (اور وہ) پوری سزا (ہے)\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmxciii{اور ان میں سے جس کو بہکا سکے اپنی آواز سے بہکاتا رہ۔ اور ان پر اپنے سواروں اور پیاروں کو چڑھا کر لاتا رہ اور ان کے مال اور اولاد میں شریک ہوتا رہ اور ان سے وعدے کرتا رہ۔ اور شیطان جو وعدے ان سے کرتا ہے سب دھوکا ہے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmxciv{جو میرے (مخلص) بندے ہیں ان پر تیرا کچھ زور نہیں۔ اور (اے پیغمبر) تمہارا پروردگار کارساز کافی ہے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmxcv{تمہارا پروردگار وہ ہے جو تمہارے لئے دریا میں کشتیاں چلاتا ہے تاکہ تم اس کے فضل سے (روزی) تلاش کرو۔ بےشک وہ تم پر مہربان ہے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmxcvi{اور جب تم کو دریا میں تکلیف پہنچتی ہے (یعنی ڈوبنے کا خوف ہوتا ہے) تو جن کو تم پکارا کرتے ہو سب اس (پروردگار) کے سوا گم ہوجاتے ہیں۔ پھر جب وہ تم کو (ڈوبنے سے) بچا کر خشکی پر لے جاتا ہے تو تم منہ پھیر لیتے ہو اور انسان ہے ہی ناشکرا\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmxcvii{کیا تم (اس سے) بےخوف ہو کہ خدا تمہیں خشکی کی طرف (لے جا کر زمین میں) دھنسا دے یا تم پر سنگریزوں کی بھری ہوئی آندھی چلادے۔ پھر تم اپنا کوئی نگہبان نہ پاؤ\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmxcviii{یا (اس سے) بےخوف ہو کر تم دوسری دفعہ دریا میں لے جائے پھر تم پر تیز ہوا چلائے اور تمہارے کفر کے سبب تمہیں ڈبو دے۔ پھر تم اس غرق کے سبب اپنے لئے کوئی ہمارا پیچھا کرنے والا نہ پاؤ\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmxcix{اور ہم نے بنی آدم کو عزت بخشی اور ان کو جنگل اور دریا میں سواری دی اور پاکیزہ روزی عطا کی اور اپنی بہت سی مخلوقات پر فضیلت دی\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmc{جس دن ہم سب لوگوں کو ان کے پیشواؤں کے ساتھ بلائیں گے۔ تو جن (کے اعمال) کی کتاب ان کے داہنے ہاتھ میں دی جائے گی وہ اپنی کتاب کو (خوش ہو ہو کر) پڑھیں گے اور ان پر دھاگے برابر بھی ظلم نہ ہوگا\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmci{اور جو شخص اس (دنیا) میں اندھا ہو وہ آخرت میں بھی اندھا ہوگا۔ اور (نجات کے) رستے سے بہت دور\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmcii{اور اے پیغمبر جو وحی ہم نے تمہاری طرف بھیجی ہے قریب تھا کہ یہ (کافر) لوگ تم کو اس سے بچلا دیں تاکہ تم اس کے سوا اور باتیں ہماری نسبت بنالو۔ اور اس وقت وہ تم کو دوست بنا لیتے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmciii{اور اگر تم کو ثابت قدم نہ رہنے دیتے تو تم کسی قدر ان کی طرف مائل ہونے ہی لگے تھے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmciv{اس وقت ہم تم کو زندگی میں (عذاب کا) دونا اور مرنے پر بھی دونا مزا چکھاتے پھر تم ہمارے مقابلے میں کسی کو اپنا مددگار نہ پاتے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmcv{اور قریب تھا کہ یہ لوگ تمہیں زمین (مکہ) سے پھسلا دیں تاکہ تمہیں وہاں سے جلاوطن کر دیں۔ اور اس وقت تمہارے پیچھے یہ بھی نہ رہتے مگر کم\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmcvi{جو پیغمبر ہم نے تم سے پہلے بھیجے تھے ان کا (اور ان کے بارے میں ہمارا یہی) طریق رہا ہے اور تم ہمارے طریق میں تغیروتبدل نہ پاؤ گے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmcvii{اے محمدﷺ) سورج کے ڈھلنے سے رات کے اندھیرے تک (ظہر، عصر، مغرب، عشا کی) نمازیں اور صبح کو قرآن پڑھا کرو۔ کیوں صبح کے وقت قرآن کا پڑھنا موجب حضور (ملائکہ) ہے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmcviii{اور بعض حصہ شب میں بیدار ہوا کرو (اور تہجد کی نماز پڑھا کرو) ۔ (یہ شب خیزی) تمہاری لئے (سبب) زیادت ہے (ثواب اور نماز تہجد تم کو نفل) ہے قریب ہے کہ خدا تم کو مقام محمود میں داخل کرے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmcix{اور کہو کہ اے پروردگار مجھے (مدینے میں) اچھی طرح داخل کیجیو اور (مکے سے) اچھی طرح نکالیو۔ اور اپنے ہاں سے زور وقوت کو میرا مددگار بنائیو\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmcx{اور کہہ دو کہ حق آگیا اور باطل نابود ہوگیا۔ بےشک باطل نابود ہونے والا ہے\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmcxi{اور ہم قرآن (کے ذریعے) سے وہ چیز نازل کرتے ہیں جو مومنوں کے لئے شفا اور رحمت ہے اور ظالموں کے حق میں تو اس سے نقصان ہی بڑھتا ہے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmcxii{اور جب ہم انسان کو نعمت بخشتے ہیں تو ردگرداں ہوجاتا اور پہلو پھیر لیتا ہے۔ اور جب اسے سختی پہنچتی ہے تو ناامید ہوجاتا ہے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmcxiii{کہہ دو کہ ہر شخص اپنے طریق کے مطابق عمل کرتا ہے۔ سو تمہارا پروردگار اس شخص سے خوب واقف ہے جو سب سے زیادہ سیدھے رستے پر ہے\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmcxiv{اور تم سے روح کے بارے میں سوال کرتے ہیں۔ کہہ دو کہ وہ میرے پروردگار کی ایک شان ہے اور تم لوگوں کو (بہت ہی) کم علم دیا گیا ہے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmcxv{اور اگر ہم چاہیں تو جو (کتاب) ہم تمہاری طرف بھیجتے ہیں اسے (دلوں سے) محو کردیں۔ پھر تم اس کے لئے ہمارے مقابلے میں کسی کو مددگار نہ پاؤ\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmcxvi{مگر (اس کا قائم رہنا) تمہارے پروردگار کی رحمت ہے۔ کچھ شک نہیں کہ تم پر اس کا بڑا فضل ہے\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmcxvii{کہہ دو کہ اگر انسان اور جن اس بات پر مجتمع ہوں کہ اس قرآن جیسا بنا لائیں تو اس جیسا نہ لاسکیں گے اگرچہ وہ ایک دوسرے کو مددگار ہوں\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmcxviii{اور ہم نے قرآن میں سب باتیں طرح طرح سے بیان کردی ہیں۔ مگر اکثر لوگوں نے انکار کرنے کے سوا قبول نہ کیا\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmcxix{اور کہنے لگے کہ ہم تم پر ایمان نہیں لائیں گے جب تک کہ (عجیب وغریب باتیں نہ دکھاؤ یعنی یا تو) ہمارے لئے زمین سے چشمہ جاری کردو\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmcxx{یا تمہارا کھجوروں اور انگوروں کا کوئی باغ ہو اور اس کے بیچ میں نہریں بہا نکالو\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmcxxi{یا جیسا تم کہا کرتے ہو ہم پر آسمان کے ٹکڑے لا گراؤ یا خدا اور فرشتوں کو (ہمارے) سامنے لاؤ\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmcxxii{یا تو تمہارا سونے کا گھر ہو یا تم آسمان پر چڑھ جاؤ۔ اور ہم تمہارے چڑھنے کو بھی نہیں مانیں گے جب تک کہ کوئی کتاب نہ لاؤ جسے ہم پڑھ بھی لیں۔ کہہ دو کہ میرا پروردگار پاک ہے میں تو صرف ایک پیغام پہنچانے والا انسان ہوں\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmcxxiii{اور جب لوگوں کے پاس ہدایت آگئی تو ان کو ایمان لانے سے اس کے سوا کوئی چیز مانع نہ ہوئی کہ کہنے لگے کہ کیا خدا نے آدمی کو پیغمبر کرکے بھیجا ہے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmcxxiv{کہہ دو کہ اگر زمین میں فرشتے ہوتے (کہ اس میں) چلتے پھرتے (اور) آرام کرتے (یعنی بستے) تو ہم اُن کے پاس فرشتے کو پیغمبر بنا کر بھیجتے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmcxxv{کہہ دو کہ میرے اور تمہارے درمیان خدا ہی گواہ کافی ہے۔ وہی اپنے بندوں سے خبردار (اور ان کو) دیکھنے والا ہے\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmcxxvi{اور جس شخص کو خدا ہدایت دے وہی ہدایت یاب ہے۔ اور جن کو گمراہ کرے تو تم خدا کے سوا اُن کے رفیق نہیں پاؤ گے۔ اور ہم اُن کو قیامت کے دن اوندھے منہ اندھے گونگے اور بہرے (بنا کر) اٹھائیں گے۔ اور ان کا ٹھکانہ دوزخ ہے۔ جب (اس کی آگ) بجھنے کو ہوگی تو ہم ان کو (عذاب دینے کے لئے) اور بھڑکا دیں گے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmcxxvii{یہ ان کی سزا ہے اس لئے کہ وہ ہماری آیتوں سے کفر کرتے تھے اور کہتے تھے کہ جب ہم (مر کر بوسیدہ) ہڈیاں اور ریزہ ریزہ ہوجائیں گے تو کیا ازسرنو پیدا کئے جائیں گے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmcxxviii{کیا انہوں نے نہیں دیکھا کہ خدا جس نے آسمانوں اور زمین کو پیدا کیا ہے اس بات پر قادر ہے کہ ان جیسے (لوگ) پیدا کردے۔ اور اس نے ان کے لئے ایک وقت مقرر کر دیا ہے جس میں کچھ بھی شک نہیں۔ تو ظالموں نے انکار کرنے کے سوا (اسے) قبول نہ کیا\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmcxxix{کہہ دو کہ اگر میرے پروردگار کی رحمت کے خزانے تمہارے ہاتھ میں ہوتے تو تم خرچ ہوجانے کے خوف سے (ان کو) بند رکھتے۔ اور انسان دل کا بہت تنگ ہے\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmcxxx{اور ہم نے موسیٰ کو نو کھلی نشانیاں دیں تو بنی اسرائیل سے دریافت کرلو کہ جب وہ ان کے پاس آئے تو فرعون نے ان سے کہا کہ موسیٰ میں خیال کرتا ہوں کہ تم پر جادو کیا گیا ہے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmcxxxi{انہوں نے کہا کہ تم یہ جانتے ہو کہ آسمانوں اور زمین کے پروردگار کے سوا ان کو کسی نے نازل نہیں کیا۔ (اور وہ بھی تم لوگوں کے) سمجھانے کو۔ اور اے فرعون میں خیال کرتا ہوں کہ تم ہلاک ہوجاؤ گے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmcxxxii{تو اس نے چاہا کہ ان کو سر زمین (مصر) سے نکال دے تو ہم نے اس کو اور جو اس کے ساتھ تھے سب کو ڈبو دیا\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmcxxxiii{اور اس کے بعد بنی اسرائیل سے کہا کہ تم اس ملک میں رہو سہو۔ پھر جب آخرت کا وعدہ آجائے گا تو ہم تم سب کو جمع کرکے لے آئیں گے\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmcxxxiv{اور ہم نے اس قرآن کو سچائی کے ساتھ نازل کیا ہے اور وہ سچائی کے ساتھ نازل ہوا اور (اے محمدﷺ) ہم نے تم کو صرف خوشخبری دینے والا اور ڈر سنانے والا بنا کر بھیجا ہے\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmcxxxv{اور ہم نے قرآن کو جزو جزو کرکے نازل کیا ہے تاکہ تم لوگوں کو ٹھیر ٹھیر کر پڑھ کر سناؤ اور ہم نے اس کو آہستہ آہستہ اُتارا ہے\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmcxxxvi{کہہ دو کہ تم اس پر ایمان لاؤ یا نہ لاؤ (یہ فی نفسہ حق ہے) جن لوگوں کو اس سے پہلے علم (کتاب) دیا ہے۔ جب وہ ان کو پڑھ کر سنایا جاتا ہے تو وہ تھوڑیوں کے بل سجدے میں گر پڑتے ہیں\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmcxxxvii{اور کہتے ہیں کہ ہمارا پروردگار پاک ہے بےشک ہمارے پروردگار کا وعدہ پورا ہو کر رہا\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmcxxxviii{اور وہ تھوڑیوں کے بل گر پڑتے ہیں (اور) روتے جاتے ہیں اور اس سے ان کو اور زیادہ عاجزی پیدا ہوتی ہے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmcxxxix{کہہ دو کہ تم (خدا کو) الله (کے نام سے) پکارو یا رحمٰن (کے نام سے) جس نام سے پکارو اس کے سب اچھے نام ہیں۔ اور نماز نہ بلند آواز سے پڑھو اور نہ آہستہ بلکہ اس کے بیچ کا طریقہ اختیار کرو\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmcxl{اور کہو کہ سب تعریف خدا ہی کو ہے جس نے نہ تو کسی کو بیٹا بنایا ہے اور نہ اس کی بادشاہی میں کوئی شریک ہے اور نہ اس وجہ سے کہ وہ عاجز وناتواں ہے کوئی اس کا مددگار ہے اور اس کو بڑا جان کر اس کی بڑائی کرتے رہو\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmcxli{\basmalahur سب تعریف خدا ہی کو ہے جس نے اپنے بندے (محمدﷺ) پر (یہ) کتاب نازل کی اور اس میں کسی طرح کی کجی (اور پیچیدگی) نہ رکھی\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmcxlii{سیدھی (اور سلیس اتاری) تاکہ لوگوں کو عذاب سخت سے جو اس کی طرف سے (آنے والا) ہے ڈرائے اور مومنوں کو جو نیک عمل کرتے ہیں خوشخبری سنائے کہ اُن کے لئے (ان کے کاموں کا) نیک بدلہ (یعنی) بہشت ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmcxliii{جس میں وہ ابدا لاآباد رہیں گے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmcxliv{اور ان لوگوں کو بھی ڈرائے جو کہتے ہیں کہ خدا نے (کسی کو) بیٹا بنا لیا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmcxlv{ان کو اس بات کا کچھ بھی علم نہیں اور نہ ان کے باپ دادا ہی کو تھا۔ (یہ) بڑی سخت بات ہے جو ان کے منہ سے نکلتی ہے (اور کچھ شک نہیں) کہ یہ جو کہتے ہیں محض جھوٹ ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmcxlvi{اے پیغمبر) اگر یہ اس کلام پر ایمان نہ لائیں تو شاید تم کے ان پیچھے رنج کر کر کے اپنے تئیں ہلاک کردو گے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmcxlvii{جو چیز زمین پر ہے ہم نے اس کو زمین کے لئے آرائش بنایا ہے تاکہ لوگوں کی آزمائش کریں کہ ان میں کون اچھے عمل کرنے والا ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmcxlviii{اور جو چیز زمین پر ہے ہم اس کو (نابود کرکے) بنجر میدان کردیں گے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmcxlix{کیا تم خیال کرتے ہو کہ غار اور لوح والے ہمارے نشانیوں میں سے عجیب تھے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmcl{جب وہ جوان غار میں جا رہے تو کہنے لگے کہ اے ہمارے پروردگار ہم پر اپنے ہاں سے رحمت نازل فرما۔ اور ہمارے کام درستی (کے سامان) مہیا کر\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmcli{تو ہم نے غار میں کئی سال تک ان کے کانوں پر (نیند کا) پردہ ڈالے (یعنی ان کو سلائے) رکھا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmclii{پھر ان کو جگا اُٹھایا تاکہ معلوم کریں کہ جتنی مدّت وہ (غار میں) رہے دونوں جماعتوں میں سے اس کی مقدار کس کو خوب یاد ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmcliii{ہم اُن کے حالات تم سے صحیح صحیح بیان کرتے ہیں۔ وہ کئی جوان تھے جو اپنے پروردگار پر ایمان لائے تھے اور ہم نے ان کو اور زیادہ ہدایت دی تھی\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmcliv{اور ان کے دلوں کو مربوط (یعنی مضبوط) کردیا۔ جب وہ (اُٹھ) کھڑے ہوئے تو کہنے لگے کہ ہمارا پروردگار آسمانوں اور زمین کا مالک ہے۔ ہم اس کے سوا کسی کو معبود (سمجھ کر) نہ پکاریں گے (اگر ایسا کیا) تو اس وقت ہم نے بعید از عقل بات کہی\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmclv{ان ہماری قوم کے لوگوں نے اس کے سوا اور معبود بنا رکھے ہیں۔ بھلا یہ ان (کے خدا ہونے) پر کوئی کھلی دلیل کیوں نہیں لاتے۔ تو اس سے زیادہ کون ظالم ہے جو خدا پر جھوٹ افتراء کرے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmclvi{اور جب تم نے ان (مشرکوں) سے اور جن کی یہ خدا کے سوا عبادت کرتے ہیں ان سے کنارہ کرلیا ہے تو غار میں چل رہو تمہارا پروردگار تمہارے لئے اپنی رحمت وسیع کردے گا اور تمہارے کاموں میں آسانی (کے سامان) مہیا کرے گا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmclvii{اور جب سورج نکلے تو تم دیکھو کہ (دھوپ) ان کے غار سے داہنی طرف سمٹ جائے اور جب غروب ہو تو ان سے بائیں طرف کترا جائے اور وہ اس کے میدان میں تھے۔ یہ خدا کی نشانیوں میں سے ہیں۔ جس کو خدا ہدایت دے یا وہ ہدایت یاب ہے اور جس کو گمراہ کرے تو تم اس کے لئے کوئی دوست راہ بتانے والا نہ پاؤ گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmclviii{اور تم ان کو خیال کرو کہ جاگ رہے ہیں حالانکہ وہ سوتے ہیں۔ اور ہم ان کو دائیں اور بائیں کروٹ بدلاتے تھے۔ اور ان کا کتا چوکھٹ پر دونوں ہاتھ پھیلائے ہوئے تھا۔ اگر تم ان کو جھانک کر دیکھتے تو پیٹھ پھیر کر بھاگ جاتے اور ان سے دہشت میں آجاتے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmclix{اور اس طرح ہم نے ان کو اٹھایا تاکہ آپس میں ایک دوسرے سے دریافت کریں۔ ایک کہنے والے نے کہا کہ تم (یہاں) کتنی مدت رہے؟ انہوں نے کہا کہ ایک دن یا اس سے بھی کم۔ انہوں نے کہا کہ جتنی مدت تم رہے ہو تمہارا پروردگار ہی اس کو خوب جانتا ہے۔ تو اپنے میں سے کسی کو یہ روپیہ دے کر شہر کو بھیجو وہ دیکھے کہ نفیس کھانا کون سا ہے تو اس میں سے کھانا لے آئے اور آہستہ آہستہ آئے جائے اور تمہارا حال کسی کو نہ بتائے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmclx{اگر وہ تم پر دسترس پالیں گے تو تمہیں سنگسار کردیں گے یا پھر اپنے مذہب میں داخل کرلیں گے اور اس وقت تم کبھی فلاح نہیں پاؤ گے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmclxi{اور اسی طرح ہم نے (لوگوں کو) ان (کے حال) سے خبردار کردیا تاکہ وہ جانیں کہ خدا کا وعدہ سچا ہے اور یہ کہ قیامت (جس کا وعدہ کیا جاتا ہے) اس میں کچھ شک نہیں۔ اس وقت لوگ ان کے بارے میں باہم جھگڑنے لگے اور کہنے لگے کہ ان (کے غار) پر عمارت بنا دو۔ ان کا پروردگار ان (کے حال) سے خوب واقف ہے۔ جو لوگ ان کے معاملے میں غلبہ رکھتے تھے وہ کہنے لگے کہ ہم ان (کے غار) پر مسجد بنائیں گے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmclxii{بعض لوگ) اٹکل پچو کہیں گے کہ وہ تین تھے (اور) چوتھا ان کا کتّا تھا۔ اور (بعض) کہیں گے کہ وہ پانچ تھے اور چھٹا ان کا کتّا تھا۔ اور (بعض) کہیں گے کہ وہ سات تھے اور آٹھواں ان کا کتّا تھا۔ کہہ دو کہ میرا پروردگار ہی ان کے شمار سے خوب واقف ہے ان کو جانتے بھی ہیں تو تھوڑے ہی لوگ (جانتے ہیں) تو تم ان (کے معاملے) میں گفتگو نہ کرنا مگر سرسری سی گفتگو۔ اور نہ ان کے بارے میں ان میں کسی سے کچھ دریافت ہی کرنا\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmclxiii{اور کسی کام کی نسبت نہ کہنا کہ میں اسے کل کردوں گا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmclxiv{مگر (انشاء الله کہہ کر یعنی اگر) خدا چاہے تو (کردوں گا) اور جب خدا کا نام لینا بھول جاؤ تو یاد آنے پر لے لو۔ اور کہہ دو کہ امید ہے کہ میرا پروردگار مجھے اس سے بھی زیادہ ہدایت کی باتیں بتائے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmclxv{اور اصحاب کہف اپنے غار میں نو اوپر تین سو سال رہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmclxvi{کہہ دو کہ جتنی مدّت وہ رہے اسے خدا ہی خوب جانتا ہے۔ اسی کو آسمانوں اور زمین کی پوشیدہ باتیں (معلوم) ہیں۔ وہ کیا خوب دیکھنے والا اور کیا خوب سننے والا ہے۔ اس کے سوا ان کا کوئی کارساز نہیں اور نہ وہ اپنے حکم میں کسی شریک کو کرتا ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmclxvii{اور اپنے پروردگار کی کتاب جو تمہارے پاس بھیجی جاتی ہے پڑھتے رہا کرو۔ اس کی باتوں کو کوئی بدلنے والا نہیں۔ اور اس کے سوا تم کہیں پناہ کی جگہ بھی نہیں پاؤ گے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmclxviii{اور جو لوگ صبح و شام اپنے پروردگار کو پکارتے اور اس کی خوشنودی کے طالب ہیں۔ ان کے ساتھ صبر کرتے رہو۔ اور تمہاری نگاہیں ان میں (گزر کر اور طرف) نہ دوڑیں کہ تم آرائشِ زندگانی دنیا کے خواستگار ہوجاؤ۔ اور جس شخص کے دل کو ہم نے اپنی یاد سے غافل کردیا ہے اور وہ اپنی خواہش کی پیروی کرتا ہے اور اس کا کام حد سے بڑھ گیا ہے اس کا کہا نہ ماننا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmclxix{اور کہہ دو کہ (لوگو) یہ قرآن تمہارے پروردگار کی طرف سے برحق ہے تو جو چاہے ایمان لائے اور جو چاہے کافر رہے۔ ہم نے ظالموں کے لئے دوزخ کی آگ تیار کر رکھی ہے جس کی قناتیں ان کو گھیر رہی ہوں گی۔ اور اگر فریاد کریں گے تو ایسے کھولتے ہوئے پانی سے ان کی دادرسی کی جائے گی (جو) پگھلے ہوئے تانبے کی طرح (گرم ہوگا اور جو) مونہوں کو بھون ڈالے گا (ان کے پینے کا) پانی بھی برا اور آرام گاہ بھی بری\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmclxx{اور) جو ایمان لائے اور کام بھی نیک کرتے رہے تو ہم نیک کام کرنے والوں کا اجر ضائع نہیں کرتے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmclxxi{ایسے لوگوں کے لئے ہمیشہ رہنے کے باغ ہیں جن میں ان کے (محلوں کے) نیچے نہریں بہہ رہی ہیں ان کو وہاں سونے کے کنگن پہنائے جائیں گے اور وہ باریک دیبا اور اطلس کے سبز کپڑے پہنا کریں گے (اور) تختوں پر تکیئے لگا کر بیٹھا کریں گے۔ (کیا) خوب بدلہ اور (کیا) خوب آرام گاہ ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmclxxii{اور ان سے دو شخصوں کا حال بیان کرو جن میں سے ایک ہم نے انگور کے دو باغ (عنایت) کئے تھے اور ان کے گردا گرد کھجوروں کے درخت لگا دیئے تھے اور ان کے درمیان کھیتی پیدا کردی تھی\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmclxxiii{دونوں باغ (کثرت سے) پھل لاتے۔ اور اس (کی پیداوار) میں کسی طرح کی کمی نہ ہوتی اور دونوں میں ہم نے ایک نہر بھی جاری کر رکھی تھی\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmclxxiv{اور (اس طرح) اس (شخص) کو (ان کی) پیداوار (ملتی رہتی) تھی تو (ایک دن) جب کہ وہ اپنے دوست سے باتیں کر رہا تھا کہنے لگا کہ میں تم سے مال ودولت میں بھی زیادہ ہوں اور جتھے (اور جماعت) کے لحاظ سے بھی زیادہ عزت والا ہوں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmclxxv{اور (ایسی شیخیوں) سے اپنے حق میں ظلم کرتا ہوا اپنے باغ میں داخل ہوا۔ کہنے لگا کہ میں نہیں خیال کرتا کہ یہ باغ کبھی تباہ ہو\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmclxxvi{اور نہ خیال کرتا ہوں کہ قیامت برپا ہو۔ اور اگر میں اپنے پروردگار کی طرف لوٹایا بھی جاؤں تو (وہاں) ضرور اس سے اچھی جگہ پاؤں گا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmclxxvii{تو اس کا دوست جو اس سے گفتگو کر رہا تھا کہنے لگا کہ کیا تم اس (خدا) سے کفر کرتے ہو جس نے تم کو مٹی سے پیدا کیا پھر نطفے سے پھر تمہیں پورا مرد بنایا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmclxxviii{مگر میں تو یہ کہتا ہوں کہ خدا ہی میرا پروردگار ہے اور میں اپنے پروردگار کے ساتھ کسی کو شریک نہیں کرتا\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmclxxix{اور (بھلا) جب تم اپنے باغ میں داخل ہوئے تو تم نے ماشاالله لاقوة الابالله کیوں نہ کہا۔ اگر تم مجھے مال واولاد میں اپنے سے کمتر دیکھتے ہو\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmclxxx{تو عجب نہیں کہ میرا پروردگار مجھے تمہارے باغ سے بہتر عطا فرمائے اور اس (تمہارے باغ) پر آسمان سے آفت بھیج دے تو وہ صاف میدان ہوجائے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmclxxxi{یا اس (کی نہر) کا پانی گہرا ہوجائے تو پھر تم اسے نہ لاسکو\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmclxxxii{اور اس کے میووں کو عذاب نے آگھیرا اور وہ اپنی چھتریوں پر گر کر رہ گیا۔ تو جو مال اس نے اس پر خرچ کیا تھا اس پر (حسرت سے) ہاتھ ملنے لگا اور کہنے لگا کہ کاش میں اپنے پروردگار کے ساتھ کسی کو شریک نہ بناتا\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmclxxxiii{اس وقت) خدا کے سوا کوئی جماعت اس کی مددگار نہ ہوئی اور نہ وہ بدلہ لے سکا\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmclxxxiv{یہاں (سے ثابت ہوا کہ) حکومت سب خدائے برحق ہی کی ہے۔ اسی کا صلہ بہتر اور (اسی کا) بدلہ اچھا ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmclxxxv{اور ان سے دنیا کی زندگی کی مثال بھی بیان کردو (وہ ایسی ہے) جیسے پانی جسے ہم نے آسمان سے برسایا۔ تو اس کے ساتھ زمین کی روئیدگی مل گئی۔ پھر وہ چورا چورا ہوگئی کہ ہوائیں اسے اڑاتی پھرتی ہیں۔ اور خدا تو ہر چیز پر قدرت رکھتا ہے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmclxxxvi{مال اور بیٹے تو دنیا کی زندگی کی (رونق و) زینت ہیں۔ اور نیکیاں جو باقی رہنے والی ہیں وہ ثواب کے لحاظ سے تمہارے پروردگار کے ہاں بہت اچھی اور امید کے لحاظ سے بہت بہتر ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmclxxxvii{اور جس دن ہم پہاڑوں کو چلائیں گے اور تم زمین کو صاف میدان دیکھو گے اور ان (لوگوں کو) ہم جمع کرلیں گے تو ان میں سے کسی کو بھی نہیں چھوڑیں گے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmclxxxviii{اور سب تمہارے پروردگار کے سامنے صف باندھ کر لائے جائیں گے (تو ہم ان سے کہیں گے کہ) جس طرح ہم نے تم کو پہلی بار پیدا کیا تھا (اسی طرح آج) تم ہمارے سامنے آئے لیکن تم نے تو یہ خیال کر رکھا تھا کہ ہم نے تمہارے لئے (قیامت کا) کوئی وقت مقرر ہی نہیں کیا\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmclxxxix{اور (عملوں کی) کتاب (کھول کر) رکھی جائے گی تو تم گنہگاروں کو دیکھو گے کہ جو کچھ اس میں (لکھا) ہوگا اس سے ڈر رہے ہوں گے اور کہیں گے ہائے شامت یہ کیسی کتاب ہے کہ نہ چھوٹی بات کو چھوڑتی ہے نہ بڑی کو۔ (کوئی بات بھی نہیں) مگر اسے لکھ رکھا ہے۔ اور جو عمل کئے ہوں گے سب کو حاضر پائیں گے۔ اور تمہارا پروردگار کسی پر ظلم نہیں کرے گا\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmcxc{اور جب ہم نے فرشتوں کو حکم دیا کہ آدم کو سجدہ کرو تو سب نے سجدہ کیا مگر ابلیس (نے نہ کیا) وہ جنات میں سے تھا تو اپنے پروردگار کے حکم سے باہر ہوگیا۔ کیا تم اس کو اور اس کی اولاد کو میرے سوا دوست بناتے ہو۔ حالانکہ وہ تمہارے دشمن ہیں (اور شیطان کی دوستی) ظالموں کے لئے (خدا کی دوستی کا) برا بدل ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmcxci{میں نے ان کو نہ تو آسمانوں اور زمین کے پیدا کرنے کے وقت بلایا تھا اور نہ خود ان کے پیدا کرنے کے وقت۔ اور میں ایسا نہ تھا کہ گمراہ کرنے والوں کو مددگار بناتا\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmcxcii{اور جس دن خدا فرمائے گا کہ (اب) میرے شریکوں کو جن کی نسبت تم گمان (الوہیت) رکھتے تھے بلاؤ تو وہ ان کے بلائیں گے مگر وہ ان کو کچھ جواب نہ دیں گے۔ اور ہم ان کے بیچ میں ایک ہلاکت کی جگہ بنادیں گے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmcxciii{اور گنہگار لوگ دوزخ کو دیکھیں گے تو یقین کرلیں گے کہ وہ اس میں پڑنے والے ہیں۔ اور اس سے بچنے کا کوئی رستہ نہ پائیں گے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmcxciv{اور ہم نے اس قرآن میں لوگوں (کے سمجھانے) کے لئے طرح طرح کی مثالیں بیان فرمائی ہیں۔ لیکن انسان سب چیزوں سے بڑھ کر جھگڑالو ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmcxcv{اور لوگوں کے پاس جب ہدایت آگئی تو ان کو کس چیز نے منع کیا کہ ایمان لائیں۔ اور اپنے پروردگار سے بخشش مانگیں۔ بجز اس کے کہ (اس بات کے منتظر ہوں کہ) انہیں بھی پہلوں کا سا معاملہ پیش آئے یا ان پر عذاب سامنے آموجود ہو\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmcxcvi{اور ہم جو پیغمبروں کو بھیجا کرتے ہیں تو صرف اس لئے کہ (لوگوں کو خدا کی نعمتوں کی) خوشخبریاں سنائیں اور (عذاب سے) ڈرائیں۔ اور جو کافر ہیں وہ باطل کی (سند) سے جھگڑا کرتے ہیں تاکہ اس سے حق کو پھسلا دیں اور انہوں نے ہماری آیتوں کو اور جس چیز سے ان کو ڈرایا جاتا ہے ہنسی بنا لیا\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmcxcvii{اور اس سے ظالم کون جس کو اس کے پروردگار کے کلام سے سمجھایا گیا تو اُس نے اس سے منہ پھیر لیا۔ اور جو اعمال وہ آگے کرچکا اس کو بھول گیا۔ ہم نے ان کے دلوں پر پردے ڈال دیئے کہ اسے سمجھ نہ سکیں۔ اور کانوں میں ثقل (پیدا کردیا ہے کہ سن نہ سکیں) اور اگر تم ان کو رستے کی طرف بلاؤ تو کبھی رستے پر نہ آئیں گے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmcxcviii{اور تمہارا پروردگار بخشنے والا صاحب رحمت ہے۔ اگر وہ ان کے کرتوتوں پر ان کو پکڑنے لگے تو ان پر جھٹ عذاب بھیج دے۔ مگر ان کے لئے ایک وقت (مقرر کر رکھا) ہے کہ اس کے عذاب سے کوئی پناہ کی جگہ نہ پائیں گے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmcxcix{اور یہ بستیاں (جو ویران پڑی ہیں) جب انہوں نے (کفر سے) ظلم کیا تو ہم نے ان کو تباہ کر دیا۔ اور ان کی تباہی کے لئے ایک وقت مقرر کردیا تھا\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmcc{اور جب موسیٰ نے اپنے شاگرد سے کہا کہ جب تک دو دریاؤں کے ملنے کی جگہ نہ پہنچ جاؤں ہٹنے کا نہیں خواہ برسوں چلتا رہوں\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmcci{جب ان کے ملنے کے مقام پر پہنچے تو اپنی مچھلی بھول گئے تو اس نے دریا میں سرنگ کی طرح اپنا رستہ بنالیا\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmccii{جب آگے چلے تو (موسیٰ نے) اپنے شاگرد سے کہا کہ ہمارے لئے کھانا لاؤ۔ اس سفر سے ہم کو بہت تکان ہوگئی ہے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmcciii{اس نے) کہا کہ بھلا آپ نے دیکھا کہ جب ہم نے پتھر کے ساتھ آرام کیا تھا تو میں مچھلی (وہیں) بھول گیا۔ اور مجھے (آپ سے) اس کا ذکر کرنا شیطان نے بھلا دیا۔ اور اس نے عجب طرح سے دریا میں اپنا رستہ لیا\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmcciv{موسیٰ نے) کہا یہی تو (وہ مقام) ہے جسے ہم تلاش کرتے تھے تو وہ اپنے پاؤں کے نشان دیکھتے دیکھتے لوٹ گئے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmccv{وہاں) انہوں نے ہمارے بندوں میں سے ایک بندہ دیکھا جس کو ہم نے اپنے ہاں سے رحمت (یعنی نبوت یا نعمت ولایت) دی تھی اور اپنے پاس سے علم بخشا تھا\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmccvi{موسیٰ نے ان سے (جن کا نام خضر تھا) کہا کہ جو علم (خدا کی طرف سے) آپ کو سکھایا گیا ہے اگر آپ اس میں سے مجھے کچھ بھلائی (کی باتیں) سکھائیں تو میں آپ کے ساتھ رہوں\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmccvii{خضر نے) کہا کہ تم میرے ساتھ رہ کر صبر نہیں کرسکو گے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmccviii{اور جس بات کی تمہیں خبر ہی نہیں اس پر صبر کر بھی کیوں کرسکتے ہو\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmccix{موسیٰ نے) کہا خدا نے چاہا تو آپ مجھے صابر پایئے گا۔ اور میں آپ کے ارشاد کے خلاف نہیں کروں گا\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmccx{خضر نے) کہا کہ اگر تم میرے ساتھ رہنا چاہو تو (شرط یہ ہے) مجھ سے کوئی بات نہ پوچھنا جب تک میں خود اس کا ذکر تم سے نہ کروں\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmccxi{تو دونوں چل پڑے۔ یہاں تک کہ جب کشتی میں سوار ہوئے تو (خضر نے) کشتی کو پھاڑ ڈالا۔ (موسیٰ نے) کہا کیا آپ نے اس لئے پھاڑا ہے کہ سواروں کو غرق کردیں یہ تو آپ نے بڑی (عجیب) بات کی\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmccxii{خضر نے) کہا۔ کیا میں نے نہیں کہا تھا کہ تم میرے ساتھ صبر نہ کرسکو گے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmccxiii{موسیٰ نے) کہا کہ جو بھول مجھ سے ہوئی اس پر مواخذہ نہ کیجیئے اور میرے معاملے میں مجھ پر مشکل نہ ڈالئے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmccxiv{پھر دونوں چلے۔ یہاں تک کہ (رستے میں) ایک لڑکا ملا تو (خضر نے) اُسے مار ڈالا۔ (موسیٰ نے) کہا کہ آپ نے ایک بےگناہ شخص کو ناحق بغیر قصاص کے مار ڈالا۔ (یہ تو) آپ نے بری بات کی\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmccxv{خضر نے) کہا کیا میں نے نہیں کہا تھا کہ تم سے میرے ساتھ صبر نہیں کرسکو گے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmccxvi{انہوں نے کہا کہ اگر میں اس کے بعد (پھر) کوئی بات پوچھوں (یعنی اعتراض کروں) تو مجھے اپنے ساتھ نہ رکھیئے گا کہ آپ میری طرف سے عذر (کے قبول کرنے میں غایت) کو پہنچ گئے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmccxvii{پھر دونوں چلے۔ یہاں تک کہ ایک گاؤں والوں کے پاس پہنچے اور ان سے کھانا طلب کیا۔ انہوں نے ان کی ضیافت کرنے سے انکار کر دیا۔ پھر انہوں نے وہاں ایک دیوار دیکھی جو (جھک کر) گرا چاہتی تھی۔ خضر نے اس کو سیدھا کر دیا۔ موسیٰ نے کہا اگر آپ چاہتے تو ان سے (اس کا) معاوضہ لیتے (تاکہ کھانے کا کام چلتا)\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmccxviii{خضر نے کہا اب مجھ میں اور تجھ میں علیحدگی۔ (مگر) جن باتوں پر تم صبر نہ کرسکے میں ان کا تمہیں بھید بتائے دیتا ہوں\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmccxix{کہ وہ جو) کشتی (تھی) غریب لوگوں کی تھی جو دریا میں محنت (کرکے یعنی کشتیاں چلا کر گذارہ) کرتے تھے۔ اور ان کے سامنے (کی طرف) ایک بادشاہ تھا جو ہر ایک کشتی کو زبردستی چھین لیتا تھا تو میں نے چاہا کہ اسے عیب دار کردوں (تاکہ وہ اسے غصب نہ کرسکے)\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmccxx{اور وہ جو لڑکا تھا اس کے ماں باپ دنوں مومن تھے ہمیں اندیشہ ہوا کہ (وہ بڑا ہو کر بدکردار ہوتا کہیں) ان کو سرکشی اور کفر میں نہ پھنسا دے\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmccxxi{تو ہم نے چاہا کہ ان کا پروردگار اس کی جگہ ان کو اور (بچّہ) عطا فرمائے جو پاک طینتی میں اور محبت میں اس سے بہتر ہو\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmccxxii{اور وہ جو دیوار تھی سو وہ دو یتیم لڑکوں کی تھی (جو) شہر میں (رہتے تھے) اور اس کے نیچے ان کا خزانہ (مدفون) تھا اور ان کا باپ ایک نیک بخت آدمی تھا۔ تو تمہارے پروردگار نے چاہا کہ وہ اپنی جوانی کو پہنچ جائیں اور (پھر) اپنا خزانہ نکالیں۔ یہ تمہارے پروردگار کی مہربانی ہے۔ اور یہ کام میں نے اپنی طرف سے نہیں کئے۔ یہ ان باتوں کا راز ہے جن پر تم صبر نہ کرسکے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmccxxiii{اور تم سے ذوالقرنین کے بارے میں دریافت کرتے ہیں۔ کہہ دو کہ میں اس کا کسی قدر حال تمہیں پڑھ کر سناتا ہوں\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmccxxiv{ہم نے اس کو زمین میں بڑی دسترس دی تھی اور ہر طرح کا سامان عطا کیا تھا\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmccxxv{تو اس نے (سفر کا) ایک سامان کیا\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmccxxvi{یہاں تک کہ جب سورج کے غروب ہونے کی جگہ پہنچا تو اسے ایسا پایا کہ ایک کیچڑ کی ندی میں ڈوب رہا ہے اور اس (ندی) کے پاس ایک قوم دیکھی۔ ہم نے کہا ذوالقرنین! تم ان کو خواہ تکلیف دو خواہ ان (کے بارے) میں بھلائی اختیار کرو (دونوں باتوں میں تم کو قدرت ہے)\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmccxxvii{ذوالقرنین نے کہا کہ جو (کفر وبدکرداری سے) ظلم کرے گا اسے ہم عذاب دیں گے۔ پھر (جب) وہ اپنے پروردگار کی طرف لوٹایا جائے گا تو وہ بھی اسے بُرا عذاب دے گا\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmccxxviii{اور جو ایمان لائے گا اور عمل نیک کرے گا اس کے لئے بہت اچھا بدلہ ہے۔ اور ہم اپنے معاملے میں (اس پر کسی طرح کی سختی نہیں کریں گے بلکہ) اس سے نرم بات کہیں گے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmccxxix{پھر اس نے ایک اور سامان (سفر کا) کیا\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmccxxx{یہاں تک کہ سورج کے طلوع ہونے کے مقام پر پہنچا تو دیکھا کہ وہ ایسے لوگوں پر طلوع کرتا ہے جن کے لئے ہم نے سورج کے اس طرف کوئی اوٹ نہیں بنائی تھی\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmccxxxi{حقیقت حال) یوں (تھی) اور جو کچھ اس کے پاس تھا ہم کو سب کی خبر تھی\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmccxxxii{پھر اس نے ایک اور سامان کیا\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmccxxxiii{یہاں تک کہ دو دیواروں کے درمیان پہنچا تو دیکھا کہ ان کے اس طرف کچھ لوگ ہیں کہ بات کو سمجھ نہیں سکتے\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmccxxxiv{ان لوگوں نے کہا ذوالقرنین! یاجوج اور ماجوج زمین میں فساد کرتے رہتے ہیں بھلا ہم آپ کے لئے خرچ (کا انتظام) کردیں کہ آپ ہمارے اور ان کے درمیان ایک دیوار کھینچ دیں\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmccxxxv{ذوالقرنین نے کہا کہ خرچ کا جو مقدور خدا نے مجھے بخشا ہے وہ بہت اچھا ہے۔ تم مجھے قوت (بازو) سے مدد دو۔ میں تمہارے اور ان کے درمیان ایک مضبوط اوٹ بنا دوں گا\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmccxxxvi{تو تم لوہے کے (بڑے بڑے) تختے لاؤ (چنانچہ کام جاری کردیا گیا) یہاں تک کہ جب اس نے دونوں پہاڑوں کے درمیان (کا حصہ) برابر کر دیا۔ اور کہا کہ (اب اسے) دھونکو۔ یہاں تک کہ جب اس کو (دھونک دھونک) کر آگ کر دیا تو کہا کہ (اب) میرے پاس تانبہ لاؤ اس پر پگھلا کر ڈال دوں\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmccxxxvii{پھر ان میں یہ قدرت نہ رہی کہ اس پر چڑھ سکیں اور نہ یہ طاقت رہی کہ اس میں نقب لگا سکیں\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmccxxxviii{بولا کہ یہ میرے پروردگار کی مہربانی ہے۔ جب میرے پروردگار کا وعدہ آپہنچے گا تو اس کو (ڈھا کر) ہموار کردے گا اور میرے پروردگار کا وعدہ سچا ہے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmccxxxix{اس روز) ہم ان کو چھوڑ دیں گے کہ (روئے زمین پر پھیل کر) ایک دوسرے میں گھس جائیں گے اور صور پھونکا جائے گا تو ہم سب کو جمع کرلیں گے\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmccxl{اور اُس روز جہنم کو کافروں کے سامنے لائیں گے\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmccxli{جن کی آنکھیں میری یاد سے پردے میں تھیں اور وہ سننے کی طاقت نہیں رکھتے تھے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmccxlii{کیا کافر یہ خیال کرتے ہیں کہ وہ ہمارے بندوں کو ہمارے سوا (اپنا) کارساز بنائیں گے (تو ہم خفا نہیں ہوں گے) ہم نے (ایسے) کافروں کے لئے جہنم کی (مہمانی) تیار کر رکھی ہے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmccxliii{کہہ دو کہ ہم تمہیں بتائیں جو عملوں کے لحاظ سے بڑے نقصان میں ہیں\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmccxliv{وہ لوگ جن کی سعی دنیا کی زندگی میں برباد ہوگئی۔ اور وہ یہ سمجھے ہوئے ہیں کہ اچھے کام کر رہے ہیں\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmccxlv{یہ وہ لوگ ہیں جنہوں نے اپنے پروردگار کی آیتوں اور اس کے سامنے جانے سے انکار کیا تو ان کے اعمال ضائع ہوگئے اور ہم قیامت کے دن ان کے لئے کچھ بھی وزن قائم نہیں کریں گے\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmccxlvi{یہ ان کی سزا ہے (یعنی) جہنم۔ اس لئے کہ انہوں نے کفر کیا اور ہماری آیتوں اور ہمارے پیغمبروں کی ہنسی اُڑائی\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmccxlvii{جو لوگ ایمان لائے اور عمل نیک کئے ان کے لئے بہشت کے باغ مہمانی ہوں گے\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmccxlviii{ہمیشہ ان میں رہیں گے اور وہاں سے مکان بدلنا نہ چاہیں گے\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmccxlix{کہہ دو کہ اگر سمندر میرے پروردگار کی باتوں کے (لکھنے کے) لئے سیاہی ہو تو قبل اس کے کہ میرے پروردگار کی باتیں تمام ہوں سمندر ختم ہوجائے اگرچہ ہم ویسا ہی اور (سمندر) اس کی مدد کو لائیں\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmccl{کہہ دو کہ میں تمہاری طرح کا ایک بشر ہوں۔ (البتہ) میری طرف وحی آتی ہے کہ تمہارا معبود (وہی) ایک معبود ہے۔ تو جو شخص اپنے پروردگار سے ملنے کی امید رکھے چاہیئے کہ عمل نیک کرے اور اپنے پروردگار کی عبادت میں کسی کو شریک نہ بنائے\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmccli{\basmalahur کہیٰعص\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmcclii{یہ) تمہارے پروردگار کی مہربانی کا بیان (ہے جو اس نے) اپنے بندے زکریا پر (کی تھی)\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmccliii{جب انہوں نے اپنے پروردگار کو دبی آواز سے پکارا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmccliv{اور) کہا کہ اے میرے پروردگار میری ہڈیاں بڑھاپے کے سبب کمزور ہوگئی ہیں اور سر (ہے کہ) بڑھاپے (کی وجہ سے) شعلہ مارنے لگا ہے اور اے میرے پروردگار میں تجھ سے مانگ کر کبھی محروم نہیں رہا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmcclv{اور میں اپنے بعد اپنے بھائی بندوں سے ڈرتا ہوں اور میری بیوی بانجھ ہے تو مجھے اپنے پاس سے ایک وارث عطا فرما\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmcclvi{جو میری اور اولاد یعقوب کی میراث کا مالک ہو۔ اور (اے) میرے پروردگار اس کو خوش اطوار بنائیو\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmcclvii{اے زکریا ہم تم کو ایک لڑکے کی بشارت دیتے ہیں جس کا نام یحییٰ ہے۔ اس سے پہلے ہم نے اس نام کا کوئی شخص پیدا نہیں کیا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmcclviii{انہوں نے کہا پروردگار میرے ہاں کس طرح لڑکا ہوگا۔ جس حال میں میری بیوی بانجھ ہے اور میں بڑھاپے کی انتہا کو پہنچ گیا ہوں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmcclix{حکم ہوا کہ اسی طرح (ہوگا) تمہارے پروردگار نے فرمایا ہے کہ مجھے یہ آسان ہے اور میں پہلے تم کو بھی تو پیدا کرچکا ہوں اور تم کچھ چیز نہ تھے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmcclx{کہا کہ پروردگار میرے لئے کوئی نشانی مقرر فرما۔ فرمایا نشانی یہ ہے کہ تم صحیح وسالم ہو کر تین (رات دن) لوگوں سے بات نہ کرسکو گے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmcclxi{پھر وہ (عبادت کے) حجرے سے نکل کر اپنی قوم کے پاس آئے تو ان سے اشارے سے کہا کہ صبح وشام (خدا کو) یاد کرتے رہو\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmcclxii{اے یحییٰ (ہماری) کتاب کو زور سے پکڑے رہو۔ اور ہم نے ان کو لڑکپن میں دانائی عطا فرمائی تھی\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmcclxiii{اور اپنے پاس شفقت اور پاکیزگی دی تھی۔ اور پرہیزگار تھے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmcclxiv{اور ماں باپ کے ساتھ نیکی کرنے والے تھے اور سرکش اور نافرمان نہیں تھے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmcclxv{اور جس دن وہ پیدا ہوئے اور جس دن وفات پائیں گے اور جس دن زندہ کرکے اٹھائے جائیں گے۔ ان پر سلام اور رحمت (ہے)\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmcclxvi{اور کتاب (قرآن) میں مریم کا بھی مذکور کرو، جب وہ اپنے لوگوں سے الگ ہو کر مشرق کی طرف چلی گئیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmcclxvii{تو انہوں نے ان کی طرف سے پردہ کرلیا۔ (اس وقت) ہم نے ان کی طرف اپنا فرشتہ بھیجا۔ تو ان کے سامنے ٹھیک آدمی (کی شکل) بن گیا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmcclxviii{مریم بولیں کہ اگر تم پرہیزگار ہو تو میں تم سے خدا کی پناہ مانگتی ہوں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmcclxix{انہوں نے کہا کہ میں تو تمہارے پروردگار کا بھیجا ہوا (یعنی فرشتہ) ہوں (اور اس لئے آیا ہوں) کہ تمہیں پاکیزہ لڑکا بخشوں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmcclxx{مریم نے کہا کہ میرے ہاں لڑکا کیونکر ہوگا مجھے کسی بشر نے چھوا تک نہیں اور میں بدکار بھی نہیں ہوں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmcclxxi{فرشتے نے) کہا کہ یونہی (ہوگا) تمہارے پروردگار نے فرمایا کہ یہ مجھے آسان ہے۔ اور (میں اسے اسی طریق پر پیدا کروں گا) تاکہ اس کو لوگوں کے لئے اپنی طرف سے نشانی اور (ذریعہٴ) رحمت اور (مہربانی) بناؤں اور یہ کام مقرر ہوچکا ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmcclxxii{تو وہ اس (بچّے) کے ساتھ حاملہ ہوگئیں اور اسے لے کر ایک دور جگہ چلی گئیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmcclxxiii{پھر درد زہ ان کو کھجور کے تنے کی طرف لے آیا۔ کہنے لگیں کہ کاش میں اس سے پہلے مرچکتی اور بھولی بسری ہوگئی ہوتی\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmcclxxiv{اس وقت ان کے نیچے کی جانب سے فرشتے نے ان کو آواز دی کہ غمناک نہ ہو تمہارے پروردگار نے تمہارے نیچے ایک چشمہ جاری کردیا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmcclxxv{اور کھجور کے تنے کو پکڑ کر اپنی طرف ہلاؤ تم پر تازہ تازہ کھجوریں جھڑ پڑیں گی\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmcclxxvi{تو کھاؤ اور پیو اور آنکھیں ٹھنڈی کرو۔ اگر تم کسی آدمی کو دیکھو تو کہنا کہ میں نے خدا کے لئے روزے کی منت مانی تو آج میں کسی آدمی سے ہرگز کلام نہیں کروں گی\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmcclxxvii{پھر وہ اس (بچّے) کو اٹھا کر اپنی قوم کے لوگوں کے پاس لے آئیں۔ وہ کہنے لگے کہ مریم یہ تو تُونے برا کام کیا\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmcclxxviii{اے ہارون کی بہن نہ تو تیرا باپ ہی بداطوار آدمی تھا اور نہ تیری ماں ہی بدکار تھی\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmcclxxix{تو مریم نے اس لڑکے کی طرف اشارہ کیا۔ وہ بولے کہ ہم اس سے کہ گود کا بچہ ہے کیونکر بات کریں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmcclxxx{بچے نے کہا کہ میں خدا کا بندہ ہوں اس نے مجھے کتاب دی ہے اور نبی بنایا ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmcclxxxi{اور میں جہاں ہوں (اور جس حال میں ہوں) مجھے صاحب برکت کیا ہے اور جب تک زندہ ہوں مجھ کو نماز اور زکوٰة کا ارشاد فرمایا ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmcclxxxii{اور (مجھے) اپنی ماں کے ساتھ نیک سلوک کرنے والا (بنایا ہے) اور سرکش وبدبخت نہیں بنایا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiii{اور جس دن میں پیدا ہوا اور جس دن مروں گا اور جس دن زندہ کرکے اٹھایا جاؤں گا مجھ پر سلام (ورحمت) ہے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmcclxxxiv{یہ مریم کے بیٹے عیسیٰ ہیں (اور یہ) سچی بات ہے جس میں لوگ شک کرتے ہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmcclxxxv{خدا کو سزاوار نہیں کہ کسی کو بیٹا بنائے۔ وہ پاک ہے جب کسی چیز کا ارادہ کرتا ہے تو اس کو یہی کہتا ہے کہ ہوجا تو وہ ہوجاتی ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvi{اور بےشک خدا ہی میرا اور تمہارا پروردگار ہے تو اسی کی عبادت کرو۔ یہی سیدھا رستہ ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmcclxxxvii{پھر (اہل کتاب کے) فرقوں نے باہم اختلاف کیا۔ سو جو لوگ کافر ہوئے ہیں ان کو بڑے دن (یعنی قیامت کے روز) حاضر ہونے سے خرابی ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmcclxxxviii{وہ جس دن ہمارے سامنے آئیں گے۔ کیسے سننے والے اور کیسے دیکھنے والے ہوں گے مگر ظالم آج صریح گمراہی میں ہیں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmcclxxxix{اور ان کو حسرت (وافسوس) کے دن سے ڈراؤ جب بات فیصل کردی جائے گی۔ اور (ہیہات) وہ غفلت میں (پڑے ہوئے ہیں) اور ایمان نہیں لاتے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmccxc{ہم ہی زمین کے اور جو لوگ اس پر (بستے) ہیں ان کے وارث ہیں۔ اور ہماری ہی طرف ان کو لوٹنا ہوگا\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmccxci{اور کتاب میں ابراہیم کو یاد کرو۔ بےشک وہ نہایت سچے پیغمبر تھے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmccxcii{جب انہوں نے اپنے باپ سے کہا کہ ابّا آپ ایسی چیزوں کو کیوں پوجتے ہیں جو نہ سنیں اور نہ دیکھیں اور نہ آپ کے کچھ کام آسکیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmccxciii{ابّا مجھے ایسا علم ملا ہے جو آپ کو نہیں ملا ہے تو میرے ساتھ ہوجیئے میں آپ کو سیدھی راہ پر چلا دوں گا\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmccxciv{ابّا شیطان کی پرستش نہ کیجیئے۔ بےشک شیطان خدا کا نافرمان ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmccxcv{ابّا مجھے ڈر لگتا ہے کہ آپ کو خدا کا عذاب آپکڑے تو آپ شیطان کے ساتھی ہوجائیں\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmccxcvi{اس نے کہا ابراہیم کیا تو میرے معبودوں سے برگشتہ ہے؟ اگر تو باز نہ آئے گا تو میں تجھے سنگسار کردوں گا اور تو ہمیشہ کے لئے مجھ سے دور ہوجا\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmccxcvii{ابراہیم نے سلام علیک کہا (اور کہا کہ) میں آپ کے لئے اپنے پروردگار سے بخشش مانگوں گا۔ بےشک وہ مجھ پر نہایت مہربان ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmccxcviii{اور میں آپ لوگوں سے اور جن کو آپ خدا کے سوا پکارا کرتے ہیں ان سے کنارہ کرتا ہوں اور اپنے پروردگار ہی کو پکاروں گا۔ امید ہے کہ میں اپنے پروردگار کو پکار کر محروم نہیں رہوں گا\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmccxcix{اور جب ابراہیم ان لوگوں سے اور جن کی وہ خدا کے سوا پرستش کرتے تھے اُن سے الگ ہوگئے تو ہم نے ان کو اسحاق اور (اسحاق کو) یعقوب بخشے۔ اور سب کو پیغمبر بنایا\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmccc{اور ان کو اپنی رحمت سے (بہت سی چیزیں) عنایت کیں۔ اور ان کا ذکر جمیل بلند کیا\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmccci{اور کتاب میں موسیٰ کا بھی ذکر کرو۔ بےشک وہ (ہمارے) برگزیدہ اور پیغمبر مُرسل تھے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmcccii{اور ہم نے ان کو طور کی داہنی جانب پکارا اور باتیں کرنے کے لئے نزدیک بلایا\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmccciii{اور اپنی مہربانی سے اُن کو اُن کا بھائی ہارون پیغمبر عطا کیا\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmccciv{اور کتاب میں اسمٰعیل کا بھی ذکر کرو وہ وعدے کے سچے اور ہمارے بھیجے ہوئے نبی تھے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmcccv{اور اپنے گھر والوں کو نماز اور زکوٰة کا حکم کرتے تھے اور اپنے پروردگار کے ہاں پسندیدہ (وبرگزیدہ) تھے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmcccvi{اور کتاب میں ادریس کا بھی ذکر کرو۔ وہ بھی نہایت سچے نبی تھے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmcccvii{اور ہم نے ان کو اونچی جگہ اُٹھا لیا تھا\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmcccviii{یہ وہ لوگ ہیں جن پر خدا نے اپنے پیغمبروں میں سے فضل کیا۔ (یعنی) اولاد آدم میں سے اور ان لوگوں میں سے جن کو نوح کے ساتھ (کشتی میں) سوار کیا اور ابراہیم اور یعقوب کی اولاد میں سے اور ان لوگوں میں سے جن کو ہم نے ہدایت دی اور برگزیدہ کیا۔ جب ان کے سامنے ہماری آیتیں پڑھی جاتی تھیں تو سجدے میں گر پڑتے اور روتے رہتے تھے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmcccix{پھر ان کے بعد چند ناخلف ان کے جانشیں ہوئے جنہوں نے نماز کو (چھوڑ دیا گویا اسے) کھو دیا۔ اور خواہشات نفسانی کے پیچھے لگ گئے۔ سو عنقریب ان کو گمراہی (کی سزا) ملے گی\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmcccx{ہاں جس نے توبہ کی اور ایمان لایا اور عمل نیک کئے تو اسے لوگ بہشت میں داخل ہوں گے اور ان کا ذرا نقصان نہ کیا جائے گا\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmcccxi{یعنی) بہشت جاودانی (میں) جس کا خدا نے اپنے بندوں سے وعدہ کیا ہے (اور جو ان کی آنکھوں سے) پوشیدہ (ہے) ۔ بےشک اس کا وعدہ (نیکوکاروں کے سامنے) آنے والا ہے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmcccxii{وہ اس میں سلام کے سوا کوئی بیہودہ کلام نہ سنیں گے، اور ان کے لئے صبح وشام کا کھانا تیار ہوگا\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmcccxiii{یہی وہ جنت ہے جس کا ہم اپنے بندوں میں سے ایسے شخص کو وارث بنائیں گے جو پرہیزگار ہوگا\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmcccxiv{اور (فرشتوں نے پیغمبر کو جواب دیا کہ) ہم تمہارے پروردگار کے حکم سوا اُتر نہیں سکتے۔ جو کچھ ہمارے آگے ہے اور پیچھے ہے اور جو ان کے درمیان ہے سب اسی کا ہے اور تمہارا پروردگار بھولنے والا نہیں\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmcccxv{یعنی) آسمان اور زمین کا اور جو ان دونوں کے درمیان ہے سب کا پروردگار ہے۔ تو اسی کی عبادت کرو اور اسی کی عبادت پر ثابت قدم رہو۔ بھلا تم کوئی اس کا ہم نام جانتے ہو\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmcccxvi{اور (کافر) انسان کہتا ہے کہ جب میں مر جاؤ گا تو کیا زندہ کرکے نکالا جاؤں گا؟\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmcccxvii{کیا (ایسا) انسان یاد نہیں کرتا کہ ہم نے اس کو پہلے بھی پیدا کیا تھا اور وہ کچھ بھی چیز نہ تھا\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmcccxviii{تمہارے پروردگار کی قسم! ہم ان کو جمع کریں گے اور شیطانوں کو بھی۔ پھر ان سب کو جہنم کے گرد حاضر کریں گے (اور وہ) گھٹنوں پر گرے ہوئے (ہوں گے)\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmcccxix{پھر ہر جماعت میں سے ہم ایسے لوگوں کو کھینچ نکالیں گے جو خدا سے سخت سرکشی کرتے تھے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmcccxx{اور ہم ان لوگوں سے خوب واقف ہیں جو ان میں داخل ہونے کے زیادہ لائق ہیں\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmcccxxi{اور تم میں کوئی (شخص) نہیں مگر اسے اس پر گزرنا ہوگا۔ یہ تمہارے پروردگار پر لازم اور مقرر ہے\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmcccxxii{پھر ہم پرہیزگاروں کو نجات دیں گے۔ اور ظالموں کو اس میں گھٹنوں کے بل پڑا ہوا چھوڑ دیں گے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmcccxxiii{اور جب ان لوگوں کے سامنے ہماری آیتیں پڑھی جاتی ہیں تو جو کافر ہیں وہ مومنوں سے کہتے ہیں کہ دونوں فریق میں سے مکان کس کے اچھے اور مجلسیں کس کی بہتر ہیں\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmcccxxiv{اور ہم نے ان سے پہلے بہت سی اُمتیں ہلاک کردیں۔ وہ لوگ (ان سے) ٹھاٹھ اور نمود میں کہیں اچھے تھے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmcccxxv{کہہ دو کہ جو شخص گمراہی میں پڑا ہوا ہے خدا اس کو آہستہ آہستہ مہلت دیئے جاتا ہے۔ یہاں تک کہ جب اس چیز کو دیکھ لیں گے جس کا ان سے وعدہ کیا جاتا ہے خواہ عذاب اور خواہ قیامت۔ تو (اس وقت) جان لیں گے کہ مکان کس کا برا ہے اور لشکر کس کا کمزور ہے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmcccxxvi{اور جو لوگ ہدایت یاب ہیں خدا ان کو زیادہ ہدایت دیتا ہے۔ اور نیکیاں جو باقی رہنے والی ہیں وہ تمہارے پروردگار کے صلے کے لحاظ سے خوب اور انجام کے اعتبار سے بہتر ہیں\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmcccxxvii{بھلا تم نے اس شخص کو دیکھا جس نے ہماری آیتوں سے کفر کیا اور کہنے لگا کہ (اگر میں ازسرنو زندہ ہوا بھی تو یہی) مال اور اولاد مجھے (وہاں) ملے گا\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmcccxxviii{کیا اس نے غیب کی خبر پالی ہے یا خدا کے یہاں (سے) عہد لے لیا ہے؟\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmcccxxix{ہرگز نہیں۔ یہ جو کچھ کہتا ہے ہم اس کو لکھتے جاتے اور اس کے لئے آہستہ آہستہ عذاب بڑھاتے جاتے ہیں\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmcccxxx{اور جو چیزیں یہ بتاتا ہے ان کے ہم وارث ہوں گے اور یہ اکیلا ہمارے سامنے آئے گا\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmcccxxxi{اور ان لوگوں نے خدا کے سوا اور معبود بنالئے ہیں تاکہ وہ ان کے لئے (موجب عزت و) مدد ہوں\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmcccxxxii{ہرگز نہیں وہ (معبودان باطل) ان کی پرستش سے انکار کریں گے اور ان کے دشمن (ومخالف) ہوں گے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiii{کیا تم نے نہیں دیکھا کہ ہم نے شیطانوں کو کافروں پر چھوڑ رکھا ہے کہ ان کو برانگیختہ کرتے رہتے ہیں\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmcccxxxiv{تو تم ان پر (عذاب کے لئے) جلدی نہ کرو۔ اور ہم تو ان کے لئے (دن) شمار کر رہے ہیں\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmcccxxxv{جس روز ہم پرہیزگاروں کو خدا کے سامنے (بطور) مہمان جمع کریں گے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvi{اور گنہگاروں کو دوزخ کی طرف پیاسے ہانک لے جائیں گے\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmcccxxxvii{تو لوگ) کسی کی سفارش کا اختیار نہ رکھیں گے مگر جس نے خدا سے اقرار لیا ہو\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmcccxxxviii{اور کہتے ہیں کہ خدا بیٹا رکھتا ہے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmcccxxxix{ایسا کہنے والو یہ تو) تم بری بات (زبان پر) لائے ہو\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmcccxl{قریب ہے کہ اس (افتراء) سے آسمان پھٹ پڑیں اور زمین شق ہوجائے اور پہاڑ پارہ پارہ ہو کر گر پڑیں\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmcccxli{کہ انہوں نے خدا کے لئے بیٹا تجویز کیا\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmcccxlii{اور خدا کو شایاں نہیں کہ کسی کو بیٹا بنائے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmcccxliii{تمام شخص جو آسمانوں اور زمین میں ہیں سب خدا کے روبرو بندے ہو کر آئیں گے\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmcccxliv{اُس نے ان (سب) کو (اپنے علم سے) گھیر رکھا اور (ایک ایک کو) شمار کر رکھا ہے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmcccxlv{اور سب قیامت کے دن اس کے سامنے اکیلے اکیلے حاضر ہوں گے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmcccxlvi{اور جو لوگ ایمان لائے اور عمل نیک کئے خدا ان کی محبت (مخلوقات کے دل میں) پیدا کردے گا\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmcccxlvii{اے پیغمبر) ہم نے یہ (قرآن) تمہاری زبان میں آسان (نازل) کیا ہے تاکہ تم اس سے پرہیزگاروں کو خوشخبری پہنچا دو اور جھگڑالوؤں کو ڈر سنا دو\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmcccxlviii{اور ہم نے اس سے پہلے بہت سے گروہوں کو ہلاک کردیا ہے۔ بھلا تم ان میں سے کسی کو دیکھتے ہو یا (کہیں) ان کی بھنک سنتے ہو\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmcccxlix{\basmalahur طہٰ\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmcccl{اے محمدﷺ) ہم نے تم پر قرآن اس لئے نازل نہیں کیا کہ تم مشقت میں پڑ جاؤ\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmcccli{بلکہ اس شخص کو نصیحت دینے کے لئے (نازل کیا ہے) جو خوف رکھتا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmccclii{یہ اس (ذات برتر) کا اتارا ہوا ہے جس نے زمین اور اونچے اونچے آسمان بنائے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmcccliii{یعنی خدائے) رحمٰن جس نےعرش پر قرار پکڑا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmcccliv{جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے اور جو کچھ ان دونوں کے بیچ میں ہے اور جو کچھ (زمین کی) مٹی کے نیچے ہے سب اسی کا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmccclv{اور اگر تم پکار کر بات کہو تو وہ تو چھپے بھید اور نہایت پوشیدہ بات تک کو جانتا ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmccclvi{وہ معبود برحق ہے کہ) اس کے سوا کوئی معبود نہیں ہے۔ اس کے (سب) نام اچھے ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmccclvii{اور کیا تمہیں موسیٰ (کے حال) کی خبر ملی ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmccclviii{جب انہوں نے آگ دیکھی تو اپنے گھر والوں سے کہا کہ تم (یہاں) ٹھہرو میں نے آگ دیکھی ہے (میں وہاں جاتا ہوں) شاید اس میں سے میں تمہارے پاس انگاری لاؤں یا آگ (کے مقام) کا رستہ معلوم کرسکوں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmccclix{جب وہاں پہنچے تو آواز آئی کہ موسیٰ\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmccclx{میں تو تمہارا پروردگار ہوں تو اپنی جوتیاں اتار دو۔ تم (یہاں) پاک میدان (یعنی) طویٰ میں ہو\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmccclxi{اور میں نے تم کو انتخاب کرلیا ہے تو جو حکم دیا جائے اسے سنو\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmccclxii{بےشک میں ہی خدا ہوں۔ میرے سوا کوئی معبود نہیں تو میری عبادت کرو اور میری یاد کے لئے نماز پڑھا کرو\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmccclxiii{قیامت یقیناً آنے والی ہے۔ میں چاہتا ہوں کہ اس (کے وقت) کو پوشیدہ رکھوں تاکہ ہر شخص جو کوشش کرے اس کا بدلا پائے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmccclxiv{تو جو شخص اس پر ایمان نہیں رکھتا اور اپنی خواہش کے پیچھے چلتا ہے (کہیں) تم کو اس (کے یقین) سے روک نہ دے تو (اس صورت میں) تم ہلاک ہوجاؤ\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmccclxv{اور موسی یہ تمہارے داہنے ہاتھ میں کیا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmccclxvi{انہوں نے کہا یہ میری لاٹھی ہے۔ اس پر میں سہارا لگاتا ہوں اور اس سے اپنی بکریوں کے لئے پتے جھاڑتا ہوں اور اس میں میرے لئے اور بھی کئی فائدے ہیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmccclxvii{فرمایا کہ موسیٰ اسے ڈال دو\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmccclxviii{تو انہوں نے اس کو ڈال دیا اور وہ ناگہاں سانپ بن کر دوڑنے لگا\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmccclxix{خدا نے فرمایا کہ اسے پکڑ لو اور ڈرنا مت۔ ہم اس کو ابھی اس کی پہلی حالت پر لوٹا دیں گے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmccclxx{اور اپنا ہاتھ اپنی بغل سے لگالو وہ کسی عیب (وبیماری) کے بغیر سفید (چمکتا دمکتا) نکلے گا۔ (یہ) دوسری نشانی (ہے)\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmccclxxi{تاکہ ہم تمہیں اپنے نشانات عظیم دکھائیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmccclxxii{تم فرعون کے پاس جاؤ (کہ) وہ سرکش ہو رہا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmccclxxiii{کہا میرے پروردگار (اس کام کے لئے) میرا سینہ کھول دے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmccclxxiv{اور میرا کام آسان کردے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmccclxxv{اور میری زبان کی گرہ کھول دے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmccclxxvi{تاکہ وہ بات سمجھ لیں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmccclxxvii{اور میرے گھر والوں میں سے (ایک کو) میرا وزیر (یعنی مددگار) مقرر فرما\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmccclxxviii{یعنی) میرے بھائی ہارون کو\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmccclxxix{اس سے میری قوت کو مضبوط فرما\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmccclxxx{اور اسے میرے کام میں شریک کر\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmccclxxxi{تاکہ ہم تیری بہت سی تسبیح کریں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmccclxxxii{اور تجھے کثرت سے یاد کریں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiii{تو ہم کو (ہر حال میں) دیکھ رہا ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmccclxxxiv{فرمایا موسیٰ تمہاری دعا قبول کی گئی\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmccclxxxv{اور ہم نے تم پر ایک بار اور بھی احسان کیا تھا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvi{جب ہم نے تمہاری والدہ کو الہام کیا تھا جو تمہیں بتایا جاتا ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmccclxxxvii{وہ یہ تھا) کہ اسے (یعنی موسیٰ کو) صندوق میں رکھو پھر اس (صندوق) کو دریا میں ڈال دو تو دریا اسے کنارے پر ڈال دے گا (اور) میرا اور اس کا دشمن اسے اٹھا لے گا۔ اور (موسیٰ) میں نے تم پر اپنی طرف سے محبت ڈال دی ہے (اس لئے کہ تم پر مہربانی کی جائے) اور اس لئے کہ تم میرے سامنے پرورش پاؤ\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmccclxxxviii{جب تمہاری بہن (فرعون کے ہاں) گئی اور کہنے لگی کہ میں تمہیں ایسا شخص بتاؤں جو اس کو پالے۔ تو (اس طریق سے) ہم نے تم کو تمہاری ماں کے پاس پہنچا دیا تاکہ ان کی آنکھیں ٹھنڈی ہوں اور وہ رنج نہ کریں۔ اور تم نے ایک شخص کو مار ڈالا تو ہم نے تم کو غم سے مخلصی دی اور ہم نے تمہاری (کئی بار) آزمائش کی۔ پھر تم کئی سال اہل مدین میں ٹھہرے رہے۔ پھر اے موسیٰ تم (قابلیت رسالت کے) اندازے پر آ پہنچے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmccclxxxix{اور میں نے تم کو اپنے (کام کے) لئے بنایا ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmcccxc{تو تم اور تمہارا بھائی دونوں ہماری نشانیاں لے کر جاؤ اور میری یاد میں سستی نہ کرنا\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmcccxci{دونوں فرعون کے پاس جاؤ وہ سرکش ہو رہا ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmcccxcii{اور اس سے نرمی سے بات کرنا شاید وہ غور کرے یا ڈر جائے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmcccxciii{دونوں کہنے لگے کہ ہمارے پروردگار ہمیں خوف ہے کہ ہم پر تعدی کرنے لگے یا زیادہ سرکش ہوجائے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmcccxciv{خدا نے فرمایا کہ ڈرو مت میں تمہارے ساتھ ہوں (اور) سنتا اور دیکھتا ہوں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmcccxcv{اچھا) تو اس کے پاس جاؤ اور کہو کہ ہم آپ کے پروردگار کے بھیجے ہوئے ہیں تو بنی اسرائیل کو ہمارے ساتھ جانے کی اجازت دیجیئے۔ اور انہیں عذاب نہ کیجیئے۔ ہم آپ کے پاس آپ کے پروردگار کی طرف سے نشانی لے کر آئے ہیں۔ اور جو ہدایت کی بات مانے اس کو سلامتی ہو\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmcccxcvi{ہماری طرف یہ وحی آئی ہے کہ جو جھٹلائے اور منہ پھیرے اس کے لئے عذاب (تیار) ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmcccxcvii{غرض موسیٰ اور ہارون فرعون کے پاس گئے) اس نے کہا کہ موسیٰ تمہارا پروردگار کون ہے؟\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmcccxcviii{کہا کہ ہمارا پروردگار وہ ہے جس نے ہر چیز کو اس کی شکل وصورت بخشی پھر راہ دکھائی\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmcccxcix{کہا تو پہلی جماعتوں کا کیا حال؟\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmcd{کہا کہ ان کا علم میرے پروردگار کو ہے (جو) کتاب میں (لکھا ہوا ہے) ۔ میرا پروردگار نہ چوکتا ہے نہ بھولتا ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmcdi{وہ (وہی تو ہے) جس نے تم لوگوں کے لئے زمین کو فرش بنایا اور اس میں تمہارے لئے رستے جاری کئے اور آسمان سے پانی برسایا۔ پھر اس سے انواع واقسام کی مختلف روئیدگیاں پیدا کیں\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmcdii{کہ (خود بھی) کھاؤ اور اپنے چارپایوں کو بھی چراؤ۔ بےشک ان (باتوں) میں عقل والوں کے لئے (بہت سی) نشانیاں ہیں\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmcdiii{اسی (زمین) سے ہم تم کو پیدا کیا اور اسی میں تمہیں لوٹائیں گے اور اسی سے دوسری دفعہ نکالیں گے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmcdiv{اور ہم نے فرعون کو اپنی سب نشانیاں دکھائیں مگر وہ تکذیب وانکار ہی کرتا رہا\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmcdv{کہنے لگا کہ موسیٰ تم ہمارے پاس اس لئے آئے ہو کہ اپنے جادو (کے زور) سے ہمیں ہمارے ملک سے نکال دو\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmcdvi{تو ہم بھی تمہارے مقابل ایسا ہی جادو لائیں گے تو ہمارے اور اپنے درمیان ایک وقت مقرر کر لو کہ نہ تو ہم اس کے خلاف کریں اور نہ تم (اور یہ مقابلہ) ایک ہموار میدان میں (ہوگا)\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmcdvii{موسیٰ نے کہا آپ کے لئے (مقابلے کا) دن نو روز (مقرر کیا جاتا ہے) اور یہ کہ لوگ اس دن چاشت کے وقت اکھٹے ہوجائیں\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmcdviii{تو فرعون لوٹ گیا اور اپنے سامان جمع کرکے پھر آیا\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmcdix{موسیٰ نے ان (جادوگروں) سے کہا کہ ہائے تمہاری کمبختی۔ خدا پر جھوٹ افتراء نہ کرو کہ وہ تمہیں عذاب سے فنا کردے گا اور جس نے افتراء کیا وہ نامراد رہا\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmcdx{تو وہ باہم اپنے معاملے میں جھگڑانے اور چپکے چپکے سرگوشی کرنے لگے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmcdxi{کہنے لگے یہ دونوں جادوگر ہیں چاہتے ہیں کہ اپنے جادو (کے زور) سے تم کو تمہارے ملک سے نکل دیں اور تمہارے شائستہ مذہب کو نابود کردیں\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmcdxii{تو تم (جادو کا) سامان اکھٹا کرلو اور پھر قطار باندھ کر آؤ۔ آج جو غالب رہا وہی کامیاب ہوا\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmcdxiii{بولے کہ موسیٰ یا تم (اپنی چیز) ڈالو یا ہم (اپنی چیزیں) پہلے ڈالتے ہیں\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmcdxiv{موسیٰ نے کہا نہیں تم ہی ڈالو۔ (جب انہوں نے چیزیں ڈالیں) تو ناگہاں ان کی رسیاں اور لاٹھیاں موسی کے خیال میں ایسی آنے لگیں کہ وہ (میدان) میں ادھر اُدھر دوڑ رہی ہیں\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmcdxv{اُس وقت) موسیٰ نے اپنے دل میں خوف معلوم کیا\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmcdxvi{ہم نے کہا خوف نہ کرو بلاشبہ تم ہی غالب ہو\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmcdxvii{اور جو چیز (یعنی لاٹھی) تمہارے داہنے ہاتھ میں ہے اسے ڈال دو کہ جو کچھ انہوں نے بنایا ہے اس کو نگل جائے گی۔ جو کچھ انہوں نے بنایا ہے (یہ تو) جادوگروں کے ہتھکنڈے ہیں اور جادوگر جہاں جائے فلاح نہیں پائے گا\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmcdxviii{القصہ یوں ہی ہوا) تو جادوگر سجدے میں گر پڑے (اور) کہنے لگے کہ ہم موسیٰ اور ہارون کے پروردگار پر ایمان لائے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmcdxix{فرعون) بولا کہ پیشتر اس کے میں تمہیں اجازت دوں تم اس پر ایمان لے آئے۔ بےشک وہ تمہارا بڑا (یعنی استاد) ہے جس نے تم کو جادو سکھایا ہے۔ سو میں تمہارے ہاتھ اور پاؤں (جانب) خلاف سے کٹوا دوں گا اور کھجور کے تنوں پر سولی چڑھوا دوں گا (اس وقت) تم کو معلوم ہوگا کہ ہم میں سے کس کا عذاب زیادہ سخت اور دیر تک رہنے والا ہے\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmcdxx{انہوں نے کہا جو دلائل ہمارے پاس آگئے ہیں ان پر اور جس نے ہم کو پیدا ہے اس پر ہم آپ کو ہرگز ترجیح نہیں دیں گے تو آپ کو جو حکم دینا ہو دے دیجیئے۔ اور آپ (جو) حکم دے سکتے ہیں وہ صرف اسی دنیا کی زندگی میں (دے سکتے ہیں)\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmcdxxi{ہم اپنے پروردگار پر ایمان لے آئے تاکہ وہ ہمارے گناہوں کو معاف کرے اور (اسے بھی) جو آپ نے ہم سے زبردستی جادو کرایا۔ اور خدا بہتر اور باقی رہنے والا ہے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmcdxxii{جو شخص اپنے پروردگار کے پاس گنہگار ہو کر آئے گا تو اس کے لئے جہنم ہے۔ جس میں نہ مرے گا نہ جیئے گا\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmcdxxiii{اور جو اس کے روبرو ایماندار ہو کر آئے گا اور عمل بھی نیک کئے ہوں گے تو ایسے لوگوں کے لئے اونچے اونچے درجے ہیں\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmcdxxiv{یعنی) ہمیشہ رہنے کے باغ جن کے نیچے نہریں بہہ رہی ہیں۔ ہمیشہ ان میں رہیں گے۔ اور یہ اس شخص کا بدلہ ہے جو پاک ہوا\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmcdxxv{اور ہم نے موسیٰ کی طرف وحی بھیجی کہ ہمارے بندوں کو راتوں رات نکال لے جاؤ پھر ان کے لئے دریا میں (لاٹھی مار کر) خشک رستہ بنا دو پھر تم کو نہ تو (فرعون کے) آپکڑنے کا خوف ہوگا اور نہ (غرق ہونے کا) ڈر\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmcdxxvi{پھر فرعون نے اپنے لشکر کے ساتھ ان کا تعاقب کیا تو دریا (کی موجوں) نے ان پر چڑھ کر انہیں ڈھانک لیا (یعنی ڈبو دیا)\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmcdxxvii{اور فرعون نے اپنی قوم کو گمراہ کردیا اور سیدھے رستے پر نہ ڈالا\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmcdxxviii{اے آل یعقوب ہم نے تم کو تمہارے دشمن سے نجات دی اور تورات دینے کے لئے تم سے کوہ طور کی داہنی طرف مقرر کی اور تم پر من اور سلویٰ نازل کیا\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmcdxxix{اور حکم دیا کہ) جو پاکیزہ چیزیں ہم نے تم کو دی ہیں ان کو کھاؤ۔ اور اس میں حد سے نہ نکلنا۔ ورنہ تم پر میرا غضب نازل ہوگا۔ اور جس پر میرا غضب نازل ہوا وہ ہلاک ہوگیا\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmcdxxx{اور جو توبہ کرے اور ایمان لائے اور عمل نیک کرے پھر سیدھے رستے چلے اس کو میں بخش دینے والا ہوں\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmcdxxxi{اور اے موسیٰ تم نے اپنی قوم سے (آگے چلے آنے میں) کیوں جلدی کی\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmcdxxxii{کہا وہ میرے پیچھے (آ رہے) ہیں اور اے پروردگار میں نے تیری طرف (آنے کی) جلدی اس لئے کی کہ تو خوش ہو\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiii{فرمایا کہ ہم نے تمہاری قوم کو تمہارے بعد آزمائش میں ڈال دیا ہے اور سامری نے ان کو بہکا دیا ہے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmcdxxxiv{اور موسیٰ غصّے اور غم کی حالت میں اپنی قوم کے پاس واپس آئے (اور) کہنے لگے کہ اے قوم کیا تمہارے پروردگار نے تم سے ایک اچھا وعدہ نہیں کیا تھا؟ کیا (میری جدائی کی) مدت تمہیں دراز (معلوم) ہوئی یا تم نے چاہا کہ تم پر تمہارے پروردگار کی طرف سے غضب نازل ہو۔ اور (اس لئے) تم نے مجھ سے جو وعدہ کیا تھا (اس کے) خلاف کیا\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmcdxxxv{وہ کہنے لگے کہ ہم نے اپنے اختیار سے تم سے وعدہ خلاف نہیں کیا۔ بلکہ ہم لوگوں کے زیوروں کا بوجھ اٹھائے ہوئے تھے۔ پھر ہم نے اس کو (آگ میں) ڈال دیا اور اسی طرح سامری نے ڈال دیا\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvi{تو اس نے ان کے لئے ایک بچھڑا بنا دیا (یعنی اس کا) قالب جس کی آواز گائے کی سی تھی۔ تو لوگ کہنے لگے کہ یہی تمہارا معبود ہے اور موسیٰ کا بھی معبود ہے۔ مگر وہ بھول گئے ہیں\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmcdxxxvii{کیا یہ لوگ نہیں دیکھتے کہ وہ ان کی کسی بات کا جواب نہیں دیتا۔ اور نہ ان کے نقصان اور نفع کا کچھ اختیار رکھتا ہے\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmcdxxxviii{اور ہارون نے ان سے پہلے ہی کہہ دیا تھا کہ لوگو اس سے صرف تمہاری آزمائش کی گئی ہے۔ اور تمہارا پروردگار تو خدا ہے تو میری پیروی کرو اور میرا کہا مانو\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmcdxxxix{وہ کہنے لگے کہ جب تک موسیٰ ہمارے پاس واپس نہ آئیں ہم تو اس کی پوجا پر قائم رہیں گے\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmcdxl{پھر موسیٰ نے ہارون سے) کہا کہ ہارون جب تم نے ان کو دیکھا تھا کہ گمراہ ہو رہے ہیں تو تم کو کس چیز نے روکا\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmcdxli{یعنی) اس بات سے کہ تم میرے پیچھے چلے آؤ۔ بھلا تم نے میرے حکم کے خلاف (کیوں) کیا؟\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmcdxlii{کہنے لگے کہ بھائی میری ڈاڑھی اور سر (کے بالوں) کو نہ پکڑیئے۔ میں تو اس سے ڈرا کہ آپ یہ نہ کہیں کہ تم نے بنی اسرائیل میں تفرقہ ڈال دیا اور میری بات کو ملحوظ نہ رکھا\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmcdxliii{پھر (سامری سے) کہنے لگے کہ سامری تیرا کیا حال ہے؟\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmcdxliv{اس نے کہا کہ میں نے ایسی چیز دیکھی جو اوروں نے نہیں دیکھی تو میں نے فرشتے کے نقش پا سے (مٹی کی) ایک مٹھی بھر لی۔ پھر اس کو (بچھڑے کے قالب میں) ڈال دیا اور مجھے میرے جی نے (اس کام کو) اچھا بتایا\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmcdxlv{موسیٰ نے) کہا جا تجھ کو دنیا کی زندگی میں یہ (سزا) ہے کہ کہتا رہے کہ مجھ کو ہاتھ نہ لگانا اور تیرے لئے ایک اور وعدہ ہے (یعنی عذاب کا) جو تجھ سے ٹل نہ سکے گا اور جس معبود (کی پوجا) پر تو (قائم و) معتکف تھا اس کو دیکھ۔ ہم اسے جلادیں گے پھر اس (کی راکھ) کو اُڑا کر دریا میں بکھیر دیں گے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmcdxlvi{تمہارا معبود خدا ہی ہے جس کے سوا کوئی معبود نہیں۔ اس کا علم ہر چیز پر محیط ہے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmcdxlvii{اس طرح پر ہم تم سے وہ حالات بیان کرتے ہیں جو گذر چکے ہیں۔ اور ہم نے تمہیں اپنے پاس سے نصیحت (کی کتاب) عطا فرمائی ہے\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmcdxlviii{جو شخص اس سے منہ پھیرے گا وہ قیامت کے دن (گناہ کا) بوجھ اُٹھائے گا\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmcdxlix{ایسے لوگ) ہمیشہ اس (عذاب) میں (مبتلا) رہیں گے اور یہ بوجھ قیامت کے روز ان کے لئے برا ہے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmcdl{جس روز صور پھونکا جائے گا اور ہم گنہگاروں کو اکھٹا کریں گے اور ان کی آنکھیں نیلی نیلی ہوں گی\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmcdli{تو) وہ آپس میں آہستہ آہستہ کہیں گے کہ تم (دنیا میں) صرف دس ہی دن رہے ہو\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmcdlii{جو باتیں یہ کریں گے ہم خوب جانتے ہیں۔ اس وقت ان میں سب سے اچھی راہ والا (یعنی عاقل وہوشمند) کہے گا کہ (نہیں بلکہ) صرف ایک ہی روز ٹھہرے ہو\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmcdliii{اور تم سے پہاڑوں کے بارے میں دریافت کرتے ہیں۔ کہہ دو کہ خدا ان کو اُڑا کر بکھیر دے گا\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmcdliv{اور زمین کو ہموار میدان کر چھوڑے گا\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmcdlv{جس میں نہ تم کجی (اور پستی) دیکھو گے نہ ٹیلا (اور بلندی)\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmcdlvi{اس روز لوگ ایک پکارنے والے کے پیچھے چلیں گے اور اس کی پیروی سے انحراف نہ کرسکیں گے اور خدا کے سامنے آوازیں پست ہوجائیں گی تو تم آواز خفی کے سوا کوئی آواز نہ سنو گے\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmcdlvii{اس روز (کسی کی) سفارش کچھ فائدہ نہ دے گی مگر اس شخص کی جسے خدا اجازت دے اور اس کی بات کو پسند فرمائے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmcdlviii{جو کچھ ان کے آگے ہے اور کچھ ان کے پیچھے ہے وہ اس کو جانتا ہے اور وہ (اپنے) علم سے خدا (کے علم) پر احاطہ نہیں کرسکتے\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmcdlix{اور اس زندہ و قائم کے رو برو منہ نیچے ہوجائیں گے۔ اور جس نے ظلم کا بوجھ اٹھایا وہ نامراد رہا\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmcdlx{اور جو نیک کام کرے گا اور مومن بھی ہوگا تو اس کو نہ ظلم کا خوف ہوگا اور نہ نقصان کا\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmcdlxi{اور ہم نے اس کو اسی طرح کا قرآن عربی نازل کیا ہے اور اس میں طرح طرح کے ڈراوے بیان کردیئے ہیں تاکہ لوگ پرہیزگار بنیں یا خدا ان کے لئے نصیحت پیدا کردے\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mmcdlxii{تو خدا جو سچا بادشاہ ہے عالی قدر ہے۔ اور قرآن کی وحی جو تمہاری طرف بھیجی جاتی ہے اس کے پورا ہونے سے پہلے قرآن کے (پڑھنے کے) لئے جلدی نہ کیا کرو اور دعا کرو کہ میرے پروردگار مجھے اور زیادہ علم دے\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mmcdlxiii{اور ہم نے پہلے آدم سے عہد لیا تھا مگر وہ (اسے) بھول گئے اور ہم نے ان میں صبر وثبات نہ دیکھا\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mmcdlxiv{اور جب ہم نے فرشتوں سے کہا کہ آدم کے آگے سجدہ کرو تو سب سجدے میں گر پڑے مگر ابلیس نے انکار کیا\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mmcdlxv{ہم نے فرمایا کہ آدم یہ تمہارا اور تمہاری بیوی کا دشمن ہے تو یہ کہیں تم دونوں کو بہشت سے نکلوا نہ دے۔ پھر تم تکلیف میں پڑجاؤ\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mmcdlxvi{یہاں تم کو یہ (آسائش) ہوگی کہ نہ بھوکے رہو نہ ننگے\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mmcdlxvii{اور یہ کہ نہ پیاسے رہو اور نہ دھوپ کھاؤ\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mmcdlxviii{تو شیطان نے ان کے دل میں وسوسہ ڈالا۔ (اور) کہا کہ آدم بھلا میں تم کو (ایسا) درخت بتاؤں (جو) ہمیشہ کی زندگی کا (ثمرہ دے) اور (ایسی) بادشاہت کہ کبھی زائل نہ ہو\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mmcdlxix{تو دونوں نے اس درخت کا پھل کھا لیا تو ان پر ان کی شرمگاہیں ظاہر ہوگئیں اور وہ اپنے (بدنوں) پر بہشت کے پتّے چپکانے لگے۔ اور آدم نے اپنے پروردگار کے حکم خلاف کیا تو (وہ اپنے مطلوب سے) بےراہ ہو گئے\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mmcdlxx{پھر ان کے پروردگار نے ان کو نوازا تو ان پر مہربانی سے توجہ فرمائی اور سیدھی راہ بتائی\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mmcdlxxi{فرمایا کہ تم دونوں یہاں سے نیچے اتر جاؤ۔ تم میں بعض بعض کے دشمن (ہوں گے) پھر اگر میری طرف سے تمہارے پاس ہدایت آئے تو جو شخص میری ہدایت کی پیروی کرے گا وہ نہ گمراہ ہوگا اور نہ تکلیف میں پڑے گا\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mmcdlxxii{اور جو میری نصیحت سے منہ پھیرے گا اس کی زندگی تنگ ہوجائے گی اور قیامت کو ہم اسے اندھا کرکے اٹھائیں گے\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiii{وہ کہے گا میرے پروردگار تو نے مجھے اندھا کرکے کیوں اٹھایا میں تو دیکھتا بھالتا تھا\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mmcdlxxiv{خدا فرمائے گا کہ ایسا ہی (چاہیئے تھا) تیرے پاس میری آیتیں آئیں تو تونے ان کو بھلا دیا۔ اسی طرح آج ہم تجھ کو بھلا دیں گے\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mmcdlxxv{اور جو شخص حد سے نکل جائے اور اپنے پروردگار کی آیتوں پر ایمان نہ لائے ہم اس کو ایسا ہی بدلہ دیتے ہیں۔ اور آخرت کا عذاب بہت سخت اور بہت دیر رہنے والا ہے\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvi{کیا یہ بات ان لوگوں کے لئے موجب ہدایت نہ ہوئی کہ ہم ان سے پہلے بہت سے لوگوں کو ہلاک کرچکے ہیں جن کے رہنے کے مقامات میں یہ چلتے پھرتے ہیں۔ عقل والوں کے لئے اس میں (بہت سی) نشانیاں ہیں\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mmcdlxxvii{اور اگر ایک بات تمہارے پروردگار کی طرف سے پہلے صادر اور (جزائے اعمال کے لئے) ایک میعاد مقرر نہ ہوچکی ہوتی تو (نزول) عذاب لازم ہوجاتا\qt@no{129}}%
\qt@newcmd\qurantrans@ur@mmcdlxxviii{پس جو کچھ یہ بکواس کرتے ہیں اس پر صبر کرو۔ اور سورج کے نکلنے سے پہلے اور اس کے غروب ہونے سے پہلے اپنے پروردگار کی تسبیح وتحمید کیا کرو۔ اور رات کی ساعات (اولین) میں بھی اس کی تسبیح کیا کرو اور دن کی اطراف (یعنی دوپہر کے قریب ظہر کے وقت بھی) تاکہ تم خوش ہوجاؤ\qt@no{130}}%
\qt@newcmd\qurantrans@ur@mmcdlxxix{اور کئی طرح کے لوگوں کو جو ہم نے دنیا کی زندگی میں آرائش کی چیزوں سے بہرہ مند کیا ہے تاکہ ان کی آزمائش کریں ان پر نگاہ نہ کرنا۔ اور تمہاری پروردگار کی (عطا فرمائی ہوئی) روزی بہت بہتر اور باقی رہنے والی ہے\qt@no{131}}%
\qt@newcmd\qurantrans@ur@mmcdlxxx{اور اپنے گھر والوں کو نماز کا حکم کرو اور اس پر قائم رہو۔ ہم تم سے روزی کے خواستگار نہیں۔ بلکہ تمہیں ہم روزی دیتے ہیں اور (نیک) انجام (اہل) تقویٰ کا ہے\qt@no{132}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxi{اور کہتے ہیں کہ یہ (پیغمبر) اپنے پروردگار کی طرف سے ہمارے پاس کوئی نشانی کیوں نہیں لاتے۔ کیا ان کے پاس پہلی کتابوں کی نشانی نہیں آئی؟\qt@no{133}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxii{اور اگر ہم ان کو پیغمبر (کے بھیجنے) سے پیشتر کسی عذاب سے ہلاک کردیتے تو وہ کہتے کہ اے ہمارے پروردگار تو نے ہماری طرف کوئی پیغمبر کیوں نہ بھیجا کہ ہم ذلیل اور رسوا ہونے سے پہلے تیرے کلام (واحکام) کی پیروی کرتے\qt@no{134}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiii{کہہ دو کہ سب (نتائج اعمال) کے منتظر ہیں سو تم بھی منتظر رہو۔ عنقریب تم کو معلوم ہوجائے گا کہ (دین کے) سیدھے رستے پر چلنے والے کون ہیں اور (جنت کی طرف) راہ پانے والے کون ہیں (ہم یا تم)\qt@no{135}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxiv{\basmalahur لوگوں کا حساب (اعمال کا وقت) نزدیک آپہنچا ہے اور وہ غفلت میں (پڑے اس سے) منہ پھیر رہے ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxv{ان کے پاس کوئی نئی نصیحت ان کے پروردگار کی طرف سے نہیں آتی مگر وہ اسے کھیلتے ہوئے سنتے ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvi{ان کے دل غفلت میں پڑے ہوئے ہیں اور ظالم لوگ (آپس میں) چپکے چپکے باتیں کرتے ہیں کہ یہ (شخص کچھ بھی) نہیں مگر تمہارے جیسا آدمی ہے۔ تو تم آنکھوں دیکھتے جادو (کی لپیٹ) میں کیوں آتے ہو\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxvii{پیغمبر نے) کہا کہ جو بات آسمان اور زمین میں (کہی جاتی) ہے میرا پروردگار اسے جانتا ہے۔ اور وہ سننے والا (اور) جاننے والا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxviii{بلکہ (ظالم) کہنے لگے کہ (یہ قرآن) پریشان (باتیں ہیں جو) خواب (میں دیکھ لی) ہیں۔ (نہیں) بلکہ اس نے اس کو اپنی طرف سے بنا لیا ہے (نہیں) بلکہ (یہ شعر ہے جو اس) شاعر (کا نتیجہٴ طبع) ہے۔ تو جیسے پہلے (پیغمبر نشانیاں دے کر) بھیجے گئے تھے (اسی طرح) یہ بھی ہمارے پاس کوئی نشانی لائے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmcdlxxxix{ان سے پہلے جن بستیوں کو ہم نے ہلاک کیا وہ ایمان نہیں لاتی تھیں۔ تو کیا یہ ایمان لے آئیں گے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmcdxc{اور ہم نے تم سے پہلے مرد ہی (پیغمبر بنا کر) بھیجے جن کی طرف ہم وحی بھیجتے تھے۔ اگر تم نہیں جانتے تو جو یاد رکھتے ہیں ان سے پوچھ لو\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmcdxci{اور ہم نے ان کے لئے ایسے جسم نہیں بنائے تھے کہ کھانا نہ کھائیں اور نہ وہ ہمیشہ رہنے والے تھے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmcdxcii{پھر ہم نے ان کے بارے میں (اپنا) وعدہ سچا کردیا تو ان کو اور جس کو چاہا نجات دی اور حد سے نکل جانے والوں کو ہلاک کردیا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmcdxciii{ہم نے تمہاری طرف ایسی کتاب نازل کی ہے جس میں تمہارا تذکرہ ہے۔ کیا تم نہیں سمجھتے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmcdxciv{اور ہم نے بہت سی بستیوں کو جو ستمگار تھیں ہلاک کر مارا اور ان کے بعد اور لوگ پیدا کردیئے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmcdxcv{جب انہوں نے ہمارے (مقدمہ) عذاب کو دیکھا تو لگے اس سے بھاگنے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmcdxcvi{مت بھاگو اور جن (نعمتوں) میں تم عیش وآسائش کرتے تھے ان کی اور اپنے گھروں کی طرف لوٹ جاؤ۔ شاید تم سے (اس بارے میں) دریافت کیا جائے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmcdxcvii{کہنے لگے ہائے شامت بےشک ہم ظالم تھے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmcdxcviii{تو وہ ہمیشہ اسی طرح پکارتے رہے یہاں تک کہ ہم نے ان کو (کھیتی کی طرح) کاٹ کر (اور آگ کی طرح) بجھا کر ڈھیر کردیا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmcdxcix{اور ہم نے آسمان اور زمین کو جو اور (مخلوقات) ان دونوں کے درمیان ہے اس کو لہوولعب کے لئے پیدا نہیں کیا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmd{اگر ہم چاہتے کہ کھیل (کی چیزیں یعنی زن وفرزند) بنائیں تو اگر ہم کو کرنا ہوتا تو ہم اپنے پاس سے بنالیتے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmdi{بلکہ ہم سچ کو جھوٹ پر کھینچ مارتے ہیں تو وہ اس کا سر توڑ دیتا ہے اور جھوٹ اسی وقت نابود ہوجاتا ہے۔ اور جو باتیں تم بناتے ہو ان سے تمہاری ہی خرابی ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmdii{اور جو لوگ آسمانوں میں اور جو زمین میں ہیں سب اسی کے (مملوک اور اُسی کا مال) ہیں۔ اور جو (فرشتے) اُس کے پاس ہیں وہ اس کی عبادت سے نہ کنیاتے ہیں اور نہ اکتاتے ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmdiii{رات دن (اُس کی) تسبیح کرتے رہتے ہیں (نہ تھکتے ہیں) نہ اکتاتے ہیں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmdiv{بھلا لوگوں نے جو زمین کی چیزوں سے (بعض کو) معبود بنا لیا ہے (تو کیا) وہ ان کو (مرنے کے بعد) اُٹھا کھڑا کریں گے؟\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmdv{اگر آسمان اور زمین میں خدا کے سوا اور معبود ہوتے تو زمین وآسمان درہم برہم ہوجاتے۔ جو باتیں یہ لوگ بتاتے ہیں خدائے مالک عرش ان سے پاک ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmdvi{وہ جو کام کرتا ہے اس کی پرستش نہیں ہوگی اور (جو کام یہ لوگ کرتے ہیں اس کی) ان سے پرستش ہوگی\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmdvii{کیا لوگوں نے خدا کو چھوڑ کر اور معبود بنالئے ہیں۔ کہہ دو کہ (اس بات پر) اپنی دلیل پیش کرو۔ یہ (میری اور) میرے ساتھ والوں کی کتاب بھی ہے اور جو مجھ سے پہلے (پیغمبر) ہوئے ہیں۔ ان کی کتابیں بھی ہیں۔ بلکہ (بات یہ ہے کہ) ان اکثر حق بات کو نہیں جانتے اور اس لئے اس سے منہ پھیر لیتے ہیں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmdviii{اور جو پیغمبر ہم نےتم سے پہلے بھیجے ان کی طرف یہی وحی بھیجی کہ میرے سوا کوئی معبود نہیں تو میری ہی عبادت کرو\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmdix{اور کہتے ہیں کہ خدا بیٹا رکھتا ہے۔ وہ پاک ہے (اس کے نہ بیٹا ہے نہ بیٹی) بلکہ (جن کو یہ لوگ اس کے بیٹے بیٹیاں سمجھتے ہیں) وہ اس کے عزت والے بندے ہیں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmdx{اس کے آگے بڑھ کر بول نہیں سکتے۔ اور اس کے حکم پر عمل کرتے ہیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmdxi{جو کچھ ان کے آگے ہوچکا ہے اور پیچھے ہوگا وہ سب سے واقف ہے اور وہ (اس کے پاس کسی کی) سفارش نہیں کرسکتے مگر اس شخص کی جس سے خدا خوش ہو اور وہ اس کی ہیبت سے ڈرتے رہتے ہیں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmdxii{اور جو شخص ان میں سے یہ کہے کہ خدا کے سوا میں معبود ہوں تو اسے ہم دوزخ کی سزا دیں گے اور ظالموں کو ہم ایسی ہی سزا دیا کرتے ہیں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmdxiii{کیا کافروں نے نہیں دیکھا کہ آسمان اور زمین دونوں ملے ہوئے تھے تو ہم نے جدا جدا کردیا۔ اور تمام جاندار چیزیں ہم نے پانی سے بنائیں۔ پھر یہ لوگ ایمان کیوں نہیں لاتے؟\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmdxiv{اور ہم نے زمین میں پہاڑ بنائے تاکہ لوگوں (کے بوجھ) سے ہلنے (اور جھکنے) نہ لگے اور اس میں کشادہ راستے بنائے تاکہ لوگ ان پر چلیں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmdxv{اور آسمان کو محفوظ چھت بنایا۔ اس پر بھی وہ ہماری نشانیوں سے منہ پھیر رہے ہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmdxvi{اور وہی تو ہے جس نے رات اور دن اور سورج اور چاند کو بنایا۔ (یہ) سب (یعنی سورج اور چاند اور ستارے) آسمان میں (اس طرح چلتے ہیں گویا) تیر رہے ہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmdxvii{اور (اے پیغمبر) ہم نے تم سے پہلے کسی آدمی کو بقائے دوام نہیں بخشا۔ بھلا اگر تم مرجاؤ تو کیا یہ لوگ ہمیشہ رہیں گے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmdxviii{ہر متنفس کو موت کا مزا چکھنا ہے۔ اور ہم تو لوگوں کو سختی اور آسودگی میں آزمائش کے طور پر مبتلا کرتے ہیں۔ اور تم ہماری طرف ہی لوٹ کر آؤ گے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmdxix{اور جب کافر تم کو دیکھتے ہیں تو تم سے استہزاء کرتے ہیں کہ کیا یہی شخص ہے جو تمہارے معبودوں کا ذکر (برائی سے) کیا کرتا ہے حالانکہ وہ خود رحمٰن کے نام سے منکر ہیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmdxx{انسان (کچھ ایسا جلد باز ہے کہ گویا) جلد بازی ہی سے بنایا گیا ہے۔ میں تم لوگوں کو عنقریب اپنی نشانیاں دکھاؤں گا تو تم جلدی نہ کرو\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmdxxi{اور کہتے ہیں کہ اگر تم سچے ہو تو (جس عذاب کا) یہ وعید (ہے وہ) کب (آئے گا)؟\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmdxxii{اے کاش کافر اس وقت کو جانیں جب وہ اپنے مونہوں پر سے (دوزخ کی) آگ کو روک نہ سکیں گے اور نہ اپنی پیٹھوں پر سے اور نہ ان کا کوئی مددگار ہوگا\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmdxxiii{بلکہ قیامت ان پر ناگہاں آ واقع ہوگی۔ اور ان کے ہوش کھو دے گی۔ پھر نہ تو وہ اس کو ہٹا سکیں گے اور نہ ان کو مہلت دی جائے گی\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmdxxiv{اور تم سے پہلے بھی پیغمبروں کے ساتھ استہزاء ہوتا رہا ہے تو جو لوگ ان میں سے تمسخر کیا کرتے تھے ان کو اسی (عذاب) نے جس کی ہنسی اُڑاتے تھے آگھیرا\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmdxxv{کہو کہ رات اور دن میں خدا سے تمہاری کون حفاظت کرسکتا ہے؟ بات یہ ہے کہ اپنے پروردگار کی یاد سے منہ پھیرے ہوئے ہیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmdxxvi{کیا ہمارے سوا ان کے اور معبود ہیں کہ ان کو (مصائب سے) بچاسکیں۔ وہ آپ اپنی مدد تو کر ہی نہیں سکتے اور نہ ہم سے پناہ ہی دیئے جائیں گے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmdxxvii{بلکہ ہم ان لوگوں کو اور ان کے باپ دادا کو متمتع کرتے رہے یہاں تک کہ (اسی حالت میں) ان کی عمریں بسر ہوگئیں۔ کیا یہ نہیں دیکھتے کہ ہم زمین کو اس کے کناروں سے گھٹاتے چلے آتے ہیں۔ تو کیا یہ لوگ غلبہ پانے والے ہیں؟\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmdxxviii{کہہ دو کہ میں تم کو حکم خدا کے مطابق نصیحت کرتا ہوں۔ اور بہروں کوجب نصیحت کی جائے تو وہ پکار کر سنتے ہی نہیں\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmdxxix{اور اگر ان کو تمہارے پروردگار کا تھوڑا سا عذاب بھی پہنچے تو کہنے لگیں کہ ہائے کم بختی ہم بےشک ستمگار تھے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmdxxx{اور ہم قیامت کے دن انصاف کی ترازو کھڑی کریں گے تو کسی شخص کی ذرا بھی حق تلفی نہ کی جائے گی۔ اور اگر رائی کے دانے کے برابر بھی (کسی کا عمل) ہوگا تو ہم اس کو لاحاضر کریں گے۔ اور ہم حساب کرنے کو کافی ہیں\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmdxxxi{اور ہم نے موسیٰ اور ہارون کو (ہدایت اور گمراہی میں) فرق کر دینے والی اور (سرتاپا) روشنی اور نصیحت (کی کتاب) عطا کی (یعنی) پرہیز گاروں کے لئے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmdxxxii{جو بن دیکھے اپنے پروردگار سے ڈرتے ہیں اور قیامت کا بھی خوف رکھتے ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmdxxxiii{یہ مبارک نصیحت ہے جسے ہم نے نازل فرمایا ہے تو کیا تم اس سے انکار کرتے ہو؟\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmdxxxiv{اور ہم نے ابراہیمؑ کو پہلے ہی سے ہدایت دی تھی اور ہم ان کے حال سے واقف تھے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmdxxxv{جب انہوں نے اپنے باپ اور اپنی قوم کے لوگوں سے کہا یہ کیا مورتیں ہیں جن (کی پرستش) پر تم معتکف (وقائم) ہو؟\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmdxxxvi{وہ کہنے لگے کہ ہم نے اپنے باپ دادا کو ان کی پرستش کرتے دیکھا ہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmdxxxvii{ابراہیم نے) کہا کہ تم بھی (گمراہ ہو) اور تمہارے باپ دادا بھی صریح گمراہی میں پڑے رہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmdxxxviii{وہ بولے کیا تم ہمارے پاس (واقعی) حق لائے ہو یا (ہم سے) کھیل (کی باتیں) کرتے ہو؟\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmdxxxix{ابراہیم نے) کہا (نہیں) بلکہ تمہارا پروردگار آسمانوں اور زمین کا پروردگار ہے جس نے ان کو پیدا کیا ہے۔ اور میں اس (بات) کا گواہ (اور اسی کا قائل) ہوں\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmdxl{اور خدا کی قسم جب تم پیٹھ پھیر کر چلے جاؤ گے تو میں تمہارے بتوں سے ایک چال چلوں گا\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmdxli{پھر ان کو توڑ کر ریزہ ریزہ کردیا مگر ایک بڑے (بت) کو (نہ توڑا) تاکہ وہ اس کی طرف رجوع کریں\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmdxlii{کہنے لگے کہ ہمارے معبودوں کے ساتھ یہ معاملہ کس نے کیا؟ وہ تو کوئی ظالم ہے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmdxliii{لوگوں نے کہا کہ ہم نے ایک جوان کو ان کا ذکر کرتے ہوئے سنا ہے اس کو ابراہیم کہتے ہیں\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmdxliv{وہ بولے کہ اسے لوگوں کے سامنے لاؤ تاکہ گواہ رہیں\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmdxlv{جب ابراہیم آئے تو) بت پرستوں نے کہا کہ ابراہیم بھلا یہ کام ہمارے معبودوں کے ساتھ تم نے کیا ہے؟\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmdxlvi{ابراہیم نے) کہا (نہیں) بلکہ یہ ان کے اس بڑے (بت) نے کیا (ہوگا) ۔ اگر یہ بولتے ہیں تو ان سے پوچھ لو\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmdxlvii{انہوں نے اپنے دل غور کیا تو آپس میں کہنے لگے بےشک تم ہی بےانصاف ہو\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmdxlviii{پھر (شرمندہ ہو کر) سر نیچا کرلیا (اس پر بھی ابراہیم سے کہنے لگے کہ) تم جانتے ہو یہ بولتے نہیں\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmdxlix{ابراہیم نے) کہا پھر تم خدا کو چھوڑ کر کیوں ایسی چیزوں کو پوجتے ہو جو نہ تمہیں کچھ فائدہ دے سکیں اور نقصان پہنچا سکیں؟\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmdl{تف ہے تم پر اور جن کو تم خدا کے سوا پوجتے ہو ان پر بھی کیا تم عقل نہیں رکھتے؟\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmdli{تب وہ) کہنے لگے کہ اگر تمہیں (اس سے اپنے معبود کا انتقام لینا اور) کچھ کرنا ہے تو اس کو جلا دو اور اپنے معبودوں کی مدد کرو\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmdlii{ہم نے حکم دیا اے آگ سرد ہوجا اور ابراہیم پر (موجب) سلامتی (بن جا)\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmdliii{اور ان لوگوں نے برا تو ان کا چاہا تھا مگر ہم نے ان ہی کو نقصان میں ڈال دیا\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmdliv{اور ابراہیم اور لوط کو اس سرزمین کی طرف بچا نکالا جس میں ہم نے اہل عالم کے لئے برکت رکھی تھی\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmdlv{اور ہم نے ابراہیم کو اسحق عطا کئے۔ اور مستزاد برآں یعقوب۔ اور سب کو نیک بخت کیا\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmdlvi{اور ان کو پیشوا بنایا کہ ہمارے حکم سے ہدایت کرتے تھے اور ان کو نیک کام کرنے اور نماز پڑھنے اور زکوٰة دینے کا حکم بھیجا۔ اور وہ ہماری عبادت کیا کرتے تھے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmdlvii{اور لوط (کا قصہ یاد کرو) جب ان کو ہم نے حکم (یعنی حکمت ونبوت) اور علم بخشا اور اس بستی سے جہاں کے لوگ گندے کام کیا کرتے تھے۔ بچا نکالا۔ بےشک وہ برے اور بدکردار لوگ تھے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmdlviii{اور انہیں اپنی رحمت کے (محل میں) داخل کیا۔ کچھ شک نہیں کہ وہ نیک بختوں میں تھے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmdlix{اور نوح (کا قصہ بھی یاد کرو) جب (اس سے) پیشتر انہوں نے ہم کو پکارا تو ہم نے ان کی دعا قبول فرمائی اور ان کو اور ان کے ساتھیوں کو بڑی گھبراہٹ سے نجات دی\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmdlx{اور جو لوگ ہماری آیتوں کی تکذیب کرتے تھے ان پر نصرت بخشی۔ وہ بےشک برے لوگ تھے سو ہم نے ان سب کو غرق کردیا\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmdlxi{اور داؤد اور سلیمان (کا حال بھی سن لو کہ) جب وہ ایک کھیتی کا مقدمہ فیصلہ کرنے لگے جس میں کچھ لوگوں کی بکریاں رات کو چر گئی (اور اسے روند گئی) تھیں اور ہم ان کے فیصلے کے وقت موجود تھے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmdlxii{تو ہم نے فیصلہ (کرنے کا طریق) سلیمان کو سمجھا دیا۔ اور ہم نے دونوں کو حکم (یعنی حکمت ونبوت) اور علم بخشا تھا۔ اور ہم نے پہاڑوں کو داؤد کا مسخر کردیا تھا کہ ان کے ساتھ تسبیح کرتے تھے اور جانوروں کو بھی (مسخر کردیا تھا اور ہم ہی ایسا) کرنے والے تھے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmdlxiii{اور ہم نے تمہارے لئے ان کو ایک (طرح) کا لباس بنانا بھی سکھا دیا تاکہ تم کو لڑائی (کے ضرر) سے بچائے۔ پس تم کو شکرگزار ہونا چاہیئے\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmdlxiv{اور ہم نے تیز ہوا سلیمان کے تابع (فرمان) کردی تھی جو ان کے حکم سے اس ملک میں چلتی تھی جس میں ہم نے برکت دی تھی (یعنی شام) اور ہم ہر چیز سے خبردار ہیں\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmdlxv{اور دیوؤں (کی جماعت کو بھی ان کے تابع کردیا تھا کہ ان) میں سے بعض ان کے لئے غوطے مارتے تھے اور اس کے سوا اور کام بھی کرتے تھے اور ہم ان کے نگہبان تھے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmdlxvi{اور ایوب کو (یاد کرو) جب انہوں نے اپنے پروردگار سے دعا کی کہ مجھے ایذا ہو رہی ہے اور تو سب سے بڑھ کر رحم کرنے والا ہے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmdlxvii{تو ہم نے ان کی دعا قبول کرلی اور جو ان کو تکلیف تھی وہ دور کردی اور ان کو بال بچے بھی عطا فرمائے اور اپنی مہربانی کے ساتھ اتنے ہی اور (بخشے) اور عبادت کرنے والوں کے لئے (یہ) نصیحت ہے\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmdlxviii{اور اسمٰعیل اور ادریس اور ذوالکفل (کو بھی یاد کرو) یہ سب صبر کرنے والے تھے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmdlxix{اور ہم نے ان کو اپنی رحمت میں داخل کیا۔ بلاشبہ وہ نیکوکار تھے\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmdlxx{اور ذوالنون (کو یاد کرو) جب وہ (اپنی قوم سے ناراض ہو کر) غصے کی حالت میں چل دیئے اور خیال کیا کہ ہم ان پر قابو نہیں پاسکیں گے۔ آخر اندھیرے میں (خدا کو) پکارنے لگے کہ تیرے سوا کوئی معبود نہیں۔ تو پاک ہے (اور) بےشک میں قصوروار ہوں\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmdlxxi{تو ہم نے ان کی دعا قبول کرلی اور ان کو غم سے نجات بخشی۔ اور ایمان والوں کو ہم اسی طرح نجات دیا کرتے ہیں\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmdlxxii{اور زکریا (کو یاد کرو) جب انہوں نے اپنے پروردگار کو پکارا کہ پروردگار مجھے اکیلا نہ چھوڑ اور تو سب سے بہتر وارث ہے\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmdlxxiii{تو ہم نے ان کی پکار سن لی۔ اور ان کو یحییٰ بخشے اور ان کی بیوی کو اُن کے (حسن معاشرت کے) قابل بنادیا۔ یہ لوگ لپک لپک کر نیکیاں کرتے اور ہمیں امید سے پکارتے اور ہمارے آگے عاجزی کیا کرتے تھے\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmdlxxiv{اور ان (مریم) کو (بھی یاد کرو) جنہوں نے اپنی عفّت کو محفوظ رکھا۔ تو ہم نے ان میں اپنی روح پھونک دی اور ان کے بیٹے کو اہل عالم کے لئے نشانی بنا دیا\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmdlxxv{یہ تمہاری جماعت ایک ہی جماعت ہے اور میں تمہارا پروردگار ہوں تو میری ہی عبادت کیا کرو\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmdlxxvi{اور یہ لوگ اپنے معاملے میں باہم متفرق ہوگئے۔ (مگر) سب ہماری طرف رجوع کرنے والے ہیں\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmdlxxvii{جو نیک کام کرے گا اور مومن بھی ہوگا تو اس کی کوشش رائیگاں نہ جائے گی۔ اور ہم اس کے لئے (ثواب اعمال) لکھ رہے ہیں\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmdlxxviii{اور جس بستی (والوں) کو ہم نے ہلاک کردیا محال ہے کہ (وہ دنیا کی طرف رجوع کریں) وہ رجوع نہیں کریں گے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmdlxxix{یہاں تک کہ یاجوج ماجوج کھول دیئے جائیں اور وہ ہر بلندی سے دوڑ رہے ہوں\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmdlxxx{اور (قیامت کا) سچا وعدہ قریب آجائے تو ناگاہ کافروں کی آنکھیں کھلی کی کھلی رہ جائیں (اور کہنے لگیں کہ) ہائے شامت ہم اس (حال) سے غفلت میں رہے بلکہ (اپنے حق میں) ظالم تھے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmdlxxxi{کافرو اس روز) تم اور جن کی تم خدا کے سوا عبادت کرتے ہو دوزخ کا ایندھن ہوں گے۔ اور تم سب اس میں داخل ہو کر رہو گے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmdlxxxii{اگر یہ لوگ (درحقیقت) معبود ہوتے تو اس میں داخل نہ ہوتے۔ سب اس میں ہمیشہ (جلتے) رہیں گے\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiii{وہاں ان کو چلاّنا ہوگا اور اس میں (کچھ) نہ سن سکیں گے\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmdlxxxiv{جن لوگوں کے لئے ہماری طرف سے پہلے بھلائی مقرر ہوچکی ہے۔ وہ اس سے دور رکھے جائیں گے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmdlxxxv{یہاں تک کہ) اس کی آواز بھی تو نہیں سنیں گے۔ اور جو کچھ ان کا جی چاہے گا اس میں (یعنی) ہر طرح کے عیش اور لطف میں ہمیشہ رہیں گے\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvi{ان کو (اس دن کا) بڑا بھاری خوف غمگین نہیں کرے گا۔ اور فرشتے ان کو لینے آئیں گے (اور کہیں گے کہ) یہی وہ دن ہے جس کا تم سے وعدہ کیا جاتا ہے\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmdlxxxvii{جس دن ہم آسمان کو اس طرح لپیٹ لیں گے جیسے خطوں کا طومار لپیٹ لیتے ہیں۔ جس طرح ہم نے (کائنات کو) پہلے پیدا کیا اسی طرح دوبارہ پیدا کردیں گے۔ (یہ) وعدہ (جس کا پورا کرنا لازم) ہے۔ ہم (ایسا) ضرور کرنے والے ہیں\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmdlxxxviii{اور ہم نے نصیحت (کی کتاب یعنی تورات) کے بعد زبور میں لکھ دیا تھا کہ میرے نیکوکار بندے ملک کے وارث ہوں گے\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmdlxxxix{عبادت کرنے والے لوگوں کے لئے اس میں (خدا کے حکموں کی) تبلیغ ہے\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmdxc{اور (اے محمدﷺ) ہم نے تم کو تمام جہان کے لئے رحمت (بنا کر) بھیجا ہے\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmdxci{کہہ دو کہ مجھ پر (خدا کی طرف سے) یہ وحی آتی ہے کہ تم سب کا معبود خدائے واحد ہے۔ تو تم کو چاہیئے کہ فرمانبردار بن جاؤ\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmdxcii{اگر یہ لوگ منہ پھیریں تو کہہ دو کہ میں نے تم کو سب کو یکساں (احکام الہیٰ سے) آگاہ کردیا ہے۔ اور مجھ کو معلوم نہیں کہ جس چیز کا تم سے وعدہ کیا جاتا ہے وہ (عن) قریب (آنے والی) ہے یا (اس کا وقت) دور ہے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmdxciii{اور جو بات پکار کی جائے وہ اسے بھی جانتا ہے اور جو تم پوشیدہ کرتے ہو اس سے بھی واقف ہے\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmdxciv{اور میں نہیں جانتا شاید وہ تمہارے لئے آزمائش ہو اور ایک مدت تک (تم اس سے) فائدہ (اٹھاتے رہو)\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmdxcv{پیغمبر نے کہا کہ اے میرے پروردگار حق کے ساتھ فیصلہ کردے۔ اور ہمارا پروردگار بڑا مہربان ہے اسی سے ان باتوں میں جو تم بیان کرتے ہو مدد مانگی جاتی ہے\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmdxcvi{\basmalahur لوگو! اپنے پروردگار سے ڈرو۔ کہ قیامت کا زلزلہ ایک حادثہٴ عظیم ہوگا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmdxcvii{اے مخاطب) جس دن تو اس کو دیکھے گا (اُس دن یہ حال ہوگا کہ) تمام دودھ پلانے والی عورتیں اپنے بچوں کو بھول جائیں گی۔ اور تمام حمل والیوں کے حمل گر پڑیں گے۔ اور لوگ تجھ کو متوالے نظر آئیں گے مگر وہ متوالے نہیں ہوں گے بلکہ (عذاب دیکھ کر) مدہوش ہو رہے ہوں گے۔ بےشک خدا کا عذاب بڑا سخت ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmdxcviii{اور بعض لوگ ایسے ہیں جو خدا (کی شان) میں علم (ودانش) کے بغیر جھگڑتے اور ہر شیطان سرکش کی پیروی کرتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmdxcix{جس کے بارے میں لکھ دیا گیا ہے کہ جو اسے دوست رکھے گا تو اس کو گمراہ کردے گا اور دوزخ کے عذاب کا رستہ دکھائے گا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmdc{لوگو اگر تم کو مرنے کے بعد جی اُٹھنے میں کچھ شک ہو تو ہم نے تم کو (پہلی بار بھی تو) پیدا کیا تھا (یعنی ابتدا میں) مٹی سے پھر اس سے نطفہ بنا کر۔ پھر اس سے خون کا لوتھڑا بنا کر۔ پھر اس سے بوٹی بنا کر جس کی بناوٹ کامل بھی ہوتی ہے اور ناقص بھی تاکہ تم پر (اپنی خالقیت) ظاہر کردیں۔ اور ہم جس کو چاہتے ہیں ایک میعاد مقرر تک پیٹ میں ٹھہرائے رکھتے ہیں پھر تم کو بچہ بنا کر نکالتے ہیں۔ پھر تم جوانی کو پہنچتے ہو۔ اور بعض (قبل از پیری مرجاتے ہیں اور بعض شیخ فالی ہوجاتے اور بڑھاپے کی) نہایت خراب عمر کی طرف لوٹائے جاتے ہیں کہ بہت کچھ جاننے کے بعد بالکل بےعلم ہوجاتے ہیں۔ اور (اے دیکھنے والے) تو دیکھتا ہے (کہ ایک وقت میں) زمین خشک (پڑی ہوتی ہے) پھر جب ہم اس پر مینہ برساتے ہیں تو شاداب ہوجاتی اور ابھرنے لگتی ہے اور طرح طرح کی بارونق چیزیں اُگاتی ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmdci{ان قدرتوں سے ظاہر ہے کہ خدا ہی (قادر مطلق ہے جو) برحق ہے اور یہ کہ وہ مردوں کو زندہ کردیتا ہے۔ اور یہ کہ وہ ہر چیز پر قدرت رکھتا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmdcii{اور یہ کہ قیامت آنے والی ہے۔ اس میں کچھ شک نہیں۔ اور یہ کہ خدا سب لوگوں کو جو قبروں میں ہیں جلا اٹھائے گا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmdciii{اور لوگوں میں کوئی ایسا بھی ہے جو خدا (کی شان) میں بغیر علم (ودانش) کے اور بغیر ہدایت کے اور بغیر کتاب روشن کے جھگڑتا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmdciv{اور تکبر سے) گردن موڑ لیتا (ہے) تاکہ (لوگوں کو) خدا کے رستے سے گمراہ کردے۔ اس کے لئے دنیا میں ذلت ہے۔ اور قیامت کے دن ہم اسے عذاب (آتش) سوزاں کا مزہ چکھائیں گے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmdcv{اے سرکش) یہ اس (کفر) کی سزا ہے جو تیرے ہاتھوں نے آگے بھیجا ہے اور خدا اپنے بندوں پر ظلم کرنے والا نہیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmdcvi{اور لوگوں میں بعض ایسا بھی ہے جو کنارے پر (کھڑا ہو کر) خدا کی عبادت کرتا ہے۔ اگر اس کو کوئی (دنیاوی) فائدہ پہنچے تو اس کے سبب مطمئن ہوجائے اور اگر کوئی آفت پڑے تو منہ کے بل لوٹ جائے (یعنی پھر کافر ہوجائے) اس نے دنیا میں بھی نقصان اٹھایا اور آخرت میں بھی۔ یہی تو نقصان صریح ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmdcvii{یہ خدا کے سوا ایسی چیز کو پکارتا ہے جو نہ اسے نقصان پہنچائے اور نہ فائدہ دے سکے۔ یہی تو پرلے درجے کی گمراہی ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmdcviii{ایسے شخص کو پکارتا ہے جس کا نقصان فائدہ سے زیادہ قریب ہے۔ ایسا دوست برا بھی اور ایسا ہم صحبت بھی برا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmdcix{جو لوگ ایمان لائے اور عمل نیک کرتے رہے خدا ان کو بہشتوں میں داخل کرے گا جن کے نیچے نہریں چل رہیں ہیں۔ کچھ شک نہیں کہ خدا جو چاہتا ہے کرتا ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmdcx{جو شخص یہ گمان کرتا ہے کہ خدا اس کو دنیا اور آخرت میں مدد نہیں دے گا تو اس کو چاہیئے کہ اوپر کی طرف (یعنی اپنے گھر کی چھت میں) ایک رسی باندھے پھر (اس سے اپنا) گلا گھونٹ لے۔ پھر دیکھے کہ آیا یہ تدبیر اس کے غصے کو دور کردیتی ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmdcxi{اور اسی طرح ہم نے اس قرآن کو اُتارا ہے (جس کی تمام) باتیں کھلی ہوئی (ہیں) اور یہ (یاد رکھو) کہ خدا جس کو چاہتا ہے ہدایات دیتا ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmdcxii{جو لوگ مومن (یعنی مسلمان) ہیں اور جو یہودی ہیں اور ستارہ پرست اور عیسائی اور مجوسی اور مشرک۔ خدا ان (سب) میں قیامت کے دن فیصلہ کردے گا۔ بےشک خدا ہر چیز سے باخبر ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmdcxiii{کیا تم نے نہیں دیکھا کہ جو (مخلوق) آسمانوں میں ہے اور جو زمین میں ہے اور سورج اور چاند ستارے اور پہاڑ اور درخت اور چار پائے اور بہت سے انسان خدا کو سجدہ کرتے ہیں۔ اور بہت سے ایسے ہیں جن پر عذاب ثابت ہوچکا ہے۔ اور جس شخص کو خدا ذلیل کرے اس کو عزت دینے والا نہیں۔ بےشک خدا جو چاہتا ہے کرتا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmdcxiv{یہ دو (فریق) ایک دوسرے کے دشمن اپنے پروردگار (کے بارے) میں جھگڑتے ہیں۔ تو کافر ہیں ان کے لئے آگ کے کپڑے قطع کئے جائیں گے (اور) ان کے سروں پر جلتا ہوا پانی ڈالا جائے گا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmdcxv{اس سے ان کے پیٹ کے اندر کی چیزیں اور کھالیں گل جائیں گی\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmdcxvi{اور ان (کے مارنے ٹھوکنے) کے لئے لوہے کے ہتھوڑے ہوں گے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmdcxvii{جب وہ چاہیں گے کہ اس رنج (وتکلیف) کی وجہ سے دوزخ سے نکل جائیں تو پھر اسی میں لوٹا دیئے جائیں گے۔ اور (کہا جائے گا کہ) جلنے کے عذاب کا مزہ چکھتے رہو\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmdcxviii{جو لوگ ایمان لائے اور عمل نیک کرتے رہے خدا ان کو بہشتوں میں داخل کرے گا جن کے تلے نہریں بہہ رہیں ہیں۔ وہاں ان کو سونے کے کنگن پہنائے جائیں گے اور موتی۔ اور وہاں ان کا لباس ریشمی ہوگا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmdcxix{اور ان کو پاکیزہ کلام کی ہدایت کی گئی اور (خدائے) حمید کی راہ بتائی گئی\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmdcxx{جو لوگ کافر ہیں اور (لوگوں کو) خدا کے رستے سے اور مسجد محترم سے جسے ہم نے لوگوں کے لئے یکساں (عبادت گاہ) بنایا ہے روکتے ہیں۔ خواہ وہاں کے رہنے والے ہوں یا باہر سے آنے والے۔ اور جو اس میں شرارت سے کج روی (وکفر) کرنا چاہے اس کو ہم درد دینے والے عذاب کا مزہ چکھائیں گے۔\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmdcxxi{اور ایک وقت تھا) جب ہم نے ابراہیم کے لئے خانہ کعبہ کو مقرر کیا (اور ارشاد فرمایا) کہ میرے ساتھ کسی چیز کو شریک نہ کیجیو اور طواف کرنے والوں اور قیام کرنے والوں اور رکوع کرنے والوں (اور) سجدہ کرنے والوں کے لئے میرے گھر کو صاف رکھا کرو\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmdcxxii{اور لوگوں میں حج کے لئے ندا کر دو کہ تمہاری پیدل اور دبلے دبلے اونٹوں پر جو دور دراز رستوں سے چلے آتے ہو (سوار ہو کر) چلے آئیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmdcxxiii{تاکہ اپنے فائدے کے کاموں کے لئے حاضر ہوں۔ اور (قربانی کے) ایام معلوم میں چہار پایاں مویشی (کے ذبح کے وقت) جو خدا نے ان کو دیئے ہیں ان پر خدا کا نام لیں۔ اس میں سے تم خود بھی کھاؤ اور فقیر درماندہ کو بھی کھلاؤ\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmdcxxiv{پھر چاہیئے کہ لوگ اپنا میل کچیل دور کریں اور نذریں پوری کریں اور خانہٴ قدیم (یعنی بیت الله) کا طواف کریں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmdcxxv{یہ (ہمارا حکم ہے) جو شخص ادب کی چیزوں کی جو خدا نے مقرر کی ہیں عظمت رکھے تو یہ پروردگار کے نزدیک اس کے حق میں بہتر ہے۔ اور تمہارے لئے مویشی حلال کردیئے گئے ہیں۔ سوا ان کے جو تمہیں پڑھ کر سنائے جاتے ہیں تو بتوں کی پلیدی سے بچو اور جھوٹی بات سے اجتناب کرو\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmdcxxvi{صرف ایک خدا کے ہو کر اس کے ساتھ شریک نہ ٹھیرا کر۔ اور جو شخص (کسی کو) خدا کے ساتھ شریک مقرر کرے تو وہ گویا ایسا ہے جیسے آسمان سے گر پڑے پھر اس کو پرندے اُچک لے جائیں یا ہوا کسی دور جگہ اُڑا کر پھینک دے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmdcxxvii{یہ ہمارا حکم ہے) اور جو شخص ادب کی چیزوں کی جو خدا نے مقرر کی ہیں عظمت رکھے تو یہ (فعل) دلوں کی پرہیزگاری میں سے ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmdcxxviii{ان میں ایک وقت مقرر تک تمہارے لئے فائدے ہیں پھر ان کو خانہٴ قدیم (یعنی بیت الله) تک پہنچانا (اور ذبح ہونا) ہے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmdcxxix{اور ہم نے ہر اُمت کے لئے قربانی کا طریق مقرر کردیا ہے تاکہ جو مویشی چارپائے خدا نے ان کو دیئے ہیں (ان کے ذبح کرنے کے وقت) ان پر خدا کا نام لیں۔ سو تمہارا معبود ایک ہی ہے تو اسی کے فرمانبردار ہوجاؤ۔ اور عاجزی کرنے والوں کو خوشخبری سنادو\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmdcxxx{یہ وہ لوگ ہیں کہ جب خدا کا نام لیا جاتا ہے تو ان کے دل ڈر جاتے ہیں اور جب ان پر مصیبت پڑتی ہے تو صبر کرتے ہیں اور نماز آداب سے پڑھتے ہیں اور جو (مال) ہم نے ان کو عطا فرمایا ہے (اس میں سے) (نیک کاموں میں) خرچ کرتے ہیں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmdcxxxi{اور قربانی کے اونٹوں کو بھی ہم نے تمہارے لئے شعائر خدا مقرر کیا ہے۔ ان میں تمہارے لئے فائدے ہیں۔ تو (قربانی کرنے کے وقت) قطار باندھ کر ان پر خدا کا نام لو۔ جب پہلو کے بل گر پڑیں تو ان میں سے کھاؤ اور قناعت سے بیٹھ رہنے والوں اور سوال کرنے والوں کو بھی کھلاؤ۔ اس طرح ہم نے ان کو تمہارے زیرفرمان کردیا ہے تاکہ تم شکر کرو\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmdcxxxii{خدا تک نہ اُن کا گوشت پہنچتا ہے اور نہ خون۔ بلکہ اس تک تمہاری پرہیزگاری پہنچتی ہے۔ اسی طرح خدا نے ان کو تمہارا مسخر کر دیا ہے تاکہ اس بات کے بدلے کہ اس نے تم کو ہدایت بخشی ہے اسے بزرگی سے یاد کرو۔ اور (اے پیغمبر) نیکوکاروں کو خوشخبری سنا دو\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiii{خدا تو مومنوں سے ان کے دشمنوں کو ہٹاتا رہتا ہے۔ بےشک خدا کسی خیانت کرنے والے اور کفران نعمت کرنے والے کو دوست نہیں رکھتا۔\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmdcxxxiv{جن مسلمانوں سے (خواہ مخواہ) لڑائی کی جاتی ہے ان کو اجازت ہے (کہ وہ بھی لڑیں) کیونکہ ان پر ظلم ہو رہا ہے۔ اور خدا (ان کی مدد کرے گا وہ) یقیناً ان کی مدد پر قادر ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmdcxxxv{یہ وہ لوگ ہیں کہ اپنے گھروں سے ناحق نکال دیئے گئے (انہوں نے کچھ قصور نہیں کیا) ہاں یہ کہتے ہیں کہ ہمارا پروردگار خدا ہے۔ اور اگر خدا لوگوں کو ایک دوسرے سے نہ ہٹاتا رہتا تو (راہبوں کے) صومعے اور (عیسائیوں کے) گرجے اور (یہودیوں کے) عبادت خانے اور (مسلمانوں کی) مسجدیں جن میں خدا کا بہت سا ذکر کیا جاتا ہے ویران ہوچکی ہوتیں۔ اور جو شخص خدا کی مدد کرتا ہے خدا اس کی ضرور مدد کرتا ہے۔ بےشک خدا توانا اور غالب ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvi{یہ وہ لوگ ہیں کہ اگر ہم ان کو ملک میں دسترس دیں تو نماز پڑھیں اور زکوٰة ادا کریں اور نیک کام کرنے کا حکم دیں اور برے کاموں سے منع کریں اور سب کاموں کا انجام خدا ہی کے اختیار میں ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmdcxxxvii{اور اگر یہ لوگ تم کو جھٹلاتے ہیں ان سے پہلے نوح کی قوم اور عاد وثمود بھی (اپنے پیغمبروں کو) جھٹلا چکے ہیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmdcxxxviii{اور قوم ابراہیم اور قوم لوط بھی\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmdcxxxix{اور مدین کے رہنے والے بھی۔ اور موسیٰ بھی تو جھٹلائے جاچکے ہیں لیکن میں کافروں کو مہلت دیتا رہا پھر ان کو پکڑ لیا۔ تو (دیکھ لو) کہ میرا عذاب کیسا (سخت) تھا\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmdcxl{اور بہت سی بستیاں ہیں کہ ہم نے ان کو تباہ کر ڈالا کہ وہ نافرمان تھیں۔ سو وہ اپنی چھتوں پر گری پڑی ہیں۔ اور (بہت سے) کنوئیں بےکار اور (بہت سے) محل ویران پڑے ہیں\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmdcxli{کیا ان لوگوں نے ملک میں سیر نہیں کی تاکہ ان کے دل (ایسے) ہوتے کہ ان سے سمجھ سکتے۔ اور کان (ایسے) ہوتے کہ ان سے سن سکتے۔ بات یہ ہے کہ آنکھیں اندھی نہیں ہوتیں بلکہ دل جو سینوں میں ہیں (وہ) اندھے ہوتے ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmdcxlii{اور (یہ لوگ) تم سے عذاب کے لئے جلدی کر رہے ہیں اور خدا اپنا وعدہ ہرگز خلاف نہیں کرے گا۔ اور بےشک تمہارے پروردگار کے نزدیک ایک روز تمہارے حساب کے رو سے ہزار برس کے برابر ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmdcxliii{اور بہت سی بستیاں ہیں کہ میں ان کو مہلت دیتا رہا اور وہ نافرمان تھیں۔ پھر میں نے ان کو پکڑ لیا۔ اور میری طرف ہی لوٹ کر آنا ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmdcxliv{اے پیغمبر) کہہ دو کہ لوگو! میں تم کو کھلم کھلا نصیحت کرنے والا ہوں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmdcxlv{تو جو لوگ ایمان لائے اور نیک کام کئے ان کے لئے بخشش اور آبرو کی روزی ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmdcxlvi{اور جن لوگوں نے ہماری آیتوں میں (اپنے زعم باطل میں) ہمیں عاجز کرنے کے لئے سعی کی، وہ اہل دوزخ ہیں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmdcxlvii{اور ہم نے تم سے پہلے کوئی رسول اور نبی نہیں بھیجا مگر (اس کا یہ حال تھا کہ) جب وہ کوئی آرزو کرتا تھا تو شیطان اس کی آرزو میں (وسوسہ) ڈال دیتا تھا۔ تو جو (وسوسہ) شیطان ڈالتا ہے خدا اس کو دور کردیتا ہے۔ پھر خدا اپنی آیتوں کو مضبوط کردیتا ہے۔ اور خدا علم والا اور حکمت والا ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmdcxlviii{غرض (اس سے) یہ ہے کہ جو (وسوسہ) شیطان ڈالتا ہے اس کو ان لوگوں کے لئے جن کے دلوں میں بیماری ہے اور جن کے دل سخت ہیں ذریعہ آزمائش ٹھہرائے۔ بےشک ظالم پرلے درجے کی مخالفت میں ہیں\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmdcxlix{اور یہ بھی غرض ہے کہ جن لوگوں کو علم عطا ہوا ہے وہ جان لیں کہ وہ (یعنی وحی) تمہارے پروردگار کی طرف سے حق ہے تو وہ اس پر ایمان لائیں اور ان کے دل خدا کے آگے عاجزی کریں۔ اور جو لوگ ایمان لائے ہیں خدا ان کو سیدھے رستے کی طرف ہدایت کرتا ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmdcl{اور کافر لوگ ہمیشہ اس سے شک میں رہیں گے یہاں تک کہ قیامت ان پر ناگہاں آجائے یا ایک نامبارک دن کا عذاب ان پر واقع ہو\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmdcli{اس روز بادشاہی خدا ہی کی ہوگی۔ اور ان میں فیصلہ کردے گا تو جو لوگ ایمان لائے اور عمل نیک کرتے رہے وہ نعمت کے باغوں میں ہوں گے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmdclii{اور جو کافر ہوئے اور ہماری آیتوں کو جھٹلاتے رہے ان کے لئے ذلیل کرنے والا عذاب ہوگا\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmdcliii{اور جن لوگوں نے خدا کی راہ میں ہجرت کی پھر مارے گئے یا مر گئے۔ ان کو خدا اچھی روزی دے گا۔ اور بےشک خدا سب سے بہتر رزق دینے والا ہے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmdcliv{وہ ان کو ایسے مقام میں داخل کرے گا جسے وہ پسند کریں گے۔ اور خدا تو جاننے والا (اور) بردبار ہے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmdclv{یہ (بات خدا کے ہاں ٹھہر چکی ہے) اور جو شخص (کسی کو) اتنی ہی ایذا دے جتنی ایذا اس کو دی گئی پھر اس شخص پر زیادتی کی جائے تو خدا اس کی مدد کرے گا۔ بےشک خدا معاف کرنے والا اور بخشنے والا ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmdclvi{یہ اس لئے کہ خدا رات کو دن میں داخل کردیتا ہے اور دن کو رات میں داخل کرتا ہے۔ اور خدا تو سننے والا دیکھنے والا ہے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmdclvii{یہ اس لئے کہ خدا ہی برحق ہے اور جس چیز کو (کافر) خدا کے سوا پکارتے ہیں وہ باطل ہے اور اس لئے خدا رفیع الشان اور بڑا ہے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmdclviii{کیا تم نہیں دیکھتے کہ خدا آسمان سے مینہ برساتا ہے تو زمین سرسبز ہوجاتی ہے۔ بےشک خدا باریک بین اور خبردار ہے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmdclix{جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے اسی کا ہے۔ اور بےشک خدا بےنیاز اور قابل ستائش ہے۔\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmdclx{کیا تم نہیں دیکھتے کہ جتنی چیزیں زمین میں ہیں (سب) خدا نے تمہارے زیرفرمان کر رکھی ہیں اور کشتیاں (بھی) جو اسی کے حکم سے دریا میں چلتی ہیں۔ اور وہ آسمان کو تھامے رہتا ہے کہ زمین پر (نہ) گڑ پڑے مگر اس کے حکم سے۔ بےشک خدا لوگوں پر نہایت شفقت کرنے والا مہربان ہے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmdclxi{اور وہی تو ہے جس نے تم کو حیات بخشی۔ پھر تم کو مارتا ہے۔ پھر تمہیں زندہ بھی کرے گا۔ اور انسان تو بڑا ناشکر ہے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmdclxii{ہم نے ہر ایک اُمت کے لئے ایک شریعت مقرر کردی ہے جس پر وہ چلتے ہیں تو یہ لوگ تم سے اس امر میں جھگڑا نہ کریں اور تم (لوگوں کو) اپنے پروردگار کی طرف بلاتے رہو۔ بےشک تم سیدھے رستے پر ہو\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmdclxiii{اور اگر یہ تم سے جھگڑا کریں تو کہہ دو کہ جو عمل تم کرتے ہو خدا ان سے خوب واقف ہے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmdclxiv{جن باتوں میں تم اختلاف کرتے ہو خدا تم میں قیامت کے روز ان کا فیصلہ کردے گا\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmdclxv{کیا تم نہیں جانتے کہ جو کچھ آسمان اور زمین میں ہے خدا اس کو جانتا ہے۔ یہ (سب کچھ) کتاب میں (لکھا ہوا) ہے۔ بےشک یہ سب خدا کو آسان ہے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmdclxvi{اور (یہ لوگ) خدا کے سوا ایسی چیزوں کی عبادت کرتے ہیں جن کی اس نے کوئی سند نازل نہیں فرمائی اور نہ ان کے پاس اس کی کوئی دلیل ہے۔ اور ظالموں کا کوئی بھی مددگار نہیں ہوگا\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmdclxvii{اور جب ان کو ہماری آیتیں پڑھ کر سنائی جاتی تو (ان کی شکل بگڑ جاتی ہے اور) تم ان کے چہروں میں صاف طور پر ناخوشی (کے آثار) دیکھتے ہو۔ قریب ہوتے ہیں کہ جو لوگ ان کو ہماری آیتیں پڑھ کر سناتے ہیں ان پر حملہ کردیں۔ کہہ دو کہ میں تم کو اس سے بھی بری چیز بتاؤں؟ وہ دوزخ کی آگ ہے۔ جس کا خدا نے کافروں سے وعدہ کیا ہے۔ اور وہ برا ٹھکانا ہے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmdclxviii{لوگو! ایک مثال بیان کی جاتی ہے اسے غور سے سنو۔ کہ جن لوگوں کو تم خدا کے سوا پکارتے ہو وہ ایک مکھی بھی نہیں بنا سکتے اگرچہ اس کے لئے سب مجتمع ہوجائیں۔ اور اگر ان سے مکھی کوئی چیز لے جائے تو اسے اس سے چھڑا نہیں سکتے۔ طالب اور مطلوب (یعنی عابد اور معبود دونوں) گئے گزرے ہیں\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmdclxix{ان لوگوں نے خدا کی قدر جیسی کرنی چاہیئے تھی نہیں کی۔ کچھ شک نہیں کہ خدا زبردست اور غالب ہے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmdclxx{خدا فرشتوں میں سے پیغام پہنچانے والے منتخب کرلیتا ہے اور انسانوں میں سے بھی۔ بےشک خدا سننے والا (اور) دیکھنے والا ہے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmdclxxi{جو ان کے آگے ہے اور جن ان کے پیچھے ہے وہ اس سے واقف ہے۔ اور سب کاموں کا رجوع خدا ہی کی طرف ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmdclxxii{مومنو! رکوع کرتے اور سجدے کرتے اور اپنے پروردگار کی عبادت کرتے رہو اور نیک کام کرو تاکہ فلاح پاؤ\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmdclxxiii{اور خدا (کی راہ) میں جہاد کرو جیسا جہاد کرنے کا حق ہے۔ اس نے تم کو برگزیدہ کیا ہے اور تم پر دین کی (کسی بات) میں تنگی نہیں کی۔ (اور تمہارے لئے) تمہارے باپ ابراہیم کا دین (پسند کیا) اُسی نے پہلے (یعنی پہلی کتابوں میں) تمہارا نام مسلمان رکھا تھا اور اس کتاب میں بھی (وہی نام رکھا ہے تو جہاد کرو) تاکہ پیغمبر تمہارے بارے میں شاہد ہوں۔ اور تم لوگوں کے مقابلے میں شاہد اور نماز پڑھو اور زکوٰة دو اور خدا کے دین کی (رسی کو) پکڑے رہو۔ وہی تمہارا دوست ہے۔ اور خوب دوست اور خوب مددگار ہے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmdclxxiv{\basmalahur بےشک ایمان والے رستگار ہوگئے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmdclxxv{جو نماز میں عجزو نیاز کرتے ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmdclxxvi{اور جو بیہودہ باتوں سے منہ موڑے رہتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmdclxxvii{اور جو زکوٰة ادا کرتے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmdclxxviii{اور جو اپنی شرمگاہوں کی حفاظت کرتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmdclxxix{مگر اپنی بیویوں سے یا (کنیزوں سے) جو ان کی مِلک ہوتی ہیں کہ (ان سے) مباشرت کرنے سے انہیں ملامت نہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmdclxxx{اور جو ان کے سوا اوروں کے طالب ہوں وہ (خدا کی مقرر کی ہوئی حد سے) نکل جانے والے ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmdclxxxi{اور جو امانتوں اور اقراروں کو ملحوظ رکھتے ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmdclxxxii{اور جو نمازوں کی پابندی کرتے ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiii{یہ ہی لوگ میراث حاصل کرنے والے ہیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmdclxxxiv{یعنی) جو بہشت کی میراث حاصل کریں گے۔ اور اس میں ہمیشہ رہیں گے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmdclxxxv{اور ہم نے انسان کو مٹی کے خلاصے سے پیدا کیا ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvi{پھر اس کو ایک مضبوط (اور محفوظ) جگہ میں نطفہ بنا کر رکھا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmdclxxxvii{پھر نطفے کا لوتھڑا بنایا۔ پھر لوتھڑے کی بوٹی بنائی پھر بوٹی کی ہڈیاں بنائیں پھر ہڈیوں پر گوشت (پوست) چڑھایا۔ پھر اس کو نئی صورت میں بنا دیا۔ تو خدا جو سب سے بہتر بنانے والا بڑا بابرکت ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmdclxxxviii{پھر اس کے بعد تم مرجاتے ہو\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmdclxxxix{پھر قیامت کے روز اُٹھا کھڑے کئے جاؤ گے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmdcxc{اور ہم نے تمہارے اوپر (کی جانب) سات آسمان پیدا کئے۔ اور ہم خلقت سے غافل نہیں ہیں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmdcxci{اور ہم ہی نے آسمان سے ایک اندازے کے ساتھ پانی نازل کیا۔ پھر اس کو زمین میں ٹھہرا دیا اور ہم اس کے نابود کردینے پر بھی قادر ہیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmdcxcii{پھر ہم نے اس سے تمہارے لئے کھجوروں اور انگوروں کے باغ بنائے، ان میں تمہارے لئے بہت سے میوے پیدا ہوتے ہیں۔ اور ان میں سے تم کھاتے بھی ہو\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmdcxciii{اور وہ درخت بھی (ہم ہی نے پیدا کیا) جو طور سینا میں پیدا ہوتا ہے (یعنی زیتون کا درخت کہ) کھانے کے لئے روغن اور سالن لئے ہوئے اُگتا ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmdcxciv{اور تمہارے لئے چارپایوں میں بھی عبرت (اور نشانی) ہے کہ ان کے پیٹوں میں ہے اس سے ہم تمہیں (دودھ) پلاتے ہیں اور تمہارے لئے ان میں اور بھی بہت سے فائدے ہیں اور بعض کو تم کھاتے بھی ہو\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmdcxcv{اور ان پر اور کشتیوں پر تم سوار ہوتے ہو\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmdcxcvi{اور ہم نے نوح کو ان کی قوم کی طرف بھیجا تو انہوں نے ان سے کہا کہ اے قوم! خدا ہی کی عبادت کرو اس کے سوا تمہارا کوئی معبود نہیں، کیا تم ڈرتے نہیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmdcxcvii{تو ان کی قوم کے سردار جو کافر تھے کہنے لگے کہ یہ تو تم ہی جیسا آدمی ہے۔ تم پر بڑائی حاصل کرنی چاہتا ہے۔ اور اگر خدا چاہتا تو فرشتے اُتار دیتا۔ ہم نے اپنے اگلے باپ دادا میں تو یہ بات کبھی سنی نہیں تھی\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmdcxcviii{اس آدمی کو تو دیوانگی (کا عارضہ) ہے تو اس کے بارے میں کچھ مدت انتظار کرو\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmdcxcix{نوح نے کہا کہ پروردگار انہوں نے مجھے جھٹلایا ہے تو میری مدد کر\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmdcc{پس ہم نے ان کی طرف وحی بھیجی کہ ہمارے سامنے اور ہمارے حکم سے ایک کشتی بناؤ۔ پھر جب ہمارا حکم آ پہنچے اور تنور (پانی سے بھر کر) جوش مارنے لگے تو سب (قسم کے حیوانات) میں جوڑا جوڑا (یعنی نر اور مادہ) دو دو کشتی میں بٹھا دو اور اپنے گھر والوں کو بھی، سو ان کے جن کی نسبت ان میں سے (ہلاک ہونے کا) حکم پہلے صادر ہوچکا ہے۔ اور ظالموں کے بارے میں ہم سے کچھ نہ کہنا، وہ ضرور ڈبو دیئے جائیں گے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmdcci{اور جب تم اور تمہارے ساتھی کشتی میں بیٹھ جاؤ تو (خدا کا شکر کرنا اور) کہنا کہ سب تعریف خدا ہی کو (سزاوار) ہے۔ جس نے ہم کو نجات بخشی ظالم لوگوں سے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmdccii{اور (یہ بھی) دعا کرنا کہ اے پروردگار ہم کو مبارک جگہ اُتاریو اور تو سب سے بہتر اُتارنے والا ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmdcciii{بےشک اس (قصے) میں نشانیاں ہیں اور ہمیں تو آزمائش کرنی تھی\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmdcciv{پھر ان کے بعد ہم نے ایک اور جماعت پیدا کی\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmdccv{اور ان ہی میں سے ان میں ایک پیغمبر بھیجا (جس نے ان سے کہا) کہ خدا ہی کی عبادت کرو (کہ) اس کے سوا تمہارا کوئی معبود نہیں، تو کیا تم ڈرتے نہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmdccvi{تو ان کی قوم کے سردار جو کافر تھے اور آخرت کے آنے کو جھوٹ سمجھتے تھے اور دنیا کی زندگی میں ہم نے ان کو آسودگی دے رکھی تھی۔ کہنے لگے کہ یہ تو تم ہی جیسا آدمی ہے، جس قسم کا کھانا تم کھاتے ہو، اسی طرح کا یہ بھی کھاتا ہے اور جو پانی تم پیتے ہو اسی قسم کا یہ بھی پیتا ہے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmdccvii{اور اگر تم اپنے ہی جیسے آدمی کا کہا مان لیا تو گھاٹے میں پڑ گئے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmdccviii{کیا یہ تم سے یہ کہتا ہے کہ جب تم مر جاؤ گے اور مٹی ہو جاؤ گے اور استخوان (کے سوا کچھ نہ رہے گا) تو تم (زمین سے) نکالے جاؤ گے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmdccix{جس بات کا تم سے وعدہ کیا جاتا ہے (بہت) بعید اور (بہت) بعید ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmdccx{زندگی تو یہی ہماری دنیا کی زندگی ہے کہ (اسی میں) ہم مرتے اور جیتے ہیں، اور ہم پھر نہیں اُٹھائے جائیں گے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmdccxi{یہ تو ایک ایسا آدمی ہے جس نے خدا پر جھوٹ افتراء کیا ہے اور ہم اس کو ماننے والے نہیں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmdccxii{پیغمبر نے کہا کہ اے پروردگار انہوں نے مجھے جھوٹا سمجھا ہے تو میری مدد کر\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmdccxiii{فرمایا کہ یہ تھوڑے ہی عرصے میں پشیمان ہو کر رہ جائیں گے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmdccxiv{تو ان کو (وعدہٴ برحق کے مطابق) زور کی آواز نے آپکڑا، تو ہم نے ان کو کوڑا کرڈالا۔ پس ظالم لوگوں پر لعنت ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmdccxv{پھر ان کے بعد ہم نے اور جماعتیں پیدا کیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmdccxvi{کوئی جماعت اپنے وقت سے نہ آگے جاسکتی ہے نہ پیچھے رہ سکتی ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmdccxvii{پھر ہم نے پے درپے اپنے پیغمبر بھیجتے رہے۔ جب کسی اُمت کے پاس اس کا پیغمبر آتا تھا تو وہ اسے جھٹلاتے تھے تو ہم بھی بعض کو بعض کے پیچھے (ہلاک کرتے اور ان پر عذاب) لاتے رہے اور ان کے افسانے بناتے رہے۔ پس جو لوگ ایمان نہیں لاتے ان پر لعنت\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmdccxviii{پھر ہم نے موسیٰ اور ان کے بھائی ہارون کو اپنی نشانیاں اور دلیل ظاہر دے کر بھیجا\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmdccxix{یعنی) فرعون اور اس کی جماعت کی طرف، تو انہوں نے تکبر کیا اور وہ سرکش لوگ تھے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmdccxx{کہنے لگے کہ کیا ہم ان اپنے جیسے دو آدمیوں پر ایمان لے آئیں اور اُن کو قوم کے لوگ ہمارے خدمت گار ہیں\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmdccxxi{تو اُن لوگوں نے اُن کی تکذیب کی سو (آخر) ہلاک کر دیئے گئے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmdccxxii{اور ہم نے موسیٰ کو کتاب دی تھی تاکہ وہ لوگ ہدایت پائیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmdccxxiii{اور ہم نے مریم کے بیٹے (عیسیٰ) اور ان کی ماں کو (اپنی) نشانی بنایا تھا اور ان کو ایک اونچی جگہ پر جو رہنے کے لائق تھی اور جہاں (نتھرا ہوا) پانی جاری تھا، پناہ دی تھی\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmdccxxiv{اے پیغمبرو! پاکیزہ چیزیں کھاؤ اور عمل نیک کرو۔ جو عمل تم کرتے ہو میں ان سے واقف ہوں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmdccxxv{اور یہ تمہاری جماعت (حقیقت میں) ایک ہی جماعت ہے اور میں تمہارا پروردگار ہوں تو مجھ سے ڈرو\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmdccxxvi{تو پھر آپس میں اپنے کام کو متفرق کرکے جدا جدا کردیا۔ جو چیزیں جس فرقے کے پاس ہے وہ اس سے خوش ہو رہا ہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmdccxxvii{تو ان کو ایک مدت تک ان کی غفلت میں رہنے دو\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmdccxxviii{کیا یہ لوگ خیال کرتے ہیں کہ ہم جو دنیا میں ان کو مال اور بیٹوں سے مدد دیتے ہیں\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmdccxxix{تو (اس سے) ان کی بھلائی میں جلدی کر رہے ہیں (نہیں) بلکہ یہ سمجھتے ہی نہیں\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmdccxxx{جو اپنے پروردگار کے خوف سے ڈرتے ہیں\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmdccxxxi{اور جو اپنے پروردگار کی آیتوں پر ایمان رکھتے ہیں\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmdccxxxii{اور جو اپنے پروردگار کے ساتھ شریک نہیں کرتے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiii{اور جو دے سکتے ہیں دیتے ہیں اور ان کے دل اس بات سے ڈرتے رہتے ہیں کہ ان کو اپنے پروردگار کی لوٹ کر جانا ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmdccxxxiv{یہی لوگ نیکیوں میں جلدی کرے اور یہی اُن کے لئے آگے نکل جاتے ہیں\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmdccxxxv{اور ہم کسی شخص کو اس کی طاقت سے زیادہ تکلیف نہیں دیتے اور ہمارے پاس کتاب ہے جو سچ سچ کہہ دیتی ہے اور ان لوگوں پر ظلم نہیں کیا جائے گا\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvi{مگر ان کے دل ان (باتوں) کی طرف سے غفلت میں (پڑے ہوئے) ہیں، اور ان کے سوا اور اعمال بھی ہیں جو یہ کرتے رہتے ہیں\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmdccxxxvii{یہاں تک کہ جب ہم نے ان میں سے آسودہ حال لوگوں کو پکڑ لیا تو وہ اس وقت چلاّئیں گے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmdccxxxviii{آج مت چلاّؤ! تم کو ہم سے کچھ مدد نہیں ملے گی\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmdccxxxix{میری آیتیں تم کو پڑھ پڑھ کر سنائی جاتی تھیں اور تم الٹے پاؤں پھر پھر جاتے تھے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmdccxl{ان سے سرکشی کرتے، کہانیوں میں مشغول ہوتے اور بیہودہ بکواس کرتے تھے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmdccxli{کیا انہوں نے اس کلام میں غور نہیں کیا یا ان کے پاس کوئی ایسی چیز آئی ہے جو ان کے اگلے باپ دادا کے پاس نہیں تھی\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmdccxlii{یا یہ اپنے پیغمبر کو جانتے پہنچانتے نہیں، اس وجہ سے ان کو نہیں مانتے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmdccxliii{کیا یہ کہتے ہیں کہ اسے سودا ہے (نہیں) بلکہ وہ ان کے پاس حق کو لے کر آئے ہیں اور ان میں سے اکثر حق کو ناپسند کرتے ہیں\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmdccxliv{اور خدائے (برحق) ان کی خواہشوں پر چلے تو آسمان اور زمین اور جو ان میں ہیں سب درہم برہم ہوجائیں۔ بلکہ ہم نے ان کے پاس ان کی نصیحت (کی کتاب) پہنچا دی ہے اور وہ اپنی (کتاب) نصیحت سے منہ پھیر رہے ہیں\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmdccxlv{کیا تم ان سے (تبلیغ کے صلے میں) کچھ مال مانگتے ہو، تو تمہارا پروردگار کا مال بہت اچھا ہے اور وہ سب سے بہتر رزق دینے والا ہے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmdccxlvi{اور تم تو ان کو سیدھے راستے کی طرف بلاتے ہو\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmdccxlvii{اور جو لوگ آخرت پر ایمان نہیں لاتے وہ رستے سے الگ ہو رہے ہیں\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmdccxlviii{اور اگر ہم ان پر رحم کریں اور جو تکلیفیں ان کو پہنچ رہی ہیں، وہ دور کردیں تو اپنی سرکشی پر اڑے رہیں (اور) بھٹکتے (پھریں)\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmdccxlix{اور ہم نے ان کو عذاب میں پکڑا تو بھی انہوں نے خدا کے آگے عاجزی نہ کی اور وہ عاجزی کرتے ہی نہیں\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmdccl{یہاں تک کہ جب ہم نے پر عذاب شدید کا دروازہ کھول دیا تو اس وقت وہاں ناامید ہوگئے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmdccli{اور وہی تو ہے جس نے تمہارے کان اور آنکھیں اور دل بنائے۔ (لیکن) تم کم شکرگزاری کرتے ہو\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmdcclii{اور وہی تو ہے جس نے تم کو زمین میں پیدا کیا اور اسی کی طرف تم جمع ہو کر جاؤ گے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmdccliii{اور وہی ہے جو زندگی بخشتا ہے اور موت دیتا ہے اور رات اور دن کا بدلتے رہنا اسی کا تصرف ہے، کیا تم سمجھتے نہیں\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmdccliv{بات یہ ہے کہ جو بات اگلے (کافر) کہتے تھے اسی طرح کی (بات یہ) کہتے ہیں\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmdcclv{کہتے ہیں کہ جب ہم مر جائیں گے اور مٹی ہو جائیں گے اور استخوان (بوسیدہ کے سوا کچھ) نہ رہے گا تو کیا ہم پھر اٹھائے جائیں گے؟\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmdcclvi{یہ وعدہ ہم سے اور ہم سے پہلے ہمارے باپ دادا سے بھی ہوتا چلا آیا ہے (اجی) یہ تو صرف اگلے لوگوں کی کہانیاں ہیں\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmdcclvii{کہو کہ اگر تم جانتے ہو تو بتاؤ کہ زمین اور جو کچھ زمین میں ہے سب کس کا مال ہے؟\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmdcclviii{جھٹ بول اٹھیں گے کہ خدا کا۔ کہو کہ پھر تم سوچتے کیوں نہیں؟\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmdcclix{ان سے) پوچھو کہ سات آسمانوں کا کون مالک ہے اور عرش عظیم کا (کون) مالک (ہے؟)\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmdcclx{بےساختہ کہہ دیں گے کہ یہ (چیزیں) خدا ہی کی ہیں، کہو کہ پھر تم ڈرتے کیوں نہیں؟\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmdcclxi{کہو کہ اگر تم جانتے ہو تو بتاؤ کہ وہ کون ہے جس کے ہاتھ میں ہر چیز کی بادشاہی ہے اور وہ پناہ دیتا ہے اور اس کے مقابل کوئی کسی کو پناہ نہیں دے سکتا\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmdcclxii{فوراً کہہ دیں گے کہ (ایسی بادشاہی تو) خدا ہی کی ہے، تو کہو پھر تم پر جادو کہاں سے پڑ جاتا ہے؟\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmdcclxiii{بات یہ ہے کہ ہم نے ان کے پاس حق پہنچا دیا ہے اور جو (بت پرستی کئے جاتے ہیں) بےشک جھوٹے ہیں\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmdcclxiv{خدا نے نہ تو (اپنا) کسی کو بیٹا بنایا ہے اور نہ اس کے ساتھ کوئی معبود ہے، ایسا ہوتا تو ہر معبود اپنی اپنی مخلوقات کو لے کر چل دیتا اور ایک دوسرے پر غالب آجاتا۔ یہ لوگ جو کچھ خدا کے بارے میں بیان کرتے ہیں خدا اس سے پاک ہے\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmdcclxv{وہ پوشیدہ اور ظاہر کو جانتا ہے اور (مشرک) جو اس کے ساتھ شریک کرتے ہیں اس کی شان اس سے اونچی ہے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmdcclxvi{اے محمدﷺ) کہو کہ اے پروردگار جس عذاب کا ان (کفار) سے وعدہ ہو رہا ہے، اگر تو میری زندگی میں ان پر نازل کرکے مجھے بھی دکھادے\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmdcclxvii{تو اے پروردگار مجھے (اس سے محفوظ رکھیئے اور) ان ظالموں میں شامل نہ کیجیئے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmdcclxviii{اور جو وعدہ ہم ان سے کر رہے ہیں ہم تم کو دکھا کر ان پر نازل کرنے پر قادر ہیں\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmdcclxix{اور بری بات کے جواب میں ایسی بات کہو جو نہایت اچھی ہو۔ اور یہ جو کچھ بیان کرتے ہیں ہمیں خوب معلوم ہے\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmdcclxx{اور کہو کہ اے پروردگار! میں شیطانوں کے وسوسوں سے تیری پناہ مانگتا ہو\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmdcclxxi{اور اے پروردگار! اس سے بھی تیری پناہ مانگتا ہوں کہ وہ میرے پاس آموجود ہوں\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmdcclxxii{یہ لوگ اسی طرح غفلت میں رہیں گے) یہاں تک کہ جب ان میں سے کسی کے پاس موت آجائے گی تو کہے گا کہ اے پروردگار! مجھے پھر (دنیا میں) واپس بھیج دے\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiii{تاکہ میں اس میں جسے چھوڑ آیا ہوں نیک کام کیا کروں۔ ہرگز نہیں۔ یہ ایک ایسی بات ہے کہ وہ اسے زبان سے کہہ رہا ہوگا (اور اس کے ساتھ عمل نہیں ہوگا) اور اس کے پیچھے برزخ ہے (جہاں وہ) اس دن تک کہ (دوبارہ) اٹھائے جائیں گے، (رہیں گے)\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmdcclxxiv{پھر جب صور پھونکا جائے گا تو نہ تو ان میں قرابتیں ہوں گی اور نہ ایک دوسرے کو پوچھیں گے\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmdcclxxv{تو جن کے (عملوں کے) بوجھ بھاری ہوں گے۔ وہ فلاح پانے والے ہیں\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvi{اور جن کے بوجھ ہلکے ہوں گے وہ لوگ ہیں جنہوں نے اپنے تئیں خسارے میں ڈالا، ہمیشہ دوزخ میں رہیں گے\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmdcclxxvii{آگ ان کے مونہوں کو جھلس دے گی اور وہ اس میں تیوری چڑھائے ہوں گے\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmdcclxxviii{کیا تم کو میری آیتیں پڑھ کر نہیں سنائی جاتیں تھیں (نہیں) تم ان کو سنتے تھے (اور) جھٹلاتے تھے\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmdcclxxix{اے ہمارے پروردگار! ہم پر ہماری کم بختی غالب ہوگئی اور ہم رستے سے بھٹک گئے\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmdcclxxx{اے پروردگار! ہم کو اس میں سے نکال دے، اگر ہم پھر (ایسے کام) کریں تو ظالم ہوں گے\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxi{خدا) فرمائے گا کہ اسی میں ذلت کے ساتھ پڑے رہو اور مجھ سے بات نہ کرو\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxii{میرے بندوں میں ایک گروہ تھا جو دعا کیا کرتا تھا کہ اے ہمارے پروردگار ہم ایمان لائے تو تُو ہم کو بخش دے اور ہم پر رحم کر اور تو سب سے بہتر رحم کرنے والا ہے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiii{تو تم ان سے تمسخر کرتے رہے یہاں تک کہ ان کے پیچھے میری یاد بھی بھول گئے اور تم (ہمیشہ) ان سے ہنسی کیا کرتے تھے\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxiv{آج میں نے اُن کو اُن کے صبر کا بدلہ دیا، کہ وہ کامیاب ہوگئے\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxv{خدا) پوچھے گا کہ تم زمین میں کتنے برس رہے؟\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvi{وہ کہیں گے کہ ہم ایک روز یا ایک روز سے بھی کم رہے تھے، شمار کرنے والوں سے پوچھ لیجیئے\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxvii{خدا) فرمائے گا کہ (وہاں) تم (بہت ہی) کم رہے۔ کاش تم جانتے ہوتے\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxviii{کیا تم یہ خیال کرتے ہو کہ ہم نے تم کو بےفائدہ پیدا کیا ہے اور یہ تم ہماری طرف لوٹ کر نہیں آؤ گے؟\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mmdcclxxxix{تو خدا جو سچا بادشاہ ہے (اس کی شان) اس سے اونچی ہے، اس کے سوا کوئی معبود نہیں، وہی عرش بزرگ کا مالک ہے\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mmdccxc{اور جو شخص خدا کے ساتھ اور معبود کو پکارتا ہے جس کی اس کے پاس کچھ بھی سند نہیں تو اس کا حساب خدا ہی کے ہاں ہوگا۔ کچھ شک نہیں کہ کافر رستگاری نہیں پائیں گے\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mmdccxci{اور خدا سے دعا کرو کہ میرے پروردگار مجھے بخش دے اور (مجھ پر) رحم کر اور تو سب سے بہتر رحم کرنے والا ہے\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mmdccxcii{\basmalahur یہ (ایک) سورت ہے جس کو ہم نے نازل کیا اور اس (کے احکام) کو فرض کر دیا، اور اس میں واضح المطالب آیتیں نازل کیں تاکہ تم یاد رکھو\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmdccxciii{بدکاری کرنے والی عورت اور بدکاری کرنے والا مرد (جب ان کی بدکاری ثابت ہوجائے تو) دونوں میں سے ہر ایک کو سو درے مارو۔ اور اگر تم خدا اور روز آخرت پر ایمان رکھتے ہو تو شرع خدا (کے حکم) میں تمہیں ان پر ہرگز ترس نہ آئے۔ اور چاہیئے کہ ان کی سزا کے وقت مسلمانوں کی ایک جماعت بھی موجود ہو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmdccxciv{بدکار مرد تو بدکار یا مشرک عورت کے سوا نکاح نہیں کرتا اور بدکار عورت کو بھی بدکار یا مشرک مرد کے سوا اور کوئی نکاح میں نہیں لاتا اور یہ (یعنی بدکار عورت سے نکاح کرنا) مومنوں پر حرام ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmdccxcv{اور جو لوگ پرہیزگار عورتوں کو بدکاری کا عیب لگائیں اور اس پر چار گواہ نہ لائیں تو ان کو اسی درے مارو اور کبھی ان کی شہادت قبول نہ کرو۔ اور یہی بدکردار ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmdccxcvi{ہاں جو اس کے بعد توبہ کرلیں اور (اپنی حالت) سنوار لیں تو خدا (بھی) بخشنے والا مہربان ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmdccxcvii{اور جو لوگ اپنی عورتوں پر بدکاری کی تہمت لگائیں اور خود ان کے سوا ان کے گواہ نہ ہوں تو ہر ایک کی شہادت یہ ہے کہ پہلے تو چار بار خدا کی قسم کھائے کہ بےشک وہ سچا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmdccxcviii{اور پانچویں بار یہ (کہے) کہ اگر وہ جھوٹا ہو تو اس پر خدا کی لعنت\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmdccxcix{اور عورت سے سزا کو یہ بات ٹال سکتی ہے کہ وہ پہلے چار بار خدا کی قسم کھائے کہ بےشک یہ جھوٹا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmdccc{اور پانچویں دفعہ یوں (کہے) کہ اگر یہ سچا ہو تو مجھ پر خدا کا غضب (نازل ہو)\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmdccci{اور اگر تم پر خدا کا فضل اور اس کی مہربانی نہ ہوتی تو بہت سی خرابیاں پیدا ہوجاتیں۔ مگر وہ صاحب کرم ہے اور یہ کہ خدا توبہ قبول کرنے والا حکیم ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmdcccii{جن لوگوں نے بہتان باندھا ہے تم ہی میں سے ایک جماعت ہے اس کو اپنے حق میں برا نہ سمجھنا۔ بلکہ وہ تمہارے لئے اچھا ہے۔ ان میں سے جس شخص نے گناہ کا جتنا حصہ لیا اس کے لئے اتنا ہی وبال ہے۔ اور جس نے ان میں سے اس بہتان کا بڑا بوجھ اٹھایا ہے اس کو بڑا عذاب ہوگا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmdccciii{جب تم نے وہ بات سنی تھی تو مومن مردوں اور عورتوں نے کیوں اپنے دلوں میں نیک گمان نہ کیا۔ اور کیوں نہ کہا کہ یہ صریح طوفان ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmdccciv{یہ (افتراء پرداز) اپنی بات (کی تصدیق) کے (لئے) چار گواہ کیوں نہ لائے۔ تو جب یہ گواہ نہیں لاسکے تو خدا کے نزدیک یہی جھوٹے ہیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmdcccv{اور اگر دنیا اور آخرت میں تم پر خدا کا فضل اور اس کی رحمت نہ ہوتی تو جس بات کا تم چرچا کرتے تھے اس کی وجہ سے تم پر بڑا (سخت) عذاب نازل ہوتا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmdcccvi{جب تم اپنی زبانوں سے اس کا ایک دوسرے سے ذکر کرتے تھے اور اپنے منہ سے ایسی بات کہتے تھے جس کا تم کو کچھ علم نہ تھا اور تم اسے ایک ہلکی بات سمجھتے تھے اور خدا کے نزدیک وہ بڑی بھاری بات تھی\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmdcccvii{اور جب تم نے اسے سنا تھا تو کیوں نہ کہہ دیا کہ ہمیں شایاں نہیں کہ ایسی بات زبان پر نہ لائیں۔ (پروردگار) تو پاک ہے یہ تو (بہت) بڑا بہتان ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmdcccviii{خدا تمہیں نصیحت کرتا ہے کہ اگر مومن ہو تو پھر کبھی ایسا کام نہ کرنا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmdcccix{اور خدا تمہارے (سمجھانے کے لئے) اپنی آیتیں کھول کھول کر بیان فرماتا ہے۔ اور خدا جاننے والا حکمت والا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmdcccx{اور جو لوگ اس بات کو پسند کرتے ہیں کہ مومنوں میں بےحیائی یعنی (تہمت بدکاری کی خبر) پھیلے ان کو دنیا اور آخرت میں دکھ دینے والا عذاب ہوگا۔ اور خدا جانتا ہے اور تم نہیں جانتے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmdcccxi{اور اگر تم پر خدا کا فضل اور اس کی رحمت نہ ہوتی (تو کیا کچھ نہ ہوتا مگر وہ کریم ہے) اور یہ کہ خدا نہایت مہربان اور رحیم ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmdcccxii{اے مومنو! شیطان کے قدموں پر نہ چلنا۔ اور جو شخص شیطان کے قدموں پر چلے گا تو شیطان تو بےحیائی (کی باتیں) اور برے کام ہی بتائے گا۔ اور اگر تم پر خدا کا فضل اور اس کی مہربانی نہ ہوتی تو ایک شخص بھی تم میں پاک نہ ہوسکتا۔ مگر خدا جس کو چاہتا ہے پاک کردیتا ہے۔ اور خدا سننے والا (اور) جاننے والا ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmdcccxiii{اور جو لوگ تم میں صاحب فضل (اور صاحب) وسعت ہیں، وہ اس بات کی قسم نہ کھائیں کہ رشتہ داروں اور محتاجوں اور وطن چھوڑ جانے والوں کو کچھ خرچ پات نہیں دیں گے۔ ان کو چاہیئے کہ معاف کردیں اور درگزر کریں۔ کیا تم پسند نہیں کرتے کہ خدا تم کو بخش دے؟ اور خدا تو بخشنے والا مہربان ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmdcccxiv{جو لوگ پرہیزگار اور برے کاموں سے بےخبر اور ایمان دار عورتوں پر بدکاری کی تہمت لگاتے ہیں ان پر دنیا وآخرت (دونوں) میں لعنت ہے۔ اور ان کو سخت عذاب ہوگا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmdcccxv{یعنی قیامت کے روز) جس دن ان کی زبانیں ہاتھ اور پاؤں سب ان کے کاموں کی گواہی دیں گے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmdcccxvi{اس دن خدا ان کو (ان کے اعمال کا) پورا پورا (اور) ٹھیک بدلہ دے گا اور ان کو معلوم ہوجائے گا کہ خدا برحق (اور حق کو) ظاہر کرنے والا ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmdcccxvii{ناپاک عورتیں ناپاک مردوں کے لئے اور ناپاک مرد ناپاک عورتوں کے لئے۔ اور پاک عورتیں پاک مردوں کے لئے۔ اور پاک مرد پاک عورتوں کے لئے۔ یہ (پاک لوگ) ان (بدگویوں) کی باتوں سے بری ہیں (اور) ان کے لئے بخشش اور نیک روزی ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmdcccxviii{مومنو! اپنے گھروں کے سوا دوسرے (لوگوں کے) گھروں میں گھر والوں سے اجازت لئے اور ان کو سلام کئے بغیر داخل نہ ہوا کرو۔ یہ تمہارے حق میں بہتر ہے (اور ہم) یہ نصیحت اس لئے کرتے ہیں کہ شاید تم یاد رکھو\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmdcccxix{اگر تم گھر میں کسی کو موجود نہ پاؤ تو جب تک تم کو اجازت نہ دی جائے اس میں مت داخل ہو۔ اور اگر یہ کہا جائے کہ (اس وقت) لوٹ جاؤ تو لوٹ جایا کرو۔ یہ تمہارے لئے بڑی پاکیزگی کی بات ہے۔ اور جو کام تم کرتے ہو خدا سب جانتا ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmdcccxx{ہاں اگر تم کسی ایسے مکان میں جاؤ جس میں کوئی نہ بستا ہو اور اس میں تمہارا اسباب (رکھا) ہو، تم پر کچھ گناہ نہیں، اور جو کچھ تم ظاہر کرتے ہو اور جو پوشیدہ کرتے ہو خدا کو سب معلوم ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmdcccxxi{مومن مردوں سے کہہ دو کہ اپنی نظریں نیچی رکھا کریں اور اپنی شرم گاہوں کی حفاظت کیا کریں۔ یہ ان کے لئے بڑی پاکیزگی کی بات ہے اور جو کام یہ کرتے ہیں خدا ان سے خبردار ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmdcccxxii{اور مومن عورتوں سے بھی کہہ دو کہ وہ بھی اپنی نگاہیں نیچی رکھا کریں اور اپنی شرم گاہوں کی حفاظت کیا کریں اور اپنی آرائش (یعنی زیور کے مقامات) کو ظاہر نہ ہونے دیا کریں مگر جو ان میں سے کھلا رہتا ہو۔ اور اپنے سینوں پر اوڑھنیاں اوڑھے رہا کریں اور اپنے خاوند اور باپ اور خسر اور بیٹیوں اور خاوند کے بیٹوں اور بھائیوں اور بھتیجیوں اور بھانجوں اور اپنی (ہی قسم کی) عورتوں اور لونڈی غلاموں کے سوا نیز ان خدام کے جو عورتوں کی خواہش نہ رکھیں یا ایسے لڑکوں کے جو عورتوں کے پردے کی چیزوں سے واقف نہ ہوں (غرض ان لوگوں کے سوا) کسی پر اپنی زینت (اور سنگار کے مقامات) کو ظاہر نہ ہونے دیں۔ اور اپنے پاؤں (ایسے طور سے زمین پر) نہ ماریں (کہ جھنکار کانوں میں پہنچے اور) ان کا پوشیدہ زیور معلوم ہوجائے۔ اور مومنو! سب خدا کے آگے توبہ کرو تاکہ فلاح پاؤ\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiii{اور اپنی قوم کی بیوہ عورتوں کے نکاح کردیا کرو۔ اور اپنے غلاموں اور لونڈیوں کے بھی جو نیک ہوں (نکاح کردیا کرو) اگر وہ مفلس ہوں گے تو خدا ان کو اپنے فضل سے خوش حال کردے گا۔ اور خدا (بہت) وسعت والا اور (سب کچھ) جاننے والا ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmdcccxxiv{اور جن کو بیاہ کا مقدور نہ ہو وہ پاک دامنی کو اختیار کئے رہیں یہاں تک کہ خدا ان کو اپنے فضل سے غنی کردے۔ اور جو غلام تم سے مکاتبت چاہیں اگر تم ان میں (صلاحیت اور) نیکی پاؤ تو ان سے مکاتبت کرلو۔ اور خدا نے جو مال تم کو بخشا ہے اس میں سے ان کو بھی دو۔ اور اپنی لونڈیوں کو اگر وہ پاک دامن رہنا چاہیں تو (بےشرمی سے) دنیاوی زندگی کے فوائد حاصل کرنے کے لئے بدکاری پر مجبور نہ کرنا۔ اور جو ان کو مجبور کرے گا تو ان (بیچاریوں) کے مجبور کئے جانے کے بعد خدا بخشنے والا مہربان ہے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmdcccxxv{اور ہم نے تمہاری طرف روشن آیتیں نازل کی ہیں اور جو لوگ تم سے پہلے گزر چکے ہیں ان کی خبریں اور پرہیزگاروں کے لئے نصیحت\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvi{خدا آسمانوں اور زمین کا نور ہے۔ اس کے نور کی مثال ایسی ہے کہ گویا ایک طاق ہے جس میں چراغ ہے۔ اور چراغ ایک قندیل میں ہے۔ اور قندیل (ایسی صاف شفاف ہے کہ) گویا موتی کا سا چمکتا ہوا تارہ ہے اس میں ایک مبارک درخت کا تیل جلایا جاتا ہے (یعنی) زیتون کہ نہ مشرق کی طرف ہے نہ مغرب کی طرف۔ (ایسا معلوم ہوتا ہے کہ) اس کا تیل خواہ آگ اسے نہ بھی چھوئے جلنے کو تیار ہے (پڑی) روشنی پر روشنی (ہو رہی ہے) خدا اپنے نور سے جس کو چاہتا ہے سیدھی راہ دکھاتا ہے۔ اور خدا نے (جو مثالیں) بیان فرماتا ہے (تو) لوگوں کے (سمجھانے کے) لئے اور خدا ہر چیز سے واقف ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmdcccxxvii{وہ قندیل) ان گھروں میں (ہے) جن کے بارے میں خدا نے ارشاد فرمایا ہے کہ بلند کئے جائیں اور وہاں خدا کے نام کا ذکر کیا جائے (اور) ان میں صبح وشام اس کی تسبیح کرتے رہیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmdcccxxviii{یعنی ایسے) لوگ جن کو خدا کے ذکر اور نماز پڑھنے اور زکوٰة دینے سے نہ سوداگری غافل کرتی ہے نہ خرید وفروخت۔ وہ اس دن سے جب دل (خوف اور گھبراہٹ کے سبب) الٹ جائیں گے اور آنکھیں (اوپر کو چڑھ جائیں گی) ڈرتے ہیں\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmdcccxxix{تاکہ خدا ان کو ان کے عملوں کا بہت اچھا بدلہ دے اور اپنے فضل سے زیادہ بھی عطا کرے۔ اور جس کو چاہتا ہے خدا بےشمار رزق دیتا ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmdcccxxx{جن لوگوں نے کفر کیا ان کے اعمال کی مثال ایسی ہے جیسے میدان میں ریت کہ پیاسا اسے پانی سمجھے یہاں تک کہ جب اس کے پاس آئے تو اسے کچھ بھی نہ پائے اور خدا ہی کو اپنے پاس دیکھے تو وہ اسے اس کا حساب پورا پورا چکا دے۔ اور خدا جلد حساب کرنے والا ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxi{یا (ان کے اعمال کی مثال ایسی ہے) جیسے دریائے عمیق میں اندھیرے جس پر لہر چڑھی چلی آتی ہو اور اس کے اوپر اور لہر (آرہی ہو) اور اس کے اوپر بادل ہو، غرض اندھیرے ہی اندھیرے ہوں، ایک پر ایک (چھایا ہوا) جب اپنا ہاتھ نکالے تو کچھ نہ دیکھ سکے۔ اور جس کو خدا روشنی نہ دے اس کو (کہیں بھی) روشنی نہیں (مل سکتی)\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxii{کیا تم نے نہیں دیکھا کہ جو لوگ آسمانوں اور زمین میں ہیں خدا کی تسبیح کرتے ہیں اور پر پھیلائے ہوئے جانور بھی۔ اور سب اپنی نماز اور تسبیح کے طریقے سے واقف ہیں۔ اور جو کچھ وہ کرتے ہیں (سب) خدا کو معلوم ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiii{اور آسمان اور زمین کی بادشاہی خدا کے لئے ہے۔ اور خدا ہی کی طرف لوٹ کر جانا ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxiv{کیا تم نے نہیں دیکھا کہ خدا ہی بادلوں کو چلاتا ہے، اور ان کو آپس میں ملا دیتا ہے، پھر ان کو تہ بہ تہ کردیتا ہے، پھر تم دیکھتے ہو کہ بادل میں سے مینہ نکل (کر برس) رہا ہے اور آسمان میں جو (اولوں کے) پہاڑ ہیں، ان سے اولے نازل کرتا ہے تو جس پر چاہتا ہے اس کو برسا دیتا ہے اور جس سے چاہتا ہے ہٹا دیتا ہے۔ اور بادل میں جو بجلی ہوتی ہے اس کی چمک آنکھوں کو خیرہ کرکے بینائی کو اُچکے لئے جاتی ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxv{اور خدا ہی رات اور دن کو بدلتا رہتا ہے۔ اہل بصارت کے لئے اس میں بڑی عبرت ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvi{اور خدا ہی نے ہر چلنے پھرنے والے جاندار کو پانی سے پیدا کیا۔ تو اس میں بعضے ایسے ہیں کہ پیٹ کے بل چلتے ہیں اور بعض ایسے ہیں جو دو پاؤں پر چلتے ہیں اور بعض ایسے ہیں جو چار پاؤں پر چلتے ہیں۔ خدا جو چاہتا ہے پیدا کرتا ہے، بےشک خدا ہر چیز پر قادر ہے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxvii{ہم ہی نے روشن آیتیں نازل کیں ہیں اور خدا جس کو چاہتا ہے سیدھے رستے کی طرف ہدایات کرتا ہے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxviii{اور بعض لوگ کہتے ہیں کہ ہم خدا پر اور رسول پر ایمان لائے اور (ان کا) حکم مان لیا پھر اس کے بعد ان میں سے ایک فرقہ پھر جاتا ہے اور یہ لوگ صاحب ایمان ہی نہیں ہیں\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmdcccxxxix{اور جب ان کو خدا اور اس کے رسول کی طرف بلایا جاتا ہے تاکہ (رسول خدا) ان کا قضیہ چکا دیں تو ان میں سے ایک فرقہ منہ پھیر لیتا ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmdcccxl{اگر (معاملہ) حق (ہو اور) ان کو (پہنچتا) ہو تو ان کی طرف مطیع ہو کر چلے آتے ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmdcccxli{کیا ان کے دلوں میں بیماری ہے یا (یہ) شک میں ہیں یا ان کو یہ خوف ہے کہ خدا اور اس کا رسول ان کے حق میں ظلم کریں گے (نہیں) بلکہ یہ خود ظالم ہیں\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmdcccxlii{مومنوں کی تو یہ بات ہے کہ جب خدا اور اس کے رسول کی طرف بلائے جائیں تاکہ وہ ان میں فیصلہ کریں تو کہیں کہ ہم نے (حکم) سن لیا اور مان لیا۔ اور یہی لوگ فلاح پانے والے ہیں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmdcccxliii{اور جو شخص خدا اور اس کے رسول کی فرمانبرداری کرے گا اور اس سے ڈرے گا تو ایسے لوگ مراد کو پہنچنے والے ہیں\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmdcccxliv{اور (یہ) خدا کی سخت سخت قسمیں کھاتے ہیں کہ اگر تم ان کو حکم دو تو (سب گھروں سے) نکل کھڑے ہوں۔ کہہ دو کہ قسمیں مت کھاؤ، پسندیدہ فرمانبرداری (درکار ہے) ۔ بےشک خدا تمہارے سب اعمال سے خبردار ہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmdcccxlv{کہہ دو کہ خدا کی فرمانبرداری کرو اور رسول خدا کے حکم پر چلو۔ اگر منہ موڑو گے تو رسول پر (اس چیز کا ادا کرنا) جو ان کے ذمے ہے اور تم پر (اس چیز کا ادا کرنا) ہے جو تمہارے ذمے ہے اور اگر تم ان کے فرمان پر چلو گے تو سیدھا رستہ پالو گے اور رسول کے ذمے تو صاف صاف (احکام خدا کا) پہنچا دینا ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvi{جو لوگ تم میں سے ایمان لائے اور نیک کام کرتے رہے ان سے خدا کا وعدہ ہے کہ ان کو ملک کا حاکم بنادے گا جیسا ان سے پہلے لوگوں کو حاکم بنایا تھا اور ان کے دین کو جسے اس نے ان کے لئے پسند کیا ہے مستحکم وپائیدار کرے گا اور خوف کے بعد ان کو امن بخشے گا۔ وہ میری عبادت کریں گے اور میرے ساتھ کسی چیز کو شریک نہ بنائیں گے۔ اور جو اس کے بعد کفر کرے تو ایسے لوگ بدکردار ہیں\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmdcccxlvii{اور نماز پڑھتے رہو اور زکوٰة دیتے رہو اور پیغمبر خدا کے فرمان پر چلتے رہو تاکہ تم پر رحمت کی جائے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmdcccxlviii{اور ایسا خیال نہ کرنا کہ تم پر کافر لوگ غالب آجائیں گے (وہ جا ہی کہاں سکتے ہیں) ان کا ٹھکانا دوزخ ہے اور وہ بہت برا ٹھکانا ہے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmdcccxlix{مومنو! تمہارے غلام لونڈیاں اور جو بچّے تم میں سے بلوغ کو نہیں پہنچے تین دفعہ یعنی (تین اوقات میں) تم سے اجازت لیا کریں۔ (ایک تو) نماز صبح سے پہلے اور (دوسرے گرمی کی دوپہر کو) جب تم کپڑے اتار دیتے ہو۔ اور تیسرے عشاء کی نماز کے بعد۔ (یہ) تین (وقت) تمہارے پردے (کے) ہیں ان کے (آگے) پیچھے (یعنی دوسرے وقتوں میں) نہ تم پر کچھ گناہ ہے اور نہ ان پر۔ کہ کام کاج کے لئے ایک دوسرے کے پاس آتے رہتے ہو۔ اس طرح خدا اپنی آیتیں تم سے کھول کھول کر بیان فرماتا ہے اور خدا بڑا علم والا اور بڑا حکمت والا ہے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmdcccl{اور جب تمہارے لڑکے بالغ ہوجائیں تو ان کو بھی اسی طرح اجازت لینی چاہیئے جس طرح ان سے اگلے (یعنی بڑے آدمی) اجازت حاصل کرتے رہے ہیں۔ اس طرح خدا تم سے اپنی آیتیں کھول کھول کر سناتا ہے۔ اور خدا جاننے والا اور حکمت والا ہے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmdcccli{اور بڑی عمر کی عورتیں جن کو نکاح کی توقع نہیں رہی، اور وہ کپڑے اتار کر سر ننگا کرلیا کریں تو ان پر کچھ گناہ نہیں بشرطیکہ اپنی زینت کی چیزیں نہ ظاہر کریں۔ اور اس سے بھی بچیں تو یہ ان کے حق میں بہتر ہے۔ اور خدا سنتا اور جانتا ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmdccclii{نہ تو اندھے پر کچھ گناہ ہے اور نہ لنگڑے پر اور نہ بیمار پر اور نہ خود تم پر کہ اپنے گھروں سے کھانا کھاؤ یا اپنے باپوں کے گھروں سے یا اپنی ماؤں کے گھروں سے یا بھائیوں کے گھروں سے یا اپنی بہنوں کے گھروں سے یا اپنے چچاؤں کے گھروں سے یا اپنی پھوپھیوں کے گھروں سے یا اپنے ماموؤں کے گھروں سے یا اپنی خالاؤں کے گھروں سے یا اس گھر سے جس کی کنجیاں تمہارے ہاتھ میں ہوں یا اپنے دوستوں کے گھروں سے (اور اس کا بھی) تم پر کچھ گناہ نہیں کہ سب مل کر کھانا کھاؤ یا جدا جدا۔ اور جب گھروں میں جایا کرو تو اپنے (گھر والوں کو) سلام کیا کرو۔ (یہ) خدا کی طرف سے مبارک اور پاکیزہ تحفہ ہے۔ اس طرح خدا اپنی آیتیں کھول کھول کر بیان فرماتا ہے تاکہ تم سمجھو\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmdcccliii{مومن تو وہ ہیں جو خدا پر اور اس کے رسول پر ایمان لائے اور جب کبھی ایسے کام کے لئے جو جمع ہو کر کرنے کا ہو پیغمبر خدا کے پاس جمع ہوں تو ان سے اجازت لئے بغیر چلے نہیں جاتے۔ اے پیغمبر جو لوگ تم سے اجازت حاصل کرتے ہیں وہی خدا پر اور اس کے رسول پر ایمان رکھتے ہیں۔ سو جب یہ لوگ تم سے کسی کام کے لئے اجازت مانگا کریں تو ان میں سے جسے چاہا کرو اجازت دے دیا کرو اور ان کے لئے خدا سے بخششیں مانگا کرو۔ کچھ شک نہیں کہ خدا بخشنے والا مہربان ہے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmdcccliv{مومنو پیغمبر کے بلانے کو ایسا خیال نہ کرنا جیسا تم آپس میں ایک دوسرے کو بلاتے ہو۔ بےشک خدا کو یہ لوگ معلوم ہیں جو تم میں سے آنکھ بچا کر چل دیتے ہیں تو جو لوگ ان کے حکم کی مخالفت کرتے ہیں ان کو ڈرنا چاہیئے کہ (ایسا نہ ہو کہ) ان پر کوئی آفت پڑ جائے یا تکلیف دینے والا عذاب نازل ہو\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmdccclv{دیکھو جو کچھ آسمانوں اور زمین میں ہے سب خدا ہی کا ہے۔ جس (طریق) پر تم ہو وہ اسے جانتا ہے۔ اور جس روز لوگ اس کی طرف لوٹائے جائیں گے تو جو لوگ عمل کرتے رہے وہ ان کو بتا دے گا۔ اور خدا ہر چیز پر قادر ہے۔\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmdccclvi{\basmalahur وہ (خدائے غزوجل) بہت ہی بابرکت ہے جس نے اپنے بندے پر قرآن نازل فرمایا تاکہ اہل حال کو ہدایت کرے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmdccclvii{وہی کہ آسمان اور زمین کی بادشاہی اسی کی ہے اور جس نے (کسی کو) بیٹا نہیں بنایا اور جس کا بادشاہی میں کوئی شریک نہیں اور جس نے ہر چیز کو پیدا کیا اور پھر اس کا ایک اندازہ ٹھہرایا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmdccclviii{اور (لوگوں نے) اس کے سوا اور معبود بنا لئے ہیں جو کوئی چیز بھی پیدا نہیں کرسکتے اور خود پیدا کئے گئے ہیں۔ اور نہ اپنے نقصان اور نفع کا کچھ اختیار رکھتے ہیں اور نہ مرنا ان کے اختیار میں ہے اور نہ جینا اور نہ مر کر اُٹھ کھڑے ہونا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmdccclix{اور کافر کہتے ہیں کہ یہ (قرآن) من گھڑت باتیں ہی جو اس (مدعی رسالت) نے بنالی ہیں۔ اور لوگوں نے اس میں اس کی مدد کی ہے۔ یہ لوگ (ایسا کہنے سے) ظلم اور جھوٹ پر (اُتر) آئے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmdccclx{اور کہتے ہیں کہ یہ پہلے لوگوں کی کہانیاں ہیں جس کو اس نے لکھ رکھا ہے اور وہ صبح وشام اس کو پڑھ پڑھ کر سنائی جاتی ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmdccclxi{کہہ دو کہ اُس نے اُس کو اُتارا ہے جو آسمانوں اور زمین کی پوشیدہ باتوں کو جانتا ہے۔ بےشک وہ بخشنے والا مہربان ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmdccclxii{اور کہتے ہیں کہ یہ کیسا پیغمبر ہے کہ کھاتا ہے اور بازاروں میں چلتا پھرتا ہے۔ کیوں نازل نہیں کیا گیا اس کے پاس کوئی فرشتہ اس کے ساتھ ہدایت کرنے کو رہتا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmdccclxiii{یا اس کی طرف (آسمان سے) خزانہ اتارا جاتا یا اس کا کوئی باغ ہوتا کہ اس میں کھایا کرتا۔ اور ظالم کہتے ہیں کہ تم تو ایک جادو زدہ شخص کی پیروی کرتے ہو\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmdccclxiv{اے پیغمبر) دیکھو تو یہ تمہارے بارے میں کس کس طرح کی باتیں کرتے ہیں سو گمراہ ہوگئے اور رستہ نہیں پاسکتے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmdccclxv{وہ (خدا) بہت بابرکت ہے جو اگر چاہے تو تمہارے لئے اس سے بہتر (چیزیں) بنا دے (یعنی) باغات جن کے نیچے نہریں بہہ رہی ہوں۔ نیز تمہارے لئے محل بنادے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmdccclxvi{بلکہ یہ تو قیامت ہی کو جھٹلاتے ہیں اور ہم نے قیامت کے جھٹلانے والوں کے لئے دوزخ تیار کر رکھی ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmdccclxvii{جس وقت وہ ان کو دور سے دیکھے گی (تو غضبناک ہو رہی ہوگی اور یہ) اس کے جوش (غضب) اور چیخنے چلانے کو سنیں گے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmdccclxviii{اور جب یہ دوزخ کی کسی تنگ جگہ میں (زنجیروں میں) جکڑ کر ڈالے جائیں گے تو وہاں موت کو پکاریں گے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmdccclxix{آج ایک ہی موت کو نہ پکارو بہت سی موتوں کو پکارو\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmdccclxx{پوچھو کہ یہ بہتر ہے یا بہشت جاودانی جس کا پرہیزگاروں سے وعدہ ہے۔ یہ ان (کے عملوں) کا بدلہ اور رہنے کا ٹھکانہ ہوگا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmdccclxxi{وہاں جو چاہیں گے ان کے لئے میسر ہوگا ہمیشہ اس میں رہیں گے۔ یہ وعدہ خدا کو (پورا کرنا) لازم ہے اور اس لائق ہے کہ مانگ لیا جائے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmdccclxxii{اور جس دن (خدا) ان کو اور اُن کو جنہیں یہ خدا کے سوا پوجتے ہیں جمع کرے گا تو فرمائے گا کیا تم نے میرے ان بندوں کو گمراہ کیا تھا یا یہ خود گمراہ ہوگئے تھے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiii{وہ کہیں گے تو پاک ہے ہمیں یہ بات شایان نہ تھی کہ تیرے سوا اوروں کو دوست بناتے۔ لیکن تو نے ہی ان کو اور ان کے باپ دادا کو برتنے کو نعمتیں دیں یہاں تک کہ وہ تیری یاد کو بھول گئے۔ اور یہ ہلاک ہونے والے لوگ تھے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmdccclxxiv{تو (کافرو) انہوں نے تو تم کو تمہاری بات میں جھٹلا دیا۔ پس (اب) تم (عذاب کو) نہ پھیر سکتے ہو۔ نہ (کسی سے) مدد لے سکتے ہو۔ اور جو شخص تم میں سے ظلم کرے گا ہم اس کو بڑے عذاب کا مزا چکھائیں گے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmdccclxxv{اور ہم نے تم سے پہلے جتنے پیغمبر بھیجے ہیں سب کھانا کھاتے تھے اور بازاروں میں چلتے پھرتے تھے۔ اور ہم نے تمہیں ایک دوسرے کے لئے آزمائش بنایا ہے۔ کیا تم صبر کرو گے۔ اور تمہارا پروردگار تو دیکھنے والا ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvi{اور جو لوگ ہم سے ملنے کی امید نہیں رکھتے۔ کہتے ہیں کہ ہم پر فرشتے کیوں نہ نازل کئے گئے۔ یا ہم اپنی آنکھ سے اپنے پروردگار کو دیکھ لیں۔ یہ اپنے خیال میں بڑائی رکھتے ہیں اور (اسی بنا پر) بڑے سرکش ہو رہے ہی\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmdccclxxvii{جس دن یہ فرشتوں کو دیکھیں گے اس دن گنہگاروں کے لئے خوشی کی بات نہیں ہوگی اور کہیں گے (خدا کرے تم) روک لئے (اور بند کردیئے) جاؤ\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmdccclxxviii{اور جو انہوں نے عمل کئے ہوں گے ہم ان کی طرف متوجہ ہوں گے تو ان کو اُڑتی خاک کردیں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmdccclxxix{اس دن اہل جنت کا ٹھکانا بھی بہتر ہوگا اور مقام استراحت بھی ہوگا\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmdccclxxx{اور جس دن آسمان ابر کے ساتھ پھٹ جائے گا اور فرشتے نازل کئے جائیں گے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxi{اس دن سچی بادشاہی خدا ہی کی ہوگی۔ اور وہ دن کافروں پر (سخت) مشکل ہوگا\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxii{اور جس دن (ناعاقبت اندیش) ظالم اپنے ہاتھ کاٹ کاٹ کر کھائے گا (اور کہے گا) کہ اے کاش میں نے پیغمبر کے ساتھ رشتہ اختیار کیا ہوتا\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiii{ہائے شامت کاش میں نے فلاں شخص کو دوست نہ بنایا ہوتا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxiv{اس نے مجھ کو (کتاب) نصیحت کے میرے پاس آنے کے بعد بہکا دیا۔ اور شیطان انسان کو وقت پر دغا دینے والا ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxv{اور پیغمبر کہیں گے کہ اے پروردگار میری قوم نے اس قرآن کو چھوڑ رکھا تھا\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvi{اور اسی طرح ہم نے گنہگاروں میں سے ہر پیغمبر کا دشمن بنا دیا۔ اور تمہارا پروردگار ہدایت دینے اور مدد کرنے کو کافی ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxvii{اور کافر کہتے ہیں کہ اس پر قرآن ایک ہی دفعہ کیوں نہیں اُتارا گیا۔ اس طرح (آہستہ آہستہ) اس لئے اُتارا گیا کہ اس سے تمہارے دل کو قائم رکھیں۔ اور اسی واسطے ہم اس کو ٹھہر ٹھہر کر پڑھتے رہے ہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxviii{اور یہ لوگ تمہارے پاس جو (اعتراض کی) بات لاتے ہیں ہم تمہارے پاس اس کا معقول اور خوب مشرح جواب بھیج دیتے ہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmdccclxxxix{جو لوگ اپنے مونہوں کے بل دوزخ کی طرف جمع کئے جائیں گے ان کا ٹھکانا بھی برا ہے اور وہ رستے سے بھی بہکے ہوئے ہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmdcccxc{اور ہم نے موسیٰ کو کتاب دی اور ان کے بھائی ہارون کو مددگار بنا کر ان کے ساتھ کیا\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmdcccxci{اور کہا کہ دونوں ان لوگوں کے پاس جاؤ جن لوگوں نے ہماری آیتوں کی تکذیب کی۔ (جب تکذیب پر اڑے رہے) تو ہم نے ان کو ہلاک کر ڈالا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmdcccxcii{اور نوح کی قوم نے بھی جب پیغمبروں کو جھٹلایا تو ہم نے انہیں غرق کر ڈالا اور لوگوں کے لئے نشانی بنا دیا۔ اور ظالموں کے لئے ہم نے دکھ دینے والا عذاب تیار کر رکھا ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmdcccxciii{اور عاد اور ثمود اور کنوئیں والوں اور ان کے درمیان اور بہت سی جماعتوں کو بھی (ہلاک کر ڈالا)\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmdcccxciv{اور سب کے (سمجھانے کے لئے) ہم نے مثالیں بیان کیں اور (نہ ماننے پر) سب کا تہس نہس کردیا\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmdcccxcv{اور یہ کافر اس بستی پر بھی گزر چکے ہیں جس پر بری طرح کا مینہ برسایا گیا تھا۔ کیا وہ اس کو دیکھتے نہ ہوں گے۔ بلکہ ان کو (مرنے کے بعد) جی اُٹھنے کی امید ہی نہیں تھی۔\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvi{اور یہ لوگ جب تم کو دیکھتے ہیں تو تمہاری ہنسی اُڑاتے ہیں۔ کہ کیا یہی شخص ہے جس کو خدا نے پیغمبر بنا کر بھیجا ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmdcccxcvii{اگر ہم نے اپنے معبودوں کے بارے میں ثابت قدم نہ رہتے تو یہ ضرور ہم کو بہکا دیتا۔ (اور ان سے پھیر دیتا) اور یہ عنقریب معلوم کرلیں گے جب عذاب دیکھیں گے کہ سیدھے رستے سے کون بھٹکا ہوا ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmdcccxcviii{کیا تم نے اس شخص کو دیکھا جس نے خواہش نفس کو معبود بنا رکھا ہے تو کیا تم اس پر نگہبان ہوسکتے ہو\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmdcccxcix{یا تم یہ خیال کرتے ہو کہ ان میں اکثر سنتے یا سمجھتے ہیں (نہیں) یہ تو چوپایوں کی طرح ہیں بلکہ ان سے بھی زیادہ گمراہ ہیں\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmcm{بلکہ تم نے اپنے پروردگار (کی قدرت) کو نہیں دیکھا کہ وہ سائے کو کس طرح دراز کر (کے پھیلا) دیتا ہے۔ اور اگر وہ چاہتا تو اس کو (بےحرکت) ٹھیرا رکھتا پھر سورج کو اس کا رہنما بنا دیتا ہے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmcmi{پھر اس کو ہم آہستہ آہستہ اپنی طرف سمیٹ لیتے ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmcmii{اور وہی تو ہے جس نے رات کو تمہارے لئے پردہ اور نیند کو آرام بنایا اور دن کو اُٹھ کھڑے ہونے کا وقت ٹھہرایا\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmcmiii{اور وہی تو ہے جو اپنی رحمت کے مینھہ کے آگے ہواؤں کو خوش خبری بنا کر بھیجتا ہے۔ اور ہم آسمان سے پاک (اور نتھرا ہوا) پانی برساتے ہیں\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmcmiv{تاکہ اس سے شہر مردہ (یعنی زمین افتادہ) کو زندہ کردیں اور پھر اسے بہت سے چوپایوں اور آدمیوں کو جو ہم نے پیدا کئے ہیں پلاتے ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmcmv{اور ہم نے اس (قرآن کی آیتوں) کو طرح طرح سے لوگوں میں بیان کیا تاکہ نصیحت پکڑیں مگر بہت سے لوگوں نے انکار کے سوا قبول نہ کیا\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmcmvi{اور اگر ہم چاہتے تو ہر بستی میں ڈرانے والا بھیج دیتے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmcmvii{تو تم کافروں کا کہا نہ مانو اور ان سے اس قرآن کے حکم کے مطابق بڑے شدومد سے لڑو\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmcmviii{اور وہی تو ہے جس نے دو دریاؤں کو ملا دیا ایک کا پانی شیریں ہے پیاس بجھانے والا اور دوسرے کا کھاری چھاتی جلانے والا۔ اور دونوں کے درمیان ایک آڑ اور مضبوط اوٹ بنادی\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmcmix{اور وہی تو ہے جس نے پانی سے آدمی پیدا کیا۔ پھر اس کو صاحب نسب اور صاحب قرابت دامادی بنایا۔ اور تمہارا پروردگار (ہر طرح کی) قدرت رکھتا ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmcmx{اور یہ لوگ خدا کو چھوڑ کر ایسی چیز کی پرستش کر تے ہیں جو نہ ان کو فائدہ پہنچا سکے اور نہ ضرر۔ اور کافر اپنے پروردگار کی مخالفت میں بڑا زور مارتا ہے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmcmxi{اور ہم نے (اے محمدﷺ) تم کو صرف خوشی اور عذاب کی خبر سنانے کو بھیجا ہے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmcmxii{کہہ دو کہ میں تم سے اس (کام) کی اجرت نہیں مانگتا، ہاں جو شخص چاہے اپنے پروردگار کی طرف جانے کا رستہ اختیار کرے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmcmxiii{اور اس (خدائے) زندہ پر بھروسہ رکھو جو (کبھی) نہیں مرے گا اور اس کی تعریف کے ساتھ تسبیح کرتے رہو۔ اور وہ اپنے بندوں کے گناہوں سے خبر رکھنے کو کافی ہے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmcmxiv{جس نے آسمانوں اور زمین کو اور جو کچھ ان دونوں کے درمیان ہے چھ دن میں پیدا کیا پھر عرش پر جا ٹھہرا وہ (جس کا نام) رحمٰن (یعنی بڑا مہربان ہے) تو اس کا حال کسی باخبر سے دریافت کرلو\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmcmxv{اور جب ان (کفار) سے کہا جاتا ہے کہ رحمٰن کو سجدہ کرو تو کہتے ہیں رحمٰن کیا؟ کیا جس کے لئے تم ہم سے کہتے ہو ہم اس کے آگے سجدہ کریں اور اس سے بدکتے ہیں\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmcmxvi{اور (خدا) بڑی برکت والا ہے جس نے آسمانوں میں برج بنائے اور ان میں (آفتاب کا نہایت روشن) چراغ اور چمکتا ہوا چاند بھی بنایا\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmcmxvii{اور وہی تو ہے جس نے رات اور دن کو ایک دوسرے کے پیچھے آنے جانے والا بنایا۔ (یہ باتیں) اس شخص کے لئے جو غور کرنا چاہے یا شکرگزاری کا ارادہ کرے (سوچنے اور سمجھنے کی ہیں)\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmcmxviii{اور خدا کے بندے تو وہ ہیں جو زمین پر آہستگی سے چلتے ہیں اور جب جاہل لوگ ان سے (جاہلانہ) گفتگو کرتے ہیں تو سلام کہتے ہیں\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmcmxix{اور جو وہ اپنے پروردگار کے آگے سجدے کرکے اور (عجز وادب سے) کھڑے رہ کر راتیں بسر کرتے ہیں\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmcmxx{اور جو دعا مانگتے رہتے ہیں کہ اے پروردگار دوزخ کے عذاب کو ہم سے دور رکھیو کہ اس کا عذاب بڑی تکلیف کی چیز ہے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmcmxxi{اور دوزخ ٹھیرنے اور رہنے کی بہت بری جگہ ہے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmcmxxii{اور وہ جب خرچ کرتے ہیں تو نہ بےجا اُڑاتے ہیں اور نہ تنگی کو کام میں لاتے ہیں بلکہ اعتدال کے ساتھ۔ نہ ضرورت سے زیادہ نہ کم\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmcmxxiii{اور وہ جو خدا کے ساتھ کسی اور معبود کو نہیں پکارتے اور جن جاندار کو مار ڈالنا خدا نے حرام کیا ہے اس کو قتل نہیں کرتے مگر جائز طریق پر (یعنی شریعت کے مطابق) اور بدکاری نہیں کرتے۔ اور جو یہ کام کرے گا سخت گناہ میں مبتلا ہوگا\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmcmxxiv{قیامت کے دن اس کو دونا عذاب ہوگا اور ذلت وخواری سے ہمیشہ اس میں رہے گا\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmcmxxv{مگر جس نے توبہ کی اور ایمان لایا اور اچھے کام کئے تو ایسے لوگوں کے گناہوں کو خدا نیکیوں سے بدل دے گا۔ اور خدا تو بخشنے والا مہربان ہے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmcmxxvi{اور جو توبہ کرتا اور عمل نیک کرتا ہے تو بےشک وہ خدا کی طرف رجوع کرتا ہے\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmcmxxvii{اور وہ جو جھوٹی گواہی نہیں دیتے اور جب ان کو بیہودہ چیزوں کے پاس سے گزرنے کا اتفاق ہو تو بزرگانہ انداز سے گزرتے ہیں\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmcmxxviii{اور وہ کہ جب ان کو پروردگار کی باتیں سمجھائی جاتی ہیں تو اُن پر اندھے اور بہرے ہو کر نہیں گرتے (بلکہ غور سے سنتے ہیں)\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmcmxxix{اور وہ جو (خدا سے) دعا مانگتے ہیں کہ اے پروردگار ہم کو ہماری بیویوں کی طرف سے (دل کا چین) اور اولاد کی طرف سے آنکھ کی ٹھنڈک عطا فرما اور ہمیں پرہیزگاروں کا امام بنا\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmcmxxx{ان (صفات کے) لوگوں کو ان کے صبر کے بدلے اونچے اونچے محل دیئے جائیں گے۔ اور وہاں فرشتے ان سے دعا وسلام کے ساتھ ملاقات کریں گے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmcmxxxi{اس میں وہ ہمیشہ رہیں گے۔ اور وہ ٹھیرنے اور رہنے کی بہت ہی عمدہ جگہ ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmcmxxxii{کہہ دو کہ اگر تم (خدا کو) نہیں پکارتے تو میرا پروردگار بھی تمہاری کچھ پروا نہیں کرتا۔ تم نے تکذیب کی ہے سو اس کی سزا (تمہارے لئے) لازم ہوگی\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiii{\basmalahur طٰسٓمٓ\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmcmxxxiv{یہ کتاب روشن کی آیتیں ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmcmxxxv{اے پیغمبرﷺ) شاید تم اس (رنج) سے کہ یہ لوگ ایمان نہیں لاتے اپنے تئیں ہلاک کردو گے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvi{اگر ہم چاہیں تو ان پر آسمان سے نشانی اُتار دیں۔ پھر ان کی گردنیں اس کے آگے جھک جائیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmcmxxxvii{اور ان کے پاس (خدائے) رحمٰن کی طرف سے کوئی نصیحت نہیں آتی مگر یہ اس سے منہ پھیر لیتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmcmxxxviii{سو یہ تو جھٹلا چکے اب ان کو اس چیز کی حقیقت معلوم ہوگی جس کی ہنسی اُڑاتے تھے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmcmxxxix{کیا انہوں نے زمین کی طرف نہیں دیکھا کہ ہم نے اس میں ہر قسم کی کتنی نفیس چیزیں اُگائی ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmcmxl{کچھ شک نہیں کہ اس میں (قدرت خدا کی) نشانی ہے مگر یہ اکثر ایمان لانے والے نہیں ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmcmxli{اور تمہارا پروردگار غالب (اور) مہربان ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmcmxlii{اور جب تمہارے پروردگار نے موسیٰ کو پکارا کہ ظالم لوگوں کے پاس جاؤ\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmcmxliii{یعنی) قوم فرعون کے پاس، کیا یہ ڈرتے نہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmcmxliv{انہوں نے کہا کہ میرے پروردگار میں ڈرتا ہوں کہ یہ مجھے جھوٹا سمجھیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmcmxlv{اور میرا دل تنگ ہوتا ہے اور میری زبان رکتی ہے تو ہارون کو حکم بھیج کہ میرے ساتھ چلیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmcmxlvi{اور ان لوگوں کا مجھ پر ایک گناہ (یعنی قبطی کے خون کا دعویٰ) بھی ہے سو مجھے یہ بھی خوف ہے کہ مجھ کو مار ہی ڈالیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmcmxlvii{فرمایا ہرگز نہیں۔ تم دونوں ہماری نشانیاں لے کر جاؤ ہم تمہارے ساتھ سننے والے ہیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmcmxlviii{تو دونوں فرعون کے پاس جاؤ اور کہو کہ ہم تمام جہان کے مالک کے بھیجے ہوئے ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmcmxlix{اور اس لئے آئے ہیں) کہ آپ بنی اسرائیل کو ہمارے ساتھ جانے کی اجازت دیں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmcml{فرعون نے موسیٰ سے کہا) کیا ہم نے تم کو کہ ابھی بچّے تھے پرورش نہیں کیا اور تم نے برسوں ہمارے ہاں عمر بسر (نہیں) کی\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmcmli{اور تم نے وہ کام کیا تھا جو کیا اور تم ناشکرے معلوم ہوتے ہو\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmcmlii{موسیٰ نے) کہاں (ہاں) وہ حرکت مجھ سے ناگہاں سرزد ہوئی تھی اور میں خطا کاروں میں تھا\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmcmliii{تو جب مجھے تم سے ڈر لگا تو تم میں سے بھاگ گیا۔ پھر خدا نے مجھ کو نبوت وعلم بخشا اور مجھے پیغمبروں میں سے کیا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmcmliv{اور (کیا) یہی احسان ہے جو آپ مجھ پر رکھتے ہیں کہ آپ نے بنی اسرائیل کو غلام بنا رکھا ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmcmlv{فرعون نے کہا کہ تمام جہان مالک کیا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmcmlvi{کہا کہ آسمانوں اور زمین اور جو کچھ ان دونوں میں ہے سب کا مالک۔ بشرطیکہ تم لوگوں کو یقین ہو\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmcmlvii{فرعون نے اپنے اہالی موالی سے کہا کہ کیا تم سنتے نہیں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmcmlviii{موسیٰ نے) کہا کہ تمہارا اور تمہارے پہلے باپ دادا کا مالک\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmcmlix{فرعون نے) کہا کہ (یہ) پیغمبر جو تمہاری طرف بھیجا گیا ہے باؤلا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmcmlx{موسیٰ نے کہا کہ مشرق اور مغرب اور جو کچھ ان دونوں میں ہے سب کا مالک، بشرطیکہ تم کو سمجھ ہو\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmcmlxi{فرعون نے) کہا کہ اگر تم نے میرے سوا کسی اور کو معبود بنایا تو میں تمہیں قید کردوں گا\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmcmlxii{موسیٰ نے) کہا خواہ میں آپ کے پاس روشن چیز لاؤں (یعنی معجزہ)\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmcmlxiii{فرعون نے کہا اگر سچے ہو تو اسے لاؤ (دکھاؤ)\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmcmlxiv{پس انہوں نے اپنی لاٹھی ڈالی تو وہ اسی وقت صریح اژدہا بن گئی\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmcmlxv{اور اپنا ہاتھ نکالا تو اسی دم دیکھنے والوں کے لئے سفید (براق نظر آنے لگا)\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmcmlxvi{فرعون نے اپنے گرد کے سرداروں سے کہا کہ یہ تو کامل فن جادوگر ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmcmlxvii{چاہتا ہے کہ تم کو اپنے جادو (کے زور) سے تمہارے ملک سے نکال دے تو تمہاری کیا رائے ہے؟\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmcmlxviii{انہوں نے کہا کہ اسے اور اس کے بھائی (کے بارے) میں کچھ توقف کیجیئے اور شہروں میں ہرکارے بھیج دیجیئے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmcmlxix{کہ سب ماہر جادوگروں کو (جمع کرکے) آپ کے پاس لے آئیں\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmcmlxx{تو جادوگر ایک مقررہ دن کی میعاد پر جمع ہوگئے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmcmlxxi{اور لوگوں سے کہہ دیا گیا کہ تم (سب) کو اکھٹے ہو کر جانا چاہیئے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmcmlxxii{تاکہ اگر جادوگر غالب رہیں تو ہم ان کے پیرو ہوجائیں\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiii{جب جادوگر آگئے تو فرعون سے کہنے لگے اگر ہم غالب رہے تو ہمیں صلہ بھی عطا ہوگا؟\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmcmlxxiv{فرعون نے کہا ہاں اور تم مقربوں میں بھی داخل کرلئے جاؤ گے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmcmlxxv{موسیٰ نے ان سے کہا کہ جو چیز ڈالنی چاہتے ہو، ڈالو\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvi{تو انہوں نے اپنی رسیاں اور لاٹھیاں ڈالیں اور کہنے لگے کہ فرعون کے اقبال کی قسم ہم ضرور غالب رہیں گے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmcmlxxvii{پھر موسیٰ نے اپنی لاٹھی ڈالی تو وہ ان چیزوں کو جو جادوگروں نے بنائی تھیں یکایک نگلنے لگی\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmcmlxxviii{تب جادوگر سجدے میں گر پڑے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmcmlxxix{اور) کہنے لگے کہ ہم تمام جہان کے مالک پر ایمان لے آئے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmcmlxxx{جو موسیٰ اور ہارون کا مالک ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxi{فرعون نے کہا کیا اس سے پہلے کہ میں تم کو اجازت دوں تم اس پر ایمان لے آئے، بےشک یہ تمہارا بڑا ہے جس نے تم کو جادو سکھایا ہے۔ سو عنقریب تم (اس کا انجام) معلوم کرلو گے کہ میں تمہارے ہاتھ اور پاؤں اطراف مخالف سے کٹوا دوں گا اور تم سب کو سولی پر چڑھوا دوں گا\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxii{انہوں نے کہا کہ کچھ نقصان (کی بات) نہیں ہم اپنے پروردگار کی طرف لوٹ جانے والے ہیں\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiii{ہمیں امید ہے کہ ہمارا پروردگار ہمارے گناہ بخش دے گا۔ اس لئے کہ ہم اول ایمان لانے والوں میں ہیں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxiv{اور ہم نے موسیٰ کی طرف وحی بھیجی کہ ہمارے بندوں کو رات کو لے نکلو کہ (فرعونیوں کی طرف سے) تمہارا تعاقب کیا جائے گا\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxv{تو فرعون نے شہروں میں نقیب راونہ کئے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvi{اور کہا) کہ یہ لوگ تھوڑی سی جماعت ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxvii{اور یہ ہمیں غصہ دلا رہے ہیں\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxviii{اور ہم سب باسازو سامان ہیں\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmcmlxxxix{تو ہم نے ان کو باغوں اور چشموں سے نکال دیا\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmcmxc{اور خزانوں اور نفیس مکانات سے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmcmxci{ان کے ساتھ ہم نے) اس طرح (کیا) اور ان چیزوں کا وارث بنی اسرائیل کو کر دیا\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmcmxcii{تو انہوں نے سورج نکلتے (یعنی صبح کو) ان کا تعاقب کیا\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmcmxciii{جب دونوں جماعتیں آمنے سامنے ہوئیں تو موسیٰ کے ساتھی کہنے لگے کہ ہم تو پکڑ لئے گئے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmcmxciv{موسیٰ نے کہا ہرگز نہیں میرا پروردگار میرے ساتھ ہے وہ مجھے رستہ بتائے گا\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmcmxcv{اس وقت ہم نے موسیٰ کی طرف وحی بھیجی کہ اپنی لاٹھی دریا پر مارو۔ تو دریا پھٹ گیا۔ اور ہر ایک ٹکڑا (یوں) ہوگیا (کہ) گویا بڑا پہاڑ (ہے)\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmcmxcvi{اور دوسروں کو وہاں ہم نے قریب کردیا\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmcmxcvii{اور موسیٰ اور ان کے ساتھ والوں کو تو بچا لیا\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmcmxcviii{پھر دوسروں کو ڈبو دیا\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmcmxcix{بےشک اس (قصے) میں نشانی ہے۔ لیکن یہ اکثر ایمان لانے والے نہیں\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmm{اور تمہارا پروردگار تو غالب (اور) مہربان ہے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmi{اور ان کو ابراہیم کا حال پڑھ کر سنا دو\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmii{جب انہوں نے اپنے باپ اور اپنی قوم کے لوگوں سے کہا کہ تم کس چیز کو پوجتے ہو\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmiii{وہ کہنے لگے کہ ہم بتوں کو پوجتے ہیں اور ان کی پوجا پر قائم ہیں\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmiv{ابراہیم نے کہا کہ جب تم ان کو پکارتے ہو تو کیا وہ تمہاری آواز کو سنتے ہیں؟\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmv{یا تمہیں کچھ فائدے دے سکتے یا نقصان پہنچا سکتے ہیں؟\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmvi{انہوں نے کہا (نہیں) بلکہ ہم نے اپنے باپ دادا کو اسی طرح کرتے دیکھا ہے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmvii{ابراہیم نے کہا کیا تم نے دیکھا کہ جن کو تم پوجتے رہے ہو\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmviii{تم بھی اور تمہارے اگلے باپ دادا بھی\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmix{وہ میرے دشمن ہیں۔ مگر خدائے رب العالمین (میرا دوست ہے)\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmx{جس نے مجھے پیدا کیا ہے اور وہی مجھے رستہ دکھاتا ہے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmxi{اور وہ جو مجھے کھلاتا اور پلاتا ہے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmxii{اور جب میں بیمار پڑتا ہوں تو مجھے شفا بخشتا ہے\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmxiii{اور جو مجھے مارے گا اور پھر زندہ کرے گا\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmxiv{اور وہ جس سے میں امید رکھتا ہوں کہ قیامت کے دن میرے گناہ بخشے گا\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmxv{اے پروردگار مجھے علم ودانش عطا فرما اور نیکوکاروں میں شامل کر\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmxvi{اور پچھلے لوگوں میں میرا ذکر نیک (جاری) کر\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmxvii{اور مجھے نعمت کی بہشت کے وارثوں میں کر\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmxviii{اور میرے باپ کو بخش دے کہ وہ گمراہوں میں سے ہے\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmxix{اور جس دن لوگ اٹھا کھڑے کئے جائیں گے مجھے رسوا نہ کیجیو\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmxx{جس دن نہ مال ہی کچھ فائدہ دے سکا گا اور نہ بیٹے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmxxi{ہاں جو شخص خدا کے پاس پاک دل لے کر آیا (وہ بچ جائے گا)\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmmxxii{اور بہشت پرہیزگاروں کے قریب کردی جائے گی\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmmxxiii{اور دوزخ گمراہوں کے سامنے لائی جائے گی\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmmxxiv{اور ان سے کہا جائے گا کہ جن کو تم پوجتے تھے وہ کہاں ہیں؟\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmmxxv{یعنی جن کو خدا کے سوا (پوجتے تھے) کیا وہ تمہاری مدد کرسکتے ہیں یا خود بدلہ لے سکتے ہیں\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmmxxvi{تو وہ اور گمراہ (یعنی بت اور بت پرست) اوندھے منہ دوزخ میں ڈال دیئے جائیں گے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmmxxvii{اور شیطان کے لشکر سب کے سب (داخل جہنم ہوں گے)\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmmxxviii{وہ آپس میں جھگڑیں گے اور کہیں گے\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmmxxix{کہ خدا کی قسم ہم تو صریح گمراہی میں تھے\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmmxxx{جب کہ تمہیں (خدائے) رب العالمین کے برابر ٹھہراتے تھے\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmmxxxi{اور ہم کو ان گنہگاروں ہی نے گمراہ کیا تھا\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmmxxxii{تو (آج) نہ کوئی ہمارا سفارش کرنے والا ہے\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmmxxxiii{اور نہ گرم جوش دوست\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmmxxxiv{کاش ہمیں (دنیا میں) پھر جانا ہو تم ہم مومنوں میں ہوجائیں\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmmxxxv{بےشک اس میں نشانی ہے اور ان میں اکثر ایمان لانے والے نہیں\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmmxxxvi{اور تمہارا پروردگار تو غالب اور مہربان ہے\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmmxxxvii{قوم نوح نے بھی پیغمبروں کو جھٹلایا\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmmxxxviii{جب ان سے ان کے بھائی نوح نے کہا کہ تم ڈرتے کیوں نہیں\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmmxxxix{میں تو تمہارا امانت دار ہوں\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmmxl{تو خدا سے ڈرو اور میرا کہا مانو\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmmxli{اور اس کام کا تم سے کچھ صلہ نہیں مانگتا۔ میرا صلہ تو خدائے رب العالمین ہی پر ہے\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmmxlii{تو خدا سے ڈرو اور میرے کہنے پر چلو\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmmxliii{وہ بولے کہ کیا ہم تم کو مان لیں اور تمہارے پیرو تو رذیل لوگ ہوتے ہیں\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmmxliv{نوح نے کہا کہ مجھے کیا معلوم کہ وہ کیا کرتے ہیں\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmmxlv{ان کا حساب (اعمال) میرے پروردگار کے ذمے ہے کاش تم سمجھو\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mmmxlvi{اور میں مومنوں کو نکال دینے والا نہیں ہوں\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mmmxlvii{میں تو صرف کھول کھول کر نصیحت کرنے والا ہوں\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mmmxlviii{انہوں نے کہا کہ نوح اگر تم باز نہ آؤ گے تو سنگسار کردیئے جاؤ گے\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mmmxlix{نوح نے کہا کہ پروردگار میری قوم نے تو مجھے جھٹلا دیا\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mmml{سو تو میرے اور ان کے درمیان ایک کھلا فیصلہ کردے اور مجھے اور جو میرے ساتھ ہیں ان کو بچا لے\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mmmli{پس ہم نے ان کو اور جو ان کے ساتھ کشتی میں سوار تھے، ان کو بچا لیا\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mmmlii{پھر اس کے بعد باقی لوگوں کو ڈبو دیا\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mmmliii{بےشک اس میں نشانی ہے اور ان میں اکثر ایمان لانے والے نہیں تھے\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mmmliv{اور تمہارا پروردگار تو غالب (اور) مہربان ہے\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mmmlv{عاد نے بھی پیغمبروں کو جھٹلایا\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mmmlvi{جب ان سے ان کے بھائی ہود نے کہا کیا تم ڈرتے نہیں\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mmmlvii{میں تو تمہارا امانت دار پیغمبر ہوں\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mmmlviii{تو خدا سے ڈرو اور میرا کہا مانو\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mmmlix{اور میں اس کا تم سے کچھ بدلہ نہیں مانگتا۔ میرا بدلہ (خدائے) رب العالمین کے ذمے ہے\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mmmlx{بھلا تم ہر اونچی جگہ پر نشان تعمیر کرتے ہو\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mmmlxi{اور محل بناتے ہو شاید تم ہمیشہ رہو گے\qt@no{129}}%
\qt@newcmd\qurantrans@ur@mmmlxii{اور جب (کسی کو) پکڑتے ہو تو ظالمانہ پکڑتے ہو\qt@no{130}}%
\qt@newcmd\qurantrans@ur@mmmlxiii{تو خدا سے ڈرو اور میری اطاعت کرو\qt@no{131}}%
\qt@newcmd\qurantrans@ur@mmmlxiv{اور اس سے جس نے تم کو ان چیزوں سے مدد دی جن کو تم جانتے ہو۔ ڈرو\qt@no{132}}%
\qt@newcmd\qurantrans@ur@mmmlxv{اس نے تمہیں چارپایوں اور بیٹوں سے مدد دی\qt@no{133}}%
\qt@newcmd\qurantrans@ur@mmmlxvi{اور باغوں اور چشموں سے\qt@no{134}}%
\qt@newcmd\qurantrans@ur@mmmlxvii{مجھ کو تمہارے بارے میں بڑے (سخت) دن کے عذاب کا خوف ہے\qt@no{135}}%
\qt@newcmd\qurantrans@ur@mmmlxviii{وہ کہنے لگے کہ ہمیں خواہ نصیحت کرو یا نہ کرو ہمارے لئے یکساں ہے\qt@no{136}}%
\qt@newcmd\qurantrans@ur@mmmlxix{یہ تو اگلوں ہی کے طریق ہیں\qt@no{137}}%
\qt@newcmd\qurantrans@ur@mmmlxx{اور ہم پر کوئی عذاب نہیں آئے گا\qt@no{138}}%
\qt@newcmd\qurantrans@ur@mmmlxxi{تو انہوں نے ہود کو جھٹلایا تو ہم نے ان کو ہلاک کر ڈالا۔ بےشک اس میں نشانی ہے۔ اور ان میں اکثر ایمان لانے والے نہیں تھے\qt@no{139}}%
\qt@newcmd\qurantrans@ur@mmmlxxii{اور تمہارا پروردگار تو غالب اور مہربان ہے\qt@no{140}}%
\qt@newcmd\qurantrans@ur@mmmlxxiii{اور) قوم ثمود نے بھی پیغمبروں کو جھٹلا دیا\qt@no{141}}%
\qt@newcmd\qurantrans@ur@mmmlxxiv{جب ان سے ان کے بھائی صالح نے کہا کہ تم ڈرتے کیوں نہیں؟\qt@no{142}}%
\qt@newcmd\qurantrans@ur@mmmlxxv{میں تو تمہارا امانت دار ہوں\qt@no{143}}%
\qt@newcmd\qurantrans@ur@mmmlxxvi{تو خدا سے ڈرو اور میرا کہا مانو\qt@no{144}}%
\qt@newcmd\qurantrans@ur@mmmlxxvii{اور میں اس کا تم سے بدلہ نہیں مانگتا۔ میرا بدلہ (خدا) رب العالمین کے ذمے ہے\qt@no{145}}%
\qt@newcmd\qurantrans@ur@mmmlxxviii{کیا وہ چیزیں (تمہیں یہاں میسر) ہیں ان میں تم بےخوف چھوڑ دیئے جاؤ گے\qt@no{146}}%
\qt@newcmd\qurantrans@ur@mmmlxxix{یعنی) باغ اور چشمے\qt@no{147}}%
\qt@newcmd\qurantrans@ur@mmmlxxx{اور کھیتیاں اور کھجوریں جن کے خوشے لطیف ونازک ہوتے ہیں\qt@no{148}}%
\qt@newcmd\qurantrans@ur@mmmlxxxi{اور تکلف سے پہاڑوں میں تراش خراش کر گھر بناتے ہو\qt@no{149}}%
\qt@newcmd\qurantrans@ur@mmmlxxxii{تو خدا سے ڈرو اور میرے کہنے پر چلو\qt@no{150}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiii{اور حد سے تجاوز کرنے والوں کی بات نہ مانو\qt@no{151}}%
\qt@newcmd\qurantrans@ur@mmmlxxxiv{جو ملک میں فساد کرتے ہیں اور اصلاح نہیں کرتے\qt@no{152}}%
\qt@newcmd\qurantrans@ur@mmmlxxxv{وہ کہنے لگے کہ تم تو جادو زدہ ہو\qt@no{153}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvi{تم اور کچھ نہیں ہماری طرح آدمی ہو۔ اگر سچے ہو تو کوئی نشانی پیش کرو\qt@no{154}}%
\qt@newcmd\qurantrans@ur@mmmlxxxvii{صالح نے کہا (دیکھو) یہ اونٹنی ہے (ایک دن) اس کی پانی پینے کی باری ہے اور ایک معین روز تمہاری باری\qt@no{155}}%
\qt@newcmd\qurantrans@ur@mmmlxxxviii{اور اس کو کوئی تکلیف نہ دینا (نہیں تو) تم کو سخت عذاب آ پکڑے گا\qt@no{156}}%
\qt@newcmd\qurantrans@ur@mmmlxxxix{تو انہوں نے اس کی کونچیں کاٹ ڈالیں پھر نادم ہوئے\qt@no{157}}%
\qt@newcmd\qurantrans@ur@mmmxc{سو ان کو عذاب نے آن پکڑا۔ بےشک اس میں نشانی ہے۔ اور ان میں اکثر ایمان لانے والے نہیں تھے\qt@no{158}}%
\qt@newcmd\qurantrans@ur@mmmxci{اور تمہارا پروردگار تو غالب (اور) مہربان ہے\qt@no{159}}%
\qt@newcmd\qurantrans@ur@mmmxcii{اور قوم) لوط نے بھی پیغمبروں کو جھٹلایا\qt@no{160}}%
\qt@newcmd\qurantrans@ur@mmmxciii{جب ان سے ان کے بھائی لوط نے کہا کہ تم کیوں نہیں ڈرتے؟\qt@no{161}}%
\qt@newcmd\qurantrans@ur@mmmxciv{میں تو تمہارا امانت دار پیغمبر ہوں\qt@no{162}}%
\qt@newcmd\qurantrans@ur@mmmxcv{تو خدا سے ڈرو اور میرا کہا مانو\qt@no{163}}%
\qt@newcmd\qurantrans@ur@mmmxcvi{اور میں تم سے اس (کام) کا بدلہ نہیں مانگتا۔ میرا بدلہ (خدائے) رب العالمین کے ذمے ہے\qt@no{164}}%
\qt@newcmd\qurantrans@ur@mmmxcvii{کیا تم اہل عالم میں سے لڑکوں پر مائل ہوتے ہو\qt@no{165}}%
\qt@newcmd\qurantrans@ur@mmmxcviii{اور تمہارے پروردگار نے جو تمہارے لئے تمہاری بیویاں پیدا کی ہیں ان کو چھوڑ دیتے ہو۔ حقیقت یہ ہے کہ تم حد سے نکل جانے والے ہو\qt@no{166}}%
\qt@newcmd\qurantrans@ur@mmmxcix{وہ کہنے لگے کہ لوط اگر تم باز نہ آؤ گے تو شہر بدر کردیئے جاؤ گے\qt@no{167}}%
\qt@newcmd\qurantrans@ur@mmmc{لوط نے کہا کہ میں تمہارے کام کا سخت دشمن ہوں\qt@no{168}}%
\qt@newcmd\qurantrans@ur@mmmci{اے میرے پروردگار مجھ کو اور میرے گھر والوں کو ان کے کاموں (کے وبال) سے نجات دے\qt@no{169}}%
\qt@newcmd\qurantrans@ur@mmmcii{سو ہم نے ان کو اور ان کے گھر والوں کو سب کو نجات دی\qt@no{170}}%
\qt@newcmd\qurantrans@ur@mmmciii{مگر ایک بڑھیا کہ پیچھے رہ گئی\qt@no{171}}%
\qt@newcmd\qurantrans@ur@mmmciv{پھر ہم نے اوروں کو ہلاک کردیا\qt@no{172}}%
\qt@newcmd\qurantrans@ur@mmmcv{اور ان پر مینھہ برسایا۔ سو جو مینھہ ان (لوگوں) پر (برسا) جو ڈرائے گئے برا تھا\qt@no{173}}%
\qt@newcmd\qurantrans@ur@mmmcvi{بےشک اس میں نشانی ہے۔ اور ان میں اکثر ایمان لانے والے نہیں تھے\qt@no{174}}%
\qt@newcmd\qurantrans@ur@mmmcvii{اور تمہارا پروردگار تو غالب (اور) مہربان ہے۔\qt@no{175}}%
\qt@newcmd\qurantrans@ur@mmmcviii{اور بن کے رہنے والوں نے بھی پیغمبروں کو جھٹلایا\qt@no{176}}%
\qt@newcmd\qurantrans@ur@mmmcix{جب ان سے شعیب نے کہا کہ تم ڈرتے کیوں نہیں؟\qt@no{177}}%
\qt@newcmd\qurantrans@ur@mmmcx{میں تو تمہارا امانت دار پیغمبر ہوں\qt@no{178}}%
\qt@newcmd\qurantrans@ur@mmmcxi{تو خدا سے ڈرو اور میرا کہا مانو\qt@no{179}}%
\qt@newcmd\qurantrans@ur@mmmcxii{اور میں اس کام کا تم سے کچھ بدلہ نہیں مانگتا میرا بدلہ تو خدائے رب العالمین کے ذمے ہے\qt@no{180}}%
\qt@newcmd\qurantrans@ur@mmmcxiii{دیکھو) پیمانہ پورا بھرا کرو اور نقصان نہ کیا کرو\qt@no{181}}%
\qt@newcmd\qurantrans@ur@mmmcxiv{اور ترازو سیدھی رکھ کر تولا کرو\qt@no{182}}%
\qt@newcmd\qurantrans@ur@mmmcxv{اور لوگوں کو ان کی چیزیں کم نہ دیا کرو اور ملک میں فساد نہ کرتے پھرو\qt@no{183}}%
\qt@newcmd\qurantrans@ur@mmmcxvi{اور اس سے ڈرو جس نے تم کو اور پہلی خلقت کو پیدا کیا\qt@no{184}}%
\qt@newcmd\qurantrans@ur@mmmcxvii{وہ کہنے لگے کہ تم جادو زدہ ہو\qt@no{185}}%
\qt@newcmd\qurantrans@ur@mmmcxviii{اور تم اور کچھ نہیں ہم ہی جیسے آدمی ہو۔ اور ہمارا خیال ہے کہ تم جھوٹے ہو\qt@no{186}}%
\qt@newcmd\qurantrans@ur@mmmcxix{اور اگر سچے ہو تو ہم پر آسمان سے ایک ٹکڑا لا کر گراؤ\qt@no{187}}%
\qt@newcmd\qurantrans@ur@mmmcxx{شعیب نے کہا کہ جو کام تم کرتے ہو میرا پروردگار اس سے خوب واقف ہے\qt@no{188}}%
\qt@newcmd\qurantrans@ur@mmmcxxi{تو ان لوگوں نے ان کو جھٹلایا، پس سائبان کے عذاب نے ان کو آ پکڑا۔ بےشک وہ بڑے (سخت) دن کا عذاب تھا\qt@no{189}}%
\qt@newcmd\qurantrans@ur@mmmcxxii{اس میں یقیناً نشانی ہے۔ اور ان میں اکثر ایمان لانے والے نہیں تھے\qt@no{190}}%
\qt@newcmd\qurantrans@ur@mmmcxxiii{اور تمہارا پروردگار تو غالب (اور) مہربان ہے\qt@no{191}}%
\qt@newcmd\qurantrans@ur@mmmcxxiv{اور یہ قرآن (خدائے) پروردگار عالم کا اُتارا ہوا ہے\qt@no{192}}%
\qt@newcmd\qurantrans@ur@mmmcxxv{اس کو امانت دار فرشتہ لے کر اُترا ہے\qt@no{193}}%
\qt@newcmd\qurantrans@ur@mmmcxxvi{یعنی اس نے) تمہارے دل پر (القا) کیا ہے تاکہ (لوگوں کو) نصیحت کرتے رہو\qt@no{194}}%
\qt@newcmd\qurantrans@ur@mmmcxxvii{اور (القا بھی) فصیح عربی زبان میں (کیا ہے)\qt@no{195}}%
\qt@newcmd\qurantrans@ur@mmmcxxviii{اور اس کی خبر پہلے پیغمبروں کی کتابوں میں (لکھی ہوئی) ہے\qt@no{196}}%
\qt@newcmd\qurantrans@ur@mmmcxxix{کیا ان کے لئے یہ سند نہیں ہے کہ علمائے بنی اسرائیل اس (بات) کو جانتے ہیں\qt@no{197}}%
\qt@newcmd\qurantrans@ur@mmmcxxx{اور اگر ہم اس کو کسی غیر اہل زبان پر اُتارتے\qt@no{198}}%
\qt@newcmd\qurantrans@ur@mmmcxxxi{اور وہ اسے ان (لوگوں کو) پڑھ کر سناتا تو یہ اسے (کبھی) نہ مانتے\qt@no{199}}%
\qt@newcmd\qurantrans@ur@mmmcxxxii{اسی طرح ہم نے انکار کو گنہگاروں کے دلوں میں داخل کردیا\qt@no{200}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiii{وہ جب تک درد دینے والا عذاب نہ دیکھ لیں گے، اس کو نہیں مانیں گے\qt@no{201}}%
\qt@newcmd\qurantrans@ur@mmmcxxxiv{وہ ان پر ناگہاں آ واقع ہوگا اور انہیں خبر بھی نہ ہوگی\qt@no{202}}%
\qt@newcmd\qurantrans@ur@mmmcxxxv{اس وقت کہیں گے کیا ہمیں ملہت ملے گی؟\qt@no{203}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvi{تو کیا یہ ہمارے عذاب کو جلدی طلب کر رہے ہیں\qt@no{204}}%
\qt@newcmd\qurantrans@ur@mmmcxxxvii{بھلا دیکھو تو اگر ہم ان کو برسوں فائدے دیتے رہے\qt@no{205}}%
\qt@newcmd\qurantrans@ur@mmmcxxxviii{پھر ان پر وہ (عذاب) آ واقع ہو جس کا تم سے وعدہ کیا جاتا ہے\qt@no{206}}%
\qt@newcmd\qurantrans@ur@mmmcxxxix{تو جو فائدے یہ اٹھاتے رہے ان کے کس کام آئیں گے\qt@no{207}}%
\qt@newcmd\qurantrans@ur@mmmcxl{اور ہم نے کوئی بستی ہلاک نہیں کی مگر اس کے لئے نصیحت کرنے والے (پہلے بھیج دیتے) تھے\qt@no{208}}%
\qt@newcmd\qurantrans@ur@mmmcxli{نصیحت کردیں اور ہم ظالم نہیں ہیں\qt@no{209}}%
\qt@newcmd\qurantrans@ur@mmmcxlii{اور اس (قرآن) کو شیطان لے کر نازل نہیں ہوئے\qt@no{210}}%
\qt@newcmd\qurantrans@ur@mmmcxliii{یہ کام نہ تو ان کو سزاوار ہے اور نہ وہ اس کی طاقت رکھتے ہیں\qt@no{211}}%
\qt@newcmd\qurantrans@ur@mmmcxliv{وہ (آسمانی باتوں) کے سننے (کے مقامات) سے الگ کر دیئے گئے ہیں\qt@no{212}}%
\qt@newcmd\qurantrans@ur@mmmcxlv{تو خدا کے سوا کسی اور معبود کو مت پکارنا، ورنہ تم کو عذاب دیا جائے گا\qt@no{213}}%
\qt@newcmd\qurantrans@ur@mmmcxlvi{اور اپنے قریب کے رشتہ داروں کو ڈر سنا دو\qt@no{214}}%
\qt@newcmd\qurantrans@ur@mmmcxlvii{اور جو مومن تمہارے پیرو ہوگئے ہیں ان سے متواضع پیش آؤ\qt@no{215}}%
\qt@newcmd\qurantrans@ur@mmmcxlviii{پھر اگر لوگ تمہاری نافرمانی کریں تو کہہ دو کہ میں تمہارے اعمال سے بےتعلق ہوں\qt@no{216}}%
\qt@newcmd\qurantrans@ur@mmmcxlix{اور (خدائے) غالب اور مہربان پر بھروسا رکھو\qt@no{217}}%
\qt@newcmd\qurantrans@ur@mmmcl{جو تم کو جب تم (تہجد) کے وقت اُٹھتے ہو دیکھتا ہے\qt@no{218}}%
\qt@newcmd\qurantrans@ur@mmmcli{اور نمازیوں میں تمہارے پھرنے کو بھی\qt@no{219}}%
\qt@newcmd\qurantrans@ur@mmmclii{بےشک وہ سننے اور جاننے والا ہے\qt@no{220}}%
\qt@newcmd\qurantrans@ur@mmmcliii{اچھا) میں تمیں بتاؤں کہ شیطان کس پر اُترتے ہیں\qt@no{221}}%
\qt@newcmd\qurantrans@ur@mmmcliv{ہر جھوٹے گنہگار پر اُترتے ہیں\qt@no{222}}%
\qt@newcmd\qurantrans@ur@mmmclv{جو سنی ہوئی بات (اس کے کام میں) لا ڈالتے ہیں اور وہ اکثر جھوٹے ہیں\qt@no{223}}%
\qt@newcmd\qurantrans@ur@mmmclvi{اور شاعروں کی پیروی گمراہ لوگ کیا کرتے ہیں\qt@no{224}}%
\qt@newcmd\qurantrans@ur@mmmclvii{کیا تم نے نہیں دیکھا کہ وہ ہر وادی میں سر مارتے پھرتے ہیں\qt@no{225}}%
\qt@newcmd\qurantrans@ur@mmmclviii{اور کہتے وہ ہیں جو کرتے نہیں\qt@no{226}}%
\qt@newcmd\qurantrans@ur@mmmclix{مگر جو لوگ ایمان لائے اور نیک کام کئے اور خدا کو بہت یاد کرتے رہے اور اپنے اوپر ظلم ہونے کے بعد انتقام لیا اور ظالم عنقریب جان لیں گے کہ کون سی جگہ لوٹ کر جاتے ہیں\qt@no{227}}%
\qt@newcmd\qurantrans@ur@mmmclx{\basmalahur ٰطٰسٓ۔ یہ قرآن اور روشن کتاب کی آیتیں ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmclxi{مومنوں کے لئے ہدایت اور بشارت\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmclxii{وہ جو نماز پڑھتے اور زکوٰة دیتے اور آخرت کا یقین رکھتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmclxiii{جو لوگ آخرت پر ایمان نہیں رکھتے ہیں ہم نے ان کے اعمال ان کے لئے آرستہ کردیئے ہیں تو وہ سرگرداں ہو رہے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmclxiv{یہی لوگ ہیں جن کے لئے بڑا عذاب ہے اور وہ آخرت میں بھی وہ بہت نقصان اٹھانے والے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmclxv{اور تم کو قرآن (خدائے) حکیم وعلیم کی طرف سے عطا کیا جاتا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmclxvi{جب موسیٰ نے اپنے گھر والوں سے کہا کہ میں نے آگ دیکھی ہے، میں وہاں سے (رستے) کا پتہ لاتا ہوں یا سلگتا ہوا انگارہ تمہارے پاس لاتا ہوں تاکہ تم تاپو\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmclxvii{جب موسیٰ اس کے پاس آئے تو ندا آئی کہ وہ جو آگ میں (تجلّی دکھاتا) ہے بابرکت ہے۔ اور جو آگ کے اردگرد ہیں اور خدا جو تمام عالم کا پروردگار ہے پاک ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmclxviii{اے موسیٰ میں ہی خدائے غالب ودانا ہوں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmclxix{اور اپنی لاٹھی ڈال دو۔ جب اُسے دیکھا تو (اس طرح) ہل رہی تھی گویا سانپ ہے تو پیٹھ پھیر کر بھاگے اور پیچھے مڑ کر نہ دیکھا (حکم ہوا کہ) موسیٰ ڈرو مت۔ ہمارے پاس پیغمبر ڈرا نہیں کرتے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmclxx{ہاں جس نے ظلم کیا پھر برائی کے بعد اسے نیکی سے بدل دیا تو میں بخشنے والا مہربان ہوں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmclxxi{اور اپنا ہاتھ اپنے گریبان میں ڈالو سفید نکلے گا۔ (ان دو معجزوں کے ساتھ جو) نو معجزوں میں (داخل ہیں) فرعون اور اس کی قوم کے پاس جاؤ کہ وہ بےحکم لوگ ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmclxxii{جب ان کے پاس ہماری روشن نشانیاں پہنچیں، کہنے لگے یہ صریح جادو ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmclxxiii{اور بےانصافی اور غرور سے ان سے انکار کیا لیکن ان کے دل ان کو مان چکے تھے۔ سو دیکھ لو فساد کرنے والوں کا انجام کیسا ہوا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmclxxiv{اور ہم نے داؤد اور سلیمان کو علم بخشا اور انہوں نے کہا کہ خدا کا شکر ہے جس نے ہمیں بہت سے مومن بندوں پر فضلیت دی\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmclxxv{اور سلیمان اور داؤد کے قائم مقام ہوئے۔ اور کہنے لگے کہ لوگو! ہمیں (خدا کی طرف سے) جانوروں کی بولی سکھائی گئی ہے اور ہر چیز عنایت فرمائی گئی ہے۔ بےشک یہ (اُس کا) صریح فضل ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmclxxvi{اور سلیمان کے لئے جنوں اور انسانوں اور پرندوں کے لشکر جمع کئے گئے اور قسم وار کئے جاتے تھے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmclxxvii{یہاں تک کہ جب چیونٹیوں کے میدان میں پہنچے تو ایک چیونٹی نے کہا کہ چیونٹیوں اپنے اپنے بلوں میں داخل ہو جاؤ ایسا نہ ہو کہ سلیمان اور اس کے لشکر تم کو کچل ڈالیں اور ان کو خبر بھی نہ ہو\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmclxxviii{تو وہ اس کی بات سن کر ہنس پڑے اور کہنے لگے کہ اے پروردگار! مجھے توفیق عطا فرما کہ جو احسان تونے مجھ پر اور میرے ماں باپ پر کئے ہیں ان کا شکر کروں اور ایسے نیک کام کروں کہ تو ان سے خوش ہوجائے اور مجھے اپنی رحمت سے اپنے نیک بندوں میں داخل فرما\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmclxxix{انہوں نے جانوروں کا جائزہ لیا تو کہنے لگے کیا سبب ہے کہ ہُدہُد نظر نہیں آتا۔ کیا کہیں غائب ہوگیا ہے؟\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmclxxx{میں اسے سخت سزا دوں گا یا ذبح کر ڈالوں گا یا میرے سامنے (اپنی بےقصوری کی) دلیل صریح پیش کرے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmclxxxi{ابھی تھوڑی ہی دیر ہوئی تھی کہ ہُدہُد آ موجود ہوا اور کہنے لگا کہ مجھے ایک ایسی چیز معلوم ہوئی ہے جس کی آپ کو خبر نہیں اور میں آپ کے پاس (شہر) سبا سے ایک سچی خبر لے کر آیا ہوں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmclxxxii{میں نے ایک عورت دیکھی کہ ان لوگوں پر بادشاہت کرتی ہے اور ہر چیز اسے میسر ہے اور اس کا ایک بڑا تخت ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiii{میں نے دیکھا کہ وہ اور اس کی قوم خدا کو چھوڑ کر آفتاب کو سجدہ کرتے ہیں اور شیطان نے ان کے اعمال انہیں آراستہ کر دکھائے ہیں اور ان کو رستے سے روک رکھا ہے پس وہ رستے پر نہیں آئے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmclxxxiv{اور نہیں سمجھتے) کہ خدا کو آسمانوں اور زمین میں چھپی چیزوں کو ظاہر کردیتا اور تمہارے پوشیدہ اور ظاہر اعمال کو جانتا ہے کیوں سجدہ نہ کریں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmclxxxv{خدا کے سوا کوئی عبادت کے لائق نہیں وہی عرش عظیم کا مالک ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvi{سلیمان نے کہا (اچھا) ہم دیکھیں گے، تونے سچ کہا ہے یا تو جھوٹا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmclxxxvii{یہ میرا خط لے جا اور اسے ان کی طرف ڈال دے پھر ان کے پاس سے پھر آ اور دیکھ کہ وہ کیا جواب دیتے ہیں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmclxxxviii{ملکہ نے کہا کہ دربار والو! میری طرف ایک نامہ گرامی ڈالا گیا ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmclxxxix{وہ سلیمان کی طرف سے ہے اور مضمون یہ ہے کہ شروع خدا کا نام لے کر جو بڑا مہربان نہایت رحم والا ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmcxc{بعد اس کے یہ) کہ مجھے سرکشی نہ کرو اور مطیع ومنقاد ہو کر میرے پاس چلے آؤ\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmcxci{خط سنا کر) وہ کہنے لگی کہ اے اہل دربار میرے اس معاملے میں مجھے مشورہ دو، جب تک تم حاضر نہ ہو (اور صلاح نہ دو) میں کسی کام کو فیصل کرنے والی نہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmcxcii{وہ بولے کہ ہم بڑے زورآور اور سخت جنگجو ہیں اور حکم آپ کے اختیار ہے تو جو حکم دیجیئے گا (اس کے مآل پر) نظر کرلیجیئے گا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmcxciii{اس نے کہا کہ بادشاہ جب کسی شہر میں داخل ہوتے ہیں تو اس کو تباہ کر دیتے ہیں اور وہاں کے عزت والوں کو ذلیل کر دیا کرتے ہیں اور اسی طرح یہ بھی کریں گے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmcxciv{اور میں ان کی طرف کچھ تحفہ بھیجتی ہوں اور دیکھتی ہوں کہ قاصد کیا جواب لاتے ہیں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmcxcv{جب (قاصد) سلیمان کے پاس پہنچا تو سلیمان نے کہا کیا تم مجھے مال سے مدد دینا چاہتے ہو، جو کچھ خدا نے مجھے عطا فرمایا ہے وہ اس سے بہتر ہے جو تمہیں دیا ہے حقیقت یہ ہے کہ تم ہی اپنے تحفے سے خوش ہوتے ہوگے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmcxcvi{ان کے پاس واپس جاؤ ہم ان پر ایسے لشکر سے حملہ کریں گے جس کے مقابلے کی ان میں طاقت نہ ہوگی اور ان کو وہاں سے بےعزت کرکے نکال دیں گے اور وہ ذلیل ہوں گے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmcxcvii{سلیمان نے کہا کہ اے دربار والو! کوئی تم میں ایسا ہے کہ قبل اس کے کہ وہ لوگ فرمانبردار ہو کر ہمارے پاس آئیں ملکہ کا تخت میرے پاس لے آئے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmcxcviii{جنات میں سے ایک قوی ہیکل جن نے کہا کہ قبل اس کے کہ آپ اپنی جگہ سے اٹھیں میں اس کو آپ کے پاس لاحاضر کرتا ہوں اور میں اس (کے اٹھانے کی) طاقت رکھتا ہوں (اور) امانت دار ہوں\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmcxcix{ایک شخص جس کو کتاب الہیٰ کا علم تھا کہنے لگا کہ میں آپ کی آنکھ کے جھپکنے سے پہلے پہلے اسے آپ کے پاس حاضر کئے دیتا ہوں۔ جب سلیمان نے تخت کو اپنے پاس رکھا ہوا دیکھا تو کہا کہ یہ میرے پروردگار کا فضل ہے تاکہ مجھے آزمائے کہ میں شکر کرتا ہوں یا کفران نعمت کرتا ہوں اور جو شکر کرتا ہے تو اپنے ہی فائدے کے لئے شکر کرتا ہے اور جو ناشکری کرتا ہے تو میرا پروردگار بےپروا (اور) کرم کرنے والا ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmcc{سلیمان نے کہا کہ ملکہ کے (امتحان عقل کے) لئے اس کے تخت کی صورت بدل دو۔ دیکھیں کہ وہ سوجھ رکھتی ہے یا ان لوگوں میں ہے جو سوجھ نہیں رکھتے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmcci{جب وہ آ پہنچی تو پوچھا گیا کہ کیا آپ کا تخت بھی اسی طرح کا ہے؟ اس نے کہا کہ یہ تو گویا ہو بہو وہی ہے اور ہم کو اس سے پہلے ہی (سلیمان کی عظمت شان) کا علم ہوگیا تھا اور ہم فرمانبردار ہیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmccii{اور وہ جو خدا کے سوا (اور کی) پرستش کرتی تھی، سلیمان نے اس کو اس سے منع کیا (اس سے پہلے تو) وہ کافروں میں سے تھی\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmcciii{پھر) اس سے کہا گیا کہ محل میں چلیے، جب اس نے اس (کے فرش) کو دیکھا تو اسے پانی کا حوض سمجھا اور (کپڑا اٹھا کر) اپنی پنڈلیاں کھول دیں۔ سلیمان نے کہا یہ ایسا محل ہے جس میں (نیچے بھی) شیشے جڑے ہوئے ہیں۔ وہ بول اٹھی کہ پروردگار میں اپنے آپ پر ظلم کرتی رہی تھی اور (اب) میں سلیمان کے ہاتھ پر خدائے رب العالمین پر ایمان لاتی ہوں\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmcciv{اور ہم نے ثمود کی طرف اس کے بھائی صالح کو بھیجا کہ خدا کی عبادت کرو تو وہ دو فریق ہو کر آپس میں جھگڑنے لگے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmccv{صالح نے کہا کہ بھائیو تم بھلائی سے پہلے برائی کے لئے کیوں جلدی کرتے ہو (اور) خدا سے بخشش کیوں نہیں مانگتے تاکہ تم پر رحم کیا جائے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmccvi{وہ کہنے لگے کہ تم اور تمہارے ساتھی ہمارے لئے شگون بد ہے۔ صالح نے کہا کہ تمہاری بدشگونی خدا کی طرف سے ہے بلکہ تم ایسے لوگ ہو جن کی آزمائش کی جاتی ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmccvii{اور شہر میں نو شخص تھے جو ملک میں فساد کیا کرتے تھے اور اصلاح سے کام نہیں لیتے تھے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmccviii{کہنے لگے کہ خدا کی قسم کھاؤ کہ ہم رات کو اس پر اور اس کے گھر والوں پر شب خون ماریں گے پھر اس کے وارث سے کہہ دیں گے کہ ہم تو صالح کے گھر والوں کے موقع ہلاکت پر گئے ہی نہیں اور ہم سچ کہتے ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmccix{اور وہ ایک چال چلے اور ان کو کچھ خبر نہ ہوئی\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmccx{تو دیکھ لو ان کی چال کا کیسا انجام ہوا۔ ہم نے ان کو اور ان کی قوم سب کو ہلاک کر ڈالا\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmccxi{اب یہ ان کے گھر ان کے ظلم کے سبب خالی پڑے ہیں۔ جو لوگ دانش رکھتے ہیں، ان کے لئے اس میں نشانی ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmccxii{اور جو لوگ ایمان لائے اور ڈرتے تھے ان کو ہم نے نجات دی\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmccxiii{اور لوط کو (یاد کرو) جب انہوں نے اپنی قوم سے کہا کہ تم بےحیائی (کے کام) کیوں کرتے ہو اور تم دیکھتے ہو\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmccxiv{کیا تم عورتوں کو چھوڑ کر (لذت حاصل کرنے) کے لئے مردوں کی طرف مائل ہوتے ہو۔ حقیقت یہ ہے کہ تم احمق لوگ ہو\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmccxv{تو ان کی قوم کے لوگ (بولے تو) یہ بولے اور اس کے سوا ان کا کچھ جواب نہ تھا کہ لوط کے گھر والوں کو اپنے شہر سے نکال دو۔ یہ لوگ پاک رہنا چاہتے ہیں\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmccxvi{تو ہم نے ان کو اور ان کے گھر والوں کو نجات دی۔ مگر ان کی بیوی کہ اس کی نسبت ہم نے مقرر کر رکھا ہے (کہ وہ پیچھے رہنے والوں میں ہوگی)\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmccxvii{اور ہم نے ان پر مینھہ برسایا سو (جو) مینھہ ان لوگوں پر برسا جن کو متنبہ کردیا گیا تھا، برا تھا\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmccxviii{کہہ دو کہ سب تعریف خدا ہی کو سزاوار ہے اور اس کے بندوں پر سلام ہے جن کو اس نے منتخب فرمایا۔ بھلا خدا بہتر ہے یا وہ جن کو یہ (اس کا شریک) ٹھہراتے ہیں\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmccxix{بھلا کس نے آسمانوں اور زمین کو پیدا کیا اور (کس نے) تمہارے لئے آسمان سے پانی برسایا۔ (ہم نے) پھر ہم ہی نے اس سے سرسبز باغ اُگائے۔ تمہارا کام تو نہ تھا کہ تم اُن کے درختوں کو اگاتے۔ تو کیا خدا کے ساتھ کوئی اور بھی معبود ہے؟ (ہرگز نہیں) بلکہ یہ لوگ رستے سے الگ ہو رہے ہیں\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmccxx{بھلا کس نے زمین کو قرار گاہ بنایا اور اس کے بیچ نہریں بنائیں اور اس کے لئے پہاڑ بنائے اور (کس نے) دو دریاؤں کے بیچ اوٹ بنائی (یہ سب کچھ خدا نے بنایا) تو کیا خدا کے ساتھ کوئی اور معبود بھی ہے؟ (ہرگز نہیں) بلکہ ان میں اکثر دانش نہیں رکھتے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmccxxi{بھلا کون بیقرار کی التجا قبول کرتا ہے۔ جب وہ اس سے دعا کرتا ہے اور (کون اس کی) تکلیف کو دور کرتا ہے اور (کون) تم کو زمین میں (اگلوں کا) جانشین بناتا ہے (یہ سب کچھ خدا کرتا ہے) تو کیا خدا کے ساتھ کوئی اور معبود بھی ہے (ہرگز نہیں مگر) تم بہت کم غور کرتے ہو\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmccxxii{بھلا کون تم کو جنگل اور دریا کے اندھیروں میں رستہ بناتا ہے اور (کون) ہواؤں کو اپنی رحمت کے آگے خوشخبری بناکر بھیجتا ہے (یہ سب کچھ خدا کرتا ہے) تو کیا خدا کے ساتھ کوئی اور معبود بھی ہے؟ (ہرگز نہیں) ۔ یہ لوگ جو شرک کرتے ہیں خدا (کی شان) اس سے بلند ہے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmccxxiii{بھلا کون خلقت کو پہلی بار پیدا کرتا۔ پھر اس کو بار بار پیدا کرتا رہتا ہے اور (کون) تم کو آسمان اور زمین سے رزق دیتا ہے (یہ سب کچھ خدا کرتا ہے) تو کیا خدا کے ساتھ کوئی اور معبود بھی ہے (ہرگز نہیں) کہہ دو کہ (مشرکو) اگر تم سچے ہو تو دلیل پیش کرو\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmccxxiv{کہہ دو کہ جو لوگ آسمانوں اور زمین میں ہیں خدا کے سوا غیب کی باتیں نہیں جانتے۔ اور نہ یہ جانتے ہیں کہ کب (زندہ کرکے) اٹھائے جائیں گے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmccxxv{بلکہ آخرت (کے بارے) میں ان کا علم منتہی ہوچکا ہے بلکہ وہ اس سے شک میں ہیں۔ بلکہ اس سے اندھے ہو رہے ہیں\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmccxxvi{اور جو لوگ کافر ہیں کہتے ہیں جب ہم اور ہمارے باپ دادا مٹی ہو جائیں گے تو کیا ہم پھر (قبروں سے) نکالے جائیں گے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmccxxvii{یہ وعدہ ہم سے اور ہمارے باپ دادا سے پہلے سے ہوتا چلا آیا ہے (کہاں کا اُٹھنا اور کیسی قیامت) یہ تو صرف پہلے لوگوں کی کہانیاں ہیں\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmccxxviii{کہہ دو کہ ملک میں چلو پھرو پھر دیکھو کہ گنہگاروں کا انجام کیا ہوا ہے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmccxxix{اور ان (کے حال) پر غم نہ کرنا اور نہ اُن چالوں سے جو یہ کر رہے ہیں تنگ دل ہونا\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmccxxx{اور کہتے ہیں کہ اگر تم سچے ہو تو یہ وعدہ کب پورا ہوگا؟\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmccxxxi{کہہ دو کہ جس (عذاب) کے لئے تم جلدی کر رہے ہو شاید اس میں سے کچھ تمہارے نزدیک آپہنچا ہو\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmccxxxii{اور تمہارا پروردگار تو لوگوں پر فضل کرنے والا ہے لیکن ان میں سے اکثر شکر نہیں کرتے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiii{اور جو باتیں ان کے سینوں میں پوشیدہ ہوتی ہیں اور جو کام وہ ظاہر کرتے ہیں تمہارا پروردگار ان (سب) کو جانتا ہے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmccxxxiv{اور آسمانوں اور زمین میں کوئی پوشیدہ چیز نہیں ہے مگر (وہ) کتاب روشن میں (لکھی ہوئی) ہے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmccxxxv{بےشک یہ قرآن بنی اسرائیل کے سامنے اکثر باتیں جن میں وہ اختلاف کرتے ہیں، بیان کر دیتا ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvi{اور بےشک یہ مومنوں کے لئے ہدایات اور رحمت ہے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmccxxxvii{تمہارا پروردگار (قیامت کے روز) اُن میں اپنے حکم سے فیصلہ کر دے گا اور وہ غالب (اور) علم والا ہے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmccxxxviii{تو خدا پر بھروسہ رکھو تم تو حق صریح پر ہو\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmccxxxix{کچھ شک نہیں کہ تم مردوں کو (بات) نہیں سنا سکتے اور نہ بہروں کو جب کہ وہ پیٹھ پھیر کر پھر جائیں آواز سنا سکتے ہو\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmccxl{اور نہ اندھوں کو گمراہی سے (نکال کر) رستہ دیکھا سکتے ہو۔ تم ان ہی کو سنا سکتے ہو جو ہماری آیتوں پر ایمان لاتے ہیں اور وہ فرمانبردار ہو جاتے ہیں\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmccxli{اور جب اُن کے بارے میں (عذاب) کا وعدہ پورا ہوگا تو ہم اُن کے لئے زمین میں سے ایک جانور نکالیں گے جو ان سے بیان کر دے گا۔ اس لئے کہ لوگ ہماری آیتوں پر ایمان نہیں لاتے تھے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmccxlii{اور جس روز ہم ہر اُمت میں سے اس گروہ کو جمع کریں گے جو ہماری آیتوں کی تکذیب کرتے تھے تو اُن کی جماعت بندی کی جائے گی\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmccxliii{یہاں تک کہ جب (سب) آجائیں گے تو (خدا) فرمائے گا کہ کیا تم نے میری آیتوں کو جھٹلا دیا تھا اور تم نے (اپنے) علم سے ان پر احاطہ تو کیا ہی نہ تھا۔ بھلا تم کیا کرتے تھے\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmccxliv{اور اُن کے ظلم کے سبب اُن کے حق میں وعدہ (عذاب) پورا ہوکر رہے گا تو وہ بول بھی نہ سکیں گے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmccxlv{کیا اُنہوں نے نہیں دیکھا کہ ہم نے رات کو (اس لئے) بنایا ہے کہ اس میں آرام کریں اور دن کو روشن (بنایا ہے کہ اس میں کام کریں) بےشک اس میں مومن لوگوں کے لئے نشانیاں ہیں\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmccxlvi{اور جس روز صور پھونکا جائے گا تو جو لوگ آسمانوں اور زمین میں ہیں سب گھبرا اُٹھیں گے مگر وہ جسے خدا چاہے اور سب اس کے پاس عاجز ہو کر چلے آئیں گے\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmccxlvii{اور تم پہاڑوں کو دیکھتے ہو تو خیال کرتے ہو کہ (اپنی جگہ پر) کھڑے ہیں مگر وہ (اس روز) اس طرح اُڑے پھریں گے جیسے بادل۔ (یہ) خدا کی کاریگری ہے جس نے ہر چیز کو مضبوط بنایا۔ بےشک وہ تمہارے سب افعال سے باخبر ہے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmccxlviii{جو شخص نیکی لےکر آئے گا تو اس کے لئے اس سے بہتر (بدلہ تیار) ہے اور ایسے لوگ (اُس روز) گھبراہٹ سے بےخوف ہوں گے\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmmccxlix{اور جو برائی لے کر آئے گا تو ایسے لوگ اوندھے منہ دوزخ میں ڈال دیئے جائیں گے۔ تم کو تو اُن ہی اعمال کا بدلہ ملے گا جو تم کرتے رہے ہو\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmmccl{کہہ دو) کہ مجھ کو یہی ارشاد ہوا ہے کہ اس شہر (مکہ) کے مالک کی عبادت کروں جس نے اس کو محترم (اور مقام ادب) بنایا ہے اور سب چیز اُسی کی ہے اور یہ بھی حکم ہوا ہے کہ اس کا حکم بردار رہوں\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmmccli{اور یہ بھی کہ قرآن پڑھا کروں۔ تو جو شخص راہ راست اختیار کرتا ہے تو اپنے ہی فائدے کے لئے اختیار کرتا ہے۔ اور جو گمراہ رہتا ہے تو کہہ دو کہ میں تو صرف نصیحت کرنے والا ہوں\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmmcclii{اور کہو کہ خدا کا شکر ہے۔ وہ تم کو عنقریب اپنی نشانیاں دکھائے گا تو تم اُن کو پہچان لو گے۔ اور جو کام تم کرتے ہو تمہارا پروردگار اُن سے بےخبر نہیں ہے\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmmccliii{\basmalahur طٰسٓمٓ\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmccliv{یہ کتاب روشن کی آیتیں ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmcclv{اے محمدﷺ) ہم تمہیں موسٰی اور فرعون کے کچھ حالات مومن لوگوں کو سنانے کے لئے صحیح صحیح سناتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmcclvi{کہ فرعون نے ملک میں سر اُٹھا رکھا تھا اور وہاں کے باشندوں کو گروہ گروہ بنا رکھا تھا اُن میں سے ایک گروہ کو (یہاں تک) کمزور کر دیا تھا کہ اُن کے بیٹوں کو ذبح کر ڈالتا اور اُن کی لڑکیوں کو زندہ رہنے دیتا۔ بیشک وہ مفسدوں میں تھا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmcclvii{اور ہم چاہتے تھے کہ جو لوگ ملک میں کمزور کر دیئے گئے ہیں اُن پر احسان کریں اور اُن کو پیشوا بنائیں اور انہیں (ملک کا) وارث کریں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmcclviii{اور ملک میں ان کو قدرت دیں اور فرعون اور ہامان اور اُن کے لشکر کو وہ چیزیں دکھا دیں جس سے وہ ڈرتے تھے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmcclix{اور ہم نے موسٰی کی ماں کی طرف وحی بھیجی کہ اس کو دودھ پلاؤ جب تم کو اس کے بارے میں کچھ خوف پیدا ہو تو اسے دریا میں ڈال دینا اور نہ تو خوف کرنا اور نہ رنج کرنا۔ ہم اس کو تمہارے پاس واپس پہنچا دیں گے اور (پھر) اُسے پیغمبر بنا دیں گے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmcclx{تو فرعون کے لوگوں نے اس کو اُٹھا لیا اس لئے کہ (نتیجہ یہ ہونا تھا کہ) وہ اُن کا دشمن اور (ان کے لئے موجب) غم ہو۔ بیشک فرعون اور ہامان اور اُن کے لشکر چوک گئے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmcclxi{اور فرعون کی بیوی نے کہا کہ (یہ) میری اور تمہاری (دونوں کی) آنکھوں کی ٹھنڈک ہے اس کو قتل نہ کرنا۔ شاید یہ ہمیں فائدہ پہنچائے یا ہم اُسے بیٹا بنالیں اور وہ انجام سے بےخبر تھے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmcclxii{اور موسٰی کی ماں کا دل بے صبر ہو گیا اگر ہم اُن کے دل مضبوط نہ کر دیتے تو قریب تھا کہ وہ اس (قصّے) کو ظاہر کر دیں۔ غرض یہ تھی کہ وہ مومنوں میں رہیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmcclxiii{اور اس کی بہن سے کہا کہ اس کے پیچھے پیچھے چلی جا تو وہ اُسے دور سے دیکھتی رہی اور ان (لوگوں) کو کچھ خبر نہ تھی\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmcclxiv{اور ہم نے پہلے ہی سے اس پر (دائیوں) کے دودھ حرام کر دیئے تھے۔ تو موسٰی کی بہن نے کہا کہ میں تمہیں ایسے گھر والے بتاؤں کہ تمہارے لئے اس (بچے) کو پالیں اور اس کی خیر خواہی (سے پرورش) کریں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmcclxv{تو ہم نے (اس طریق سے) اُن کو ان کی ماں کے پاس واپس پہنچا دیا تاکہ اُن کی آنکھیں ٹھنڈی ہوں اور وہ غم نہ کھائیں اور معلوم کریں کہ خدا کا وعدہ سچا ہے لیکن یہ اکثر نہیں جانتے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmcclxvi{اور جب موسٰی جوانی کو پہنچے اور بھرپور (جوان) ہو گئے تو ہم نے اُن کو حکمت اور علم عنایت کیا۔ اور ہم نیکو کاروں کو ایسا ہی بدلہ دیا کرتے ہیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmcclxvii{اور وہ ایسے وقت شہر میں داخل ہوئے کہ وہاں کے باشندے بےخبر ہو رہے تھے تو دیکھا کہ وہاں دو شخص لڑ رہے تھے ایک تو موسٰی کی قوم کا ہے اور دوسرا اُن کے دشمنوں میں سے تو جو شخص اُن کی قوم میں سے تھا اس نے دوسرے شخص کے مقابلے میں جو موسٰی کے دشمنوں میں سے تھا مدد طلب کی تو اُنہوں نے اس کو مکا مارا اور اس کا کام تمام کر دیا کہنے لگے کہ یہ کام تو (اغوائے) شیطان سے ہوا بیشک وہ (انسان کا) دشمن اور صریح بہکانے والا ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmcclxviii{بولے کہ اے پروردگار میں نے اپنے آپ پر ظلم کیا تو مجھے بخش دے تو خدا نے اُن کو بخش دیا۔ بیشک وہ بخشنے والا مہربان ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmcclxix{کہنے لگے کہ اے پروردگار تو نے جو مجھ پر مہربانی فرمائی ہے میں (آئندہ) کبھی گنہگاروں کا مددگار نہ بنوں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmcclxx{الغرض صبح کے وقت شہر میں ڈرتے ڈرتے داخل ہوئے کہ دیکھیں (کیا ہوتا ہے) تو ناگہاں وہی شخص جس نے کل اُن سے مدد مانگی تھی پھر اُن کو پکار رہا ہے۔ موسٰی نے اس سے کہا کہ تُو تو صریح گمراہ ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmcclxxi{جب موسٰی نے ارادہ کیا کہ اس شخص کو جو ان دونوں کا دشمن تھا پکڑ لیں تو وہ (یعنی موسٰی کی قوم کا آدمی) بول اُٹھا کہ جس طرح تم نے کل ایک شخص کو مار ڈالا تھا اسی طرح چاہتے ہو کہ مجھے بھی مار ڈالو۔ تم تو یہی چاہتے ہو کہ ملک میں ظلم وستم کرتے پھرو اور یہ نہیں چاہتے ہو کہ نیکو کاروں میں ہو\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmcclxxii{اور ایک شخص شہر کی پرلی طرف سے دوڑتا ہوا آیا (اور) بولا کہ موسٰی (شہر کے) رئیس تمہارے بارے میں صلاحیں کرتے ہیں کہ تم کو مار ڈالیں سو تم یہاں سے نکل جاؤ۔ میں تمہارا خیر خواہ ہوں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiii{موسٰی وہاں سے ڈرتے ڈرتے نکل کھڑے ہوئے کہ دیکھیں (کیا ہوتا ہے) اور دعا کرنے لگے کہ اے پروردگار مجھے ظالم لوگوں سے نجات دے۔\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmcclxxiv{اور جب مدین کی طرف رخ کیا تو کہنے لگے اُمید ہے کہ میرا پروردگار مجھے سیدھا رستہ بتائے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmcclxxv{اور جب مدین کے پانی (کے مقام) پر پہنچے تو دیکھا کہ وہاں لوگ جمع ہو رہے (اور اپنے چارپایوں کو) پانی پلا رہے ہیں اور ان کے ایک طرف دو عورتیں (اپنی بکریوں کو) روکے کھڑی ہیں۔ موسٰی نے (اُن سے) کہا تمہارا کیا کام ہے۔ وہ بولیں کہ جب تک چرواہے (اپنے چارپایوں کو) لے نہ جائیں ہم پانی نہیں پلا سکتے اور ہمارے والد بڑی عمر کے بوڑھے ہیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvi{تو موسٰی نے اُن کے لئے (بکریوں کو) پانی پلا دیا پھر سائے کی طرف چلے گئے۔ اور کہنے لگے کہ پروردگار میں اس کا محتاج ہوں کہ تو مجھ پر اپنی نعمت نازل فرمائے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmcclxxvii{تھوڑی دیر کے بعد) ان میں سے ایک عورت جو شرماتی اور لجاتی چلی آتی تھی۔ موسٰی کے پاس آئی اور کہنے لگی کہ تم کو میرے والد بلاتے ہیں کہ تم نے جو ہمارے لئے پانی پلایا تھا اس کی تم کو اُجرت دیں۔ جب وہ اُن کے پاس آئے اور اُن سے اپنا ماجرا بیان کیا تو اُنہوں نے کہا کہ کچھ خوف نہ کرو۔ تم ظالم لوگوں سے بچ آئے ہو\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmcclxxviii{ایک لڑکی بولی کہ ابّا ان کو نوکر رکھ لیجئے کیونکہ بہتر نوکر جو آپ رکھیں وہ ہے (جو) توانا اور امانت دار (ہو)\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmcclxxix{اُنہوں نے (موسٰی سے) کہا کہ میں چاہتا ہوں اپنی دو بیٹیوں میں سے ایک کو تم سے بیاہ دوں اس عہد پر کہ تم آٹھ برس میری خدمت کرو اور اگر دس سال پورے کر دو تو تمہاری طرف سے (احسان) ہے اور میں تم پر تکلیف ڈالنی نہیں چاہتا۔ مجھے انشاء الله نیک لوگوں میں پاؤ گے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmcclxxx{موسٰی نے کہا کہ مجھ میں اور آپ میں یہ (عہد پختہ ہوا) میں جونسی مدت (چاہوں) پوری کردوں پھر مجھ پر کوئی زیادتی نہ ہو۔ اور ہم جو معاہدہ کرتے ہیں خدا اس کا گواہ ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxi{جب موسٰی نے مدت پوری کردی اور اپنے گھر کے لوگوں کو لے کر چلے تو طور کی طرف سے آگ دکھائی دی تو اپنے گھر والوں سے کہنے لگے کہ تم یہاں ٹھیرو۔ مجھے آگ نظر آئی ہے شاید میں وہاں سے (رستے کا) کچھ پتہ لاؤں یا آگ کا انگارہ لے آؤں تاکہ تم تاپو\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxii{جب اس کے پاس پہنچے تو میدان کے دائیں کنارے سے ایک مبارک جگہ میں ایک درخت میں سے آواز آئی کہ موسٰی میں تو خدائے رب العالمین ہوں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiii{اور یہ کہ اپنی لاٹھی ڈالدو۔ جب دیکھا کہ وہ حرکت کر رہی ہے گویا سانپ ہے، تو پیٹھ پھیر کر چل دیئے اور پیچھے پھر کر بھی نہ دیکھا۔ (ہم نے کہا کہ) موسٰی آگے آؤ اور ڈرومت تم امن پانے والوں میں ہو\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxiv{اپنا ہاتھ گریبان میں ڈالو تو بغیر کسی عیب کے سفید نکل آئے گا اور خوف دور ہونے (کی وجہ) سے اپنے بازو کو اپنی طرف سیکڑلو۔ یہ دو دلیلیں تمہارے پروردگار کی طرف سے ہیں (ان کے ساتھ) فرعون اور اس کے درباریوں کے پاس جاؤ کہ وہ نافرمان لوگ ہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxv{موسٰی نے کہا اے پروردگار اُن میں کا ایک شخص میرے ہاتھ سے قتل ہوچکا ہے سو مجھے خوف ہے کہ وہ (کہیں) مجھ کو مار نہ ڈالیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvi{اور ہارون (جو) میرا بھائی (ہے) اس کی زبان مجھ سے زیادہ فصیح ہے تو اس کو میرے ساتھ مددگار بناکر بھیج کہ میری تصدیق کرے مجھے خوف ہے کہ وہ میری لوگ تکذیب کریں گے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxvii{خدا نے) فرمایا ہم تمہارے بھائی سے تمہارے بازو مضبوط کریں گے اور تم دونوں کو غلبہ دیں گے تو ہماری نشانیوں کے سبب وہ تم تک پہنچ نہ سکیں گے (اور) تم اور جنہوں نے تمہاری پیروی کی غالب رہو گے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxviii{اور جب موسٰی اُن کے پاس ہماری کھلی نشانیاں لےکر آئے تو وہ کہنے لگے کہ یہ جادو ہے جو اُس نے بنا کھڑا کیا ہے اور یہ باتیں ہم نے اپنے اگلے باپ دادا میں تو (کبھی) سنی نہیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmcclxxxix{اور موسٰی نے کہا کہ میرا پروردگار اس شخص کو خوب جانتا ہے جو اس کی طرف سے حق لےکر آیا ہے اور جس کے لئے عاقبت کا گھر (یعنی بہشت) ہے۔ بیشک ظالم نجات نہیں پائیں گے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmccxc{اور فرعون نے کہا کہ اے اہلِ دربار میں تمہارا اپنے سوا کسی کو خدا نہیں جانتا تو ہامان میرے لئے گارے کو آگ لگوا (کر اینٹیں پکوا) دو پھر ایک (اُونچا) محل بنادو تاکہ میں موسٰی کے خدا کی طرف چڑھ جاؤں اور میں تو اُسے جھوٹا سمجھتا ہوں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmccxci{اور وہ اور اس کے لشکر ملک میں ناحق مغرور ہورہے تھے اور خیال کرتے تھے کہ وہ ہماری طرف لوٹ کر نہیں آئیں گے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmccxcii{تو ہم نے اُن کو اور اُن کے لشکروں کو پکڑلیا اور دریا میں ڈال دیا۔ سو دیکھ لو ظالموں کا کیسا انجام ہوا\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmccxciii{اور ہم نے ان کو پیشوا بنایا تھا وہ (لوگوں) کو دوزخ کی طرف بلاتے تھے اور قیامت کے دن اُن کی مدد نہیں کی جائے گی\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmccxciv{اور اس دنیا سے ہم نے اُن کے پیچھے لعنت لگادی اور وہ قیامت کے روز بھی بدحالوں میں ہوں گے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmccxcv{اور ہم نے پہلی اُمتوں کے ہلاک کرنے کے بعد موسٰی کو کتاب دی جو لوگوں کے لئے بصیرت اور ہدایت اور رحمت ہے تاکہ وہ نصیحت پکڑیں\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmccxcvi{اور جب ہم نے موسٰی کی طرف حکم بھیجا تو تم (طور کی) غرب کی طرف نہیں تھے اور نہ اس واقعے کے دیکھنے والوں میں تھے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmccxcvii{لیکن ہم نے (موسٰی کے بعد) کئی اُمتوں کو پیدا کیا پھر ان پر مدت طویل گذر گئی اور نہ تم مدین والوں میں رہنے والے تھے کہ ان کو ہماری آیتیں پڑھ پڑھ کر سناتے تھے۔ ہاں ہم ہی تو پیغمبر بھیجنے والے تھے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmccxcviii{اور نہ تم اس وقت جب کہ ہم نے (موسٰی کو) آواز دی طور کے کنارے تھے بلکہ (تمہارا بھیجا جانا) تمہارے پروردگار کی رحمت ہے تاکہ تم اُن لوگوں کو جن کے پاس تم سے پہلے کوئی ہدایت کرنے والا نہیں آیا ہدایت کرو تاکہ وہ نصیحت پکڑیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmccxcix{اور (اے پیغمبر ہم نے تو کو اس لئے بھیجا ہے کہ) ایسا نہ ہو کہ اگر ان (اعمال) کے سبب جو اُن کے ہاتھ آگے بھیج چکے ہیں ان پر کوئی مصیبت واقع ہو تو یہ کہنے لگیں کہ اے پروردگار تو نے ہماری طرف کوئی پیغمبر کیوں نہ بھیجا کہ ہم تیری آیتوں کی پیروی کرنے اور ایمان لانے والوں میں ہوتے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmccc{پھر جب اُن کے پاس ہماری طرف سے حق آپہنچا تو کہنے لگے کہ جیسی (نشانیاں) موسٰی کو ملی تھیں ویسی اس کو کیوں نہیں ملیں۔ کیا جو (نشانیاں) پہلے موسٰی کو دی گئی تھیں اُنہوں نے اُن سے کفر نہیں کیا۔ کہنے لگے کہ دونوں جادوگر ہیں ایک دوسرے کے موافق۔ اور بولے کہ ہم سب سے منکر ہیں\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmccci{کہہ دو کہ اگر سچے ہو تو تم خدا کے پاس سے کوئی کتاب لے آؤ جو ان دونوں (کتابوں) سے بڑھ کر ہدایت کرنے والی ہو۔ تاکہ میں بھی اسی کی پیروی کروں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmcccii{پھر اگر یہ تمہاری بات قبول نہ کریں تو جان لو کہ یہ صرف اپنی خواہشوں کی پیروی کرتے ہیں۔ اور اس سے زیادہ کون گمراہ ہوگا جو خدا کی ہدایت کو چھوڑ کر اپنی خواہش کے پیچھے چلے۔ بیشک خدا ظالم لوگوں کو ہدایت نہیں دیتا\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmccciii{اور ہم پے درپے اُن لوگوں کے پاس (ہدایت کی) باتیں بھیجتے رہے ہیں تاکہ نصیحت پکڑیں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmccciv{جن لوگوں کو ہم نے اس سے پہلے کتاب دی تھی وہ اس پر ایمان لے آتے ہیں\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmcccv{اور جب (قرآن) اُن کو پڑھ کر سنایا جاتا ہے تو کہتے ہیں کہ ہم اس پر ایمان لے آئے بیشک وہ ہمارے پروردگار کی طرف سے برحق ہے اور ہم تو اس سے پہلے کے حکمبردار ہیں\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmcccvi{ان لوگوں کو دگنا بدلہ دیا جائے گا کیونکہ صبر کرتے رہے ہیں اور بھلائی کے ساتھ برائی کو دور کرتے ہیں اور جو (مال) ہم نے اُن کو دیا ہے اس میں سے خرچ کرتے ہیں\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmcccvii{اور جب بیہودہ بات سنتے ہیں تو اس سے منہ پھیر لیتے ہیں اور کہتے ہیں کہ ہم کو ہمارے اعمال اور تم کو تمہارے اعمال۔ تم کو سلام۔ ہم جاہلوں کے خواستگار نہیں ہیں\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmcccviii{اے محمدﷺ) تم جس کو دوست رکھتے ہو اُسے ہدایت نہیں کر سکتے بلکہ خدا ہی جس کو چاہتا ہے ہدایت کرتا ہے اور وہ ہدایت پانیوالوں کو خوب جانتا ہے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmcccix{اور کہتے ہیں کہ اگر ہم تمہارے ساتھ ہدایت کی پیروی کریں تو اپنے ملک سے اُچک لئے جائیں۔ کیا ہم نے اُن کو حرم میں جو امن کا مقام ہے جگہ نہیں دی۔ جہاں ہر قسم کے میوے پہنچائے جاتے ہیں (اور یہ) رزق ہماری طرف سے ہے لیکن ان میں سے اکثر نہیں جانتے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmcccx{اور ہم نے بہت سی بستیوں کو ہلاک کر ڈالا جو اپنی (فراخی) معیشت میں اترا رہے تھے۔ سو یہ اُن کے مکانات ہیں جو اُن کے بعد آباد ہی نہیں ہوئے مگر بہت کم۔ اور اُن کے پیچھے ہم ہی اُن کے وارث ہوئے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmcccxi{اور تمہارا پروردگار بستیوں کو ہلاک نہیں کیا کرتا۔ جب تک اُن کے بڑے شہر میں پیغمبر نہ بھیج لے جو اُن کو ہماری آیتیں پڑھ پڑھ کر سنائے اور ہم بستیوں کو ہلاک نہیں کیا کرتے مگر اس حالت میں کہ وہاں کے باشندے ظالم ہوں\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmcccxii{اور جو چیز تم کو دی گئی ہے وہ دنیا کی زندگی کا فائدہ اور اس کی زینت ہے۔ اور جو خدا کے پاس ہے وہ بہتر اور باقی رہنے والی ہے۔ کیا تم سمجھتے نہیں؟\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmcccxiii{بھلا جس شخص سے ہم نے نیک وعدہ کیا اور اُس نے اُسے حاصل کرلیا تو کیا وہ اس شخص کا سا ہے جس کو ہم نے دنیا کی زندگی کے فائدے سے بہرہ مند کیا پھر وہ قیامت کے روز ان لوگوں میں ہو جو (ہمارے روبرو) حاضر کئے جائیں گے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmcccxiv{اور جس روز خدا اُن کو پکارے گا اور کہے گا کہ میرے وہ شریک کہاں ہیں جن کا تمہیں دعویٰ تھا\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmcccxv{تو) جن لوگوں پر (عذاب کا) حکم ثابت ہوچکا ہوگا وہ کہیں گے کہ ہمارے پروردگار یہ وہ لوگ ہیں جن کو ہم نے گمراہ کیا تھا۔ اور جس طرح ہم خود گمراہ ہوئے تھے اسی طرح اُن کو گمراہ کیا تھا (اب) ہم تیری طرف (متوجہ ہوکر) اُن سے بیزار ہوتے ہیں یہ ہمیں نہیں پوجتے تھے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmcccxvi{اور کہا جائے گا کہ اپنے شریکوں کو بلاؤ۔ تو وہ اُن کو پکاریں گے اور وہ اُن کو جواب نہ دے سکیں گے اور (جب) عذاب کو دیکھ لیں گے (تو تمنا کریں گے کہ) کاش وہ ہدایت یاب ہوتے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmcccxvii{اور جس روز خدا اُن کو پکارے گا اور کہے گا کہ تم نے پیغمبروں کو کیا جواب دیا\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmcccxviii{تو وہ اس روز خبروں سے اندھے ہو جائیں گے، اور آپس میں کچھ بھی پوچھ نہ سکیں گے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmcccxix{لیکن جس نے توبہ کی اور ایمان لایا اور عمل نیک کئے تو اُمید ہے کہ وہ نجات پانے والوں میں ہو\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmcccxx{اور تمہارا پروردگار جو چاہتا ہے پیدا کرتا ہے اور (جسے چاہتا ہے) برگزیدہ کرلیتا ہے۔ ان کو اس کا اختیار نہیں ہے۔ یہ جو شرک کرتے ہیں خدا اس سے پاک وبالاتر ہے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmcccxxi{اور ان کے سینے جو کچھ مخفی کرتے اور جو یہ ظاہر کرتے ہیں تمہارا پروردگار اس کو جانتا ہے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmcccxxii{اور وہی خدا ہے اس کے سوا کوئی معبود نہیں دنیا اور آخرت میں اُسی کی تعریف ہے اور اُسی کا حکم اور اسی کی طرف تم لوٹائے جاؤ گے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiii{کہو بھلا دیکھو تو اگر خدا تم پر ہمیشہ قیامت کے دن تک رات (کی تاریکی) کئے رہے تو خدا کے سوا کون معبود ہے ہے جو تم کو روشنی لا دے تو کیا تم سنتے نہیں؟\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmcccxxiv{کہو تو بھلا دیکھو تو اگر خدا تم پر ہمیشہ قیامت تک دن کئے رہے تو خدا کے سوا کون معبود ہے کہ تم کو رات لا دے جس میں تم آرام کرو۔ تو کیا تم دیکھتے نہیں؟\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmcccxxv{اور اس نے اپنی رحمت سے تمہارے لئے رات کو اور دن کو بنایا تاکہ تم اس میں آرام کرو اور اس میں اس کا فضل تلاش کرو اور تاکہ شکر کرو\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvi{اور جس دن وہ اُن کو پکارے گا اور کہے گا کہ میرے وہ شریک جن کا تمہیں دعویٰ تھا کہاں گئے؟\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmcccxxvii{اور ہم ہر ایک اُمت میں سے گواہ نکال لیں گے پھر کہیں گے کہ اپنی دلیل پیش کرو تو وہ جان لیں گے کہ سچ بات خدا کی ہے اور جو کچھ وہ افتراء کیا کرتے تھے ان سے جاتا رہے گا\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmcccxxviii{قارون موسٰی کی قوم میں سے تھا اور ان پر تعدّی کرتا تھا۔ اور ہم نے اس کو اتنے خزانے دیئے تھے کہ اُن کی کنجیاں ایک طاقتور جماعت کو اُٹھانی مشکل ہوتیں جب اس سے اس کی قوم نے کہا کہ اترائیے مت۔ کہ خدا اترانے والوں کو پسند نہیں کرتا\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmcccxxix{اور جو (مال) تم کو خدا نے عطا فرمایا ہے اس سے آخرت کی بھلائی طلب کیجئے اور دنیا سے اپنا حصہ نہ بھلائیے اور جیسی خدا نے تم سے بھلائی کی ہے (ویسی) تم بھی (لوگوں سے) بھلائی کرو۔ اور ملک میں طالب فساد نہ ہو۔ کیونکہ خدا فساد کرنے والوں کو دوست نہیں رکھتا\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmcccxxx{بولا کہ یہ (مال) مجھے میری دانش (کے زور) سے ملا ہے کیا اس کو معلوم نہیں کہ خدا نے اس سے پہلے بہت سی اُمتیں جو اس سے قوت میں بڑھ کر اور جمعیت میں بیشتر تھیں ہلاک کر ڈالی ہیں۔ اور گنہگاروں سے اُن کے گناہوں کے بارے میں پوچھا نہیں جائے گا\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxi{تو (ایک روز) قارون (بڑی) آرائش (اور ٹھاٹھ) سے اپنی قوم کے سامنے نکلا۔ جو لوگ دنیا کی زندگی کے طالب تھے کہنے لگے کہ جیسا (مال ومتاع) قارون کو ملا ہے کاش ایسا ہی ہمیں بھی ملے۔ وہ تو بڑا ہی صاحب نصیب ہے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxii{اور جن لوگوں کو علم دیا گیا تھا وہ کہنے لگے کہ تم پر افسوس۔ مومنوں اور نیکوکاروں کے لئے (جو) ثواب خدا (کے ہاں تیار ہے وہ) کہیں بہتر ہے اور وہ صرف صبر کرنے والوں ہی کو ملے گا\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiii{پس ہم نے قارون کو اور اس کے گھر کو زمین میں دھنسا دیا تو خدا کے سوا کوئی جماعت اس کی مددگار نہ ہوسکی۔ اور نہ وہ بدلہ لے سکا\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxiv{اور وہ لوگ جو کل اُس کے رتبے کی تمنا کرتے تھے صبح کو کہنے لگے ہائے شامت! خدا ہی تو اپنے بندوں میں سے جس کے لئے چاہتا ہے رزق فراخ کر دیتا ہے اور (جس کے لئے چاہتا ہے) تنگ کر دیتا ہے۔ اگر خدا ہم پر احسان نہ کرتا تو ہمیں بھی دھنسا دیتا۔ ہائے خرابی! کافر نجات نہیں پا سکتے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxv{وہ (جو) آخرت کا گھر (ہے) ہم نے اُسے اُن لوگوں کے لئے (تیار) کر رکھا ہے جو ملک میں ظلم اور فساد کا ارادہ نہیں رکھتے اور انجام (نیک) تو پرہیزگاروں ہی کا ہے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvi{جو شخص نیکی لے کر آئے گا اس کے لئے اس سے بہتر (صلہ موجود) ہے اور جو برائی لائے گا تو جن لوگوں نے برے کام کئے ان کو بدلہ بھی اسی طرح کا ملے گا جس طرح کے وہ کام کرتے تھے\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxvii{اے پیغمبر) جس (خدا) نے تم پر قرآن (کے احکام) کو فرض کیا ہے وہ تمہیں بازگشت کی جگہ لوٹا دے گا۔ کہہ دو کہ میرا پروردگار اس شخص کو بھی خوب جانتا ہے جو ہدایت لےکر آیا اور (اس کو بھی) جو صریح گمراہی میں ہے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxviii{اور تمہیں اُمید نہ تھی کہ تم پر کتاب نازل کی جائے گی۔ مگر تمہارے پروردگار کی مہربانی سے (نازل ہوئی) تو تم ہرگز کافروں کے مددگار نہ ہونا\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmcccxxxix{اور وہ تمہیں خدا کی آیتوں کی تبلیغ سے بعد اس کے کہ وہ تم پر نازل ہوچکی ہیں روک نہ دیں اور اپنے پروردگار کو پکارتے رہو اور مشرکوں میں ہرگز نہ ہو جیو\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmcccxl{اور خدا کے ساتھ کسی اور کو معبود (سمجھ کر) نہ پکارنا اس کے سوا کوئی معبود نہیں۔ اس کی ذات (پاک) کے سوا ہر چیز فنا ہونے والی ہے۔ اسی کا حکم ہے اور اسی کی طرف تم لوٹ کر جاؤ گے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmcccxli{\basmalahur الم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmcccxlii{کیا لوگ یہ خیال کئے ہوئے ہیں کہ صرف یہ کہنے سے کہ ہم ایمان لے آئے چھوڑ دیئے جائیں گے اور اُن کی آزمائش نہیں کی جائے گی\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmcccxliii{اور جو لوگ اُن سے پہلے ہو چکے ہیں ہم نے اُن کو بھی آزمایا تھا (اور ان کو بھی آزمائیں گے) سو خدا اُن کو ضرور معلوم کریں گے جو (اپنے ایمان میں) سچے ہیں اور اُن کو بھی جو جھوٹے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmcccxliv{کیا وہ لوگ جو برے کام کرتے ہیں یہ سمجھے ہوئے ہیں کہ یہ ہمارے قابو سے نکل جائیں گے۔ جو خیال یہ کرتے ہیں برا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmcccxlv{جو شخص خدا کی ملاقات کی اُمید رکھتا ہو خدا کا (مقرر کیا ہوا) وقت ضرور آنے والا ہے۔ اور وہ سننے والا اور جاننے والا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvi{اور جو شخص محنت کرتا ہے تو اپنے ہی فائدے کے لئے محنت کرتا ہے۔ اور خدا تو سارے جہان سے بےپروا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmcccxlvii{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے ہم ان کے گناہوں کو اُن سے دور کردیں گے اور ان کو ان کے اعمال کا بہت اچھا بدلہ دیں گے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmcccxlviii{اور ہم نے انسان کو اپنے ماں باپ کے ساتھ نیک سلوک کرنے کا حکم دیا ہے۔ (اے مخاطب) اگر تیرے ماں باپ تیرے درپے ہوں کہ تو میرے ساتھ کسی کو شریک بنائے جس کی حقیقت کی تجھے واقفیت نہیں۔ تو ان کا کہنا نہ مانیو۔ تم (سب) کو میری طرف لوٹ کر آنا ہے۔ پھر جو کچھ تم کرتے تھے میں تم کو جتا دوں گا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmcccxlix{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے ان کو ہم نیک لوگوں میں داخل کریں گے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmcccl{اور بعض لوگ ایسے ہیں جو کہتے ہیں کہ ہم خدا پر ایمان لائے جب اُن کو خدا (کے رستے) میں کوئی ایذا پہنچتی ہے تو لوگوں کی ایذا کو (یوں) سمجھتے ہیں جیسے خدا کا عذاب۔ اگر تمہارے پروردگار کی طرف سے مدد پہنچے تو کہتے ہیں کہ ہم تمہارے ساتھ تھے۔ کیا جو اہل عالم کے سینوں میں ہے خدا اس سے واقف نہیں؟\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmcccli{اور خدا اُن کو ضرور معلوم کرے گا جو (سچے) مومن ہیں اور منافقوں کو بھی معلوم کرکے رہے گا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmccclii{اور جو کافر ہیں وہ مومنوں سے کہتے ہیں کہ ہمارے طریق کی پیروی کرو ہم تمہارے گناہ اُٹھالیں گے۔ حالانکہ وہ اُن کے گناہوں کا کچھ بھی بوجھ اُٹھانے والے نہیں۔ کچھ شک نہیں کہ یہ جھوٹے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmcccliii{اور یہ اپنے بوجھ بھی اُٹھائیں گے اور اپنے بوجھوں کے ساتھ اور (لوگوں کے) بوجھ بھی۔ اور جو بہتان یہ باندھتے رہے قیامت کے دن اُن کی اُن سے ضرور پرسش ہوگی\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmcccliv{اور ہم نے نوحؑ کو اُن کی قوم کی طرف بھیجا تو وہ ان میں پچاس برس کم ہزار برس رہے پھر اُن کو طوفان (کے عذاب) نے آپکڑا۔ اور وہ ظالم تھے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmccclv{پھر ہم نے نوحؑ کو اور کشتی والوں کو نجات دی اور کشتی کو اہل عالم کے لئے نشانی بنا دیا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmccclvi{اور ابراہیمؑ کو (یاد کرو) جب اُنہوں نے اپنی قوم سے کہا کہ خدا کی عبادت کرو اور اس سے ڈرو اگر تم سمجھ رکھتے ہو تو یہ تمہارے حق میں بہتر ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmccclvii{تو تم خدا کو چھوڑ کر بتوں کو پوجتے اور طوفان باندھتے ہو تو جن لوگوں کو تم خدا کے سوا پوجتے ہو وہ تم کو رزق دینے کا اختیار نہیں رکھتے پس خدا ہی کے ہاں سے رزق طلب کرو اور اسی کی عبادت کرو اور اسی کا شکر کرو اسی کی طرف تم لوٹ کر جاؤ گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmccclviii{اور اگر تم (میری) تکذیب کرو تو تم سے پہلے بھی اُمتیں (اپنے پیغمبروں کی) تکذیب کرچکی ہیں۔ اور پیغمبر کے ذمے کھول کر سنا دینے کے سوا اور کچھ نہیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmccclix{کیا اُنہوں نے نہیں دیکھا کہ خدا کس طرح خلقت کو پہلی بار پیدا کرتا پھر (کس طرح) اس کو بار بار پیدا کرتا رہتا ہے۔ یہ خدا کو آسان ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmccclx{کہہ دو کہ ملک میں چلو پھرو اور دیکھو کہ اس نے کس طرح خلقت کو پہلی دفعہ پیدا کیا ہے پھر خدا ہی پچھلی پیدائش پیدا کرے گا۔ بےشک خدا ہر چیز پر قادر ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmccclxi{وہ جسے چاہے عذاب دے اور جس پر چاہے رحم کرے۔ اور اُسی کی طرف تم لوٹائے جاؤ گے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmccclxii{اور تم (اُس کو) نہ زمین میں عاجز کرسکتے ہو نہ آسمان میں اور نہ خدا کے سوا تمہارا کوئی دوست ہے اور نہ مددگار\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmccclxiii{اور جن لوگوں نے خدا کی آیتوں سے اور اس کے ملنے سے انکار کیا وہ میری رحمت سے نااُمید ہوگئے ہیں اور ان کو درد دینے والا عذاب ہوگا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmccclxiv{تو اُن کی قوم کے لوگ جواب میں بولے تو یہ بولے کہ اُسے مار ڈالو یا جلا دو۔ مگر خدا نے اُن کو آگ (کی سوزش) سے بچالیا۔ جو لوگ ایمان رکھتے ہیں اُن کے لئے اس میں نشانیاں ہیں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmccclxv{اور ابراہیم نے کہا کہ تم جو خدا کو چھوڑ کر بتوں کو لے بیٹھے ہو تو دنیا کی زندگی میں باہم دوستی کے لئے (مگر) پھر قیامت کے دن تم ایک دوسرے (کی دوستی) سے انکار کر دو گے اور ایک دوسرے پر لعنت بھیجو گے اور تمہارا ٹھکانا دوزخ ہوگا اور کوئی تمہارا مددگار نہ ہوگا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmccclxvi{پس اُن پر (ایک) لوط ایمان لائے اور (ابراہیم) کہنے لگے کہ میں اپنے پروردگار کی طرف ہجرت کرنے والا ہوں۔ بیشک وہ غالب حکمت والا ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmccclxvii{اور ہم نے اُن کو اسحٰق اور یعقوب بخشے اور اُن کی اولاد میں پیغمبری اور کتاب (مقرر) کر دی اور ان کو دنیا میں بھی اُن کا صلہ عنایت کیا اور وہ آخرت میں بھی نیک لوگوں میں ہوں گے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmccclxviii{اور لوط (کو یاد کرو) جب اُنہوں نے اپنی قوم سے کہا کہ تم (عجب) بےحیائی کے مرتکب ہوتے ہو۔ تم سے پہلے اہل عالم میں سے کسی نے ایسا کام نہیں کیا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmccclxix{تم کیوں (لذت کے ارادے سے) لونڈوں کی طرف مائل ہوتے اور (مسافروں کی) رہزنی کرتے ہو اور اپنی مجلسوں میں ناپسندیدہ کام کرتے ہو۔ تو اُن کی قوم کے لوگ جواب میں بولے تو یہ بولے کہ اگر تم سچے ہو تو ہم پر عذاب لے آؤ\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmccclxx{لوط نے کہا کہ اے میرے پروردگار ان مفسد لوگوں کے مقابلے میں مجھے نصرت عنایت فرما\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmccclxxi{اور جب ہمارے فرشتے ابراہیم کے پاس خوشی کی خبر لے کر آئے تو کہنے لگے کہ ہم اس بستی کے لوگوں کو ہلاک کر دینے والے ہیں کہ یہاں کے رہنے والے نافرمان ہیں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmccclxxii{ابراہیم نے کہا کہ اس میں تو لوط بھی ہیں۔ وہ کہنے لگے کہ جو لوگ یہاں (رہتے) ہیں ہمیں سب معلوم ہیں۔ ہم اُن کو اور اُن کے گھر والوں کو بچالیں گے بجز اُن کی بیوی کے وہ پیچھے رہنے والوں میں ہوگی\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiii{اور جب ہمارے فرشتے لوط کے پاس آئے تو وہ اُن (کی وجہ) سے ناخوش اور تنگ دل ہوئے۔ فرشتوں نے کہا کچھ خوف نہ کیجئے۔ اور نہ رنج کیجئے ہم آپ کو اور آپ کے گھر والوں کو بچالیں گے مگر آپ کی بیوی کہ پیچھے رہنے والوں میں ہوگی\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmccclxxiv{ہم اس بستی کے رہنے والوں پر اس سبب سے کہ یہ بدکرداری کرتے رہے ہیں آسمان سے عذاب نازل کرنے والے ہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmccclxxv{اور ہم نے سمجھنے والے لوگوں کے لئے اس بستی سے ایک کھلی نشانی چھوڑ دی\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvi{اور مدین کی طرف اُن کے بھائی شعیب کو (بھیجا) تو اُنہوں نے کہا (اے قوم) خدا کی عبادت کرو اور پچھلے دن کے آنے کی اُمید رکھو اور ملک میں فساد نہ مچاؤ\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmccclxxvii{مگر اُنہوں نے اُن کو جھوٹا سمجھا سو اُن کو زلزلے (کے عذاب) نے آپکڑا اور وہ اپنے گھروں میں اوندھے پڑے رہ گئے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmccclxxviii{اور عاد اور ثمود کو بھی (ہم نے ہلاک کر دیا) چنانچہ اُن کے (ویران گھر) تمہاری آنکھوں کے سامنے ہیں اور شیطان نے اُن کے اعمال ان کو آراستہ کر دکھائے اور ان کو (سیدھے) رستے سے روک دیا۔ حالانکہ وہ دیکھنے والے (لوگ) تھے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmccclxxix{اور قارون اور فرعون اور ہامان کو بھی (ہلاک کر دیا) اور اُن کے پاس موسٰی کھلی نشانی لےکر آئے تو وہ ملک میں مغرور ہوگئے اور ہمارے قابو سے نکل جانے والے نہ تھے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmccclxxx{تو ہم نے سب کو اُن کے گناہوں کے سبب پکڑ لیا۔ سو ان میں کچھ تو ایسے تھے جن پر ہم نے پتھروں کا مینھہ برسایا۔ اور کچھ ایسے تھے جن کو چنگھاڑ نے آپکڑا اور کچھ ایسے تھے جن کو ہم نے زمین میں دھنسا دیا۔ اور کچھ ایسے تھے جن کو غرق کر دیا اور خدا ایسا نہ تھا کہ اُن پر ظلم کرتا لیکن وہی اپنے آپ پر ظلم کرتے تھے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxi{جن لوگوں نے خدا کے سوا (اوروں کو) کارساز بنا رکھا ہے اُن کی مثال مکڑی کی سی ہے کہ وہ بھی ایک (طرح کا) گھر بناتی ہے۔ اور کچھ شک نہیں کہ تمام گھروں سے کمزور مکڑی کا گھر ہے کاش یہ (اس بات کو) جانتے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxii{یہ جس چیز کو خدا کے سوا پکارتے ہیں (خواہ) وہ کچھ ہی ہو خدا اُسے جانتا ہے۔ اور وہ غالب اور حکمت والا ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiii{اور یہ مثالیں ہم لوگوں کے (سمجھانے کے) لئے بیان کرتے ہیں اور اُسے تو اہلِ دانش ہی سمجھتے ہیں\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxiv{خدا نے آسمانوں اور زمین کو حکمت کے ساتھ پیدا کیا ہے۔ کچھ شک نہیں کہ ایمان والوں کے لئے اس میں نشانی ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxv{اے محمدﷺ! یہ) کتاب جو تمہاری طرف وحی کی گئی ہے اس کو پڑھا کرو اور نماز کے پابند رہو۔ کچھ شک نہیں کہ نماز بےحیائی اور بری باتوں سے روکتی ہے۔ اور خدا کا ذکر بڑا (اچھا کام) ہے۔ اور جو کچھ تم کرتے ہو خدا اُسے جانتا ہے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvi{اور اہلِ کتاب سے جھگڑا نہ کرو مگر ایسے طریق سے کہ نہایت اچھا ہو۔ ہاں جو اُن میں سے بےانصافی کریں (اُن کے ساتھ اسی طرح مجادلہ کرو) اور کہہ دو کہ جو (کتاب) ہم پر اُتری اور جو (کتابیں) تم پر اُتریں ہم سب پر ایمان رکھتے ہیں اور ہمارا اور تمہارا معبود ایک ہی ہے اور ہم اُسی کے فرمانبردار ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxvii{اور اسی طرح ہم نے تمہاری طرف کتاب اُتاری ہے۔ تو جن لوگوں کو ہم نے کتابیں دی تھیں وہ اس پر ایمان لے آتے ہیں۔ اور بعض ان (مشرک) لوگوں میں سے بھی اس پر ایمان لے آتے ہیں۔ اور ہماری آیتوں سے وہی انکار کرتے ہیں جو کافر (ازلی) ہیں\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxviii{اور تم اس سے پہلے کوئی کتاب نہیں پڑھتے تھے اور نہ اُسے اپنے ہاتھ سے لکھ ہی سکتے تھے ایسا ہوتا تو اہلِ باطل ضرور شک کرتے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmccclxxxix{بلکہ یہ روشن آیتیں ہیں۔ جن لوگوں کو علم دیا گیا ہے اُن کے سینوں میں (محفوظ) اور ہماری آیتوں سے وہی لوگ انکار کرتے ہیں جو بےانصاف ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmcccxc{اور (کافر) کہتے ہیں کہ اس پر اس کے پروردگار کی طرف سے نشانیاں کیوں نازل نہیں ہوئیں کہہ دو کہ نشانیاں تو خدا ہی کے پاس ہیں۔ اور میں تو کھلم کھلا ہدایت کرنے والا ہوں\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmcccxci{کیا اُن لوگوں کے لئے یہ کافی نہیں کہ ہم نے تم پر کتاب نازل کی جو اُن کو پڑھ کر سنائی جاتی ہے۔ کچھ شک نہیں کہ مومن لوگوں کے لیے اس میں رحمت اور نصیحت ہے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmcccxcii{کہہ دو کہ میرے اور تمہارے درمیان خدا ہی گواہ کافی ہے جو چیز آسمانوں میں اور زمین میں ہے وہ سب کو جانتا ہے۔ اور جن لوگوں نے باطل کو مانا اور خدا سے انکار کیا وہی نقصان اُٹھانے والے ہیں\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmcccxciii{اور یہ لوگ تم سے عذاب کے لئے جلدی کر رہے ہیں۔ اگر ایک وقت مقرر نہ (ہو چکا) ہوتا تو اُن پر عذاب آبھی گیا ہوتا۔ اور وہ (کسی وقت میں) اُن پر ضرور ناگہاں آکر رہے گا اور اُن کو معلوم بھی نہ ہوگا\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmcccxciv{یہ تم سے عذاب کے لئے جلدی کررہے ہیں۔ اور دوزخ تو کافروں کو گھیر لینے والی ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmcccxcv{جس دن عذاب اُن کو اُن کے اُوپر سے اور نیچے سے ڈھانک لے گا اور (خدا) فرمائے گا کہ جو کام تم کیا کرتے تھے (اب) اُن کا مزہ چکھو\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvi{اے میرے بندو جو ایمان لائے ہو میری زمین فراخ ہے تو میری ہی عبادت کرو\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmcccxcvii{ہر متنفس موت کا مزہ چکھنے والا ہے۔ پھر تم ہماری ہی طرف لوٹ کر آؤ گے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmcccxcviii{اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے اُن کو ہم بہشت کے اُونچے اُونچے محلوں میں جگہ دیں گے۔ جن کے نیچے نہریں بہ رہی ہیں۔ ہمیشہ ان میں رہیں گے۔ (نیک) عمل کرنے والوں کا (یہ) خوب بدلہ ہے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmcccxcix{جو صبر کرتے اور اپنے پروردگار پر بھروسہ رکھتے ہیں\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmcd{اور بہت سے جانور ہیں جو اپنا رزق اُٹھائے نہیں پھرتے خدا ہی ان کو رزق دیتا ہے اور تم کو بھی۔ اور وہ سننے والا اور جاننے والا ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmcdi{اور اگر اُن سے پوچھو کہ آسمانوں اور زمین کو کس نے پیدا کیا۔ اور سورج اور چاند کو کس نے (تمہارے) زیر فرمان کیا تو کہہ دیں گے خدا نے۔ تو پھر یہ کہاں اُلٹے جا رہے ہیں\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmcdii{خدا ہی اپنے بندوں میں سے جس کے لئے چاہتا ہے روزی فراخ کر دیتا ہے اور جس کے لئے چاہتا ہے تنگ کر دیتا ہے بیشک خدا ہر چیز سے واقف ہے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmcdiii{اور اگر تم ان سے پوچھو کہ آسمان سے پانی کس نے نازل فرمایا پھر اس سے زمین کو اس کے مرنے کے بعد (کس نے) زندہ کیا تو کہہ دیں گے کہ خدا نے۔ کہہ دو کہ خدا کا شکر ہے۔ لیکن ان میں اکثر نہیں سمجھتے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmcdiv{اور یہ دنیا کی زندگی تو صرف کھیل اور تماشہ ہے اور (ہمیشہ کی) زندگی (کا مقام) تو آخرت کا گھر ہے۔ کاش یہ (لوگ) سمجھتے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmcdv{پھر جب یہ کشتی میں سوار ہوتے ہیں تو خدا کو پکارتے (اور) خالص اُسی کی عبادت کرتے ہیں۔ لیکن جب وہ اُن کو نجات دے کر خشکی پر پہنچا دیتا ہے تو جھٹ شرک کرنے لگے جاتے ہیں\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmcdvi{تاکہ جو ہم نے اُن کو بخشا ہے اُس کی ناشکری کریں اور فائدہ اٹھائیں (سو خیر) عنقریب اُن کو معلوم ہوجائے گا\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmcdvii{کیا اُنہوں نے نہیں دیکھا کہ ہم نے حرم کو مقام امن بنایا ہے اور لوگ اس کے گرد ونواح سے اُچک لئے جاتے ہیں۔ کیا یہ لوگ باطل پر اعتقاد رکھتے ہیں اور خدا کی نعمتوں کی ناشکری کرتے ہیں\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmcdviii{اور اس سے ظالم کون جو خدا پر جھوٹ بہتان باندھے یا جب حق بات اُس کے پاس آئے تو اس کی تکذیب کرے۔ کیا کافروں کا ٹھکانا جہنم میں نہیں ہے؟\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmcdix{اور جن لوگوں نے ہمارے لئے کوشش کی ہم اُن کو ضرور اپنے رستے دکھا دیں گے۔ اور خدا تو نیکو کاروں کے ساتھ ہے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmcdx{\basmalahur الٓمٓ\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmcdxi{اہلِ) روم مغلوب ہوگئے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmcdxii{نزدیک کے ملک میں اور وہ مغلوب ہونے کے بعد عنقریب غالب آجائیں گے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmcdxiii{چند ہی سال میں پہلے بھی اور پیچھے بھی خدا ہی کا حکم ہے اور اُس روز مومن خوش ہوجائیں گے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmcdxiv{یعنی) خدا کی مدد سے۔ وہ جسے چاہتا ہے مدد دیتا ہے اور وہ غالب (اور) مہربان ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmcdxv{یہ) خدا کا وعدہ (ہے) خدا اپنے وعدے کے خلاف نہیں کرتا لیکن اکثر لوگ نہیں جانتے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmcdxvi{یہ تو دنیا کی ظاہری زندگی کو جانتے ہیں۔ اور آخرت (کی طرف) سے غافل ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmcdxvii{کیا اُنہوں نے اپنے دل میں غور نہیں کیا۔ کہ خدا نے آسمانوں اور زمین کو اور جو کچھ ان دونوں کے درمیان ہے اُن کو حکمت سے اور ایک وقت مقرر تک کے لئے پیدا کیا ہے۔ اور بہت سے لوگ اپنے پروردگار سے ملنے کے قائل ہی نہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmcdxviii{کیا اُن لوگوں نے ملک میں سیر نہیں کی (سیر کرتے) تو دیکھ لیتے کہ جو لوگ اُن سے پہلے تھے ان کا انجام کیسے ہوا۔ وہ اُن سے زورو قوت میں کہیں زیادہ تھے اور اُنہوں نے زمین کو جوتا اور اس کو اس سے زیادہ آباد کیا تھا جو اُنہوں نے آباد کیا۔ اور اُن کے پاس اُن کے پیغمبر نشانیاں لےکر آتے رہے تو خدا ایسا نہ تھا کہ اُن پر ظلم کرتا۔ بلکہ وہی اپنے آپ پر ظلم کرتے تھے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmcdxix{پھر جن لوگوں نے برائی کی اُن کا انجام بھی برا ہوا اس لیے کہ خدا کی آیتوں کو جھٹلاتے اور اُن کی ہنسی اُڑاتے رہے تھے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmcdxx{خدا ہی خلقت کو پہلی بار پیدا کرتا ہے وہی اس کو پھر پیدا کرے گا پھر تم اُسی کی طرف لوٹ جاؤ گے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmcdxxi{اور جس دن قیامت برپا ہوگی گنہگار نااُمید ہوجائیں گے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmcdxxii{اور ان کے (بنائے ہوئے) شریکوں میں سے کوئی ان کا سفارشی نہ ہوگا اور وہ اپنے شریکوں سے نامعتقد ہوجائیں گے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiii{اور جس دن قیامت برپا ہوگی اس روز وہ الگ الگ فرقے ہوجائیں گے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmcdxxiv{تو جو لوگ ایمان لائے اور عمل نیک کرتے رہے وہ (بہشت کے) باغ میں خوش حال ہوں گے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmcdxxv{اور جنہوں نے کفر کیا اور ہماری آیتوں اور آخرت کے آنے کو جھٹلایا۔ وہ عذاب میں ڈالے جائیں گے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvi{تو جس وقت تم کو شام ہو اور جس وقت صبح ہو خدا کی تسبیح کرو (یعنی نماز پڑھو)\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmcdxxvii{اور آسمانوں اور زمین میں اُسی کی تعریف ہے۔ اور تیسرے پہر بھی اور جب دوپہر ہو (اُس وقت بھی نماز پڑھا کرو)\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmcdxxviii{وہی زندے کو مردے سے نکالتا اور (وہی) مردے کو زندے سے نکالتا ہے اور (وہی) زمین کو اس کے مرنے کے بعد زندہ کرتا ہے۔ اور اسی طرح تم (دوبارہ زمین میں سے) نکالے جاؤ گے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmcdxxix{اور اسی کے نشانات (اور تصرفات) میں سے ہے کہ اُس نے تمہیں مٹی سے پیدا کیا۔ پھر اب تم انسان ہوکر جا بجا پھیل رہے ہو\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmcdxxx{اور اسی کے نشانات (اور تصرفات) میں سے ہے کہ اُس نے تمہارے لئے تمہاری ہی جنس کی عورتیں پیدا کیں تاکہ اُن کی طرف (مائل ہوکر) آرام حاصل کرو اور تم میں محبت اور مہربانی پیدا کر دی جو لوگ غور کرتے ہیں اُن کے لئے ان باتوں میں (بہت سی) نشانیاں ہیں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxi{اور اسی کے نشانات (اور تصرفات) میں سے ہے آسمانوں اور زمین کا پیدا کرنا اور تمہاری زبانوں اور رنگوں کا جدا جدا ہونا۔ اہلِ دانش کے لیے ان (باتوں) میں (بہت سی) نشانیاں ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxii{اور اسی کے نشانات (اور تصرفات) میں سے ہے تمہارا رات اور دن میں سونا اور اُس کے فضل کا تلاش کرنا۔ جو لوگ سنتے ہیں اُن کے لیے ان باتوں میں (بہت سی) نشانیاں ہیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiii{اور اسی کے نشانات (اور تصرفات) میں سے ہے کہ تم کو خوف اور اُمید دلانے کے لئے بجلی دکھاتا ہے اور آسمان سے مینھہ برساتا ہے۔ پھر زمین کو اس کے مر جانے کے بعد زندہ (و شاداب) کر دیتا ہے۔ عقل والوں کے لئے ان (باتوں) میں (بہت سی) نشانیاں ہیں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxiv{اور اسی کے نشانات (اور تصرفات) میں سے ہے کہ آسمان اور زمین اس کے حکم سے قائم ہیں۔ پھر جب وہ تم کو زمین میں سے (نکلنے کے لئے) آواز دے گا تو تم جھٹ نکل پڑو گے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxv{اور آسمانوں اور زمین میں (جتنے فرشتے اور انسان وغیرہ ہیں) اسی کے (مملوک) ہیں (اور) تمام اس کے فرمانبردار ہیں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvi{اور وہی تو ہے جو خلقت کو پہلی دفعہ پیدا کرتا ہے پھر اُسے دوبارہ پیدا کرے گا۔ اور یہ اس کو بہت آسان ہے۔ اور آسمانوں اور زمین میں اس کی شان بہت بلند ہے۔ اور وہ غالب حکمت والا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxvii{وہ تمہارے لئے تمہارے ہی حال کی ایک مثال بیان فرماتا ہے کہ بھلا جن (لونڈی غلاموں) کے تم مالک ہو وہ اس (مال) میں جو ہم نے تم کو عطا فرمایا ہے تمہارے شریک ہیں، اور (کیا) تم اس میں (اُن کو اپنے) برابر (مالک سمجھتے) ہو (اور کیا) تم اُن سے اس طرح ڈرتے ہو جس طرح اپنوں سے ڈرتے ہو، اسی طرح عقل والوں کے لئے اپنی آیتیں کھول کھول کر بیان کرتے ہیں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxviii{مگر جو ظالم ہیں بےسمجھے اپنی خواہشوں کے پیچھے چلتے ہیں تو جس کو خدا گمراہ کرے اُسے کون ہدایت دے سکتا ہے؟ اور ان کا کوئی مددگار نہیں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmcdxxxix{تو تم ایک طرف کے ہوکر دین (خدا کے رستے) پر سیدھا منہ کئے چلے جاؤ (اور) خدا کی فطرت کو جس پر اُس نے لوگوں کو پیدا کیا ہے (اختیار کئے رہو) خدا کی بنائی ہوئی (فطرت) میں تغیر وتبدل نہیں ہو سکتا۔ یہی سیدھا دین ہے لیکن اکثر لوگ نہیں جانتے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmcdxl{مومنو) اُسی (خدا) کی طرف رجوع کئے رہو اور اس سے ڈرتے رہو اور نماز پڑھتے رہو اور مشرکوں میں نہ ہونا\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmcdxli{اور نہ) اُن لوگوں میں (ہونا) جنہوں نے اپنے دین کو ٹکڑے ٹکڑے کر دیا اور (خود) فرقے فرقے ہو گئے۔ سب فرقے اسی سے خوش ہیں جو اُن کے پاس ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmcdxlii{اور جب لوگوں کو تکلیف پہنچتی ہے تو اپنے پروردگار کو پکارتے اور اسی کی طرف رجوع ہوتے ہیں۔ پھر جب وہ ان کو اپنی رحمت کا مزا چکھاتا ہے تو ایک فرقہ اُن میں سے اپنے پروردگار سے شرک کرنے لگتا ہے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmcdxliii{تاکہ جو ہم نے ان کو بخشا ہے اُس کی ناشکری کریں سو (خیر) فائدے اُٹھالو عنقریب تم کو (اس کا انجام) معلوم ہو جائے گا\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmcdxliv{کیا ہم نے ان پر کوئی ایسی دلیل نازل کی ہے کہ اُن کو خدا کے ساتھ شرک کرنا بتاتی ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmcdxlv{اور جب ہم لوگوں کو اپنی رحمت کا مزا چکھاتے ہیں تو اُس سے خوش ہو جاتے ہیں اور اگر اُن کے عملوں کے سبب جو اُن کے ہاتھوں نے آگے بھیجے ہیں کوئی گزند پہنچے تو نااُمید ہو کر رہ جاتے ہیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvi{کیا اُنہوں نے نہیں دیکھا کہ خدا ہی جس کے لئے چاہتا ہے رزق فراخ کرتا ہے اور (جس کے لئے چاہتا ہے) تنگ کرتا ہے۔ بیشک اس میں ایمان لانے والوں کے لئے نشانیاں ہیں\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmcdxlvii{تو اہلِ قرابت اور محتاجوں اور مسافروں کو ان کا حق دیتے رہو۔ جو لوگ رضائے خدا کے طالب ہیں یہ اُن کے حق میں بہتر ہے۔ اور یہی لوگ نجات حاصل کرنے والے ہیں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmcdxlviii{اور جو تم سود دیتے ہو کہ لوگوں کے مال میں افزائش ہو تو خدا کے نزدیک اس میں افزائش نہیں ہوتی اور جو تم زکوٰة دیتے ہو اور اُس سے خدا کی رضا مندی طلب کرتے ہو تو (وہ موجبِ برکت ہے اور) ایسے ہی لوگ (اپنے مال کو) دو چند سہ چند کرنے والے ہیں\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmcdxlix{خدا ہی تو ہے جس نے تم کو پیدا کیا پھر تم کو رزق دیا پھر تمہیں مارے گا۔ پھر زندہ کرے گا۔ بھلا تمہارے (بنائے ہوئے) شریکوں میں بھی کوئی ایسا ہے جو ان کاموں میں سے کچھ کر سکے۔ وہ پاک ہے اور (اس کی شان) ان کے شریکوں سے بلند ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmcdl{خشکی اور تری میں لوگوں کے اعمال کے سبب فساد پھیل گیا ہے تاکہ خدا اُن کو اُن کے بعض اعمال کا مزہ چکھائے عجب نہیں کہ وہ باز آجائیں\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmcdli{کہہ دو کہ ملک میں چلو پھرو اور دیکھو کہ جو لوگ (تم سے) پہلے ہوئے ہیں ان کا کیسا انجام ہوا ہے۔ ان میں زیادہ تر مشرک ہی تھے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmcdlii{تو اس روز سے پہلے جو خدا کی طرف سے آکر رہے گا اور رک نہیں سکے گا دین (کے رستے) پر سیدھا منہ کئے چلے چلو اس روز (سب) لوگ منتشر ہوجائیں گے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmcdliii{جس شخص نے کفر کیا تو اس کے کفر کا ضرر اُسی کو ہے اور جس نے نیک عمل کئے تو ایسے لوگ اپنے ہی لئے آرام گاہ درست کرتے ہیں\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmcdliv{جو لوگ ایمان لائے اور نیک عمل کرتے رہے اُن کو خدا اپنے فضل سے بدلہ دے گا۔ بیشک وہ کافروں کو دوست نہیں رکھتا\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmcdlv{اور اُسی کی نشانیوں میں سے ہے کہ ہواؤں کو بھیجتا ہے کہ خوشخبری دیتی ہیں تاکہ تم کو اپنی رحمت کے مزے چکھائے اور تاکہ اس کے حکم سے کشتیاں چلیں اور تاکہ اس کے فضل سے (روزی) طلب کرو عجب نہیں کہ تم شکر کرو\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmcdlvi{اور ہم نے تم سے پہلے بھی پیغمبر ان کی قوم کی طرف بھیجے تو وہ اُن کے پاس نشانیاں لےکر آئے سو جو لوگ نافرمانی کرتے تھے ہم نے اُن سے بدلہ لےکر چھوڑا اور مومنوں کی مدد ہم پر لازم تھی\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmcdlvii{خدا ہی تو ہے جو ہواؤں کو چلاتا ہے تو وہ بادل کو اُبھارتی ہیں۔ پھر خدا اس کو جس طرح چاہتا ہے آسمان میں پھیلا دیتا اور تہ بتہ کر دیتا ہے پھر تم دیکھتے ہو کہ اس کے بیچ میں سے مینھہ نکلنے لگتا ہے پھر جب وہ اپنے بندوں میں سے جن پر چاہتا ہے اُسے برسا دیتا ہے تو وہ خوش ہو جاتے ہیں\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmcdlviii{اور بیشتر تو وہ مینھہ کے اُترنے سے پہلے نااُمید ہو رہے تھے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmcdlix{تو (اے دیکھنے والے) خدا کی رحمت کی نشانیوں کی طرف دیکھ کہ وہ کس طرح زمین کو اس کے مرنے کے بعد زندہ کرتا ہے۔ بیشک وہ مردوں کو زندہ کرنے والا ہے۔ اور وہ ہر چیز پر قادر ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmcdlx{اور اگر ہم ایسی ہوا بھیجیں کہ وہ (اس کے سبب) کھیتی کو دیکھیں (کہ) زرد (ہو گئی ہے) تو اس کے بعد وہ ناشکری کرنے لگ جائیں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmcdlxi{تو تم مردوں کی (بات) نہیں سنا سکتے اور نہ بہروں کو جب وہ پیٹھ پھیر کر پھر جائیں آواز سنا سکتے ہو\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmcdlxii{اور نہ اندھوں کو اُن کی گمراہی سے (نکال کر) راہ راست پر لاسکتے ہو۔ تم تو انہی لوگوں کو سنا سکتے ہو جو ہماری آیتوں پر ایمان لاتے ہیں سو وہی فرمانبردار ہیں\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiii{خدا ہی تو ہے جس نے تم کو (ابتدا میں) کمزور حالت میں پیدا کیا پھر کمزوری کے بعد طاقت عنایت کی پھر طاقت کے بعد کمزوری اور بڑھاپا دیا۔ وہ جو چاہتا ہے پیدا کرتا ہے اور وہ صاحب دانش اور صاحب قدرت ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmcdlxiv{اور جس روز قیامت برپا ہوگی گنہگار قسمیں کھائیں گے کہ وہ (دنیا میں) ایک گھڑی سے زیادہ نہیں رہے تھے۔ اسی طرح وہ (رستے سے) اُلٹے جاتے تھے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmcdlxv{اور جن لوگوں کو علم اور ایمان دیا گیا تھا وہ کہیں گے کہ خدا کی کتاب کے مطابق تم قیامت تک رہے ہو۔ اور یہ قیامت ہی کا دن ہے لیکن تم کو اس کا یقین ہی نہیں تھا\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvi{تو اس روز ظالم لوگوں کو ان کا عذر کچھ فائدہ نہ دے گا اور نہ اُن سے توبہ قبول کی جائے گی\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmcdlxvii{اور ہم نے لوگوں کے (سمجھانے کے) لئے اس قرآن میں ہر طرح کی مثال بیان کر دی ہے اور اگر تم اُن کے سامنے کوئی نشانی پیش کرو تو یہ کافر کہہ دیں گے کہ تم تو جھوٹے ہو\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmcdlxviii{اسی طرح خدا اُن لوگوں کے دلوں پر جو سمجھ نہیں رکھتے مہر لگا دیتا ہے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmcdlxix{پس تم صبر کرو بیشک خدا کا وعدہ سچا ہے اور (دیکھو) جو لوگ یقین نہیں رکھتے وہ تمہیں اوچھا نہ بنادیں\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmcdlxx{\basmalahur الٓمٓ\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxi{یہ حکمت کی (بھری ہوئی) کتاب کی آیتیں ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxii{نیکوکاروں کے لئے ہدایت اور رحمت ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiii{جو نماز کی پابندی کرتے اور زکوٰة دیتے اور آخرت کا یقین رکھتے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxiv{یہی اپنے پروردگار (کی طرف) سے ہدایت پر ہیں اور یہی نجات پانے والے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxv{اور لوگوں میں بعض ایسا ہے جو بیہودہ حکایتیں خریدتا ہے تاکہ (لوگوں کو) بےسمجھے خدا کے رستے سے گمراہ کرے اور اس سے استہزاء کرے یہی لوگ ہیں جن کو ذلیل کرنے والا عذاب ہوگا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvi{اور جب اس کو ہماری آیتیں سنائی جاتی ہیں تو اکڑ کر منہ پھیر لیتا ہے گویا اُن کو سنا ہی نہیں جیسے اُن کے کانوں میں ثقل ہے تو اس کو درد دینے والے عذاب کی خوشخبری سنادو\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxvii{جو لوگ ایمان لائے اور نیک کام کرتے رہے اُن کے لئے نعمت کے باغ ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxviii{ہمیشہ اُن میں رہیں گے۔ خدا کا وعدہ سچا ہے اور وہ غالب حکمت والا ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxix{اُسی نے آسمانوں کو ستونوں کے بغیر پیدا کیا جیسا کہ تم دیکھتے ہو اور زمین پر پہاڑ (بنا کر) رکھ دیئے تاکہ تم کو ہلا ہلا نہ دے اور اس میں ہر طرح کے جانور پھیلا دیئے۔ اور ہم ہی نے آسمانوں سے پانی نازل کیا پھر (اُس سے) اس میں ہر قسم کی نفیس چیزیں اُگائیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxx{یہ تو خدا کی پیدائش ہے تو مجھے دکھاؤ کہ خدا کے سوا جو لوگ ہیں اُنہوں نے کیا پیدا کیا ہے؟ حقیقت یہ ہے کہ یہ ظالم صریح گمراہی میں ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxi{اور ہم نے لقمان کو دانائی بخشی۔ کہ خدا کا شکر کرو۔ اور جو شخص شکر کرتا ہے تو اپنے ہی فائدے کے لئے شکر کرتا ہے۔ اور جو ناشکری کرتا ہے تو خدا بھی بےپروا اور سزاوار حمد (وثنا) ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxii{اور (اُس وقت کو یاد کرو) جب لقمان نے اپنے بیٹے کو نصیحت کرتے ہوئے کہا کہ بیٹا خدا کے ساتھ شرک نہ کرنا۔ شرک تو بڑا (بھاری) ظلم ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiii{اور ہم نے انسان کو جسے اُس کی ماں تکلیف پر تکلیف سہہ کر پیٹ میں اُٹھائے رکھتی ہے (پھر اس کو دودھ پلاتی ہے) اور (آخرکار) دو برس میں اس کا دودھ چھڑانا ہوتا ہے (اپنے نیز) اس کے ماں باپ کے بارے میں تاکید کی ہے کہ میرا بھی شکر کرتا رہ اور اپنے ماں باپ کا بھی (کہ تم کو) میری ہی طرف لوٹ کر آنا ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxiv{اور اگر وہ تیرے درپے ہوں کہ تو میرے ساتھ کسی ایسی چیز کو شریک کرے جس کا تجھے کچھ بھی علم نہیں تو ان کا کہا نہ ماننا۔ ہاں دنیا (کے کاموں) میں ان کا اچھی طرح ساتھ دینا اور جو شخص میری طرف رجوع لائے اس کے رستے پر چلنا پھر تم کو میری طرف لوٹ کر آنا ہے۔ تو جو کام تم کرتے رہے میں سب سے تم کو آگاہ کروں گا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxv{لقمان نے یہ بھی کہا کہ) بیٹا اگر کوئی عمل (بالفرض) رائی کے دانے کے برابر بھی (چھوٹا) ہو اور ہو بھی کسی پتھر کے اندر یا آسمانوں میں (مخفی ہو) یا زمین میں۔ خدا اُس کو قیامت کے دن لاموجود کرے گا۔ کچھ شک نہیں کہ خدا باریک بین (اور) خبردار ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvi{بیٹا نماز کی پابندی رکھنا اور (لوگوں کو) اچھے کاموں کے کرنے کا امر اور بری باتوں سے منع کرتے رہنا اور جو مصیبت تجھ پر واقع ہو اس پر صبر کرنا۔ بیشک یہ بڑی ہمت کے کام ہیں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxvii{اور (ازراہ غرور) لوگوں سے گال نہ پھلانا اور زمین میں اکڑ کر نہ چلنا۔ کہ خدا کسی اترانے والے خود پسند کو پسند نہیں کرتا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxviii{اور اپنی چال میں اعتدال کئے رہنا اور (بولتے وقت) آواز نیچی رکھنا کیونکہ (اُونچی آواز گدھوں کی ہے اور کچھ شک نہیں کہ) سب آوازوں سے بُری آواز گدھوں کی ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmcdlxxxix{کیا تم نے نہیں دیکھا کہ جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے سب کو خدا نے تمہارے قابو میں کر دیا ہے اور تم پر اپنی ظاہری اور باطنی نعمتیں پوری کردی ہیں۔ اور بعض لوگ ایسے ہیں کہ خدا کے بارے میں جھگڑتے ہیں نہ علم رکھتے ہیں اور نہ ہدایت اور نہ کتاب روشن\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmcdxc{اور جب اُن سے کہا جاتا ہے کہ جو (کتاب) خدا نے نازل فرمائی ہے اُس کی پیروی کرو۔ تو کہتے ہیں کہ ہم تو اسی کی پیروی کریں گے جس پر اپنے باپ دادا کو پایا۔ بھلا اگرچہ شیطان ان کو دوزخ کے عذاب کی طرف بلاتا ہو (تب بھی؟)\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmcdxci{اور جو شخص اپنے تئیں خدا کا فرمانبردار کردے اور نیکوکار بھی ہو تو اُس نے مضبوط دستاویز ہاتھ میں لے لی۔ اور (سب) کاموں کا انجام خدا ہی کی طرف ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmcdxcii{اور جو کفر کرے تو اُس کا کفر تمہیں غمناک نہ کردے ان کو ہماری طرف لوٹ کر آنا ہے پھر جو کام وہ کیا کرتے تھے ہم اُن کو جتا ئیں گے۔ بیشک خدا دلوں کی باتوں سے واقف ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmcdxciii{ہم اُن کو تھوڑا سا فائدہ پہنچائیں گے پھر عذاب شدید کی طرف مجبور کر کے لیجائیں گے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmcdxciv{اور اگر تم اُن سے پوچھو کہ آسمانوں اور زمین کو کس نے پیدا کیا تو بول اُٹھیں گے کہ خدا نے۔ کہہ دو کہ خدا کا شکر ہے لیکن ان میں اکثر سمجھ نہیں رکھتے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmcdxcv{جو کچھ آسمانوں اور زمین میں ہے (سب) خدا ہی کا ہے۔ بیشک خدا بےپروا اور سزا وارِ حمد (وثنا) ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvi{اور اگر یوں ہو کہ زمین میں جتنے درخت ہیں (سب کے سب) قلم ہوں اور سمندر (کا تمام پانی) سیاہی ہو (اور) اس کے بعد سات سمندر اور (سیاہی ہو جائیں) تو خدا کی باتیں (یعنی اس کی صفتیں) ختم نہ ہوں۔ بیشک خدا غالب حکمت والا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmcdxcvii{خدا کو) تمہارا پیدا کرنا اور جِلا اُٹھانا ایک شخص (کے پیدا کرنے اور جلا اُٹھانے) کی طرح ہے۔ بیشک خدا سننے والا دیکھنے والا ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmcdxcviii{کیا تم نے نہیں دیکھا کہ خدا ہی رات کو دن میں داخل کرتا ہے اور (وہی) دن کو رات میں داخل کرتا ہے اور اُسی نے سورج اور چاند کو (تمہارے) زیر فرمان کر رکھا ہے۔ ہر ایک ایک وقتِ مقرر تک چل رہا ہے اور یہ کہ خدا تمہارے سب اعمال سے خبردار ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmcdxcix{یہ اس لئے کہ خدا کی ذات برحق ہے اور جن کو یہ لوگ خدا کے سوا پکارتے ہیں وہ لغو ہیں اور یہ کہ خدا ہی عالی رتبہ اور گرامی قدر ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmd{کیا تم نے نہیں دیکھا کہ خدا ہی کی مہربانی سے کشتیاں دریا میں چلتی ہیں۔ تاکہ وہ تم کو اپنی کچھ نشانیاں دکھائے۔ بیشک اس میں ہر صبر کرنے والے (اور) شکر کرنے والے کے لئے نشانیاں ہیں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdi{اور جب اُن پر (دریا کی) لہریں سائبانوں کی طرح چھا جاتی ہیں تو خدا کو پکارنے (اور) خالص اس کی عبادت کرنے لگتے ہیں پھر جب وہ اُن کو نجات دے کر خشکی پر پہنچا دیتا ہے تو بعض ہی انصاف پر قائم رہتے ہیں۔ اور ہماری نشانیوں سے وہی انکار کرتے ہیں جو عہد شکن اور ناشکرے ہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdii{لوگو اپنے پروردگار سے ڈرو اور اُس دن کا خوف کرو کہ نہ تو باپ اپنے بیٹے کے کچھ کام آئے۔ اور نہ بیٹا باپ کے کچھ کام آسکے۔ بیشک خدا کا وعدہ سچا ہے پس دنیا کی زندگی تم کو دھوکے میں نہ ڈال دے۔ اور نہ فریب دینے والا (شیطان) تمہیں خدا کے بارے میں کسی طرح کا فریب دے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdiii{خدا ہی کو قیامت کا علم ہے اور وہی مینھہ برساتا ہے۔ اور وہی (حاملہ کے) پیٹ کی چیزوں کو جانتا ہے (کہ نر ہے یا مادہ) اور کوئی شخص نہیں جانتا کہ وہ کل کیا کام کرے گا۔ اور کوئی متنفس نہیں جانتا کہ کس سرزمین میں اُسے موت آئے گی بیشک خدا ہی جاننے والا (اور) خبردار ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdiv{\basmalahur الٓمٓ\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdv{اس میں کچھ شک نہیں کہ اس کتاب کا نازل کیا جانا تمام جہان کے پروردگار کی طرف سے ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdvi{کیا یہ لوگ یہ کہتے ہیں کہ پیغمبر نے اس کو از خود بنا لیا ہے (نہیں) بلکہ وہ تمہارے پروردگار کی طرف سے برحق ہے تاکہ تم ان لوگوں کو ہدایت کرو جن کے پاس تم سے پہلے کوئی ہدایت کرنے والا نہیں آیا تاکہ یہ رستے پر چلیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdvii{خدا ہی تو ہے جس نے آسمانوں اور زمین کو اور جو چیزیں ان دونوں میں ہیں سب کو چھ دن میں پیدا کیا پھر عرش پر جا ٹھہرا۔ اس کے سوا نہ تمہارا کوئی دوست ہے اور نہ سفارش کرنے والا۔ کیا تم نصیحت نہیں پکڑتے؟\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdviii{وہی آسمان سے زمین تک (کے) ہر کام کا انتظام کرتا ہے۔ پھر وہ ایک روز جس کی مقدار تمہارے شمار کے مطابق ہزار برس ہوگی۔ اس کی طرف صعود (اور رجوع) کرے گا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdix{یہی تو پوشیدہ اور ظاہر کا جاننے والا (اور) غالب اور رحم والا (خدا) ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdx{جس نے ہر چیز کو بہت اچھی طرح بنایا (یعنی) اس کو پیدا کیا۔ اور انسان کی پیدائش کو مٹی سے شروع کیا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdxi{پھر اس کی نسل خلاصے سے (یعنی) حقیر پانی سے پیدا کی\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdxii{پھر اُس کو درست کیا پھر اس میں اپنی (طرف سے) روح پھونکی اور تمہارے کان اور آنکھیں اور دل بنائے مگر تم بہت کم شکر کرتے ہو\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdxiii{اور کہنے لگے کہ جب ہم زمین میں ملیامیٹ ہوجائیں گے تو کیا ازسرنو پیدا ہوں گے۔ حقیقت یہ ہے کہ یہ لوگ اپنے پروردگار کے سامنے جانے ہی کے قائل نہیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdxiv{کہہ دو کہ موت کا فرشتہ جو تم پر مقرر کیا گیا ہے تمہاری روحیں قبض کر لیتا ہے پھر تم اپنے پروردگار کی طرف لوٹائے جاؤ گے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdxv{اور تم (تعجب کرو) جب دیکھو کہ گنہگار اپنے پروردگار کے سامنے سرجھکائے ہوں گے (اور کہیں گے کہ) اے ہمارے پروردگار ہم نے دیکھ لیا اور سن لیا تو ہم کو (دنیا میں) واپس بھیج دے کہ نیک عمل کریں بیشک ہم یقین کرنے والے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdxvi{اور اگر ہم چاہتے تو ہر شخص کو ہدایت دے دیتے۔ لیکن میری طرف سے یہ بات قرار پاچکی ہے کہ میں دوزخ کو جنوں اور انسانوں سب سے بھردوں گا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdxvii{سو (اب آگ کے) مزے چکھو اس لئے کہ تم نے اُس دن کے آنے کو بھلا رکھا تھا (آج) ہم بھی تمہیں بھلا دیں گے اور جو کام تم کرتے تھے اُن کی سزا میں ہمیشہ کے عذاب کے مزے چکھتے رہو\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdxviii{ہماری آیتوں پر تو وہی لوگ ایمان لاتے ہیں کہ جب اُن کو اُن سے نصیحت کی جاتی ہے تو سجدے میں گرپڑتے اور اپنے پروردگار کی تعریف کے ساتھ تسبیح کرتے ہیں اور غرور نہیں کرتے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdxix{اُن کے پہلو بچھونوں سے الگ رہتے ہیں (اور) وہ اپنے پروردگار کو خوف اور اُمید سے پکارتے اور جو (مال) ہم نے اُن کو دیا ہے اس میں سے خرچ کرتے ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdxx{کوئی متنفس نہیں جانتا کہ اُن کے لئے کیسی آنکھوں کی ٹھنڈک چھپا کر رکھی گئی ہے۔ یہ ان اعمال کا صلہ ہے جو وہ کرتے تھے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdxxi{بھلا جو مومن ہو وہ اس شخص کی طرح ہوسکتا ہے جو نافرمان ہو؟ دونوں برابر نہیں ہو سکتے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdxxii{جو لوگ ایمان لائے اور نیک عمل کرتے رہے اُن کے (رہنے کے) لئے باغ ہیں یہ مہمانی اُن کاموں کی جزا ہے جو وہ کرتے تھے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdxxiii{اور جنہوں نے نافرمانی کی اُن کے رہنے کے لئے دوزخ ہے جب چاہیں گے کہ اس میں سے نکل جائیں تو اس میں لوٹا دیئے جائیں گے۔ اور اُن سے کہا جائے گا کہ جس دوزخ کے عذاب کو تم جھوٹ سمجھتے تھے اس کے مزے چکھو\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdxxiv{اور ہم اُن کو (قیامت کے) بڑے عذاب کے سوا عذاب دنیا کا بھی مزہ چکھائیں گے۔ شاید (ہماری طرف) لوٹ آئیں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdxxv{اور اس شخص سے بڑھ کر ظالم کون جس کو اس کے پروردگار کی آیتوں سے نصیحت کی جائے تو وہ اُن سے منہ پھیر لے۔ ہم گنہگاروں سے ضرور بدلہ لینے والے ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdxxvi{اور ہم نے موسٰی کو کتاب دی تو تم اُن کے ملنے سے شک میں نہ ہونا اور ہم نے اس (کتاب) کو (یا موسٰی کو) بنی اسرائیل کے لئے (ذریعہ) ہدایت بنایا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdxxvii{اور ان میں سے ہم نے پیشوا بنائے تھے جو ہمارے حکم سے ہدایت کیا کرتے تھے۔ جب وہ صبر کرتے تھے اور وہ ہماری آیتوں پر یقین رکھتے تھے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdxxviii{بلاشبہ تمہارا پروردگار ان میں جن باتوں میں وہ اختلاف کرتے تھے۔ قیامت کے روز فیصلہ کر دے گا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdxxix{کیا اُن کو اس (امر) سے ہدایت نہ ہوئی کہ ہم نے اُن سے پہلے بہت سی اُمتوں کو جن کے مقامات سکونت میں یہ چلتے پھرتے ہیں ہلاک کر دیا۔ بیشک اس میں نشانیاں ہیں۔ تو یہ سنتے کیوں نہیں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdxxx{کیا اُنہوں نے نہیں دیکھا کہ ہم بنجر زمین کی طرف پانی رواں کرتے ہیں پھر اس سے کھیتی پیدا کرتے ہیں جس میں سے ان کے چوپائے بھی کھاتے ہیں اور وہ خود بھی (کھاتے ہیں) تو یہ دیکھتے کیوں نہیں۔\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdxxxi{اور کہتے ہیں اگر تم سچے ہو تو یہ فیصلہ کب ہوگا؟\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdxxxii{کہہ دو کہ فیصلے کے دن کافروں کو ان کا ایمان لانا کچھ بھی فائدہ نہ دے گا اور نہ اُن کو مہلت دی جائے گی\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiii{تو اُن سے منہ پھیر لو اور انتظار کرو یہ بھی انتظار کر رہے ہیں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdxxxiv{\basmalahur اے پیغمبر خدا سے ڈرتے رہنا اور کافروں اور منافقوں کا کہا نہ ماننا۔ بےشک خدا جاننے والا اور حکمت والا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdxxxv{اور جو (کتاب) تم کو تمہارے پروردگار کی طرف سے وحی کی جاتی ہے اُسی کی پیروی کئے جانا۔ بےشک خدا تمہارے سب عملوں سے خبردار ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvi{اور خدا پر بھروسہ رکھنا۔ اور خدا ہی کارساز کافی ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdxxxvii{خدا نے کسی آدمی کے پہلو میں دو دل نہیں بنائے۔ اور نہ تمہاری عورتوں کو جن کو تم ماں کہہ بیٹھتے ہو تمہاری ماں بنایا اور نہ تمہارے لے پالکوں کو تمہارے بیٹے بنایا۔ یہ سب تمہارے منہ کی باتیں ہیں۔ اور خدا تو سچی بات فرماتا ہے اور وہی سیدھا رستہ دکھاتا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdxxxviii{مومنو! لےپالکوں کو اُن کے (اصلی) باپوں کے نام سے پکارا کرو۔ کہ خدا کے نزدیک یہی بات درست ہے۔ اگر تم کو اُن کے باپوں کے نام معلوم نہ ہوں تو دین میں وہ تمہارے بھائی اور دوست ہیں اور جو بات تم سے غلطی سے ہوگئی ہو اس میں تم پر کچھ گناہ نہیں۔ لیکن جو قصد دلی سے کرو (اس پر مواخذہ ہے) اور خدا بخشنے والا مہربان ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdxxxix{پیغمبر مومنوں پر اُن کی جانوں سے بھی زیادہ حق رکھتے ہیں اور پیغمبر کی بیویاں اُن کی مائیں ہیں۔ اور رشتہ دار آپس میں کتاب الله کے رُو سے مسلمانوں اور مہاجروں سے ایک دوسرے (کے ترکے) کے زیادہ حقدار ہیں۔ مگر یہ کہ تم اپنے دوستوں سے احسان کرنا چاہو۔ (تو اور بات ہے) ۔ یہ حکم کتاب یعنی (قرآن) میں لکھ دیا گیا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdxl{اور جب ہم نے پیغمبروں سے عہد لیا اور تم سے نوح سے اور ابراہیم سے اور موسیٰ سے اور مریم کے بیٹے عیسیٰ سے۔ اور عہد بھی اُن سے پکّا لیا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdxli{تاکہ سچ کہنے والوں سے اُن کی سچائی کے بارے میں دریافت کرے اور اس نے کافروں کے لئے دکھ دینے والا عذاب تیار کر رکھا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdxlii{مومنو خدا کی اُس مہربانی کو یاد کرو جو (اُس نے) تم پر (اُس وقت کی) جب فوجیں تم پر (حملہ کرنے کو) آئیں۔ تو ہم نے اُن پر ہوا بھیجی اور ایسے لشکر (نازل کئے) جن کو تم دیکھ نہیں سکتے تھے۔ اور جو کام تم کرتے ہو خدا اُن کو دیکھ رہا ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdxliii{جب وہ تمہارے اُوپر اور نیچے کی طرف سے تم پر چڑھ آئے اور جب آنکھیں پھر گئیں اور دل (مارے دہشت کے) گلوں تک پہنچ گئے اور تم خدا کی نسبت طرح طرح کے گمان کرنے لگے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdxliv{وہاں مومن آزمائے گئے اور سخت طور پر ہلائے گئے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdxlv{اور جب منافق اور وہ لوگ جن کے دلوں میں بیماری ہے کہنے لگے کہ خدا اور اس کے رسول نے ہم سے محض دھوکے کا وعدہ کیا تھا\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdxlvi{اور جب اُن میں سے ایک جماعت کہتی تھی کہ اے اہل مدینہ (یہاں) تمہارے ٹھہرنے کا مقام نہیں تو لوٹ چلو۔ اور ایک گروہ ان میں سے پیغمبر سے اجازت مانگنے اور کہنے لگا کہ ہمارے گھر کھلے پڑے ہیں حالانکہ وہ کھلے نہیں تھے۔ وہ تو صرف بھاگنا چاہتے تھے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdxlvii{اور اگر (فوجیں) اطراف مدینہ سے ان پر آ داخل ہوں پھر اُن سے خانہ جنگی کے لئے کہا جائے تو (فوراً) کرنے لگیں اور اس کے لئے بہت ہی کم توقف کریں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdxlviii{حالانکہ پہلے خدا سے اقرار کر چکے تھے کہ پیٹھ نہیں پھریں گے۔ اور خدا سے (جو) اقرار (کیا جاتا ہے اُس کی) ضرور پرسش ہوگی\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdxlix{کہہ دو کہ اگر تم مرنے یا مارے سے بھاگتے ہو تو بھاگنا تم کو فائدہ نہیں دے گا اور اس وقت تم بہت ہی کم فائدہ اٹھاؤ گے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdl{کہہ دو کہ اگر خدا تمہارے ساتھ برائی کا ارادہ کرے تو کون تم کو اس سے بچا سکتا ہے یا اگر تم پر مہربانی کرنی چاہے تو (کون اس کو ہٹا سکتا ہے) اور یہ لوگ خدا کے سوا کسی کو نہ اپنا دوست پائیں گے اور نہ مددگار\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdli{خدا تم میں سے ان لوگوں کو بھی جانتا ہے جو (لوگوں کو) منع کرتے ہیں اور اپنے بھائیوں سے کہتے ہیں کہ ہمارے پاس چلے آؤ۔ اور لڑائی میں نہیں آتے مگر کم\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdlii{یہ اس لئے کہ) تمہارے بارے میں بخل کرتے ہیں۔ پھر جب ڈر (کا وقت) آئے تو تم ان کو دیکھو کہ تمہاری طرف دیکھ رہے ہیں (اور) اُن کی آنکھیں (اسی طرح) پھر رہی ہیں جیسے کسی کو موت سے غشی آرہی ہو۔ پھر جب خوف جاتا رہے تو تیز زبانوں کے ساتھ تمہارے بارے میں زبان درازی کریں اور مال میں بخل کریں۔ یہ لوگ (حقیقت میں) ایمان لائے ہی نہ تھے تو خدا نے ان کے اعمال برباد کر دیئے۔ اور یہ خدا کو آسان تھا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdliii{خوف کے سبب) خیال کرتے ہیں کہ فوجیں نہیں گئیں۔ اور اگر لشکر آجائیں تو تمنا کریں کہ (کاش) گنواروں میں جا رہیں (اور) تمہاری خبر پوچھا کریں۔ اور اگر تمہارے درمیان ہوں تو لڑائی نہ کریں مگر کم\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdliv{تم کو پیغمبر خدا کی پیروی (کرنی) بہتر ہے (یعنی) اس شخص کو جسے خدا (سے ملنے) اور روز قیامت (کے آنے) کی اُمید ہو اور وہ خدا کا ذکر کثرت سے کرتا ہو\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdlv{اور جب مومنوں نے (کافروں کے) لشکر کو دیکھا تو کہنے لگے یہ وہی ہے جس کا خدا اور اس کے پیغمبر نے ہم سے وعدہ کیا تھا اور خدا اور اس کے پیغمبر نے سچ کہا تھا۔ اور اس سے ان کا ایمان اور اطاعت اور زیادہ ہوگئی\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdlvi{مومنوں میں کتنے ہی ایسے شخص ہیں کہ جو اقرار اُنہوں نے خدا سے کیا تھا اس کو سچ کر دکھایا۔ تو ان میں بعض ایسے ہیں جو اپنی نذر سے فارغ ہوگئے اور بعض ایسے ہیں کہ انتظار کر رہے ہیں اور اُنہوں نے (اپنے قول کو) ذرا بھی نہیں بدلا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdlvii{تاکہ خدا سچّوں کو اُن کی سچائی کا بدلہ دے اور منافقوں کو چاہے تو عذاب دے اور (چاہے) تو اُن پر مہربانی کرے۔ بےشک خدا بخشنے والا مہربان ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdlviii{اور جو کافر تھے اُن کو خدا نے پھیر دیا وہ اپنے غصے میں (بھرے ہوئے تھے) کچھ بھلائی حاصل نہ کر سکے۔ اور خدا مومنوں کو لڑائی کے بارے میں کافی ہوا۔ اور خدا طاقتور (اور) زبردست ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdlix{اور اہل کتاب میں سے جنہوں نے اُن کی مدد کی تھی اُن کو اُن کے قلعوں سے اُتار دیا اور اُن کے دلوں میں دہشت ڈال دی۔ تو کتنوں کو تم قتل کر دیتے تھے اور کتنوں کو قید کرلیتے تھے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdlx{اور اُن کی زمین اور ان کے گھروں اور ان کے مال کا اور اس زمین کا جس میں تم نے پاؤں بھی نہیں رکھا تھا تم کو وارث بنا دیا۔ اور خدا ہر چیز پر قدرت رکھتا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdlxi{اے پیغمبر اپنی بیویوں سے کہہ دو کہ اگر تم دنیا کی زندگی اور اس کی زینت وآرائش کی خواستگار ہو تو آؤ میں تمہیں کچھ مال دوں اور اچھی طرح سے رخصت کردوں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdlxii{اور اگر تم خدا اور اس کے پیغمبر اور عاقبت کے گھر (یعنی بہشت) کی طلبگار ہو تو تم میں جو نیکوکاری کرنے والی ہیں اُن کے لئے خدا نے اجر عظیم تیار کر رکھا ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdlxiii{اے پیغمبر کی بیویو تم میں سے جو کوئی صریح ناشائستہ (الفاظ کہہ کر رسول الله کو ایذا دینے کی) حرکت کرے گی۔ اس کو دونی سزا دی جائے گی۔ اور یہ (بات) خدا کو آسان ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdlxiv{اور جو تم میں سے خدا اور اس کے رسول کی فرمانبردار رہے گی اور عمل نیک کرے گی۔ اس کو ہم دونا ثواب دیں گے اور اس کے لئے ہم نے عزت کی روزی تیار کر رکھی ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdlxv{اے پیغمبر کی بیویو تم اور عورتوں کی طرح نہیں ہو۔ اگر تم پرہیزگار رہنا چاہتی ہو تو کسی (اجنبی شخص سے) نرم نرم باتیں نہ کیا کرو تاکہ وہ شخص جس کے دل میں کسی طرح کا مرض ہے کوئی امید (نہ) پیدا کرے۔ اور ان دستور کے مطابق بات کیا کرو\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdlxvi{اور اپنے گھروں میں ٹھہری رہو اور جس طرح (پہلے) جاہلیت (کے دنوں) میں اظہار تجمل کرتی تھیں اس طرح زینت نہ دکھاؤ۔ اور نماز پڑھتی رہو اور زکوٰة دیتی رہو اور خدا اور اس کے رسول کی فرمانبرداری کرتی رہو۔ اے (پیغمبر کے) اہل بیت خدا چاہتا ہے کہ تم سے ناپاکی (کا میل کچیل) دور کردے اور تمہیں بالکل پاک صاف کردے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdlxvii{اور تمہارے گھروں میں جو خدا کی آیتیں پڑھی جاتی ہیں اور حکمت (کی باتیں سنائی جاتی ہیں) ان کو یاد رکھو۔ بےشک خدا باریک بیں اور باخبر ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdlxviii{جو لوگ خدا کے آگے سر اطاعت خم کرنے والے ہیں یعنی) مسلمان مرد اور مسلمان عورتیں اور مومن مرد اور مومن عورتیں اور فرماں بردار مرد اور فرماں بردار عورتیں اور راست باز مرد اور راست باز عورتیں اور صبر کرنے والے مرد اور صبر کرنے والی عورتیں اور فروتنی کرنے والے مرد اور فروتنی کرنے والی عورتیں اور خیرات کرنے والے مرد اور اور خیرات کرنے والی عورتیں اور روزے رکھنے والے مرد اور روزے رکھنے والی عورتیں اور اپنی شرمگاہوں کی حفاظت کرنے والے مرد اور حفاظت کرنے والی عورتیں اور خدا کو کثرت سے یاد کرنے والے مرد اور کثرت سے یاد کرنے والی عورتیں۔ کچھ شک نہیں کہ ان کے لئے خدا نے بخشش اور اجر عظیم تیار کر رکھا ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmdlxix{اور کسی مومن مرد اور مومن عورت کو حق نہیں ہے کہ جب خدا اور اس کا رسول کوئی امر مقرر کردیں تو وہ اس کام میں اپنا بھی کچھ اختیار سمجھیں۔ اور جو کوئی خدا اور اس کے رسول کی نافرمانی کرے وہ صریح گمراہ ہوگیا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmdlxx{اور جب تم اس شخص سے جس پر خدا نے احسان کیا اور تم نے بھی احسان کیا (یہ) کہتے تھے کہ اپنی بیوی کو اپنے پاس رہنے دے اور خدا سے ڈر اور تم اپنے دل میں وہ بات پوشیدہ کرتے تھے جس کو خدا ظاہر کرنے والا تھا اور تم لوگوں سے ڈرتے تھے۔ حالانکہ خدا ہی اس کا زیادہ مستحق ہے کہ اس سے ڈرو۔ پھر جب زید نے اس سے (کوئی) حاجت (متعلق) نہ رکھی (یعنی اس کو طلاق دے دی) تو ہم نے تم سے اس کا نکاح کردیا تاکہ مومنوں کے لئے ان کے منہ بولے بیٹوں کی بیویوں (کے ساتھ نکاح کرنے کے بارے) میں جب وہ ان سے اپنی حاجت (متعلق) نہ رکھیں (یعنی طلاق دے دیں) کچھ تنگی نہ رہے۔ اور خدا کا حکم واقع ہو کر رہنے والا تھا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmdlxxi{پیغمبر پر اس کام میں کچھ تنگی نہیں جو خدا نے ان کے لئے مقرر کردیا۔ اور جو لوگ پہلے گزر چکے ہیں ان میں بھی خدا کا یہی دستور رہا ہے۔ اور خدا کا حکم ٹھیر چکا ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmdlxxii{اور جو خدا کے پیغام (جوں کے توں) پہنچاتے اور اس سے ڈرتے ہیں اور خدا کے سوا کسی سے نہیں ڈرتے تھے۔ اور خدا ہی حساب کرنے کو کافی ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiii{محمدﷺ تمہارے مردوں میں سے کسی کے والد نہیں ہیں بلکہ خدا کے پیغمبر اور نبیوں (کی نبوت) کی مہر (یعنی اس کو ختم کردینے والے) ہیں اور خدا ہر چیز سے واقف ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmdlxxiv{اے اہل ایمان خدا کا بہت ذکر کیا کرو\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmdlxxv{اور صبح اور شام اس کی پاکی بیان کرتے رہو\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvi{وہی تو ہے جو تم پر رحمت بھیجتا ہے اور اس کے فرشتے بھی۔ تاکہ تم کو اندھیروں سے نکال کر روشنی کی طرف لے جائے۔ اور خدا مومنوں پر مہربان ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmdlxxvii{جس روز وہ اس سے ملیں گے ان کا تحفہ (خدا کی طرف سے) سلام ہوگا اور اس نے ان کے لئے بڑا ثواب تیار کر رکھا ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmdlxxviii{اے پیغمبر ہم نے تم کو گواہی دینے والا اور خوشخبری سنانے اور ڈرانے والا بنا کر بھیجا ہے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmdlxxix{اور خدا کی طرف بلانے والا اور چراغ روشن\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmdlxxx{اور مومنوں کو خوشخبری سنا دو کہ ان کے لئے خدا کی طرف سے بڑا فضل ہوگا\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxi{اور کافروں اور منافقوں کا کہا نہ ماننا اور نہ ان کے تکلیف دینے پر نظر کرنا اور خدا پر بھروسہ رکھنا۔ اور خدا ہی کارساز کافی ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxii{مومنو! جب تم مومن عورتوں سے نکاح کرکے ان کو ہاتھ لگانے (یعنی ان کے پاس جانے) سے پہلے طلاق دے دو تو تم کو کچھ اختیار نہیں کہ ان سے عدت پوری کراؤ۔ ان کو کچھ فائدہ (یعنی خرچ) دے کر اچھی طرح سے رخصت کردو\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiii{اے پیغمبر ہم نے تمہارے لئے تمہاری بیویاں جن کو تم نے ان کے مہر دے دیئے ہیں حلال کردی ہیں اور تمہاری لونڈیاں جو خدا نے تم کو (کفار سے بطور مال غنیمت) دلوائی ہیں اور تمہارے چچا کی بیٹیاں اور تمہاری پھوپھیوں کی بیٹیاں اور تمہارے ماموؤں کی بیٹیاں اور تمہاری خالاؤں کی بیٹیاں جو تمہارے ساتھ وطن چھوڑ کر آئی ہیں (سب حلال ہیں) اور کوئی مومن عورت اگر اپنے تئیں پیغمبر کو بخش دے (یعنی مہر لینے کے بغیر نکاح میں آنا چاہے) بشرطیکہ پیغمبر بھی ان سے نکاح کرنا چاہیں (وہ بھی حلال ہے لیکن) یہ اجازت (اے محمدﷺ) خاص تم ہی کو ہے سب مسلمانوں کو نہیں۔ ہم نے ان کی بیویوں اور لونڈیوں کے بارے میں جو (مہر واجب الادا) مقرر کردیا ہے ہم کو معلوم ہے (یہ) اس لئے (کیا گیا ہے) کہ تم پر کسی طرح کی تنگی نہ رہے۔ اور خدا بخشنے والا مہربان ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxiv{اور تم کو یہ بھی اختیار ہے کہ) جس بیوی کو چاہو علیحدہ رکھو اور جسے چاہو اپنے پاس رکھو۔ اور جس کو تم نے علیحدہ کردیا ہو اگر اس کو پھر اپنے پاس طلب کرلو تو تم پر کچھ گناہ نہیں۔ یہ (اجازت) اس لئے ہے کہ ان کی آنکھیں ٹھنڈی رہیں اور وہ غمناک نہ ہوں اور جو کچھ تم ان کو دو۔ اسے لے کر سب خوش رہیں۔ اور جو کچھ تمہارے دلوں میں ہے خدا اسے جانتا ہے۔ اور خدا جاننے والا اور بردبار ہے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxv{اے پیغمبر) ان کے سوا اور عورتیں تم کو جائز نہیں اور نہ یہ کہ ان بیویوں کو چھوڑ کر اور بیویاں کرو خواہ ان کا حسن تم کو (کیسا ہی) اچھا لگے مگر وہ جو تمہارے ہاتھ کا مال ہے (یعنی لونڈیوں کے بارے میں تم کو اختیار ہے) اور خدا ہر چیز پر نگاہ رکھتا ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvi{مومنو پیغمبر کے گھروں میں نہ جایا کرو مگر اس صورت میں کہ تم کو کھانے کے لئے اجازت دی جائے اور اس کے پکنے کا انتظار بھی نہ کرنا پڑے۔ لیکن جب تمہاری دعوت کی جائے تو جاؤ اور جب کھانا کھاچکو تو چل دو اور باتوں میں جی لگا کر نہ بیٹھ رہو۔ یہ بات پیغمبر کو ایذا دیتی ہے۔ اور وہ تم سے شرم کرتے ہیں (اور کہتے نہیں ہیں) لیکن خدا سچی بات کے کہنے سے شرم نہیں کرتا۔ اور جب پیغمبروں کی بیویوں سے کوئی سامان مانگو تو پردے کے باہر مانگو۔ یہ تمہارے اور ان کے دونوں کے دلوں کے لئے بہت پاکیزگی کی بات ہے۔ اور تم کو یہ شایاں نہیں کہ پیغمبر خدا کو تکلیف دو اور نہ یہ کہ ان کی بیویوں سے کبھی ان کے بعد نکاح کرو۔ بےشک یہ خدا کے نزدیک بڑا (گناہ کا کام) ہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxvii{اگر تم کسی چیز کو ظاہر کرو یا اس کو مخفی رکھو تو (یاد رکھو کہ) خدا ہر چیز سے باخبر ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxviii{عورتوں پر اپنے باپوں سے (پردہ نہ کرنے میں) کچھ گناہ نہیں اور نہ اپنے بیٹوں سے اور نہ اپنے بھائیوں سے اور نہ اپنے بھتیجوں سے اور نہ اپنے بھانجوں سے نہ اپنی (قسم کی) عورتوں سے اور نہ لونڈیوں سے۔ اور (اے عورتو) خدا سے ڈرتی رہو۔ بےشک خدا ہر چیز سے واقف ہے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmdlxxxix{خدا اور اس کے فرشتے پیغمبر پر درود بھیجتے ہیں۔ مومنو تم بھی ان پر دُرود اور سلام بھیجا کرو\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmdxc{جو لوگ خدا اور اس کے پیغمبر کو رنج پہنچاتے ہیں ان پر خدا دنیا اور آخرت میں لعنت کرتا ہے اور ان کے لئے اس نے ذلیل کرنے والا عذاب تیار کر رکھا ہے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmdxci{اور جو لوگ مومن مردوں اور مومن عورتوں کو ایسے کام (کی تہمت سے) جو انہوں نے نہ کیا ہو ایذا دیں تو انہوں نے بہتان اور صریح گناہ کا بوجھ اپنے سر پر رکھا\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmdxcii{اے پیغمبر اپنی بیویوں اور بیٹیوں اور مسلمانوں کی عورتوں سے کہہ دو کہ (باہر نکلا کریں تو) اپنے (مونہوں) پر چادر لٹکا (کر گھونگھٹ نکال) لیا کریں۔ یہ امر ان کے لئے موجب شناخت (وامتیاز) ہوگا تو کوئی ان کو ایذا نہ دے گا۔ اور خدا بخشنے والا مہربان ہے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmdxciii{اگر منافق اور وہ لوگ جن کے دلوں میں مرض ہے اور جو مدینے (کے شہر میں) بری بری خبریں اُڑایا کرتے ہیں (اپنے کردار) سے باز نہ آئیں گے تو ہم تم کو ان کے پیچھے لگا دیں گے پھر وہاں تمہارے پڑوس میں نہ رہ سکیں گے مگر تھوڑے دن\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmdxciv{وہ بھی) پھٹکارے ہوئے۔ جہاں پائے گئے پکڑے گئے اور جان سے مار ڈالے گئے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmdxcv{جو لوگ پہلے گزر چکے ہیں ان کے بارے میں بھی خدا کی یہی عادت رہی ہے۔ اور تم خدا کی عادت میں تغیر وتبدل نہ پاؤ گے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmdxcvi{لوگ تم سے قیامت کی نسبت دریافت کرتے ہیں (کہ کب آئے گی) کہہ دو کہ اس کا علم خدا ہی کو ہے۔ اور تمہیں کیا معلوم ہے شاید قیامت قریب ہی آگئی ہو\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmdxcvii{بےشک خدا نے کافروں پر لعنت کی ہے اور ان کے لئے (جہنم کی) آگ تیار کر رکھی ہے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmdxcviii{اس میں ابدا لآباد رہیں گے۔ نہ کسی کو دوست پائیں گے اور نہ مددگار\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmdxcix{جس دن ان کے منہ آگ میں الٹائے جائیں گے کہیں اے کاش ہم خدا کی فرمانبرداری کرتے اور رسول (خدا) کا حکم مانتے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmdc{اور کہیں گے کہ اے ہمارے پروردگار ہم نے اپنے سرداروں اور بڑے لوگوں کا کہا مانا تو انہوں نے ہم کو رستے سے گمراہ کردیا\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmdci{اے ہمارے پروردگار ان کو دگنا عذاب دے اور ان پر بڑی لعنت کر\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmdcii{مومنو تم ان لوگوں جیسے نہ ہونا جنہوں نے موسیٰ (کو عیب لگا کر) رنج پہنچایا تو خدا نے ان کو بےعیب ثابت کیا۔ اور وہ خدا کے نزدیک آبرو والے تھے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmdciii{مومنو خدا سے ڈرا کرو اور بات سیدھی کہا کرو\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmdciv{وہ تمہارے اعمال درست کردے گا اور تمہارے گناہ بخش دے گا۔ اور جو شخص خدا اور اس کے رسول کی فرمانبرداری کرے گا تو بےشک بڑی مراد پائے گا\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmdcv{ہم نے (بار) امانت کو آسمانوں اور زمین پر پیش کیا تو انہوں نے اس کے اٹھانے سے انکار کیا اور اس سے ڈر گئے۔ اور انسان نے اس کو اٹھا لیا۔ بےشک وہ ظالم اور جاہل تھا\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmdcvi{تاکہ خدا منافق مردوں اور منافق عورتوں اور مشرک مردوں اور مشرک عورتوں کو عذاب دے اور خدا مومن مردوں اور مومن عورتوں پر مہربانی کرے۔ اور خدا تو بخشنے والا مہربان ہے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmdcvii{\basmalahur سب تعریف خدا ہی کو (سزاوار) ہے (جو سب چیزوں کا مالک ہے یعنی) وہ کہ جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے سب اسی کا ہے اور آخرت میں بھی اسی کی تعریف ہے۔ اور وہ حکمت والا خبردار ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdcviii{جو کچھ زمین میں داخل ہوتا ہے اور جو اس میں سے نکلتا ہے اور جو آسمان سے اُترتا ہے اور جو اس پر چڑھتا ہے سب اس کو معلوم ہے۔ اور وہ مہربان (اور) بخشنے والا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdcix{اور کافر کہتے ہیں کہ (قیامت کی) گھڑی ہم پر نہیں آئے گی۔ کہہ دو کیوں نہیں (آئے گی) میرے پروردگار کی قسم وہ تم پر ضرور آکر رہے گی (وہ پروردگار) غیب کا جاننے والا (ہے) ذرہ بھر چیز بھی اس سے پوشیدہ نہیں (نہ) آسمانوں میں اور نہ زمین میں اور کوئی چیز ذرے سے چھوٹی یا بڑی ایسی نہیں مگر کتاب روشن میں (لکھی ہوئی) ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdcx{اس لئے کہ جو لوگ ایمان لائے اور عمل نیک کرتے رہے ان کو بدلہ دے۔ یہی ہیں جن کے لئے بخشش اور عزت کی روزی ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdcxi{اور جنہوں نے ہماری آیتوں میں کوشش کی کہ ہمیں ہرا دیں گے۔ ان کے لئے سخت درد دینے والے عذاب کی سزا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdcxii{اور جن لوگوں کو علم دیا گیا ہے وہ جانتے ہیں کہ جو (قرآن) تمہارے پروردگار کی طرف سے تم پر نازل ہوا ہے وہ حق ہے۔ اور (خدائے) غالب اور سزاوار تعریف کا رستہ بتاتا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdcxiii{اور کافر کہتے ہیں کہ بھلا ہم تمہیں ایسا آدمی بتائیں جو تمہیں خبر دیتا ہے کہ جب تم (مر کر) بالکل پارہ پارہ ہو جاؤ گے تو نئے سرے سے پیدا ہوگے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdcxiv{یا تو اس نے خدا پر جھوٹ باندھ لیا ہے۔ یا اسے جنون ہے۔ بات یہ ہے کہ جو لوگ آخرت پر ایمان نہیں رکھتے وہ آفت اور پرلے درجے کی گمراہی میں (مبتلا) ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdcxv{کیا انہوں نے اس کو نہیں دیکھا جو ان کے آگے اور پیچھے ہے یعنی آسمان اور زمین۔ اگر ہم چاہیں تو ان کو زمین میں دھنسا دیں یا ان پر آسمان کے ٹکڑے گرا دیں۔ اس میں ہر بندے کے لئے جو رجوع کرنے والا ہے ایک نشانی ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdcxvi{اور ہم نے داؤد کو اپنی طرف سے برتری بخشی تھی۔ اے پہاڑو ان کے ساتھ تسبیح کرو اور پرندوں کو (ان کا مسخر کردیا) اور ان کے لئے ہم نے لوہے کو نرم کردیا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdcxvii{کہ کشادہ زرہیں بناؤ اور کڑیوں کو اندازے سے جوڑو اور نیک عمل کرو۔ جو عمل تم کرتے ہو میں ان کو دیکھنے والا ہوں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdcxviii{اور ہوا کو (ہم نے) سلیمان کا تابع کردیا تھا اس کی صبح کی منزل ایک مہینے کی راہ ہوتی اور شام کی منزل بھی مہینے بھر کی ہوتی۔ اور ان کے لئے ہم نے تانبے کا چشمہ بہا دیا تھا اور جِنّوں میں سے ایسے تھے جو ان کے پروردگار کے حکم سے ان کے آگے کام کرتے تھے۔ اور جو کوئی ان میں سے ہمارے حکم سے پھرے گا اس کو ہم (جہنم کی) آگ کا مزہ چکھائیں گے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdcxix{وہ جو چاہتے یہ ان کے لئے بناتے یعنی قلعے اور مجسمے اور (بڑے بڑے) لگن جیسے تالاب اور دیگیں جو ایک ہی جگہ رکھی رہیں۔ اے داؤد کی اولاد (میرا) شکر کرو اور میرے بندوں میں شکرگزار تھوڑے ہیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdcxx{پھر جب ہم نے ان کے لئے موت کا حکم صادر کیا تو کسی چیز سے ان کا مرنا معلوم نہ ہوا مگر گھن کے کیڑے سے جو ان کے عصا کو کھاتا رہا۔ جب عصا گر پڑا تب جنوں کو معلوم ہوا (اور کہنے لگے) کہ اگر وہ غیب جانتے ہوتے تو ذلت کی تکلیف میں نہ رہتے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdcxxi{اہل) سبا کے لئے ان کے مقام بودوباش میں ایک نشانی تھی (یعنی) دو باغ (ایک) داہنی طرف اور (ایک) بائیں طرف۔ اپنے پروردگار کا رزق کھاؤ اور اس کا شکر کرو۔ (یہاں تمہارے رہنے کو یہ) پاکیزہ شہر ہے اور (وہاں بخشنے کو) خدائے غفار\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdcxxii{تو انہوں نے (شکرگزاری سے) منہ پھیر لیا پس ہم نے ان پر زور کا سیلاب چھوڑ دیا اور انہیں ان کے باغوں کے بدلے دو ایسے باغ دیئے جن کے میوے بدمزہ تھے اور جن میں کچھ تو جھاؤ تھا اور تھوڑی سی بیریاں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiii{یہ ہم نے ان کی ناشکری کی ان کو سزا دی۔ اور ہم سزا ناشکرے ہی کو دیا کرتے ہیں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdcxxiv{اور ہم نے ان کے اور (شام کی) ان بستیوں کے درمیان جن میں ہم نے برکت دی تھی (ایک دوسرے کے متصل) دیہات بنائے تھے جو سامنے نظر آتے تھے اور ان میں آمد ورفت کا اندازہ مقرر کردیا تھا کہ رات دن بےخوف وخطر چلتے رہو\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdcxxv{تو انہوں نے دعا کی کہ اے پروردگار ہماری مسافتوں میں بُعد (اور طول پیدا) کردے اور (اس سے) انہوں نے اپنے حق میں ظلم کیا تو ہم نے (انہیں نابود کرکے) ان کے افسانے بنادیئے اور انہیں بالکل منتشر کردیا۔ اس میں ہر صابر وشاکر کے لئے نشانیاں ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvi{اور شیطان نے ان کے بارے میں اپنا خیال سچ کر دکھایا کہ مومنوں کی ایک جماعت کے سوا وہ اس کے پیچھے چل پڑے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdcxxvii{اور اس کا ان پر کچھ زور نہ تھا مگر (ہمارا) مقصود یہ تھا کہ جو لوگ آخرت میں شک رکھتے ہیں ان سے ان لوگوں کو جو اس پر ایمان رکھتے تھے متمیز کردیں۔ اور تمہارا پروردگار ہر چیز پر نگہبان ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdcxxviii{کہہ دو کہ جن کو تم خدا کے سوا (معبود) خیال کرتے ہو ان کو بلاؤ۔ وہ آسمانوں اور زمین میں ذرہ بھر چیز کے بھی مالک نہیں ہیں اور نہ ان میں ان کی شرکت ہے اور نہ ان میں سے کوئی خدا کا مددگار ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdcxxix{اور خدا کے ہاں (کسی کے لئے) سفارش فائدہ نہ دے گی مگر اس کے لئے جس کے بارے میں وہ اجازت بخشے۔ یہاں تک کہ جب ان کے دلوں سے اضطراب دور کردیا جائے گا تو کہیں گے تمہارے پروردگار نے کیا فرمایا ہے۔ (فرشتے) کہیں گے کہ حق (فرمایا ہے) اور وہ عالی رتبہ اور گرامی قدر ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdcxxx{پوچھو کہ تم کو آسمانوں اور زمین سے کون رزق دیتا ہے؟ کہو کہ خدا اور ہم یا تم (یا تو) سیدھے رستے پر ہیں یا صریح گمراہی میں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxi{کہہ دو کہ نہ ہمارے گناہوں کی تم سے پرسش ہوگی اور نہ تمہارے اعمال کی ہم سے پرسش ہوگی\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxii{کہہ دو کہ ہمارا پروردگار ہم کو جمع کرے گا پھر ہمارے درمیان انصاف کے ساتھ فیصلہ کردے گا۔ اور وہ خوب فیصلہ کرنے والا اور صاحب علم ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiii{کہو کہ مجھے وہ لوگ تو دکھاؤ جن کو تم نے شریک (خدا) بنا کر اس کے ساتھ ملا رکھا ہے۔ کوئی نہیں بلکہ وہی (اکیلا) خدا غالب (اور) حکمت والا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxiv{اور (اے محمدﷺ) ہم نے تم کو تمام لوگوں کے لئے خوشخبری سنانے والا اور ڈرانے والا بنا کر بھیجا ہے لیکن اکثر لوگ نہیں جانتے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxv{اور کہتے ہیں اگر تم سچ کہتے ہو تو یہ (قیامت کا) وعدہ کب وقوع میں آئے گا\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvi{کہہ دو کہ تم سے ایک دن کا وعدہ ہے جس سے نہ ایک گھڑی پیچھے رہوگے اور نہ آگے بڑھو گے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxvii{اور جو کافر ہیں وہ کہتے ہیں کہ ہم نہ تو اس قرآن کو مانیں گے اور نہ ان (کتابوں) کو جو ان سے پہلے کی ہیں اور کاش (ان) ظالموں کو تم اس وقت دیکھو جب یہ اپنے پروردگار کے سامنے کھڑے ہوں گے اور ایک دوسرے سے ردوکد کر رہے ہوں گے۔ جو لوگ کمزور سمجھے جاتے تھے وہ بڑے لوگوں سے کہیں گے کہ اگر تم نہ ہوتے تو ہم ضرور مومن ہوجاتے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxviii{بڑے لوگ کمزوروں سے کہیں گے کہ بھلا ہم نے تم کو ہدایت سے جب وہ تمہارے پاس آچکی تھی روکا تھا؟ (نہیں) بلکہ تم ہی گنہگار تھے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdcxxxix{اور کمزور لوگ بڑے لوگوں سے کہیں گے (نہیں) بلکہ (تمہاری) رات دن کی چالوں نے (ہمیں روک رکھا تھا) جب تم ہم سے کہتے تھے کہ ہم خدا سے کفر کریں اور اس کا شریک بنائیں۔ اور جب وہ عذاب کو دیکھیں گے تو دل میں پشیمان ہوں گے۔ اور ہم کافروں کی گردنوں میں طوق ڈال دیں گے۔ بس جو عمل وہ کرتے تھے ان ہی کا ان کو بدلہ ملے گا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdcxl{اور ہم نے کسی بستی میں کوئی ڈرانے والا نہیں بھیجا مگر وہاں کے خوش حال لوگوں نے کہا کہ جو چیز تم دے کر بھیجے گئے ہو ہم اس کے قائل نہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdcxli{اور (یہ بھی) کہنے لگے کہ ہم بہت سا مال اور اولاد رکھتے ہیں اور ہم کو عذاب نہیں ہوگا\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmdcxlii{کہہ دو کہ میرا رب جس کے لئے چاہتا ہے روزی فراخ کردیتا ہے (اور جس کے لئے چاہتا ہے) تنگ کردیتا ہے لیکن اکثر لوگ نہیں جانتے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmdcxliii{اور تمہارا مال اور اولاد ایسی چیز نہیں کہ تم کو ہمارا مقرب بنا دیں۔ ہاں (ہمارا مقرب وہ ہے) جو ایمان لایا اور عمل نیک کرتا رہا۔ ایسے ہی لوگوں کو ان کے اعمال کے سبب دگنا بدلہ ملے گا اور وہ خاطر جمع سے بالاخانوں میں بیٹھے ہوں گے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmdcxliv{جو لوگ ہماری آیتوں میں کوشش کرتے ہیں کہ ہمیں ہرا دیں وہ عذاب میں حاضر کئے جائیں گے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmdcxlv{کہہ دو کہ میرا پروردگار اپنے بندوں میں سے جس کے لئے چاہتا ہے روزی فراخ کردیتا ہے اور (جس کے لئے چاہتا ہے) تنگ کردیتا ہے اور تم جو چیز خرچ کرو گے وہ اس کا (تمہیں) عوض دے گا۔ اور وہ سب سے بہتر رزق دینے والا ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvi{اور جس دن وہ ان سب کو جمع کرے گا پھر فرشتوں سے فرمائے گا کیا یہ لوگ تم کو پوجا کرتے تھے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmdcxlvii{وہ کہیں گے تو پاک ہے تو ہی ہمارا دوست ہے۔ نہ یہ۔ بلکہ یہ جِنّات کو پوجا کرتے تھے۔ اور اکثر انہی کو مانتے تھے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmdcxlviii{تو آج تم میں سے کوئی کسی کو نفع اور نقصان پہنچانے کا اختیار نہیں رکھتا۔ اور ہم ظالموں سے کہیں گے کہ دوزخ کے عذاب کا جس کو تم جھوٹ سمجھتے تھے مزہ چکھو\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmdcxlix{اور جب ان کو ہماری روشن آیتیں پڑھ کر سنائی جاتی ہیں تو کہتے ہیں یہ ایک (ایسا) شخص ہے جو چاہتا ہے کہ جن چیزوں کی تمہارے باپ دادا پرستش کیا کرتے تھے ان سے تم کو روک دے اور (یہ بھی) کہتے ہیں کہ یہ (قرآن) محض جھوٹ ہے (جو اپنی طرف سے) بنا لیا گیا ہے۔ اور کافروں کے پاس جب حق آیا تو اس کے بارے میں کہنے لگے کہ یہ تو صریح جادو ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmdcl{اور ہم نے نہ تو ان (مشرکوں) کو کتابیں دیں جن کو یہ پڑھتے ہیں اور نہ تم سے پہلے ان کی طرف کوئی ڈرانے والا بھیجا مگر انہوں نے تکذیب کی\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmdcli{اور جو لوگ ان سے پہلے تھے انہوں نے تکذیب کی تھی اور جو کچھ ہم نے ان کو دیا تھا یہ اس کے دسویں حصے کو بھی نہیں پہنچے تو انہوں نے میرے پیغمبروں کو جھٹلایا۔ سو میرا عذاب کیسا ہوا\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmdclii{کہہ دو کہ میں تمہیں صرف ایک بات کی نصیحت کرتا ہوں کہ تم خدا کے لئے دو دو اور اکیلے اکیلے کھڑے ہوجاؤ پھر غور کرو۔ تمہارے رفیق کو سودا نہیں وہ تم کو عذاب سخت (کے آنے) سے پہلے صرف ڈرانے والے ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmdcliii{کہہ دو کہ میں نے تم سے کچھ صلہ مانگا ہو تو وہ تم ہی کو (مبارک رہے) ۔ میرا صلہ خدا ہی کے ذمے ہے۔ اور وہ ہر چیز سے خبردار ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmdcliv{کہہ دو کہ میرا پروردگار اوپر سے حق اُتارتا ہے (اور وہ) غیب کی باتوں کا جاننے والا ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmdclv{کہہ دو کہ حق آچکا اور (معبود) باطل نہ تو پہلی بار پیدا کرسکتا ہے اور نہ دوبارہ پیدا کرے گا\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmdclvi{کہہ دو کہ اگر میں گمراہ ہوں تو میری گمراہی کا ضرر مجھی کو ہے۔ اور اگر ہدایت پر ہوں تو یہ اس کا طفیل ہے جو میرا پروردگار میری طرف وحی بھیجتا ہے۔ بےشک وہ سننے والا (اور) نزدیک ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmdclvii{اور کاش تم دیکھو جب یہ گھبرا جائیں گے تو (عذاب سے) بچ نہیں سکیں گے اور نزدیک ہی سے پکڑ لئے جائیں گے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmdclviii{اور کہیں گے کہ ہم اس پر ایمان لے آئے اور (اب) اتنی دور سے ان کا ہاتھ ایمان کے لینے کو کیونکر پہنچ سکتا ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmdclix{اور پہلے تو اس سے انکار کرتے رہے اور بن دیکھے دور ہی سے (ظن کے) تیر چلاتے رہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmdclx{اور ان میں اور ان کی خواہش کی چیزوں میں پردہ حائل کردیا گیا جیسا کہ پہلے ان کے ہم جنسوں سے کیا گیا وہ بھی الجھن میں ڈالنے والے شک میں پڑے ہوئے تھے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmdclxi{\basmalahur سب تعریف خدا ہی کو (سزاوار ہے) جو آسمانوں اور زمین کا پیدا کرنے والا (اور) فرشتوں کو قاصد بنانے والا ہے جن کے دو دو اور تین تین اور چار چار پر ہیں۔ وہ (اپنی) مخلوقات میں جو چاہتا ہے بڑھاتا ہے۔ بےشک خدا ہر چیز پر قادر ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdclxii{خدا جو اپنی رحمت (کا دروازہ) کھول دے تو کوئی اس کو بند کرنے والا نہیں۔ اور جو بند کردے تو اس کے بعد کوئی اس کو کھولنے والا نہیں۔ اور وہ غالب حکمت والا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdclxiii{لوگو خدا کے جو تم پر احسانات ہیں ان کو یاد کرو۔ کیا خدا کے سوا کوئی اور خالق (اور رازق ہے) جو تم کو آسمان اور زمین سے رزق دے۔ اس کے سوا کوئی معبود نہیں پس تم کہاں بہکے پھرتے ہو؟\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdclxiv{اور (اے پیغمبر) اگر یہ لوگ تم کو جھٹلائیں تو تم سے پہلے بھی پیغمبر جھٹلائے گئے ہیں۔ اور (سب) کام خدا ہی کی طرف لوٹائے جائیں گے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdclxv{لوگو خدا کا وعدہ سچا ہے۔ تو تم کو دنیا کی زندگی دھوکے میں نہ ڈال دے اور نہ (شیطان) فریب دینے والا تمہیں فریب دے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdclxvi{شیطان تمہارا دشمن ہے تم بھی اسے دشمن ہی سمجھو۔ وہ اپنے (پیروؤں کے) گروہ کو بلاتا ہے تاکہ دوزخ والوں میں ہوں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdclxvii{جہنوں نے کفر کیا ان کے لئے سخت عذاب ہے۔ اور جو ایمان لائے اور عمل نیک کرتے رہے ان کے لئے بخشش اور بڑا ثواب ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdclxviii{بھلا جس شخص کو اس کے اعمال بد آراستہ کرکے دکھائے جائیں اور وہ ان کو عمدہ سمجھنے لگے تو (کیا وہ نیکوکار آدمی جیسا ہوسکتا ہے) ۔ بےشک خدا جس کو چاہتا ہے گمراہ کرتا ہے اور جس کو چاہتا ہے ہدایت دیتا ہے۔ تو ان لوگوں پر افسوس کرکے تمہارا دم نہ نکل جائے۔ یہ جو کچھ کرتے ہیں خدا اس سے واقف ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdclxix{اور خدا ہی تو ہے جو ہوائیں چلاتا ہے اور وہ بادل کو اُبھارتی ہیں پھر ہم ان کو ایک بےجان شہر کی طرف چلاتے ہیں۔ پھر اس سے زمین کو اس کے مرنے کے بعد زندہ کردیتے ہیں۔ اسی طرح مردوں کو جی اُٹھنا ہوگا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdclxx{جو شخص عزت کا طلب گار ہے تو عزت تو سب خدا ہی کی ہے۔ اسی کی طرف پاکیزہ کلمات چڑھتے ہیں اور نیک عمل اس کو بلند کرتے ہیں۔ اور جو لوگ برے برے مکر کرتے ہیں ان کے لئے سخت عذاب ہے۔ اور ان کا مکر نابود ہوجائے گا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdclxxi{اور خدا ہی نے تم کو مٹی سے پیدا کیا پھر نطفے سے پھر تم کو جوڑا جوڑا بنا دیا۔ اور کوئی عورت نہ حاملہ ہوتی ہے اور نہ جنتی ہے مگر اس کے علم سے۔ اور نہ کسی بڑی عمر والے کو عمر زیادہ دی جاتی ہے اور نہ اس کی عمر کم کی جاتی ہے مگر (سب کچھ) کتاب میں (لکھا ہوا) ہے۔ بےشک یہ خدا کو آسان ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdclxxii{اور دونوں دریا (مل کر) یکساں نہیں ہوجاتے۔ یہ تو میٹھا ہے پیاس بجھانے والا۔ جس کا پانی خوشگوار ہے اور یہ کھاری ہے کڑوا۔ اور سب سے تم تازہ گوشت کھاتے ہو اور زیور نکالتے ہو جسے پہنتے ہو۔ اور تم دریا میں کشتیوں کو دیکھتے ہو کہ (پانی کو) پھاڑتی چلی آتی ہیں تاکہ تم اس کے فضل سے (معاش) تلاش کرو اور تاکہ شکر کرو\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiii{وہی رات کو دن میں داخل کرتا اور (وہی) دن کو رات میں داخل کرتا ہے اور اسی نے سورج اور چاند کو کام میں لگا دیا ہے۔ ہر ایک ایک وقت مقرر تک چل رہا ہے۔ یہی خدا تمہارا پروردگار ہے اسی کی بادشاہی ہے۔ اور جن لوگوں کو تم اس کے سوا پکارتے ہو وہ کھجور کی گٹھلی کے چھلکے کے برابر بھی تو (کسی چیز کے) مالک نہیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdclxxiv{اگر تم ان کو پکارو تو وہ تمہاری پکار نہ سنیں اور اگر سن بھی لیں تو تمہاری بات کو قبول نہ کرسکیں۔ اور قیامت کے دن تمہارے شرک سے انکار کردیں گے۔ اور (خدائے) باخبر کی طرح تم کو کوئی خبر نہیں دے گا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdclxxv{لوگو تم (سب) خدا کے محتاج ہو اور خدا بےپروا سزاوار (حمد وثنا) ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvi{اگر چاہے تو تم کو نابود کردے اور نئی مخلوقات لا آباد کرے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdclxxvii{اور یہ خدا کو کچھ مشکل نہیں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdclxxviii{اور کوئی اٹھانے والا دوسرے کا بوجھ نہ اٹھائے گا۔ اور کوئی بوجھ میں دبا ہوا اپنا بوجھ بٹانے کو کسی کو بلائے تو کوئی اس میں سے کچھ نہ اٹھائے گا اگرچہ قرابت دار ہی ہو۔ (اے پیغمبر) تم انہی لوگوں کو نصیحت کرسکتے ہو جو بن دیکھے اپنے پروردگار سے ڈرتے اور نماز بالالتزام پڑھتے ہیں۔ اور جو شخص پاک ہوتا ہے اپنے ہی لئے پاک ہوتا ہے۔ اور (سب کو) خدا ہی کی طرف لوٹ کر جانا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdclxxix{اور اندھا اور آنکھ والا برابر نہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdclxxx{اور نہ اندھیرا اور روشنی\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxi{اور نہ سایہ اور دھوپ\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxii{اور نہ زندے اور مردے برابر ہوسکتے ہیں۔ خدا جس کو چاہتا ہے سنا دیتا ہے۔ اور تم ان کو جو قبروں میں مدفون ہیں نہیں سنا سکتے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiii{تم تو صرف ڈرانے والے ہو\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxiv{ہم نے تم کو حق کے ساتھ خوشخبری سنانے والا اور ڈرانے والا بھیجا ہے۔ اور کوئی اُمت نہیں مگر اس میں ہدایت کرنے والا گزر چکا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxv{اور اگر یہ تمہاری تکذیب کریں تو جو لوگ ان سے پہلے تھے وہ بھی تکذیب کرچکے ہیں ان کے پاس ان کے پیغمبر نشانیاں اور صحیفے اور روشن کتابیں لے لے کر آتے رہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvi{پھر میں نے کافروں کو پکڑ لیا سو (دیکھ لو کہ) میرا عذاب کیسا ہوا\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxvii{کیا تم نے نہیں دیکھا کہ خدا نے آسمان سے مینہ برسایا۔ تو ہم نے اس سے طرح طرح کے رنگوں کے میوے پیدا کئے۔ اور پہاڑوں میں سفید اور سرخ رنگوں کے قطعات ہیں اور (بعض) کالے سیاہ ہیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxviii{انسانوں اور جانوروں اور چارپایوں کے بھی کئی طرح کے رنگ ہیں۔ خدا سے تو اس کے بندوں میں سے وہی ڈرتے ہیں جو صاحب علم ہیں۔ بےشک خدا غالب (اور) بخشنے والا ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdclxxxix{جو لوگ خدا کی کتاب پڑھتے اور نماز کی پابندی کرتے ہیں اور جو کچھ ہم نے ان کو دیا ہے اس میں سے پوشیدہ اور ظاہر خرچ کرتے ہیں وہ اس تجارت (کے فائدے) کے امیدوار ہیں جو کبھی تباہ نہیں ہوگی\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdcxc{کیونکہ خدا ان کو پورا پورا بدلہ دے گا اور اپنے فضل سے کچھ زیادہ بھی دے گا۔ وہ تو بخشنے والا (اور) قدردان ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdcxci{اور یہ کتاب جو ہم نے تمہاری طرف بھیجی ہے برحق ہے۔ اور ان (کتابوں) کی تصدیق کرتی ہے جو اس سے پہلے کی ہیں۔ بےشک خدا اپنے بندوں سے خبردار (اور ان کو) دیکھنے والا ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdcxcii{پھر ہم نے ان لوگوں کو کتاب کا وارث ٹھیرایا جن کو اپنے بندوں میں سے برگزیدہ کیا۔ تو کچھ تو ان میں سے اپنے آپ پر ظلم کرتے ہیں۔ اور کچھ میانہ رو ہیں۔ اور کچھ خدا کے حکم سے نیکیوں میں آگے نکل جانے والے ہیں۔ یہی بڑا فضل ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdcxciii{ان لوگوں کے لئے) بہشتِ جاودانی (ہیں) جن میں وہ داخل ہوں گے۔ وہاں ان کو سونے کے کنگن اور موتی پہنائے جائیں گے۔ اور ان کی پوشاک ریشمی ہوگی\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdcxciv{وہ کہیں گے کہ خدا کا شکر ہے جس نے ہم سے غم دور کیا۔ بےشک ہمارا پروردگار بخشنے والا (اور) قدردان ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdcxcv{جس نے ہم کو اپنے فضل سے ہمیشہ کے رہنے کے گھر میں اُتارا۔ یہاں نہ تو ہم کو رنج پہنچے گا اور نہ ہمیں تکان ہی ہوگی\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvi{اور جن لوگوں نے کفر کیا ان کے لئے دوزخ کی آگ ہے۔ نہ انہیں موت آئے گی کہ مرجائیں اور نہ ان کا عذاب ہی ان سے ہلکا کیا جائے گا۔ ہم ہر ایک ناشکرے کو ایسا ہی بدلہ دیا کرتے ہیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmdcxcvii{وہ اس میں چلائیں گے کہ اے پروردگار ہم کو نکال لے (اب) ہم نیک عمل کیا کریں گے۔ نہ وہ جو (پہلے) کرتے تھے۔ کیا ہم نے تم کو اتنی عمر نہیں دی تھی کہ اس میں جو سوچنا چاہتا سوچ لیتا اور تمہارے پاس ڈرانے والا بھی آیا۔ تو اب مزے چکھو۔ ظالموں کا کوئی مددگار نہیں\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmdcxcviii{بےشک خدا ہی آسمانوں اور زمین کی پوشیدہ باتوں کا جاننے والا ہے۔ وہ تو دل کے بھیدوں تک سے واقف ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmdcxcix{وہی تو ہے جس نے تم کو زمین میں (پہلوں کا) جانشین بنایا۔ تو جس نے کفر کیا اس کے کفر کا ضرر اسی کو ہے۔ اور کافروں کے حق میں ان کے کفر سے پروردگار کے ہاں ناخوشی ہی بڑھتی ہے اور کافروں کو ان کا کفر نقصان ہی زیادہ کرتا ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmdcc{بھلا تم نے اپنے شریکوں کو دیکھا جن کو تم خدا کے سوا پکارتے ہو۔ مجھے دکھاؤ کہ انہوں نے زمین سے کون سی چیز پیدا کی ہے یا (بتاؤ کہ) آسمانوں میں ان کی شرکت ہے۔ یا ہم نے ان کو کتاب دی ہے تو وہ اس کی سند رکھتے ہیں (ان میں سے کوئی بات بھی نہیں) بلکہ ظالم جو ایک دوسرے کو وعدہ دیتے ہیں محض فریب ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmdcci{خدا ہی آسمانوں اور زمین کو تھامے رکھتا ہے کہ ٹل نہ جائیں۔ اگر وہ ٹل جائیں تو خدا کے سوا کوئی ایسا نہیں جو ان کو تھام سکے۔ بےشک وہ بردبار (اور) بخشنے والا ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmdccii{اور یہ خدا کی سخت سخت قسمیں کھاتے ہیں کہ اگر ان کے پاس کوئی ہدایت کرنے والا آئے تو ہر ایک اُمت سے بڑھ کر ہدایت پر ہوں۔ مگر جب ان کے پاس ہدایت کرنے والا آیا تو اس سے ان کو نفرت ہی بڑھی\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmdcciii{یعنی (انہوں نے) ملک میں غرور کرنا اور بری چال چلنا (اختیار کیا) اور بری چال کا وبال اس کے چلنے والے ہی پر پڑتا ہے۔ یہ اگلے لوگوں کی روش کے سوا اور کسی چیز کے منتظر نہیں۔ سو تم خدا کی عادت میں ہرگز تبدل نہ پاؤ گے۔ اور خدا کے طریقے میں کبھی تغیر نہ دیکھو گے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmdcciv{کیا انہوں نے زمین میں کبھی سیر نہیں کی تاکہ دیکھتے کہ جو لوگ ان سے پہلے تھے ان کا انجام کیا ہوا حالانکہ وہ ان سے قوت میں بہت زیادہ تھے۔ اور خدا ایسا نہیں کہ آسمانوں اور زمین میں کوئی چیز اس کو عاجز کرسکے۔ وہ علم والا (اور) قدرت والا ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmdccv{اور اگر خدا لوگوں کو ان کے اعمال کے سبب پکڑنے لگتا۔ تو روئے زمین پر ایک چلنے پھرنے والے کو نہ چھوڑتا۔ لیکن وہ ان کو ایک وقت مقرر تک مہلت دیئے جاتا ہے۔ سو جب ان کا وقت آجائے گا تو (ان کے اعمال کا بدلہ دے گا) خدا تو اپنے بندوں کو دیکھ رہا ہے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmdccvi{\basmalahur یٰسٓ\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdccvii{قسم ہے قرآن کی جو حکمت سے بھرا ہوا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdccviii{اے محمدﷺ) بےشک تم پیغمبروں میں سے ہو\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdccix{سیدھے رستے پر\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdccx{یہ خدائے) غالب (اور) مہربان نے نازل کیا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdccxi{تاکہ تم ان لوگوں کو جن کے باپ دادا کو متنبہ نہیں کیا گیا تھا متنبہ کردو وہ غفلت میں پڑے ہوئے ہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdccxii{ان میں سے اکثر پر (خدا کی) بات پوری ہوچکی ہے سو وہ ایمان نہیں لائیں گے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdccxiii{ہم نے ان کی گردنوں میں طوق ڈال رکھے ہیں اور وہ ٹھوڑیوں تک (پھنسے ہوئے ہیں) تو ان کے سر اُلل رہے ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdccxiv{اور ہم نے ان کے آگے بھی دیوار بنا دی اور ان کے پیچھے بھی۔ پھر ان پر پردہ ڈال دیا تو یہ دیکھ نہیں سکتے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdccxv{اور تم ان کو نصیحت کرو یا نہ کرو ان کے لئے برابر ہے وہ ایمان نہیں لانے کے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdccxvi{تم تو صرف اس شخص کو نصیحت کرسکتے ہو جو نصیحت کی پیروی کرے اور خدا سے غائبانہ ڈرے سو اس کو مغفرت اور بڑے ثواب کی بشارت سنا دو\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdccxvii{بےشک ہم مردوں کو زندہ کریں گے اور جو کچھ وہ آگے بھیج چکے اور (جو) ان کے نشان پیچھے رہ گئے ہم ان کو قلمبند کرلیتے ہیں۔ اور ہر چیز کو ہم نے کتاب روشن (یعنی لوح محفوظ) میں لکھ رکھا ہے۔\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdccxviii{اور ان سے گاؤں والوں کا قصہ بیان کرو جب ان کے پاس پیغمبر آئے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdccxix{یعنی) جب ہم نے ان کی طرف دو (پیغمبر) بھیجے تو انہوں نے ان کو جھٹلایا۔ پھر ہم نے تیسرے سے تقویت دی تو انہوں نے کہا کہ ہم تمہاری طرف پیغمبر ہو کر آئے ہیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdccxx{وہ بولے کہ تم (اور کچھ) نہیں مگر ہماری طرح کے آدمی (ہو) اور خدا نے کوئی چیز نازل نہیں کی تم محض جھوٹ بولتے ہو\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdccxxi{انہوں نے کہا کہ ہمارا پروردگار جانتا ہے کہ ہم تمہاری طرف (پیغام دے کر) بھیجے گئے ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdccxxii{اور ہمارے ذمے تو صاف صاف پہنچا دینا ہے اور بس\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiii{وہ بولے کہ ہم تم کو نامبارک سمجھتے ہیں۔ اگر تم باز نہ آؤ گے تو ہم تمہیں سنگسار کردیں گے اور تم کو ہم سے دکھ دینے والا عذاب پہنچے گا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdccxxiv{انہوں نے کہا کہ تمہاری نحوست تمہارے ساتھ ہے۔ کیا اس لئے کہ تم کو نصیحت کی گئی۔ بلکہ تم ایسے لوگ ہو جو حد سے تجاوز کر گئے ہو\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdccxxv{اور شہر کے پرلے کنارے سے ایک آدمی دوڑتا ہوا آیا کہنے لگا کہ اے میری قوم پیغمبروں کے پیچھے چلو\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvi{ایسوں کے جو تم سے صلہ نہیں مانگتے اور وہ سیدھے رستے پر ہیں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdccxxvii{اور مجھے کیا ہے میں اس کی پرستش نہ کروں جس نے مجھے پیدا کیا اور اسی کی طرف تم کو لوٹ کر جانا ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdccxxviii{کیا میں ان کو چھوڑ کر اوروں کو معبود بناؤں؟ اگر خدا میرے حق میں نقصان کرنا چاہے تو ان کی سفارش مجھے کچھ بھی فائدہ نہ دے سکے اور نہ وہ مجھ کو چھڑا ہی سکیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdccxxix{تب تو میں صریح گمراہی میں مبتلا ہوگیا\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdccxxx{میں تمہارے پروردگار پر ایمان لایا ہوں سو میری بات سن رکھو\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxi{حکم ہوا کہ بہشت میں داخل ہوجا۔ بولا کاش! میری قوم کو خبر ہو\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxii{کہ خدا نے مجھے بخش دیا اور عزت والوں میں کیا\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiii{اور ہم نے اس کے بعد اس کی قوم پر کوئی لشکر نہیں اُتارا اور نہ ہم اُتارنے والے تھے ہی\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxiv{وہ تو صرف ایک چنگھاڑ تھی (آتشین) سو وہ (اس سے) ناگہاں بجھ کر رہ گئے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxv{بندوں پر افسوس ہے کہ ان کے پاس کوئی پیغمبر نہیں آتا مگر اس سے تمسخر کرتے ہیں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvi{کیا انہوں نے نہیں دیکھا کہ ہم نے ان سے پہلے بہت سے لوگوں کو ہلاک کردیا تھا اب وہ ان کی طرف لوٹ کر نہیں آئیں گے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxvii{اور سب کے سب ہمارے روبرو حاضر کيے جائیں گے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxviii{اور ایک نشانی ان کے لئے زمین مردہ ہے کہ ہم نے اس کو زندہ کیا اور اس میں سے اناج اُگایا۔ پھر یہ اس میں سے کھاتے ہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdccxxxix{اور اس میں کھجوروں اور انگوروں کے باغ پیدا کیے اور اس میں چشمے جاری کردیئے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdccxl{تاکہ یہ ان کے پھل کھائیں اور ان کے ہاتھوں نے تو ان کو نہیں بنایا تو پھر یہ شکر کیوں نہیں کرتے؟\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmdccxli{وہ خدا پاک ہے جس نے زمین کی نباتات کے اور خود ان کے اور جن چیزوں کی ان کو خبر نہیں سب کے جوڑے بنائے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmdccxlii{اور ایک نشانی ان کے لئے رات ہے کہ اس میں سے ہم دن کو کھینچ لیتے ہیں تو اس وقت ان پر اندھیرا چھا جاتا ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmdccxliii{اور سورج اپنے مقرر رستے پر چلتا رہتا ہے۔ یہ (خدائے) غالب اور دانا کا (مقرر کیا ہوا) اندازہ ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmdccxliv{اور چاند کی بھی ہم نے منزلیں مقرر کردیں یہاں تک کہ (گھٹتے گھٹتے) کھجور کی پرانی شاخ کی طرح ہو جاتا ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmdccxlv{نہ تو سورج ہی سے ہوسکتا ہے کہ چاند کو جا پکڑے اور نہ رات ہی دن سے پہلے آسکتی ہے۔ اور سب اپنے اپنے دائرے میں تیر رہے ہیں\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvi{اور ایک نشانی ان کے لئے یہ ہے کہ ہم نے ان کی اولاد کو بھری ہوئی کشتی میں سوار کیا\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmdccxlvii{اور ان کے لئے ویسی ہی اور چیزیں پیدا کیں جن پر وہ سوار ہوتے ہیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmdccxlviii{اور اگر ہم چاہیں تو ان کو غرق کردیں۔ پھر نہ تو ان کا کوئی فریاد رس ہوا اور نہ ان کو رہائی ملے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmdccxlix{مگر یہ ہماری رحمت اور ایک مدت تک کے فائدے ہیں\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmdccl{اور جب ان سے کہا جاتا ہے کہ جو تمہارے آگے اور جو تمہارے پیچھے ہے اس سے ڈرو تاکہ تم پر رحم کیا جائے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmdccli{اور ان کے پاس ان کے پروردگار کی کوئی نشانی نہیں آتی مگر اس سے منہ پھیر لیتے ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmdcclii{اور جب ان سے کہا جاتا ہے کہ جو رزق خدا نے تم کو دیا ہے اس میں سے خرچ کرو۔ تو کافر مومنوں سے کہتے ہیں کہ بھلا ہم ان لوگوں کو کھانا کھلائیں جن کو اگر خدا چاہتا تو خود کھلا دیتا۔ تم تو صریح غلطی میں ہو\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmdccliii{اور کہتے ہیں اگر تم سچ کہتے ہو تو یہ وعدہ کب (پورا) ہوگا؟\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmdccliv{یہ تو ایک چنگھاڑ کے منتظر ہیں جو ان کو اس حال میں کہ باہم جھگڑ رہے ہوں گے آپکڑے گی\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmdcclv{پھر نہ وصیت کرسکیں گے اور نہ اپنے گھر والوں میں واپس جاسکیں گے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmdcclvi{اور (جس وقت) صور پھونکا جائے گا یہ قبروں سے (نکل کر) اپنے پروردگار کی طرف دوڑ پڑیں گے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmdcclvii{کہیں گے اے ہے ہمیں ہماری خوابگاہوں سے کس نے (جگا) اُٹھایا؟ یہ وہی تو ہے جس کا خدا نے وعدہ کیا تھا اور پیغمبروں نے سچ کہا تھا\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmdcclviii{صرف ایک زور کی آواز کا ہونا ہوگا کہ سب کے سب ہمارے روبرو آحاضر ہوں گے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmdcclix{اس روز کسی شخص پر کچھ ظلم نہیں کیا جائے گا اور تم کو بدلہ ویسا ہی ملے گا جیسے تم کام کرتے تھے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmdcclx{اہل جنت اس روز عیش ونشاط کے مشغلے میں ہوں گے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmdcclxi{وہ بھی اور ان کی بیویاں بھی سایوں میں تختوں پر تکیے لگائے بیٹھے ہوں گے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmdcclxii{وہاں ان کے لئے میوے اور جو چاہیں گے (موجود ہوگا)\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiii{پروردگار مہربان کی طرف سے سلام (کہا جائے گا)\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmdcclxiv{اور گنہگارو! آج الگ ہوجاؤ\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmdcclxv{اے آدم کی اولاد ہم نے تم سے کہہ نہیں دیا تھا کہ شیطان کو نہ پوجنا وہ تمہارا کھلا دشمن ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvi{اور یہ کہ میری ہی عبادت کرنا۔ یہی سیدھا رستہ ہے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmdcclxvii{اور اس نے تم میں سے بہت سی خلقت کو گمراہ کردیا تھا۔ تو کیا تم سمجھتے نہیں تھے؟\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmdcclxviii{یہی وہ جہنم ہے جس کی تمہیں خبر دی جاتی ہے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmdcclxix{سو) جو تم کفر کرتے رہے ہو اس کے بدلے آج اس میں داخل ہوجاؤ\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmdcclxx{آج ہم ان کے مونہوں پر مہر لگا دیں گے اور جو کچھ یہ کرتے رہے تھے ان کے ہاتھ ہم سے بیان کردیں گے اور ان کے پاؤں (اس کی) گواہی دیں گے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxi{اور اگر ہم چاہیں تو ان کی آنکھوں کو مٹا کر (اندھا کر) دیں۔ پھر یہ رستے کو دوڑیں تو کہاں دیکھ سکیں گے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxii{اور اگر ہم چاہیں تو ان کی جگہ پر ان کی صورتیں بدل دیں پھر وہاں سے نہ آگے جاسکیں اور نہ (پیچھے) لوٹ سکیں\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiii{اور جس کو ہم بڑی عمر دیتے ہیں تو اسے خلقت میں اوندھا کردیتے ہیں تو کیا یہ سمجھتے نہیں؟\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxiv{اور ہم نے ان (پیغمبر) کو شعر گوئی نہیں سکھائی اور نہ وہ ان کو شایاں ہے۔ یہ تو محض نصیحت اور صاف صاف قرآن (پُرازحکمت) ہے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxv{تاکہ اس شخص کو جو زندہ ہو ہدایت کا رستہ دکھائے اور کافروں پر بات پوری ہوجائے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvi{کیا انہوں نے نہیں دیکھا کہ جو چیزیں ہم نے اپنے ہاتھوں سے بنائیں ان میں سے ہم نے ان کے لئے چارپائے پیدا کر دیئے اور یہ ان کے مالک ہیں\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxvii{اور ان کو ان کے قابو میں کردیا تو کوئی تو ان میں سے ان کی سواری ہے اور کسی کو یہ کھاتے ہیں\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxviii{اور ان میں ان کے لئے (اور) فائدے اور پینے کی چیزیں ہیں۔ تو یہ شکر کیوں نہیں کرتے؟\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxix{اور انہوں نے خدا کے سوا (اور) معبود بنا لیے ہیں کہ شاید (ان سے) ان کو مدد پہنچے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxx{مگر) وہ ان کی مدد کی (ہرگز) طاقت نہیں رکھتے۔ اور وہ ان کی فوج ہو کر حاضر کیے جائیں گے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxi{تو ان کی باتیں تمہیں غمناک نہ کردیں۔ یہ جو کچھ چھپاتے اور جو کچھ ظاہر کرتے ہیں ہمیں سب معلوم ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxii{کیا انسان نے نہیں دیکھا کہ ہم نے اس کو نطفے سے پیدا کیا۔ پھر وہ تڑاق پڑاق جھگڑنے لگا\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiii{اور ہمارے بارے میں مثالیں بیان کرنے لگا اور اپنی پیدائش کو بھول گیا۔ کہنے لگا کہ (جب) ہڈیاں بوسیدہ ہوجائیں گی تو ان کو کون زندہ کرے گا؟\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxiv{کہہ دو کہ ان کو وہ زندہ کرے گا جس نے ان کو پہلی بار پیدا کیا تھا۔ اور وہ سب قسم کا پیدا کرنا جانتا ہے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxv{جس نے تمہارے لئے سبز درخت سے آگ پیدا کی پھر تم اس (کی ٹہنیوں کو رگڑ کر ان) سے آگ نکالتے ہو\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvi{بھلا جس نے آسمانوں اور زمین کو پیدا کیا، کیا وہ اس بات پر قادر نہیں کہ (ان کو پھر) ویسے ہی پیدا کر دے۔ کیوں نہیں۔ اور وہ تو بڑا پیدا کرنے والا اور علم والا ہے\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxvii{اس کی شان یہ ہے کہ جب وہ کسی چیز کا ارادہ کرتا ہے تو اس سے فرما دیتا ہے کہ ہوجا تو وہ ہوجاتی ہے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxviii{وہ (ذات) پاک ہے جس کے ہاتھ میں ہر چیز کی بادشاہت ہے اور اسی کی طرف تم کو لوٹ کر جانا ہے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmdcclxxxix{\basmalahur قسم ہے صف باندھنے والوں کی پرا جما کر\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmdccxc{پھر ڈانٹنے والوں کی جھڑک کر\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmdccxci{پھر ذکر (یعنی قرآن) پڑھنے والوں کی (غور کرکر)\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmdccxcii{کہ تمہارا معبود ایک ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmdccxciii{جو آسمانوں اور زمین اور جو چیزیں ان میں ہیں سب کا مالک ہے اور سورج کے طلوع ہونے کے مقامات کا بھی مالک ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmdccxciv{بےشک ہم ہی نے آسمان دنیا کو ستاروں کی زینت سے مزین کیا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmdccxcv{اور ہر شیطان سرکش سے اس کی حفاظت کی\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvi{کہ اوپر کی مجلس کی طرف کان نہ لگاسکیں اور ہر طرف سے (ان پر انگارے) پھینکے جاتے ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmdccxcvii{یعنی وہاں سے) نکال دینے کو اور ان کے لئے دائمی عذاب ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmdccxcviii{ہاں جو کوئی (فرشتوں کی کسی بات کو) چوری سے جھپٹ لینا چاہتا ہے تو جلتا ہوا انگارہ ان کے پیچھے لگتا ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmdccxcix{تو ان سے پوچھو کہ ان کا بنانا مشکل ہے یا جتنی خلقت ہم نے بنائی ہے؟ انہیں ہم نے چپکتے گارے سے بنایا ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmdccc{ہاں تم تو تعجب کرتے ہو اور یہ تمسخر کرتے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmdccci{اور جب ان کو نصیحت دی جاتی ہے تو نصیحت قبول نہیں کرتے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmdcccii{اور جب کوئی نشانی دیکھتے ہیں تو ٹھٹھے کرتے ہیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmdccciii{اور کہتے ہیں کہ یہ تو صریح جادو ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmdccciv{بھلا جب ہم مرگئے اور مٹی اور ہڈیاں ہوگئے تو کیا پھر اٹھائے جائیں گے؟\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmdcccv{اور کیا ہمارے باپ دادا بھی (جو) پہلے (ہو گزرے ہیں)\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmdcccvi{کہہ دو کہ ہاں اور تم ذلیل ہوگے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmdcccvii{وہ تو ایک زور کی آواز ہوگی اور یہ اس وقت دیکھنے لگیں گے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmdcccviii{اور کہیں گے، ہائے شامت یہی جزا کا دن ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmdcccix{کہا جائے گا کہ ہاں) فیصلے کا دن جس کو تم جھوٹ سمجھتے تھے یہی ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmdcccx{جو لوگ ظلم کرتے تھے ان کو اور ان کے ہم جنسوں کو اور جن کو وہ پوجا کرتے تھے (سب کو) جمع کرلو\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmdcccxi{یعنی جن کو) خدا کے سوا (پوجا کرتے تھے) پھر ان کو جہنم کے رستے پر چلا دو\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmdcccxii{اور ان کو ٹھیرائے رکھو کہ ان سے (کچھ) پوچھنا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiii{تم کو کیا ہوا کہ ایک دوسرے کی مدد نہیں کرتے؟\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmdcccxiv{بلکہ آج تو وہ فرمانبردار ہیں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmdcccxv{اور ایک دوسرے کی طرف رخ کرکے سوال (وجواب) کریں گے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvi{کہیں گے کیا تم ہی ہمارے پاس دائیں (اور بائیں) سے آتے تھے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmdcccxvii{وہ کہیں گے بلکہ تم ہی ایمان لانے والے نہ تھے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmdcccxviii{اور ہمارا تم پر کچھ زور نہ تھا۔ بلکہ تم سرکش لوگ تھے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmdcccxix{سو ہمارے بارے میں ہمارے پروردگار کی بات پوری ہوگئی اب ہم مزے چکھیں گے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmdcccxx{ہم نے تم کو بھی گمراہ کیا (اور) ہم خود بھی گمراہ تھے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxi{پس وہ اس روز عذاب میں ایک دوسرے کے شریک ہوں گے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxii{ہم گنہگاروں کے ساتھ ایسا ہی کیا کرتے ہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiii{ان کا یہ حال تھا کہ جب ان سے کہا جاتا تھا کہ خدا کے سوا کوئی معبود نہیں تو غرور کرتے تھے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxiv{اور کہتے تھے کہ بھلا ہم ایک دیوانے شاعر کے کہنے سے کہیں اپنے معبودوں کو چھوڑ دینے والے ہیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxv{بلکہ وہ حق لے کر آئے ہیں اور (پہلے) پیغمبروں کو سچا کہتے ہیں\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvi{بےشک تم تکلیف دینے والے عذاب کا مزہ چکھنے والے ہو\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxvii{اور تم کو بدلہ ویسا ہی ملے گا جیسے تم کام کرتے تھے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxviii{مگر جو خدا کے بندگان خاص ہیں\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxix{یہی لوگ ہیں جن کے لئے روزی مقرر ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxx{یعنی) میوے اور ان کا اعزاز کیا جائے گا\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxi{نعمت کے باغوں میں\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxii{ایک دوسرے کے سامنے تختوں پر (بیٹھے ہوں گے)\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiii{شراب لطیف کے جام کا ان میں دور چل رہا ہوگا\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxiv{جو رنگ کی سفید اور پینے والوں کے لئے (سراسر) لذت ہوگی\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxv{نہ اس سے دردِ سر ہو اور نہ وہ اس سے متوالے ہوں گے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvi{اور ان کے پاس عورتیں ہوں گی جو نگاہیں نیچی رکھتی ہوں گی اور آنکھیں بڑی بڑی\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxvii{گویا وہ محفوظ انڈے ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxviii{پھر وہ ایک دوسرے کی طرف رخ کرکے سوال (وجواب) کریں گے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmdcccxxxix{ایک کہنے والا ان میں سے کہے گا کہ میرا ایک ہم نشین تھا\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmdcccxl{جو) کہتا تھا کہ بھلا تم بھی ایسی باتوں کے باور کرنے والوں میں ہو\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmdcccxli{بھلا جب ہم مر گئے اور مٹی اور ہڈیاں ہوگئے تو کیا ہم کو بدلہ ملے گا؟\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlii{پھر) کہے گا کہ بھلا تم (اسے) جھانک کر دیکھنا چاہتے ہو؟\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliii{اتنے میں) وہ (خود) جھانکے گا تو اس کو وسط دوزخ میں دیکھے گا\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmdcccxliv{کہے گا کہ خدا کی قسم تُو تو مجھے ہلاک ہی کرچکا تھا\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlv{اور اگر میرے پروردگار کی مہربانی نہ ہوتی تو میں بھی ان میں ہوتا جو (عذاب میں) حاضر کئے گئے ہیں\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvi{کیا (یہ نہیں کہ) ہم (آئندہ کبھی) مرنے کے نہیں\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlvii{ہاں (جو) پہلی بار مرنا (تھا سو مرچکے) اور ہمیں عذاب بھی نہیں ہونے کا\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlviii{بےشک یہ بڑی کامیابی ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmdcccxlix{ایسی ہی (نعمتوں) کے لئے عمل کرنے والوں کو عمل کرنے چاہئیں\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmdcccl{بھلا یہ مہمانی اچھی ہے یا تھوہر کا درخت؟\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmdcccli{ہم نے اس کو ظالموں کے لئے عذاب بنا رکھا ہے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmdccclii{وہ ایک درخت ہے کہ جہنم کے اسفل میں اُگے گا\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmdcccliii{اُس کے خوشے ایسے ہوں گے جیسے شیطانوں کے سر\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmdcccliv{سو وہ اسی میں سے کھائیں گے اور اسی سے پیٹ بھریں گے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmdccclv{پھر اس (کھانے) کے ساتھ ان کو گرم پانی ملا کر دیا جائے گا\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmdccclvi{پھر ان کو دوزخ کی طرف لوٹایا جائے گا\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmdccclvii{انہوں نے اپنے باپ دادا کو گمراہ ہی پایا\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmdccclviii{سو وہ ان ہی کے پیچھے دوڑے چلے جاتے ہیں\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmdccclix{اور ان سے پیشتر بہت سے لوگ بھی گمراہ ہوگئے تھے\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmdccclx{اور ہم نے ان میں متنبہ کرنے والے بھیجے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmdccclxi{سو دیکھ لو کہ جن کو متنبہ کیا گیا تھا ان کا انجام کیسا ہوا\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmdccclxii{ہاں خدا کے بندگان خاص (کا انجام بہت اچھا ہوا)\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiii{اور ہم کو نوح نے پکارا سو (دیکھ لو کہ) ہم (دعا کو کیسے) اچھے قبول کرنے والے ہیں\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmdccclxiv{اور ہم نے ان کو اور ان کے گھر والوں کو بڑی مصیبت سے نجات دی\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmdccclxv{اور ان کی اولاد کو ایسا کیا کہ وہی باقی رہ گئے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvi{اور پیچھے آنے والوں میں ان کا ذکر (جمیل باقی) چھوڑ دیا\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmdccclxvii{یعنی) تمام جہان میں (کہ) نوح پر سلام\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmdccclxviii{نیکوکاروں کو ہم ایسا ہی بدلہ دیا کرتے ہیں\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmdccclxix{بےشک وہ ہمارے مومن بندوں میں سے تھا\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmdccclxx{پھر ہم نے دوسروں کو ڈبو دیا\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxi{اور ان ہی کے پیرووں میں ابراہیم تھے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxii{جب وہ اپنے پروردگار کے پاس (عیب سے) پاک دل لے کر آئے\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiii{جب انہوں نے اپنے باپ سے اور اپنی قوم سے کہا کہ تم کن چیزوں کو پوجتے ہو؟\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxiv{کیوں جھوٹ (بنا کر) خدا کے سوا اور معبودوں کے طالب ہو؟\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxv{بھلا پروردگار عالم کے بارے میں تمہارا کیا خیال ہے؟\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvi{تب انہوں نے ستاروں کی طرف ایک نظر کی\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxvii{اور کہا میں تو بیمار ہوں\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxviii{تب وہ ان سے پیٹھ پھیر کر لوٹ گئے\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxix{پھر ابراہیم ان کے معبودوں کی طرف متوجہ ہوئے اور کہنے لگے کہ تم کھاتے کیوں نہیں؟\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxx{تمہیں کیا ہوا ہے تم بولتے نہیں؟\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxi{پھر ان کو داہنے ہاتھ سے مارنا (اور توڑنا) شروع کیا\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxii{تو وہ لوگ ان کے پاس دوڑے ہوئے آئے\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiii{انہوں نے کہا کہ تم ایسی چیزوں کو کیوں پوجتے ہو جن کو خود تراشتے ہو؟\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxiv{حالانکہ تم کو اور جو تم بناتے ہو اس کو خدا ہی نے پیدا کیا ہے\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxv{وہ کہنے لگے کہ اس کے لئے ایک عمارت بناؤ پھر اس کو آگ کے ڈھیر میں ڈال دو\qt@no{97}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvi{غرض انہوں نے ان کے ساتھ ایک چال چلنی چاہی اور ہم نے ان ہی کو زیر کردیا\qt@no{98}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxvii{اور ابراہیم بولے کہ میں اپنے پروردگار کی طرف جانے والا ہوں وہ مجھے رستہ دکھائے گا\qt@no{99}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxviii{اے پروردگار مجھے (اولاد) عطا فرما (جو) سعادت مندوں میں سے (ہو)\qt@no{100}}%
\qt@newcmd\qurantrans@ur@mmmdccclxxxix{تو ہم نے ان کو ایک نرم دل لڑکے کی خوشخبری دی\qt@no{101}}%
\qt@newcmd\qurantrans@ur@mmmdcccxc{جب وہ ان کے ساتھ دوڑنے (کی عمر) کو پہنچا تو ابراہیم نے کہا کہ بیٹا میں خواب میں دیکھتا ہوں کہ (گویا) تم کو ذبح کر رہا ہوں تو تم سوچو کہ تمہارا کیا خیال ہے؟ انہوں نے کہا کہ ابا جو آپ کو حکم ہوا ہے وہی کیجیئے خدا نے چاہا تو آپ مجھے صابروں میں پایئے گا\qt@no{102}}%
\qt@newcmd\qurantrans@ur@mmmdcccxci{جب دونوں نے حکم مان لیا اور باپ نے بیٹے کو ماتھے کے بل لٹا دیا\qt@no{103}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcii{تو ہم نے ان کو پکارا کہ اے ابراہیم\qt@no{104}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciii{تم نے خواب کو سچا کر دکھایا۔ ہم نیکوکاروں کو ایسا ہی بدلہ دیا کرتے ہیں\qt@no{105}}%
\qt@newcmd\qurantrans@ur@mmmdcccxciv{بلاشبہ یہ صریح آزمائش تھی\qt@no{106}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcv{اور ہم نے ایک بڑی قربانی کو ان کا فدیہ دیا\qt@no{107}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvi{اور پیچھے آنے والوں میں ابراہیم کا (ذکر خیر باقی) چھوڑ دیا\qt@no{108}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcvii{کہ ابراہیم پر سلام ہو\qt@no{109}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcviii{نیکوکاروں کو ہم ایسا ہی بدلہ دیا کرتے ہیں\qt@no{110}}%
\qt@newcmd\qurantrans@ur@mmmdcccxcix{وہ ہمارے مومن بندوں میں سے تھے\qt@no{111}}%
\qt@newcmd\qurantrans@ur@mmmcm{اور ہم نے ان کو اسحاق کی بشارت بھی دی (کہ وہ) نبی (اور) نیکوکاروں میں سے (ہوں گے)\qt@no{112}}%
\qt@newcmd\qurantrans@ur@mmmcmi{اور ہم نے ان پر اور اسحاق پر برکتیں نازل کی تھیں۔ اور ان دونوں اولاد کی میں سے نیکوکار بھی ہیں اور اپنے آپ پر صریح ظلم کرنے والے (یعنی گنہگار) بھی ہیں\qt@no{113}}%
\qt@newcmd\qurantrans@ur@mmmcmii{اور ہم نے موسیٰ اور ہارون پر بھی احسان کئے\qt@no{114}}%
\qt@newcmd\qurantrans@ur@mmmcmiii{اور ان کو اور ان کی قوم کو مصیبت عظیمہ سے نجات بخشی\qt@no{115}}%
\qt@newcmd\qurantrans@ur@mmmcmiv{اور ان کی مدد کی تو وہ غالب ہوگئے\qt@no{116}}%
\qt@newcmd\qurantrans@ur@mmmcmv{اور ان دونوں کو کتاب واضح (المطالب) عنایت کی\qt@no{117}}%
\qt@newcmd\qurantrans@ur@mmmcmvi{اور ان کو سیدھا رستہ دکھایا\qt@no{118}}%
\qt@newcmd\qurantrans@ur@mmmcmvii{اور پیچھے آنے والوں میں ان کا ذکر (خیر باقی) چھوڑ دیا\qt@no{119}}%
\qt@newcmd\qurantrans@ur@mmmcmviii{کہ موسیٰ اور ہارون پر سلام\qt@no{120}}%
\qt@newcmd\qurantrans@ur@mmmcmix{بےشک ہم نیکوکاروں کو ایسا ہی بدلہ دیا کرتے ہیں\qt@no{121}}%
\qt@newcmd\qurantrans@ur@mmmcmx{وہ دونوں ہمارے مومن بندوں میں سے تھے\qt@no{122}}%
\qt@newcmd\qurantrans@ur@mmmcmxi{اور الیاس بھی پیغمبروں میں سے تھے\qt@no{123}}%
\qt@newcmd\qurantrans@ur@mmmcmxii{جب انہوں نے اپنی قوم سے کہا کہ تم ڈرتے کیوں نہیں؟\qt@no{124}}%
\qt@newcmd\qurantrans@ur@mmmcmxiii{کیا تم بعل کو پکارتے (اور اسے پوجتے) ہو اور سب سے بہتر پیدا کرنے والے کو چھوڑ دیتے ہو\qt@no{125}}%
\qt@newcmd\qurantrans@ur@mmmcmxiv{یعنی) خدا کو جو تمہارا اور تمہارے اگلے باپ دادا کا پروردگار ہے\qt@no{126}}%
\qt@newcmd\qurantrans@ur@mmmcmxv{تو ان لوگوں نے ان کو جھٹلا دیا۔ سو وہ (دوزخ میں) حاضر کئے جائیں گے\qt@no{127}}%
\qt@newcmd\qurantrans@ur@mmmcmxvi{ہاں خدا کے بندگان خاص (مبتلائے عذاب نہیں) ہوں گے\qt@no{128}}%
\qt@newcmd\qurantrans@ur@mmmcmxvii{اور ان کا ذکر (خیر) پچھلوں میں (باقی) چھوڑ دیا\qt@no{129}}%
\qt@newcmd\qurantrans@ur@mmmcmxviii{کہ اِل یاسین پر سلام\qt@no{130}}%
\qt@newcmd\qurantrans@ur@mmmcmxix{ہم نیک لوگوں کو ایسا ہی بدلہ دیتے ہیں\qt@no{131}}%
\qt@newcmd\qurantrans@ur@mmmcmxx{بےشک وہ ہمارے مومن بندوں میں سے تھے\qt@no{132}}%
\qt@newcmd\qurantrans@ur@mmmcmxxi{اور لوط بھی پیغمبروں میں سے تھے\qt@no{133}}%
\qt@newcmd\qurantrans@ur@mmmcmxxii{جب ہم نے ان کو اور ان کے گھر والوں کو سب کو (عذاب سے) نجات دی\qt@no{134}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiii{مگر ایک بڑھیا کہ پیچھے رہ جانے والوں میں تھی\qt@no{135}}%
\qt@newcmd\qurantrans@ur@mmmcmxxiv{پھر ہم نے اوروں کو ہلاک کردیا\qt@no{136}}%
\qt@newcmd\qurantrans@ur@mmmcmxxv{اور تم دن کو بھی ان (کی بستیوں) کے پاس سے گزرتے رہتے ہو\qt@no{137}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvi{اور رات کو بھی۔ تو کیا تم عقل نہیں رکھتے\qt@no{138}}%
\qt@newcmd\qurantrans@ur@mmmcmxxvii{اور یونس بھی پیغمبروں میں سے تھے\qt@no{139}}%
\qt@newcmd\qurantrans@ur@mmmcmxxviii{جب بھاگ کر بھری ہوئی کشتی میں پہنچے\qt@no{140}}%
\qt@newcmd\qurantrans@ur@mmmcmxxix{اس وقت قرعہ ڈالا تو انہوں نے زک اُٹھائی\qt@no{141}}%
\qt@newcmd\qurantrans@ur@mmmcmxxx{پھر مچھلی نے ان کو نگل لیا اور وہ (قابل) ملامت (کام) کرنے والے تھے\qt@no{142}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxi{پھر اگر وہ (خدا کی) پاکی بیان نہ کرتے\qt@no{143}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxii{تو اس روز تک کہ لوگ دوبارہ زندہ کئے جائیں گے اسی کے پیٹ میں رہتے\qt@no{144}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiii{پھر ہم نے ان کو جب کہ وہ بیمار تھے فراخ میدان میں ڈال دیا\qt@no{145}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxiv{اور ان پر کدو کا درخت اُگایا\qt@no{146}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxv{اور ان کو لاکھ یا اس سے زیادہ (لوگوں) کی طرف (پیغمبر بنا کر) بھیجا\qt@no{147}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvi{تو وہ ایمان لے آئے سو ہم نے بھی ان کو (دنیا میں) ایک وقت (مقرر) تک فائدے دیتے رہے\qt@no{148}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxvii{ان سے پوچھو تو کہ بھلا تمہارے پروردگار کے لئے تو بیٹیاں اور ان کے لئے بیٹے\qt@no{149}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxviii{یا ہم نے فرشتوں کو عورتیں بنایا اور وہ (اس وقت) موجود تھے\qt@no{150}}%
\qt@newcmd\qurantrans@ur@mmmcmxxxix{دیکھو یہ اپنی جھوٹ بنائی ہوئی (بات) کہتے ہیں\qt@no{151}}%
\qt@newcmd\qurantrans@ur@mmmcmxl{کہ خدا کے اولاد ہے کچھ شک نہیں کہ یہ جھوٹے ہیں\qt@no{152}}%
\qt@newcmd\qurantrans@ur@mmmcmxli{کیا اس نے بیٹوں کی نسبت بیٹیوں کو پسند کیا ہے؟\qt@no{153}}%
\qt@newcmd\qurantrans@ur@mmmcmxlii{تم کیسے لوگ ہو، کس طرح کا فیصلہ کرتے ہو\qt@no{154}}%
\qt@newcmd\qurantrans@ur@mmmcmxliii{بھلا تم غور کیوں نہیں کرتے\qt@no{155}}%
\qt@newcmd\qurantrans@ur@mmmcmxliv{یا تمہارے پاس کوئی صریح دلیل ہے\qt@no{156}}%
\qt@newcmd\qurantrans@ur@mmmcmxlv{اگر تم سچے ہو تو اپنی کتاب پیش کرو\qt@no{157}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvi{اور انہوں نے خدا میں اور جنوں میں رشتہ مقرر کیا۔ حالانکہ جنات جانتے ہیں کہ وہ (خدا کے سامنے) حاضر کئے جائیں گے\qt@no{158}}%
\qt@newcmd\qurantrans@ur@mmmcmxlvii{یہ جو کچھ بیان کرتے ہیں خدا اس سے پاک ہے\qt@no{159}}%
\qt@newcmd\qurantrans@ur@mmmcmxlviii{مگر خدا کے بندگان خالص (مبتلائے عذاب نہیں ہوں گے)\qt@no{160}}%
\qt@newcmd\qurantrans@ur@mmmcmxlix{سو تم اور جن کو تم پوجتے ہو\qt@no{161}}%
\qt@newcmd\qurantrans@ur@mmmcml{خدا کے خلاف بہکا نہیں سکتے\qt@no{162}}%
\qt@newcmd\qurantrans@ur@mmmcmli{مگر اس کو جو جہنم میں جانے والا ہے\qt@no{163}}%
\qt@newcmd\qurantrans@ur@mmmcmlii{اور (فرشتے کہتے ہیں کہ) ہم میں سے ہر ایک کا ایک مقام مقرر ہے\qt@no{164}}%
\qt@newcmd\qurantrans@ur@mmmcmliii{اور ہم صف باندھے رہتے ہیں\qt@no{165}}%
\qt@newcmd\qurantrans@ur@mmmcmliv{اور (خدائے) پاک (ذات) کا ذکر کرتے رہتے ہیں\qt@no{166}}%
\qt@newcmd\qurantrans@ur@mmmcmlv{اور یہ لوگ کہا کرتے تھے\qt@no{167}}%
\qt@newcmd\qurantrans@ur@mmmcmlvi{کہ اگر ہمارے پاس اگلوں کی کوئی نصیحت (کی کتاب) ہوتی\qt@no{168}}%
\qt@newcmd\qurantrans@ur@mmmcmlvii{تو ہم خدا کے خالص بندے ہوتے\qt@no{169}}%
\qt@newcmd\qurantrans@ur@mmmcmlviii{لیکن (اب) اس سے کفر کرتے ہیں سو عنقریب ان کو (اس کا نتیجہ) معلوم ہوجائے گا\qt@no{170}}%
\qt@newcmd\qurantrans@ur@mmmcmlix{اور اپنے پیغام پہنچانے والے بندوں سے ہمارا وعدہ ہوچکا ہے\qt@no{171}}%
\qt@newcmd\qurantrans@ur@mmmcmlx{کہ وہی (مظفرو) منصور ہیں\qt@no{172}}%
\qt@newcmd\qurantrans@ur@mmmcmlxi{اور ہمارا لشکر غالب رہے گا\qt@no{173}}%
\qt@newcmd\qurantrans@ur@mmmcmlxii{تو ایک وقت تک ان سے اعراض کئے رہو\qt@no{174}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiii{اور انہیں دیکھتے رہو۔ یہ بھی عنقریب (کفر کا انجام) دیکھ لیں گے\qt@no{175}}%
\qt@newcmd\qurantrans@ur@mmmcmlxiv{کیا یہ ہمارے عذاب کے لئے جلدی کر رہے ہیں\qt@no{176}}%
\qt@newcmd\qurantrans@ur@mmmcmlxv{مگر جب وہ ان کے میدان میں آ اُترے گا تو جن کو ڈر سنا دیا گیا تھا ان کے لئے برا دن ہوگا\qt@no{177}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvi{اور ایک وقت تک ان سے منہ پھیرے رہو\qt@no{178}}%
\qt@newcmd\qurantrans@ur@mmmcmlxvii{اور دیکھتے رہو یہ بھی عنقریب (نتیجہ) دیکھ لیں گے\qt@no{179}}%
\qt@newcmd\qurantrans@ur@mmmcmlxviii{یہ جو کچھ بیان کرتے ہیں تمہارا پروردگار جو صاحب عزت ہے اس سے (پاک ہے)\qt@no{180}}%
\qt@newcmd\qurantrans@ur@mmmcmlxix{اور پیغمبروں پر سلام\qt@no{181}}%
\qt@newcmd\qurantrans@ur@mmmcmlxx{اور سب طرح کی تعریف خدائے رب العالمین کو (سزاوار) ہے\qt@no{182}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxi{\basmalahur ص۔ قسم ہے اس قرآن کی جو نصیحت دینے والا ہے (کہ تم حق پر ہو)\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxii{مگر جو لوگ کافر ہیں وہ غرور اور مخالفت میں ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiii{ہم نے ان سے پہلے بہت سی اُمتوں کو ہلاک کردیا تو وہ (عذاب کے وقت) لگے فریاد کرنے اور وہ رہائی کا وقت نہیں تھا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxiv{اور انہوں نے تعجب کیا کہ ان کے پاس ان ہی میں سے ہدایت کرنے والا آیا اور کافر کہنے لگے کہ یہ تو جادوگر ہے جھوٹا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxv{کیا اس نے اتنے معبودوں کی جگہ ایک ہی معبود بنا دیا۔ یہ تو بڑی عجیب بات ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvi{تو ان میں جو معزز تھے وہ چل کھڑے ہوئے (اور بولے) کہ چلو اور اپنے معبودوں (کی پوجا) پر قائم رہو۔ بےشک یہ ایسی بات ہے جس سے (تم پر شرف وفضلیت) مقصود ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxvii{یہ پچھلے مذہب میں ہم نے کبھی سنی ہی نہیں۔ یہ بالکل بنائی ہوئی بات ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxviii{کیا ہم سب میں سے اسی پر نصیحت (کی کتاب) اُتری ہے؟ (نہیں) بلکہ یہ میری نصیحت کی کتاب سے شک میں ہیں۔ بلکہ انہوں نے ابھی میرے عذاب کا مزہ نہیں چکھا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxix{کیا ان کے پاس تمہارے پروردگار کی رحمت کے خزانے ہیں جو غالب اور بہت عطا کرنے والا ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxx{یا آسمانوں اور زمین اور جو کچھ ان میں ہے ان (سب) پر ان ہی کی حکومت ہے۔ تو چاہیئے کہ رسیاں تان کر (آسمانوں) پر چڑھ جائیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxi{یہاں شکست کھائے ہوئے گروہوں میں سے یہ بھی ایک لشکر ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxii{ان سے پہلے نوح کی قوم اور عاد اور میخوں والا فرعون (اور اس کی قوم کے لوگ) بھی جھٹلا چکے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiii{اور ثمود اور لوط کی قوم اور بن کے رہنے والے بھی۔ یہی وہ گروہ ہیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxiv{ان) سب نے پیغمبروں کو جھٹلایا تو میرا عذاب (ان پر) آ واقع ہوا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxv{اور یہ لوگ تو صرف ایک زور کی آواز کا جس میں (شروع ہوئے پیچھے) کچھ وقفہ نہیں ہوگا، انتظار کرتے ہیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvi{اور کہتے ہیں کہ اے ہمارے پروردگار ہم کو ہمارا حصہ حساب کے دن سے پہلے ہی دے دے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxvii{اے پیغمبر) یہ جو کچھ کہتے ہیں اس پر صبر کرو۔ اور ہمارے بندے داؤد کو یاد کرو جو صاحب قوت تھے (اور) بےشک وہ رجوع کرنے والے تھے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxviii{ہم نے پہاڑوں کو ان کے زیر فرمان کردیا تھا کہ صبح وشام ان کے ساتھ (خدائے) پاک (کا) ذکر کرتے تھے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmcmlxxxix{اور پرندوں کو بھی کہ جمع رہتے تھے۔ سب ان کے فرمانبردار تھے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmcmxc{اور ہم نے ان کی بادشاہی کو مستحکم کیا اور ان کو حکمت عطا کی اور (خصومت کی) بات کا فیصلہ (سکھایا)\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmcmxci{بھلا تمہارے پاس ان جھگڑنے والوں کی بھی خبر آئی ہے جب وہ دیوار پھاند کر عبادت خانے میں داخل ہوئے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmcmxcii{جس وقت وہ داؤد کے پاس آئے تو وہ ان سے گھبرا گئے انہوں نے کہا کہ خوف نہ کیجیئے۔ ہم دونوں کا ایک مقدمہ ہے کہ ہم میں سے ایک نے دوسرے پر زیادتی کی ہے تو آپ ہم میں انصاف کا فیصلہ کر دیجیئے اور بےانصافی نہ کیجیئے گا اور ہم کو سیدھا رستہ دکھا دیجیئے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmcmxciii{کیفیت یہ ہے کہ) یہ میرا بھائی ہے اس کے (ہاں) ننانوے دنبیاں ہیں اور میرے (پاس) ایک دُنبی ہے۔ یہ کہتا ہے کہ یہ بھی میرے حوالے کردے اور گفتگو میں مجھ پر زبردستی کرتا ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmcmxciv{انہوں نے کہا کہ یہ جو تیری دنبی مانگتا ہے کہ اپنی دنبیوں میں ملالے بےشک تجھ پر ظلم کرتا ہے۔ اور اکثر شریک ایک دوسرے پر زیادتی ہی کیا کرتے ہیں۔ ہاں جو ایمان لائے اور عمل نیک کرتے رہے اور ایسے لوگ بہت کم ہیں۔ اور داؤد نے خیال کیا کہ (اس واقعے سے) ہم نے ان کو آزمایا ہے تو انہوں نے اپنے پروردگار سے مغفرت مانگی اور جھک کر گڑ پڑے اور (خدا کی طرف) رجوع کیا\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmcmxcv{تو ہم نے ان کو بخش دیا۔ اور بےشک ان کے لئے ہمارے ہاں قرب اور عمدہ مقام ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvi{اے داؤد ہم نے تم کو زمین میں بادشاہ بنایا ہے تو لوگوں میں انصاف کے فیصلے کیا کرو اور خواہش کی پیروی نہ کرنا کہ وہ تمہیں خدا کے رستے سے بھٹکا دے گی۔ جو لوگ خدا کے رستے سے بھٹکتے ہیں ان کے لئے سخت عذاب (تیار) ہے کہ انہوں نے حساب کے دن کو بھلا دیا\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmcmxcvii{اور ہم نے آسمان اور زمین کو اور جو کائنات ان میں ہے اس کو خالی از مصلحت نہیں پیدا کیا۔ یہ ان کا گمان ہے جو کافر ہیں۔ سو کافروں کے لئے دوزخ کا عذاب ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmcmxcviii{جو لوگ ایمان لائے اور عمل نیک کرتے رہے۔ کیا ان کو ہم ان کی طرح کر دیں گے جو ملک میں فساد کرتے ہیں۔ یا پرہیزگاروں کو بدکاروں کی طرح کر دیں گے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmcmxcix{یہ) کتاب جو ہم نے تم پر نازل کی ہے بابرکت ہے تاکہ لوگ اس کی آیتوں میں غور کریں اور تاکہ اہل عقل نصیحت پکڑیں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmm{اور ہم نے داؤد کو سلیمان عطا کئے۔ بہت خوب بندے (تھے اور) وہ (خدا کی طرف) رجوع کرنے والے تھے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmi{جب ان کے سامنے شام کو خاصے کے گھوڑے پیش کئے گئے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmii{تو کہنے لگے کہ میں نے اپنے پروردگار کی یاد سے (غافل ہو کر) مال کی محبت اختیار کی۔ یہاں تک کہ (آفتاب) پردے میں چھپ گیا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmiii{بولے کہ) ان کو میرے پاس واپس لے آؤ۔ پھر ان کی ٹانگوں اور گردنوں پر ہاتھ پھیرنے لگے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmiv{اور ہم نے سلیمان کی آزمائش کی اور ان کے تخت پر ایک دھڑ ڈال دیا پھر انہوں نے (خدا کی طرف) رجوع کیا\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmv{اور) دعا کی کہ اے پروردگار مجھے مغفرت کر اور مجھ کو ایسی بادشاہی عطا کر کہ میرے بعد کسی کو شایاں نہ ہو۔ بےشک تو بڑا عطا فرمانے والا ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmvi{پھر ہم نے ہوا کو ان کے زیرفرمان کردیا کہ جہاں وہ پہنچنا چاہتے ان کے حکم سے نرم نرم چلنے لگتی\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmvii{اَور دیووں کو بھی (ان کے زیرفرمان کیا) وہ سب عمارتیں بنانے والے اور غوطہ مارنے والے تھے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmviii{اور اَوروں کو بھی جو زنجیروں میں جکڑے ہوئے تھے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmix{ہم نے کہا) یہ ہماری بخشش ہے (چاہو) تو احسان کرو یا (چاہو تو) رکھ چھوڑو (تم سے) کچھ حساب نہیں ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmx{اور بےشک ان کے لئے ہمارے ہاں قُرب اور عمدہ مقام ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmxi{اور ہمارے بندے ایوب کو یاد کرو جب انہوں نے اپنے رب کو پکارا کہ (بار الہٰا) شیطان نے مجھ کو ایذا اور تکلیف دے رکھی ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmxii{ہم نے کہا کہ زمین پر) لات مارو (دیکھو) یہ (چشمہ نکل آیا) نہانے کو ٹھنڈا اور پینے کو (شیریں)\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmxiii{اور ہم نے ان کو اہل و عیال اور ان کے ساتھ ان کے برابر اور بخشے۔ (یہ) ہماری طرف سے رحمت اور عقل والوں کے لئے نصیحت تھی\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmxiv{اور اپنے ہاتھ میں جھاڑو لو اور اس سے مارو اور قسم نہ توڑو۔ بےشک ہم نے ان کو ثابت قدم پایا۔ بہت خوب بندے تھے بےشک وہ رجوع کرنے والے تھے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmxv{اور ہمارے بندوں ابراہیم اور اسحاق اور یعقوب کو یاد کرو جو ہاتھوں والے اور آنکھوں والے تھے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmxvi{ہم نے ان کو ایک (صفت) خاص (آخرت کے) گھر کی یاد سے ممتاز کیا تھا\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmxvii{اور ہمارے نزدیک منتخب اور نیک لوگوں میں سے تھے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmxviii{اور اسمٰعیل اور الیسع اور ذوالکفل کو یاد کرو۔ وہ سب نیک لوگوں میں سے تھے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmxix{یہ نصیحت ہے اور پرہیزگاروں کے لئے تو عمدہ مقام ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmxx{ہمیشہ رہنے کے باغ جن کے دروازے ان کے لئے کھلے ہوں گے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmxxi{ان میں تکیٴے لگائے بیٹھے ہوں گے اور (کھانے پینے کے لئے) بہت سے میوے اور شراب منگواتے رہیں گے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmxxii{اور ان کے پاس نیچی نگاہ رکھنے والی (اور) ہم عمر (عورتیں) ہوں گی\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmxxiii{یہ وہ چیزیں ہیں جن کا حساب کے دن کے لئے تم سے وعدہ کیا جاتا تھا\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmxxiv{یہ ہمارا رزق ہے جو کبھی ختم نہیں ہوگا\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmxxv{یہ (نعمتیں تو فرمانبرداروں کے لئے ہیں) اور سرکشوں کے لئے برا ٹھکانا ہے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmxxvi{یعنی) دوزخ۔ جس میں وہ داخل ہوں گے اور وہ بری آرام گاہ ہے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmxxvii{یہ کھولتا ہوا گرم پانی اور پیپ (ہے) اب اس کے مزے چکھیں\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmxxviii{اور اسی طرح کے اور بہت سے (عذاب ہوں گے)\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmxxix{یہ ایک فوج ہے جو تمہارے ساتھ داخل ہوگی۔ ان کو خوشی نہ ہو یہ دوزخ میں جانے والے ہیں\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmxxx{کہیں گے بلکہ تم ہی کو خوشی نہ ہو۔ تم ہی تو یہ (بلا) ہمارے سامنے لائے سو (یہ) برا ٹھکانا ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmxxxi{وہ کہیں گے اے پروردگار جو اس کو ہمارے سامنے لایا ہے اس کو دوزخ میں دونا عذاب دے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmxxxii{اور کہیں گے کیا سبب ہے کہ (یہاں) ہم ان شخصوں کو نہیں دیکھتے جن کو بروں میں شمار کرتے تھے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiii{کیا ہم نے ان سے ٹھٹھا کیا ہے یا (ہماری) آنکھیں ان (کی طرف) سے پھر گئی ہیں؟\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmxxxiv{بےشک یہ اہل دوزخ کا جھگڑنا برحق ہے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmxxxv{کہہ دو کہ میں تو صرف ہدایت کرنے والا ہوں۔ اور خدائے یکتا اور غالب کے سوا کوئی معبود نہیں\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvi{جو آسمانوں اور زمین اور جو مخلوق ان میں ہے سب کا مالک ہے غالب (اور) بخشنے والا\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmxxxvii{کہہ دو کہ یہ ایک بڑی (ہولناک چیز کی) خبر ہے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmxxxviii{جس کو تم دھیان میں نہیں لاتے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmxxxix{مجھ کو اوپر کی مجلس (والوں) کا جب وہ جھگڑتے تھے کچھ بھی علم نہ تھا\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmxl{میری طرف تو یہی وحی کی جاتی ہے کہ میں کھلم کھلا ہدایت کرنے والا ہوں\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmxli{جب تمہارے پروردگار نے فرشتوں سے کہا کہ میں مٹی سے انسان بنانے والا ہوں\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmxlii{جب اس کو درست کرلوں اور اس میں اپنی روح پھونک دوں تو اس کے آگے سجدے میں گر پڑنا\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmxliii{تو تمام فرشتوں نے سجدہ کیا\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmxliv{مگر شیطان اکڑ بیٹھا اور کافروں میں ہوگیا\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmxlv{خدا نے) فرمایا کہ اے ابلیس جس شخص کو میں نے اپنے ہاتھوں سے بنایا اس کے آگے سجدہ کرنے سے تجھے کس چیز نے منع کیا۔ کیا تو غرور میں آگیا یا اونچے درجے والوں میں تھا؟\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmxlvi{بولا کہ میں اس سے بہتر ہوں (کہ) تو نے مجھ کو کو آگ سے پیدا کیا اور اِسے مٹی سے بنایا\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmmxlvii{فرمایا یہاں سے نکل جا تو مردود ہے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmmxlviii{اور تجھ پر قیامت کے دن تک میری لعنت (پڑتی) رہے گی\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmmxlix{کہنے لگا کہ میرے پروردگار مجھے اس روز تک کہ لوگ اٹھائے جائیں مہلت دے\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmml{فرمایا کہ تجھ کو مہلت دی جاتی ہے\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmmli{اس روز تک جس کا وقت مقرر ہے\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmmlii{کہنے لگا کہ مجھے تیری عزت کی قسم میں ان سب کو بہکاتا رہوں گا\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmmliii{سوا ان کے جو تیرے خالص بندے ہیں\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmmliv{فرمایا سچ (ہے) اور میں بھی سچ کہتا ہوں\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmmlv{کہ میں تجھ سے اور جو ان میں سے تیری پیروی کریں گے سب سے جہنم کو بھر دوں گا\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmmlvi{اے پیغمبر کہہ دو کہ میں تم سے اس کا صلہ نہیں مانگتا اور نہ میں بناوٹ کرنے والوں میں ہوں\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmmlvii{یہ قرآن تو اہل عالم کے لئے نصیحت ہے\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmmlviii{اور تم کو اس کا حال ایک وقت کے بعد معلوم ہوجائے گا\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmmlix{\basmalahur اس کتاب کا اُتارا جانا خدائے غالب (اور) حکمت والے کی طرف سے ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmlx{اے پیغمبر) ہم نے یہ کتاب تمہاری طرف سچائی کے ساتھ نازل کی ہے تو خدا کی عبادت کرو (یعنی) اس کی عبادت کو (شرک سے) خالص کرکے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmlxi{دیکھو خالص عبادت خدا ہی کے لئے (زیبا ہے) اور جن لوگوں نے اس کے سوا اور دوست بنائے ہیں۔ (وہ کہتے ہیں کہ) ہم ان کو اس لئے پوجتے ہیں کہ ہم کو خدا کا مقرب بنادیں۔ تو جن باتوں میں یہ اختلاف کرتے ہیں خدا ان میں ان کا فیصلہ کردے گا۔ بےشک خدا اس شخص کو جو جھوٹا ناشکرا ہے ہدایت نہیں دیتا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmlxii{اگر خدا کسی کو اپنا بیٹا بنانا چاہتا تو اپنی مخلوق میں سے جس کو چاہتا انتخاب کرلیتا۔ وہ پاک ہے وہی تو خدا یکتا (اور) غالب ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmlxiii{اسی نے آسمانوں اور زمین کو تدبیر کے ساتھ پیدا کیا ہے۔ (اور) وہی رات کو دن پر لپیٹتا ہے اور دن کو رات پر لپیٹتا ہے اور اسی نے سورج اور چاند کو بس میں کر رکھا ہے۔ سب ایک وقت مقرر تک چلتے رہیں گے۔ دیکھو وہی غالب (اور) بخشنے والا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmlxiv{اسی نے تم کو ایک شخص سے پیدا کیا پھر اس سے اس کا جوڑا بنایا اور اسی نے تمہارے لئے چار پایوں میں سے آٹھ جوڑے بنائے۔ وہی تم کو تمہاری ماؤں کے پیٹ میں (پہلے) ایک طرح پھر دوسری طرح تین اندھیروں میں بناتا ہے۔ یہی خدا تمہارا پروردگار ہے اسی کی بادشاہی ہے۔ اس کے سوا کوئی معبود نہیں پھر تم کہاں پھرے جاتے ہو؟\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmlxv{اگر ناشکری کرو گے تو خدا تم سے بےپروا ہے۔ اور وہ اپنے بندوں کے لئے ناشکری پسند نہیں کرتا اور اگر شکر کرو گے تو وہ اس کو تمہارے لئے پسند کرے گا۔ اور کوئی اٹھانے والا دوسرے کا بوجھ نہیں اٹھائے گا۔ پھر تم اپنے پروردگار کی طرف لوٹنا ہے۔ پھر جو کچھ تم کرتے رہے وہ تم کو بتائے گا۔ وہ تو دلوں کی پوشیدہ باتوں تک سے آگاہ ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmlxvi{اور جب انسان کو تکلیف پہنچتی ہے تو اپنے پروردگار کو پکارتا (اور) اس کی طرف دل سے رجوع کرتا ہے۔ پھر جب وہ اس کو اپنی طرف سے کوئی نعمت دیتا ہے تو جس کام کے لئے پہلے اس کو پکارتا ہے اسے بھول جاتا ہے اور خدا کا شریک بنانے لگتا ہے تاکہ (لوگوں کو) اس کے رستے سے گمراہ کرے۔ کہہ دو کہ (اے کافر نعمت) اپنی ناشکری سے تھوڑا سا فائدہ اٹھالے۔ پھر تُو تو دوزخیوں میں ہوگا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmlxvii{بھلا مشرک اچھا ہے) یا وہ جو رات کے وقتوں میں زمین پر پیشانی رکھ کر اور کھڑے ہو کر عبادت کرتا اور آخرت سے ڈرتا اور اپنے پروردگار کی رحمت کی امید رکھتا ہے۔ کہو بھلا جو لوگ علم رکھتے ہیں اور جو نہیں رکھتے دونوں برابر ہوسکتے ہیں؟ (اور) نصیحت تو وہی پکڑتے ہیں جو عقلمند ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmlxviii{کہہ دو کہ اے میرے بندو جو ایمان لائے ہو اپنے پروردگار سے ڈرو۔ جنہوں نے اس دنیا میں نیکی کی ان کے لئے بھلائی ہے۔ اور خدا کی زمین کشادہ ہے۔ جو صبر کرنے والے ہیں ان کو بےشمار ثواب ملے گا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmlxix{کہہ دو کہ مجھ سے ارشاد ہوا ہے کہ خدا کی عبادت کو خالص کرکے اس کی بندگی کروں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmlxx{اور یہ بھی ارشاد ہوا ہے کہ میں سب سے اول مسلمان بنوں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmlxxi{کہہ دو کہ اگر میں اپنے پروردگار کا حکم نہ مانوں تو مجھے بڑے دن کے عذاب سے ڈر لگتا ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmlxxii{کہہ دو کہ میں اپنے دین کو (شرک سے) خالص کرکے اس کی عبادت کرتا ہوں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiii{تو تم اس کے سوا جس کی چاہو پرستش کرو۔ کہہ دو کہ نقصان اٹھانے والے وہی لوگ ہیں جنہوں نے قیامت کے دن اپنے آپ کو اور اپنے گھر والوں کو نقصان میں ڈالا۔ دیکھو یہی صریح نقصان ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmlxxiv{ان کے اوپر تو آگ کے سائبان ہوں گے اور نیچے (اس کے) فرش ہوں گے۔ یہ وہ (عذاب) ہے جس سے خدا اپنے بندوں کو ڈراتا ہے۔ تو اے میرے بندو مجھ سے ڈرتے رہو\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmlxxv{اور جنہوں نے اس سے اجتناب کیا کہ بتوں کو پوجیں اور خدا کی طرف رجوع کیا ان کے لئے بشارت ہے۔ تو میرے بندوں کو بشارت سنا دو\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvi{جو بات کو سنتے اور اچھی باتوں کی پیروی کرتے ہیں۔ یہی وہ لوگ ہیں جن کو خدا نے ہدایت دی اور یہی عقل والے ہیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmlxxvii{بھلا جس شخص پر عذاب کا حکم صادر ہوچکا۔ تو کیا تم (ایسے) دوزخی کو مخلصی دے سکو گے؟\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmlxxviii{لیکن جو لوگ اپنے پروردگار سے ڈرتے ہیں ان کے لئے اونچے اونچے محل ہیں جن کے اوپر بالا خانے بنے ہوئے ہیں۔ (اور) ان کے نیچے نہریں بہہ رہی ہیں۔ (یہ) خدا کا وعدہ ہے۔ خدا وعدے کے خلاف نہیں کرتا\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmlxxix{کیا تم نے نہیں دیکھا کہ خدا آسمان سے پانی نازل کرتا پھر اس کو زمین میں چشمے بنا کر جاری کرتا پھر اس سے کھیتی اُگاتا ہے جس کے طرح طرح کے رنگ ہوتے ہیں۔ پھر وہ خشک ہوجاتی ہے تو تم اس کو دیکھتے ہو (کہ) زرد (ہوگئی ہے) پھر اسے چورا چورا کر دیتا ہے۔ بےشک اس میں عقل والوں کے لئے نصیحت ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmlxxx{بھلا جس شخص کا سینہ خدا نے اسلام کے لئے کھول دیا ہو اور وہ اپنے پروردگار کی طرف سے روشنی پر ہو (تو کیا وہ سخت دل کافر کی طرح ہوسکتا ہے) پس ان پر افسوس ہے جن کے دل خدا کی یاد سے سخت ہو رہے ہیں۔ اور یہی لوگ صریح گمراہی میں ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxi{خدا نے نہایت اچھی باتیں نازل فرمائی ہیں (یعنی) کتاب (جس کی آیتیں باہم) ملتی جلتی (ہیں) اور دہرائی جاتی (ہیں) جو لوگ اپنے پروردگار سے ڈرتے ہیں ان کے بدن کے (اس سے) رونگٹے کھڑے ہوجاتے ہیں۔ پھر ان کے بدن اور دل نرم (ہو کر) خدا کی یاد کی طرف (متوجہ) ہوجاتے ہیں۔ یہی خدا کی ہدایت ہے وہ اس سے جس کو چاہتا ہے ہدایت دیتا ہے۔ اور جس کو خدا گمراہ کرے اس کو کوئی ہدایت دینے والا نہیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxii{بھلا جو شخص قیامت کے دن اپنے منہ سے برے عذاب کو روکتا ہو (کیا وہ ویسا ہوسکتا ہے جو چین میں ہو) اور ظالموں سے کہا جائے گا کہ جو کچھ تم کرتے رہے تھے اس کے مزے چکھو\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiii{جو لوگ ان سے پہلے تھے انہوں نے بھی تکذیب کی تھی تو ان پر عذاب ایسی جگہ سے آگیا کہ ان کو خبر ہی نہ تھی\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxiv{پھر ان کو خدا نے دنیا کی زندگی میں رسوائی کا مزہ چکھا دیا۔ اور آخرت کا عذاب تو بہت بڑا ہے۔ کاش یہ سمجھ رکھتے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxv{اور ہم نے لوگوں کے (سمجھانے کے) لئے اس قرآن میں ہر طرح کی مثالیں بیان کی ہیں تاکہ وہ نصیحت پکڑیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvi{یہ) قرآن عربی (ہے) جس میں کوئی عیب (اور اختلاف) نہیں تاکہ وہ ڈر مانیں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxvii{خدا ایک مثال بیان کرتا ہے کہ ایک شخص ہے جس میں کئی (آدمی) شریک ہیں۔ (مختلف المزاج اور) بدخو اور ایک آدمی خاص ایک شخص کا (غلام) ہے۔ بھلا دونوں کی حالت برابر ہے۔ (نہیں) الحمدلله بلکہ یہ اکثر لوگ نہیں جانتے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxviii{اے پیغمبر) تم بھی مر جاؤ گے اور یہ بھی مر جائیں گے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmlxxxix{پھر تم سب قیامت کے دن اپنے پروردگار کے سامنے جھگڑو گے (اور جھگڑا فیصل کردیا جائے گا)\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmxc{تو اس سے بڑھ کر ظالم کون جو خدا پر جھوٹ بولے اور سچی بات جب اس کے پاس پہنچ جائے تو اسے جھٹلائے۔ کیا جہنم میں کافروں کا ٹھکانا نہیں ہے؟\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmxci{اور جو شخص سچی بات لے کر آیا اور جس نے اس کی تصدیق کی وہی لوگ متقی ہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmxcii{وہ جو چاہیں گے ان کے لئے ان کے پروردگار کے پاس (موجود) ہے۔ نیکوکاروں کا یہی بدلہ ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmxciii{تاکہ خدا ان سے برائیوں کو جو انہوں نے کیں دور کردے اور نیک کاموں کا جو وہ کرتے رہے ان کو بدلہ دے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmxciv{کیا خدا اپنے بندوں کو کافی نہیں۔ اور یہ تم کو ان لوگوں سے جو اس کے سوا ہیں (یعنی غیر خدا سے) ڈراتے ہیں۔ اور جس کو خدا گمراہ کرے اسے کوئی ہدایت دینے والا نہیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmxcv{اور جس کو خدا ہدایت دے اس کو کوئی گمراہ کرنے والا نہیں۔ کیا خدا غالب (اور) بدلہ لینے والا نہیں ہے؟\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmxcvi{اور اگر تم ان سے پوچھو کہ آسمانوں اور زمین کو کس نے پیدا کیا تو کہہ دیں کہ خدا نے۔ کہو کہ بھلا دیکھو تو جن کو تم خدا کے سوا پکارتے ہو۔ اگر خدا مجھ کو کوئی تکلیف پہنچانی چاہے تو کیا وہ اس تکلیف کو دور کرسکتے ہیں یا اگر مجھ پر مہربانی کرنا چاہے تو وہ اس کی مہربانی کو روک سکتے ہیں؟ کہہ دو کہ مجھے خدا ہی کافی ہے۔ بھروسہ رکھنے والے اسی پر بھروسہ رکھتے ہیں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmxcvii{کہہ دو کہ اے قوم تم اپنی جگہ عمل کئے جاؤ میں (اپنی جگہ) عمل کئے جاتا ہوں۔ عنقریب تم کو معلوم ہوجائے گا\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmxcviii{کہ کس پر عذاب آتا ہے جو اسے رسوا کرے گا۔ اور کس پر ہمیشہ کا عذاب نازل ہوتا ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmxcix{ہم نے تم پر کتاب لوگوں (کی ہدایت) کے لئے سچائی کے ساتھ نازل کی ہے۔ تو جو شخص ہدایت پاتا ہے تو اپنے (بھلے کے) لئے اور جو گمراہ ہوتا ہے گمراہی سے تو اپنا ہی نقصان کرتا ہے۔ اور (اے پیغمبر) تم ان کے ذمہ دار نہیں ہو\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmc{خدا لوگوں کے مرنے کے وقت ان کی روحیں قبض کرلیتا ہے اور جو مرے نہیں (ان کی روحیں) سوتے میں (قبض کرلیتا ہے) پھر جن پر موت کا حکم کرچکتا ہے ان کو روک رکھتا ہے اور باقی روحوں کو ایک وقت مقرر تک کے لئے چھوڑ دیتا ہے۔ جو لوگ فکر کرتے ہیں ان کے لئے اس میں نشانیاں ہیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmci{کیا انہوں نے خدا کے سوا اور سفارشی بنالئے ہیں۔ کہو کہ خواہ وہ کسی چیز کا بھی اختیار نہ رکھتے ہوں اور نہ (کچھ) سمجھتے ہی ہوں\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmcii{کہہ دو کہ سفارش تو سب خدا ہی کے اختیار میں ہے۔ اسی کے لئے آسمانوں اور زمین کی بادشاہت ہے۔ پھر تم اسی کی طرف لوٹ کر جاؤ گے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmciii{اور جب تنہا خدا کا ذکر کیا جاتا ہے تو جو لوگ آخرت پر ایمان نہیں رکھتے ان کے دل منقبض ہوجاتے ہیں۔ اور جب اس کے سوا اوروں کا ذکر کیا جاتا ہے تو خوش ہوجاتے ہیں\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmciv{کہو کہ اے خدا (اے) آسمانوں اور زمین کے پیدا کرنے والے (اور) پوشیدہ اور ظاہر کے جاننے والے تو ہی اپنے بندوں میں ان باتوں کا جن میں وہ اختلاف کرتے رہے ہیں فیصلہ کرے گا\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmcv{اور اگر ظالموں کے پاس وہ سب (مال ومتاع) ہو جو زمین میں ہے اور اس کے ساتھ اسی قدر اور ہو تو قیامت کے روز برے عذاب (سے مخلصی پانے) کے بدلے میں دے دیں۔ اور ان پر خدا کی طرف سے وہ امر ظاہر ہوجائے گا جس کا ان کو خیال بھی نہ تھا\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmcvi{اور ان کے اعمال کی برائیاں ان پر ظاہر ہوجائیں گی اور جس (عذاب) کی وہ ہنسی اُڑاتے تھے وہ ان کو آگھیرے گا\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmcvii{جب انسان کو تکلیف پہنچتی ہے تو ہمیں پکارنے لگتا ہے۔ پھر جب ہم اس کو اپنی طرف سے نعمت بخشتے ہیں تو کہتا ہے کہ یہ تو مجھے (میرے) علم (ودانش) کے سبب ملی ہے۔ (نہیں) بلکہ وہ آزمائش ہے مگر ان میں سے اکثر نہیں جانتے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmcviii{جو لوگ ان سے پہلے تھے وہ بھی یہی کہا کرتے تھے تو جو کچھ وہ کیا کرتے تھے ان کے کچھ بھی کام نہ آیا\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmcix{ان پر ان کے اعمال کے وبال پڑ گئے۔ اور جو لوگ ان میں سے ظلم کرتے رہے ہیں ان پر ان کے عملوں کے وبال عنقریب پڑیں گے۔ اور وہ (خدا کو) عاجز نہیں کرسکتے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmcx{کیا ان کو معلوم نہیں کہ خدا ہی جس کے لئے چاہتا ہے رزق کو فراخ کردیتا ہے اور (جس کے لئے چاہتا ہے) تنگ کر دیتا ہے۔ جو لوگ ایمان لاتے ہیں ان کے لئے اس میں (بہت سی) نشانیاں ہیں\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmcxi{اے پیغمبر میری طرف سے لوگوں کو) کہہ دو کہ اے میرے بندو جنہوں نے اپنی جانوں پر زیادتی کی ہے خدا کی رحمت سے ناامید نہ ہونا۔ خدا تو سب گناہوں کو بخش دیتا ہے۔ (اور) وہ تو بخشنے والا مہربان ہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcxii{اور اس سے پہلے کہ تم پر عذاب آ واقع ہو، اپنے پروردگار کی طرف رجوع کرو اور اس کے فرمانبردار ہوجاؤ پھر تم کو مدد نہیں ملے گی\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmcxiii{اور اس سے پہلے کہ تم پر ناگہاں عذاب آجائے اور تم کو خبر بھی نہ ہو اس نہایت اچھی (کتاب) کی جو تمہارے پروردگار کی طرف سے تم پر نازل ہوئی ہے پیروی کرو\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmcxiv{کہ (مبادا اس وقت) کوئی متنفس کہنے لگے کہ (ہائے ہائے) اس تقصیر پر افسوس ہے جو میں نے خدا کے حق میں کی اور میں تو ہنسی ہی کرتا رہا\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmcxv{یا یہ کہنے لگے کہ اگر خدا مجھ کو ہدایت دیتا تو میں بھی پرہیزگاروں میں ہوتا\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmcxvi{یا جب عذاب دیکھ لے تو کہنے لگے کہ اگر مجھے پھر ایک دفعہ دنیا میں جانا ہو تو میں نیکوکاروں میں ہو جاؤں\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmcxvii{خدا فرمائے گا) کیوں نہیں میری آیتیں تیرے پاس پہنچ گئی ہیں مگر تو نے ان کو جھٹلایا اور شیخی میں آگیا اور تو کافر بن گیا\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmcxviii{اور جن لوگوں نے خدا پر جھوٹ بولا تم قیامت کے دن دیکھو گے کہ ان کے منہ کالے ہو رہے ہوں گے۔ کیا غرور کرنے والوں کو ٹھکانا دوزخ میں نہیں ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmcxix{اور جو پرہیزگار ہیں ان کی (سعادت اور) کامیابی کے سبب خدا ان کو نجات دے گا نہ تو ان کو کوئی سختی پہنچے گی اور نہ غمناک ہوں گے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmcxx{خدا ہی ہر چیز کا پیدا کرنے والا ہے۔ اور وہی ہر چیز کا نگراں ہے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmcxxi{اسی کے پاس آسمانوں اور زمین کی کنجیاں ہیں۔ اور جنہوں نے خدا کی آیتوں سے کفر کیا وہی نقصان اُٹھانے والے ہیں\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmcxxii{کہہ دو کہ اے نادانو! تم مجھ سے یہ کہتے ہو کہ میں غیر خدا کی پرستش کرنے لگوں\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiii{اور (اے محمدﷺ) تمہاری طرف اور ان (پیغمبروں) کی طرف جو تم سے پہلے ہوچکے ہیں یہی وحی بھیجی گئی ہے۔ کہ اگر تم نے شرک کیا تو تمہارے عمل برباد ہوجائیں گے اور تم زیاں کاروں میں ہوجاؤ گے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmcxxiv{بلکہ خدا ہی کی عبادت کرو اور شکرگزاروں میں ہو\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmcxxv{اور انہوں نے خدا کی قدر شناسی جیسی کرنی چاہیئے تھی نہیں کی۔ اور قیامت کے دن تمام زمین اس کی مٹھی میں ہوگی اور آسمان اس کے داہنے ہاتھ میں لپٹے ہوں گے۔ (اور) وہ ان لوگوں کے شرک سے پاک اور عالی شان ہے\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvi{اور جب صور پھونکا جائے گا تو جو لوگ آسمان میں ہیں اور جو زمین میں ہیں سب بےہوش ہو کر گر پڑیں گے مگر وہ جس کو خدا چاہے۔ پھر دوسری دفعہ پھونکا جائے گا تو فوراً سب کھڑے ہو کر دیکھنے لگیں گے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmcxxvii{اور زمین اپنے پروردگار کے نور سے جگمگا اُٹھے گی اور (اعمال کی) کتاب (کھول کر) رکھ دی جائے گی اور پیغمبر اور (اور) گواہ حاضر کئے جائیں گے اور ان میں انصاف کے ساتھ فیصلہ کیا جائے گا اور بےانصافی نہیں کی جائے گی\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmcxxviii{اور جس شخص نے جو عمل کیا ہوگا اس کو اس کا پورا پورا بدلہ مل جائے گا اور جو کچھ یہ کرتے ہیں اس کو سب کی خبر ہے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmcxxix{اور کافروں کو گروہ گروہ بنا کر جہنم کی طرف لے جائیں گے۔ یہاں تک کہ جب وہ اس کے پاس پہنچ جائیں گے تو اس کے دروازے کھول دیئے جائیں گے تو اس کے داروغہ ان سے کہیں گے کہ کیا تمہارے پاس تم ہی میں سے پیغمبر نہیں آئے تھے جو تم کو تمہارے پروردگار کی آیتیں پڑھ پڑھ کر سناتے اور اس دن کے پیش آنے سے ڈراتے تھے کہیں گے کیوں نہیں لیکن کافروں کے حق میں عذاب کا حکم متحقق ہوچکا تھا\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmcxxx{کہا جائے گا کہ دوزخ کے دروازوں میں داخل ہوجاؤ ہمیشہ اس میں رہو گے۔ تکبر کرنے والوں کا برا ٹھکانا ہے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxi{اور جو لوگ اپنے پروردگار سے ڈرتے ہیں ان کو گروہ گروہ بنا کر بہشت کی طرف لے جائیں گے یہاں تک کہ جب اس کے پاس پہنچ جائیں گے اور اس کے دروازے کھول دیئے جائیں گے تو اس کے داروغہ ان سے کہیں کہ تم پر سلام تم بہت اچھے رہے۔ اب اس میں ہمیشہ کے لئے داخل ہوجاؤ\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxii{وہ کہیں گے کہ خدا کا شکر ہے جس نے اپنے وعدہ کو ہم سے سچا کردیا اور ہم کو اس زمین کا وارث بنا دیا ہم بہشت میں جس مکان میں چاہیں رہیں تو (اچھے) عمل کرنے والوں کا بدلہ بھی کیسا خوب ہے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiii{تم فرشتوں کو دیکھو گے کہ عرش کے گرد گھیرا باندھے ہوئے ہیں (اور) اپنے پروردگار کی تعریف کے ساتھ تسبیح کر رہے ہیں۔ اور ان میں انصاف کے ساتھ فیصلہ کیا جائے گا اور کہا جائے گا کہ ہر طرح کی تعریف خدا ہی کو سزاوار ہے جو سارے جہان کا مالک ہے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxiv{\basmalahur حٰم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxv{اس کتاب کا اتارا جانا خدائے غالب ودانا کی طرف سے ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvi{جو گناہ بخشنے والا اور توبہ قبول کرنے والا ہے اور سخت عذاب دینے والا اور صاحب کرم ہے۔ اس کے سوا کوئی معبود نہیں۔ اسی کی طرف پھر کر جانا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxvii{خدا کی آیتوں میں وہی لوگ جھگڑتے ہیں جو کافر ہیں۔ تو ان لوگوں کا شہروں میں چلنا پھرنا تمہیں دھوکے میں نہ ڈال دے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxviii{ان سے پہلے نوح کی قوم اور ان کے بعد اور اُمتوں نے بھی (پیغمبروں کی) تکذیب کی۔ اور ہر اُمت نے اپنے پیغمبر کے بارے میں یہی قصد کیا کہ اس کو پکڑ لیں اور بیہودہ (شہبات سے) جھگڑتے رہے کہ اس سے حق کو زائل کردیں تو میں نے ان کو پکڑ لیا (سو دیکھ لو) میرا عذاب کیسا ہوا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcxxxix{اور اسی طرح کافروں کے بارے میں بھی تمہارے پروردگار کی بات پوری ہوچکی ہے کہ وہ اہل دوزخ ہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcxl{جو لوگ عرش کو اٹھائے ہوئے اور جو اس کے گردا گرد (حلقہ باندھے ہوئے) ہیں (یعنی فرشتے) وہ اپنے پروردگار کی تعریف کے ساتھ تسبیح کرتے رہتے ہیں اور مومنوں کے لئے بخشش مانگتے رہتے ہیں۔ کہ اے ہمارے پروردگار تیری رحمت اور تیرا علم ہر چیز کو احاطہ کئے ہوئے ہے تو جن لوگوں نے توبہ کی اور تیرے رستے پر چلے ان کو بخش دے اور دوزخ کے عذاب سے بچالے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcxli{اے ہمارے پروردگار ان کو ہمیشہ رہنے کے بہشتوں میں داخل کر جن کا تونے ان سے وعدہ کیا ہے اور جو ان کے باپ دادا اور ان کی بیویوں اور ان کی اولاد میں سے نیک ہوں ان کو بھی۔ بےشک تو غالب حکمت والا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcxlii{اور ان کو عذابوں سے بچائے رکھ۔ اور جس کو تو اس روز عذابوں سے بچا لے گا تو بےشک اس پر مہربانی فرمائی اور یہی بڑی کامیابی ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcxliii{جن لوگوں نے کفر کیا ان سے پکار کر کہہ دیا جائے گا کہ جب تم (دنیا میں) ایمان کی طرف بلائے جاتے تھے اور مانتے نہیں تھے تو خدا اس سے کہیں زیادہ بیزار ہوتا تھا جس قدر تم اپنے آپ سے بیزار ہو رہے ہو\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcxliv{وہ کہیں گے کہ اے ہمارے پروردگار تو نے ہم کو دو دفعہ بےجان کیا اور دو دفعہ جان بخشی۔ ہم کو اپنے گناہوں کا اقرار ہے تو کیا نکلنے کی کوئی سبیل ہے؟\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcxlv{یہ اس لئے کہ جب تنہا خدا کو پکارا جاتا تھا تو تم انکار کردیتے تھے۔ اور اگر اس کے ساتھ شریک مقرر کیا جاتا تھا تو تسلیم کرلیتے تھے تو حکم تو خدا ہی کا ہے جو (سب سے) اوپر اور (سب سے) بڑا ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvi{وہی تو ہے جو تم کو اپنی نشانیاں دکھاتا ہے اور تم پر آسمان سے رزق اُتارتا ہے۔ اور نصیحت تو وہی پکڑتا ہے جو (اس کی طرف) رجوع کرتا ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcxlvii{تو خدا کی عبادت کو خالص کر کر اُسی کو پکارو اگرچہ کافر برا ہی مانیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcxlviii{مالک درجات عالی اور صاحب عرش ہے۔ اپنے بندوں میں سے جس پر چاہتا ہے اپنے حکم سے وحی بھیجتا ہے تاکہ ملاقات کے دن سے ڈراوے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcxlix{جس روز وہ نکل پڑیں گے ان کی کوئی چیز خدا سے مخفی نہ رہے گی۔ آج کس کی بادشاہت ہے؟ خدا کی جو اکیلا اور غالب ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcl{آج کے دن ہر شخص کو اس کے اعمال کا بدلہ دیا جائے گا۔ آج (کسی کے حق میں) بےانصافی نہیں ہوگی۔ بےشک خدا جلد حساب لینے والا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcli{اور ان کو قریب آنے والے دن سے ڈراؤ جب کہ دل غم سے بھر کر گلوں تک آرہے ہوں گے۔ (اور) ظالموں کا کوئی دوست نہ ہوگا اور نہ کوئی سفارشی جس کی بات قبول کی جائے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmclii{وہ آنکھوں کی خیانت کو جانتا ہے اور جو (باتیں) سینوں میں پوشیدہ ہیں (ان کو بھی)\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcliii{اور خدا سچائی کے ساتھ حکم فرماتا ہے اور جن کو یہ لوگ پکارتے ہیں وہ کچھ بھی حکم نہیں دے سکتے۔ بےشک خدا سننے والا (اور) دیکھنے والا ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmcliv{کیا انہوں نے زمین میں سیر نہیں کی تاکہ دیکھ لیتے کہ جو لوگ ان سے پہلے تھے ان کا انجام کیسا ہوا۔ وہ ان سے زور اور زمین میں نشانات (بنانے) کے لحاظ سے کہیں بڑھ کر تھے تو خدا نے ان کو ان کے گناہوں کے سبب پکڑ لیا۔ اور ان کو خدا (کے عذاب) سے کوئی بھی بچانے والا نہ تھا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmclv{یہ اس لئے کہ ان کے پاس پیغمبر کھلی دلیلیں لاتے تھے تو یہ کفر کرتے تھے سو خدا نے ان کو پکڑ لیا۔ بےشک وہ صاحب قوت (اور) سخت عذاب دینے والا ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmclvi{اور ہم نے موسیٰ کو اپنی نشانیاں اور دلیل روشن دے کر بھیجا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmclvii{یعنی) فرعون اور ہامان اور قارون کی طرف تو انہوں نے کہا کہ یہ تو جادوگر ہے جھوٹا\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmclviii{غرض جب وہ ان کے پاس ہماری طرف سے حق لے کر پہنچے تو کہنے لگے کہ جو اس کے ساتھ (خدا پر) ایمان لائے ہیں ان کے بیٹوں کو قتل کردو اور بیٹیوں کو زندہ رہنے دو۔ اور کافروں کی تدبیریں بےٹھکانے ہوتی ہیں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmclix{اور فرعون بولا کہ مجھے چھوڑو کہ موسیٰ کو قتل کردوں اور وہ اپنے پروردگار کو بلالے۔ مجھے ڈر ہے کہ وہ (کہیں) تمہارے دین کو نہ بدل دے یا ملک میں فساد (نہ) پیدا کردے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmclx{موسیٰ نے کہا کہ میں ہر متکبر سے جو حساب کے دن (یعنی قیامت) پر ایمان نہیں لاتا۔ اپنے اور تمہارے پروردگار کی پناہ لے چکا ہوں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmclxi{اور فرعون کے لوگوں میں سے ایک مومن شخص جو اپنے ایمان کو پوشیدہ رکھتا تھا کہنے لگا کیا تم ایسے شخص کو قتل کرنا چاہتے ہو جو کہتا ہے کہ میرا پروردگار خدا ہے اور وہ تمہارے پروردگار (کی طرف) سے نشانیاں بھی لے کر آیا ہے۔ اور اگر وہ جھوٹا ہوگا تو اس کے جھوٹ کا ضرر اسی کو ہوگا۔ اور اگر سچا ہوگا تو کوئی سا عذاب جس کا وہ تم سے وعدہ کرتا ہے تم پر واقع ہو کر رہے گا۔ بےشک خدا اس شخص کو ہدایت نہیں دیتا جو بےلحاظ جھوٹا ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmclxii{اے قوم آج تمہاری ہی بادشاہت ہے اور تم ہی ملک میں غالب ہو۔ (لیکن) اگر ہم پر خدا کا عذاب آگیا تو (اس کے دور کرنے کے لئے) ہماری مدد کون کرے گا۔ فرعون نے کہا کہ میں تمہیں وہی بات سُجھاتا ہوں جو مجھے سوجھی ہے اور وہی راہ بتاتا ہوں جس میں بھلائی ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmclxiii{تو جو مومن تھا وہ کہنے لگا کہ اے قوم مجھے تمہاری نسبت خوف ہے کہ (مبادا) تم پر اور اُمتوں کی طرح کے دن کا عذاب آجائے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmclxiv{یعنی) نوح کی قوم اور عاد اور ثمود اور جو لوگ ان کے پیچھے ہوئے ہیں ان کے حال کی طرح (تمہارا حال نہ ہوجائے) اور خدا تو بندوں پر ظلم کرنا نہیں چاہتا\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmclxv{اور اے قوم مجھے تمہاری نسبت پکار کے دن (یعنی قیامت) کا خوف ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmclxvi{جس دن تم پیٹھ پھیر کر (قیامت کے دن سے) بھاگو گے (اس دن) تم کو کوئی (عذاب) خدا سے بچانے والا نہ ہوگا۔ اور جس شخص کو خدا گمراہ کرے اس کو کوئی ہدایت دینے والا نہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmclxvii{اور پہلے یوسف بھی تمہارے پاس نشانیاں لے کر آئے تھے تو جو وہ لائے تھے اس سے تم ہمیشہ شک ہی میں رہے۔ یہاں تک کہ جب وہ فوت ہوگئے تو تم کہنے لگے کہ خدا اس کے بعد کبھی کوئی پیغمبر نہیں بھیجے گا۔ اسی طرح خدا اس شخص کو گمراہ کر دیتا ہے جو حد سے نکل جانے والا اور شک کرنے والا ہو\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmclxviii{جو لوگ بغیر اس کے کہ ان کے پاس کوئی دلیل آئی ہو خدا کی آیتوں میں جھگڑتے ہیں۔ خدا کے نزدیک اور مومنوں کے نزدیک یہ جھگڑا سخت ناپسند ہے۔ اسی طرح خدا ہر متکبر سرکش کے دل پر مہر لگا دیتا ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmclxix{اور فرعون نے کہا کہ ہامان میرے لئے ایک محل بناؤ تاکہ میں (اس پر چڑھ کر) رستوں پر پہنچ جاؤں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmclxx{یعنی) آسمانوں کے رستوں پر، پھر موسیٰ کے خدا کو دیکھ لوں اور میں تو اسے جھوٹا سمجھتا ہوں۔ اور اسی طرح فرعون کو اس کے اعمال بد اچھے معلوم ہوتے تھے اور وہ رستے سے روک دیا گیا تھا۔ اور فرعون کی تدبیر تو بےکار تھی\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmclxxi{اور وہ شخص جو مومن تھا اس نے کہا کہ بھائیو میرے پیچھے چلو میں تمہیں بھلائی کا رستہ دکھاؤ ں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmclxxii{بھائیو یہ دنیا کی زندگی (چند روزہ) فائدہ اٹھانے کی چیز ہے۔ اور جو آخرت ہے وہی ہمیشہ رہنے کا گھر ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiii{جو برے کام کرے گا اس کو بدلہ بھی ویسا ہی ملے گا۔ اور جو نیک کام کرے گا مرد ہو یا عورت اور وہ صاحب ایمان بھی ہوگا تو ایسے لوگ بہشت میں داخل ہوں گے وہاں ان کو بےشمار رزق ملے گا\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmclxxiv{اور اے قوم میرا کیا (حال) ہے کہ میں تم کو نجات کی طرف بلاتا ہوں اور تم مجھے (دوزخ کی) آگ کی طرف بلاتے ہو\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmclxxv{تم مجھے اس لئے بلاتے ہو کہ خدا کے ساتھ کفر کروں اور اس چیز کو اس کا شریک مقرر کروں جس کا مجھے کچھ بھی علم نہیں۔ اور میں تم کو (خدائے) غالب (اور) بخشنے والے کی طرف بلاتا ہوں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvi{سچ تو یہ ہے کہ جس چیز کی طرف تم مجھے بلاتے ہو اس کو دنیا اور آخرت میں بلانے (یعنی دعا قبول کرنے) کا مقدور نہیں اور ہم کو خدا کی طرف لوٹنا ہے اور حد سے نکل جانے والے دوزخی ہیں\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmclxxvii{جو بات میں تم سے کہتا ہوں تم اسے آگے چل کر یاد کرو گے۔ اور میں اپنا کام خدا کے سپرد کرتا ہوں۔ بےشک خدا بندوں کو دیکھنے والا ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmclxxviii{غرض خدا نے موسیٰ کو ان لوگوں کی تدبیروں کی برائیوں سے محفوظ رکھا اور فرعون والوں کو برے عذاب نے آگھیرا\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmclxxix{یعنی) آتش (جہنم) کہ صبح وشام اس کے سامنے پیش کئے جاتے ہیں۔ اور جس روز قیامت برپا ہوگی (حکم ہوگا کہ) فرعون والوں کو نہایت سخت عذاب میں داخل کرو\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmclxxx{اور جب وہ دوزخ میں جھگڑیں گے تو ادنیٰ درجے کے لوگ بڑے آدمیوں سے کہیں گے کہ ہم تو تمہارے تابع تھے تو کیا تم دوزخ (کے عذاب) کا کچھ حصہ ہم سے دور کرسکتے ہو؟\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxi{بڑے آدمی کہیں گے کہ تم (بھی اور) ہم (بھی) سب دوزخ میں (رہیں گے) خدا بندوں میں فیصلہ کرچکا ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxii{اور جو لوگ آگ میں (جل رہے) ہوں گے وہ دوزخ کے داروغوں سے کہیں گے کہ اپنے پروردگار سے دعا کرو کہ ایک روز تو ہم سے عذاب ہلکا کردے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiii{وہ کہیں گے کہ کیا تمہارے پاس تمہارے پیغمبر نشانیاں لے کر نہیں آئے تھے۔ وہ کہیں گے کیوں نہیں تو وہ کہیں گے کہ تم ہی دعا کرو۔ اور کافروں کی دعا (اس روز) بےکار ہوگی\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxiv{ہم اپنے پیغمبروں کی اور جو لوگ ایمان لائے ہیں ان کی دنیا کی زندگی میں بھی مدد کرتے ہیں اور جس دن گواہ کھڑے ہوں گے (یعنی قیامت کو بھی)\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxv{جس دن ظالموں کو ان کی معذرت کچھ فائدہ نہ دے گی اور ان کے لئے لعنت اور برا گھر ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvi{اور ہم نے موسیٰ کو ہدایت (کی کتاب) دی اور بنی اسرائیل کو اس کتاب کا وارث بنایا\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxvii{عقل والوں کے لئے ہدایت اور نصیحت ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxviii{تو صبر کرو بےشک خدا کا وعدہ سچا ہے اور اپنے گناہوں کی معافی مانگو اور صبح وشام اپنے پروردگار کی تعریف کے ساتھ تسبیح کرتے رہو\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmclxxxix{جو لوگ بغیر کسی دلیل کے جو ان کے پاس آئی ہو خدا کی آیتوں میں جھگڑتے ہیں ان کے دلوں میں اور کچھ نہیں (ارادہٴ) عظمت ہے اور وہ اس کو پہنچنے والے نہیں تو خدا کی پناہ مانگو۔ بےشک وہ سننے والا (اور) دیکھنے والا ہے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmcxc{آسمانوں اور زمین کا پیدا کرنا لوگوں کے پیدا کرنے کی نسبت بڑا (کام) ہے لیکن اکثر لوگ نہیں جانتے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmcxci{اور اندھا اور آنکھ والا برابر نہیں۔ اور نہ ایمان لانے والے نیکوکار اور نہ بدکار (برابر ہیں) (حقیقت یہ ہے کہ) تم بہت کم غور کرتے ہو\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmcxcii{قیامت آنے والی ہے اس میں کچھ شک نہیں۔ لیکن اکثر لوگ ایمان نہیں رکھتے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmcxciii{اور تمہارے پروردگار نے کہا ہے کہ تم مجھ سے دعا کرو میں تمہاری (دعا) قبول کروں گا۔ جو لوگ میری عبادت سے ازراہ تکبر کنیاتے ہیں۔ عنقریب جہنم میں ذلیل ہو کر داخل ہوں گے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmcxciv{خدا ہی تو ہے جس نے تمہارے لئے رات بنائی کہ اس میں آرام کرو اور دن کو روشن بنایا (کہ اس میں کام کرو) بےشک خدا لوگوں پر فضل کرنے والا ہے۔ لیکن اکثر لوگ شکر نہیں کرتے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmcxcv{یہی خدا تمہارا پروردگار ہے جو ہر چیز کا پیدا کرنے والا ہے۔ اس کے سوا کوئی معبود نہیں پھر تم کہاں بھٹک رہے ہو؟\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvi{اسی طرح وہ لوگ بھٹک رہے تھے جو خدا کی آیتوں سے انکار کرتے تھے\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmcxcvii{خدا ہی تو ہے جس نے زمین کو تمہارے لئے ٹھیرنے کی جگہ اور آسمان کو چھت بنایا اور تمہاری صورتیں بنائیں اور صورتیں بھی خوب بنائیں اور تمہیں پاکیزہ چیزیں کھانے کو دیں۔ یہی خدا تمہارا پروردگار ہے۔ پس خدائے پروردگار عالم بہت ہی بابرکت ہے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmcxcviii{وہ زندہ ہے (جسے موت نہیں) اس کے سوا کوئی عبادت کے لائق نہیں تو اس کی عبادت کو خالص کر کر اسی کو پکارو۔ ہر طرح کی تعریف خدا ہی کو (سزاوار) ہے جو تمام جہان کا پروردگار ہے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmcxcix{اے محمدﷺ ان سے) کہہ دو کہ مجھے اس بات کی ممانعت کی گئی ہے کہ جن کو تم خدا کے سوا پکارتے ہو ان کی پرستش کروں (اور میں ان کی کیونکر پرستش کروں) جب کہ میرے پاس میرے پروردگار (کی طرف) سے کھلی دلیلیں آچکی ہیں اور مجھ کو یہ حکم ہوا ہے کہ پروردگار عالم ہی کا تابع فرمان ہوں\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmcc{وہی تو ہے جس نے تم کو (پہلے) مٹی سے پیدا کیا۔ ہھر نطفہ بنا کر پھر لوتھڑا بنا کر پھر تم کو نکالتا ہے (کہ تم) بچّے (ہوتے ہو) پھر تم اپنی جوانی کو پہنچتے ہو۔ پھر بوڑھے ہوجاتے ہو۔ اور کوئی تم میں سے پہلے ہی مرجاتا ہے اور تم (موت کے) وقت مقرر تک پہنچ جاتے ہو اور تاکہ تم سمجھو\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmcci{وہی تو ہے جو جلاتا ہے اور مارتا ہے۔ پھر جب وہ کوئی کام کرنا (اور کسی کو پیدا کرنا) چاہتا ہے تو اس سے کہہ دیتا ہے کہ ہوجا تو وہ جاتا ہے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmccii{کیا تم نے ان لوگوں کو نہیں دیکھا جو خدا کی آیتوں میں جھگڑتے ہیں۔ یہ کہاں بھٹک رہے ہیں؟\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmcciii{جن لوگوں نے کتاب (خدا) کو اور جو کچھ ہم نے پیغمبروں کو دے کر بھیجا اس کو جھٹلایا۔ وہ عنقریب معلوم کرلیں گے\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmcciv{جب کہ ان کی گردنوں میں طوق اور زنجیریں ہوں گی (اور) گھسیٹے جائیں گے\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmccv{یعنی) کھولتے ہوئے پانی میں۔ پھر آگ میں جھونک دیئے جائیں گے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmccvi{پھر ان سے کہا جائے گا کہ وہ کہاں ہیں جن کو تم (خدا کے) شریک بناتے تھے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmccvii{یعنی غیر خدا) کہیں گے وہ تو ہم سے جاتے رہے بلکہ ہم تو پہلے کسی چیز کو پکارتے ہی نہیں تھے۔ اسی طرح خدا کافروں کو گمراہ کرتا ہے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmccviii{یہ اس کا بدلہ ہے کہ تم زمین میں حق کے بغیر (یعنی اس کے خلاف) خوش ہوا کرتے تھے اور اس کی (سزا ہے) کہ اترایا کرتے تھے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmccix{اب) جہنم کے دروازوں میں داخل ہوجاؤ۔ ہمیشہ اسی میں رہو گے۔ متکبروں کا کیا برا ٹھکانا ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmmccx{تو (اے پیغمبر) صبر کرو خدا کا وعدہ سچا ہے۔ اگر ہم تم کو کچھ اس میں سے دکھادیں جس کا ہم تم سے وعدہ کرتے ہیں۔ (یعنی کافروں پر عذاب نازل کریں) یا تمہاری مدت حیات پوری کردیں تو ان کو ہماری ہی طرف لوٹ کر آنا ہے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmmccxi{اور ہم نے تم سے پہلے (بہت سے) پیغمبر بھیجے۔ ان میں کچھ تو ایسے ہیں جن کے حالات تم سے بیان کر دیئے ہیں اور کچھ ایسے ہیں جن کے حالات بیان نہیں کئے۔ اور کسی پیغمبر کا مقدور نہ تھا کہ خدا کے حکم کے سوا کوئی نشانی لائے۔ پھر جب خدا کا حکم آپہنچا تو انصاف کے ساتھ فیصلہ کردیا گیا اور اہل باطل نقصان میں پڑ گئے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmmccxii{خدا ہی تو ہے جس نے تمہارے لئے چارپائے بنائے تاکہ ان میں سے بعض پر سوار ہو اور بعض کو تم کھاتے ہو\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmmccxiii{اور تمہارے لئے ان میں (اور بھی) فائدے ہیں اور اس لئے بھی کہ (کہیں جانے کی) تمہارے دلوں میں جو حاجت ہو ان پر (چڑھ کر وہاں) پہنچ جاؤ۔ اور ان پر اور کشتیوں پر تم سوار ہوتے ہو\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmmccxiv{اور وہ تمہیں اپنی نشانیاں دکھاتا ہے تو تم خدا کی کن کن نشانیوں کو نہ مانو گے\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmmccxv{کیا ان لوگوں نے زمین میں سیر نہیں کی تاکہ دیکھتے جو لوگ ان سے پہلے تھے ان کا انجام کیسا ہوا۔ (حالانکہ) وہ ان سے کہیں زیادہ طاقتور اور زمین میں نشانات (بنانے) کے اعتبار سے بہت بڑھ کر تھے۔ تو جو کچھ وہ کرتے تھے وہ ان کے کچھ کام نہ آیا\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmmccxvi{اور جب ان کے پیغمبر ان کے پاس کھلی نشانیاں لے کر آئے تو جو علم (اپنے خیال میں) ان کے پاس تھا اس پر اترانے لگے اور جس چیز سے تمسخر کیا کرتے تھے اس نے ان کو آ گھیرا\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmmccxvii{پھر جب انہوں نے ہمارا عذاب دیکھ لیا تو کہنے لگے کہ ہم خدائے واحد پر ایمان لائے اور جس چیز کو اس کے ساتھ شریک بناتے تھے اس سے نامعتقد ہوئے\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmmccxviii{لیکن جب وہ ہمارا عذاب دیکھ چکے (اس وقت) ان کے ایمان نے ان کو کچھ بھی فائدہ نہ دیا۔ (یہ) خدا کی عادت (ہے) جو اس کے بندوں (کے بارے) میں چلی آتی ہے۔ اور وہاں کافر گھاٹے میں پڑ گئے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmmccxix{\basmalahur حٰم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmccxx{یہ کتاب خدائے) رحمٰن ورحیم (کی طرف) سے اُتری ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmccxxi{کتاب جس کی آیتیں واضح (المعانی) ہیں (یعنی) قرآن عربی ان لوگوں کے لئے جو سمجھ رکھتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmccxxii{جو بشارت بھی سناتا ہے اور خوف بھی دلاتا ہے لیکن ان میں سے اکثروں نے منہ پھیر لیا اور وہ سنتے ہی نہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiii{اور کہتے ہیں کہ جس چیز کی طرف تم ہمیں بلاتے ہو اس سے ہمارے دل پردوں میں ہیں اور ہمارے کانوں میں بوجھ (یعنی بہراپن) ہے اور ہمارے اور تمہارے درمیان پردہ ہے تو تم (اپنا) کام کرو ہم (اپنا) کام کرتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmccxxiv{کہہ دو کہ میں بھی آدمی ہوں جیسے تم۔ (ہاں) مجھ پر یہ وحی آتی ہے کہ تمہارا معبود خدائے واحد ہے تو سیدھے اسی کی طرف (متوجہ) رہو اور اسی سے مغفرت مانگو اور مشرکوں پر افسوس ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmccxxv{جو زکوٰة نہیں دیتے اور آخرت کے بھی قائل نہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvi{جو لوگ ایمان لائے اور عمل نیک کرتے رہے ان کے لئے (ایسا) ثواب ہے جو ختم ہی نہ ہو\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmccxxvii{کہو کیا تم اس سے انکار کرتے ہو جس نے زمین کو دو دن میں پیدا کیا۔ اور (بتوں کو) اس کا مدمقابل بناتے ہو۔ وہی تو سارے جہان کا مالک ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmccxxviii{اور اسی نے زمین میں اس کے اوپر پہاڑ بنائے اور زمین میں برکت رکھی اور اس میں سب سامان معیشت مقرر کیا (سب) چار دن میں۔ (اور تمام) طلبگاروں کے لئے یکساں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmccxxix{پھر آسمان کی طرف متوجہ ہوا اور وہ دھواں تھا تو اس نے اس سے اور زمین سے فرمایا کہ دونوں آؤ (خواہ) خوشی سے خواہ ناخوشی سے۔ انہوں نے کہا کہ ہم خوشی سے آتے ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmccxxx{پھر دو دن میں سات آسمان بنائے اور ہر آسمان میں اس (کے کام) کا حکم بھیجا اور ہم نے آسمان دنیا کو چراغوں (یعنی ستاروں) سے مزین کیا اور (شیطانوں سے) محفوظ رکھا۔ یہ زبردست (اور) خبردار کے (مقرر کئے ہوئے) اندازے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxi{پھر اگر یہ منہ پھیر لیں تو کہہ دو کہ میں تم کو ایسے چنگھاڑ (کے عذاب) سے آگاہ کرتا ہوں جیسے عاد اور ثمود پر چنگھاڑ (کا عذاب آیا تھا)\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxii{جب ان کے پاس پیغمبر ان کے آگے اور پیچھے سے آئے کہ خدا کے سوا (کسی کی) عبادت نہ کرو۔ کہنے لگے کہ اگر ہمارا پروردگار چاہتا تو فرشتے اُتار دیتا سو جو تم دے کر بھیجے گئے ہو ہم اس کو نہیں مانتے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiii{جو عاد تھے وہ ناحق ملک میں غرور کرنے لگے اور کہنے لگے کہ ہم سے بڑھ کر قوت میں کون ہے؟ کیا انہوں نے نہیں دیکھا کہ خدا جس نے ان کو پیدا کیا وہ ان سے قوت میں بہت بڑھ کر ہے۔ اور وہ ہماری آیتوں سے انکار کرتے رہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxiv{تو ہم نے بھی ان پر نحوست کے دنوں میں زور کی ہوا چلائی تاکہ ان کو دنیا کی زندگی میں ذلت کے عذاب کا مزہ چکھا دیں۔ اور آخرت کا عذاب تو بہت ہی ذلیل کرنے والا ہے اور (اس روز) ان کو مدد بھی نہ ملے گی\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxv{اور جو ثمود تھے ان کو ہم نے سیدھا رستہ دکھا دیا تھا مگر انہوں نے ہدایت کے مقابلے میں اندھا دھند رہنا پسند کیا تو ان کے اعمال کی سزا میں کڑک نے ان کو آپکڑا۔ اور وہ ذلت کا عذاب تھا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvi{اور جو ایمان لائے اور پرہیزگاری کرتے رہے ان کو ہم نے بچا لیا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxvii{اور جس دن خدا کے دشمن دوزخ کی طرف چلائے جائیں گے تو ترتیب وار کرلیئے جائیں گے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxviii{یہاں تک کہ جب اس کے پاس پہنچ جائیں گے تو ان کے کان اور آنکھیں اور چمڑے (یعنی دوسرے اعضا) ان کے خلاف ان کے اعمال کی شہادت دیں گے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmccxxxix{اور وہ اپنے چمڑوں (یعنی اعضا) سے کہیں گے کہ تم نے ہمارے خلاف کیوں شہادت دی؟ وہ کہیں گے کہ جس خدا نے سب چیزوں کو نطق بخشا اسی نے ہم کو بھی گویائی دی اور اسی نے تم کو پہلی بار پیدا کیا تھا اور اسی کی طرف تم کو لوٹ کر جانا ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmccxl{اور تم اس (بات کے خوف) سے تو پردہ نہیں کرتے تھے کہ تمہارے کان اور تمہاری آنکھیں اور چمڑے تمہارے خلاف شہادت دیں گے بلکہ تم یہ خیال کرتے تھے کہ خدا کو تمہارے بہت سے عملوں کی خبر ہی نہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmccxli{اور اسی خیال نے جو تم اپنے پروردگار کے بارے میں رکھتے تھے تم کو ہلاک کردیا اور تم خسارہ پانے والوں میں ہوگئے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmccxlii{اب اگر یہ صبر کریں گے تو ان کا ٹھکانا دوزخ ہے۔ اور اگر توبہ کریں گے تو ان کی توبہ قبول نہیں کی جائے گی\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmccxliii{اور ہم نے (شیطانوں کو) ان کا ہم نشین مقرر کردیا تھا تو انہوں نے ان کے اگلے اور پچھلے اعمال ان کو عمدہ کر دکھائے تھے اور جنات اور انسانوں کی جماعتیں جو ان سے پہلے گذر چکیں ان پر بھی خدا (کے عذاب) کا وعدہ پورا ہوگیا۔ بےشک یہ نقصان اٹھانے والے ہیں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmccxliv{اور کافر کہنے لگے کہ اس قرآن کو سنا ہی نہ کرو اور (جب پڑھنے لگیں تو) شور مچا دیا کرو تاکہ تم غالب رہو\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmccxlv{سو ہم بھی کافروں کو سخت عذاب کے مزے چکھائیں گے اور ان کے برے عملوں کی جو وہ کرتے تھے سزا دیں گے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvi{یہ خدا کے دشمنوں کا بدلہ ہے (یعنی) دوزخ۔ ان کے لئے اسی میں ہمیشہ کا گھر ہے۔ یہ اس کی سزا ہے کہ ہماری آیتوں سے انکار کرتے تھے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmccxlvii{اور کافر کہیں گے کہ اے ہمارے پروردگار جنوں اور انسانوں میں سے جن لوگوں نے ہم کو گمراہ کیا تھا ان کو ہمیں دکھا کہ ہم ان کو اپنے پاؤں کے تلے (روند) ڈالیں تاکہ وہ نہایت ذلیل ہوں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmccxlviii{جن لوگوں نے کہا کہ ہمارا پروردگار خدا ہے پھر وہ (اس پر) قائم رہے ان پر فرشتے اُتریں گے (اور کہیں گے) کہ نہ خوف کرو اور نہ غمناک ہو اور بہشت کی جس کا تم سے وعدہ کیا جاتا تھا خوشی مناؤ\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmccxlix{ہم دنیا کی زندگی میں بھی تمہارے دوست تھے اور آخرت میں بھی (تمہارے رفیق ہیں) ۔ اور وہاں جس (نعمت) کو تمہارا جی چاہے گا تم کو (ملے گی) اور جو چیز طلب کرو گے تمہارے لئے (موجود ہوگی)\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmccl{یہ) بخشنے والے مہربان کی طرف سے مہمانی ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmccli{اور اس شخص سے بات کا اچھا کون ہوسکتا ہے جو خدا کی طرف بلائے اور عمل نیک کرے اور کہے کہ میں مسلمان ہوں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmcclii{اور بھلائی اور برائی برابر نہیں ہوسکتی۔ تو (سخت کلامی کا) ایسے طریق سے جواب دو جو بہت اچھا ہو (ایسا کرنے سے تم دیکھو گے) کہ جس میں اور تم میں دشمنی تھی گویا وہ تمہارا گرم جوش دوست ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmccliii{اور یہ بات ان ہی لوگوں کو حاصل ہوتی ہے جو برداشت کرنے والے ہیں۔ اور ان ہی کو نصیب ہوتی ہے جو بڑے صاحب نصیب ہیں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmccliv{اور اگر تمہیں شیطان کی جانب سے کوئی وسوسہ پیدا ہو تو خدا کی پناہ مانگ لیا کرو۔ بےشک وہ سنتا جانتا ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmcclv{اور رات اور دن اور سورج اور چاند اس کی نشانیوں میں سے ہیں۔ تم لوگ نہ تو سورج کو سجدہ کرو اور نہ چاند کو۔ بلکہ خدا ہی کو سجدہ کرو جس نے ان چیزوں کو پیدا کیا ہے اگر تم کو اس کی عبادت منظور ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmcclvi{اگر یہ لوگ سرکشی کریں تو (خدا کو بھی ان کی پروا نہیں) جو (فرشتے) تمہارے پروردگار کے پاس ہیں وہ رات دن اس کی تسبیح کرتے رہتے ہیں اور (کبھی) تھکتے ہی نہیں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmcclvii{اور (اے بندے یہ) اسی کی قدرت کے نمونے ہیں کہ تو زمین کو دبی ہوئی (یعنی خشک) دیکھتا ہے۔ جب ہم اس پر پانی برسا دیتے ہیں تو شاداب ہوجاتی اور پھولنے لگتی ہے تو جس نے زمین کو زندہ کیا وہی مردوں کو زندہ کرنے والا ہے۔ بےشک وہ ہر چیز پر قادر ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmcclviii{جو لوگ ہماری آیتوں میں کج راہی کرتے ہیں وہ ہم سے پوشیدہ نہیں ہیں۔ بھلا جو شخص دوزخ میں ڈالا جائے وہ بہتر ہے یا وہ جو قیامت کے دن امن وامان سے آئے۔ (تو خیر) جو چاہو سو کرلو۔ جو کچھ تم کرتے ہو وہ اس کو دیکھ رہا ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmcclix{جن لوگوں نے نصیحت کو نہ مانا جب وہ ان کے پاس آئی۔ اور یہ تو ایک عالی رتبہ کتاب ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmcclx{اس پر جھوٹ کا دخل نہ آگے سے ہوسکتا ہے نہ پیچھے سے۔ (اور) دانا (اور) خوبیوں والے (خدا) کی اُتاری ہوئی ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmcclxi{تم سے وہی باتیں کہیں جاتی ہیں جو تم سے پہلے اور پیغمبروں سے کہی گئی تھیں۔ بےشک تمہارا پروردگار بخش دینے والا بھی اور عذاب الیم دینے والا بھی ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmcclxii{اور اگر ہم اس قرآن کو غیر زبان عرب میں (نازل) کرتے تو یہ لوگ کہتے کہ اس کی آیتیں (ہماری زبان میں) کیوں کھول کر بیان نہیں کی گئیں۔ کیا (خوب کہ قرآن تو) عجمی اور (مخاطب) عربی۔ کہہ دو کہ جو ایمان لاتے ہیں ان کے لئے (یہ) ہدایت اور شفا ہے۔ اور جو ایمان نہیں لاتے ان کے کانوں میں گرانی (یعنی بہراپن) ہے اور یہ ان کے حق میں (موجب) نابینائی ہے۔ گرانی کے سبب ان کو (گویا) دور جگہ سے آواز دی جاتی ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiii{اور ہم نے موسیٰ کو کتاب دی تو اس میں اختلاف کیا گیا۔ اور اگر تمہارے پروردگار کی طرف سے ایک بات پہلے نہ ٹھہر چکی ہوتی تو ان میں فیصلہ کردیا جاتا۔ اور یہ اس (قرآن) سے شک میں الجھ رہے ہیں\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmcclxiv{جو نیک کام کرے گا تو اپنے لئے۔ اور جو برے کام کرے گا تو ان کا ضرر اسی کو ہوگا۔ اور تمہارا پروردگار بندوں پر ظلم کرنے والا نہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmcclxv{قیامت کے علم کا حوالہ اسی کی طرف دیا جاتا ہے (یعنی قیامت کا علم اسی کو ہے) اور نہ تو پھل گا بھوں سے نکلتے ہیں اور نہ کوئی مادہ حاملہ ہوتی اور نہ جنتی ہے مگر اس کے علم سے۔ اور جس دن وہ ان کو پکارے گا (اور کہے گا) کہ میرے شریک کہاں ہیں تو وہ کہیں گے کہ ہم تجھ سے عرض کرتے ہیں کہ ہم میں سے کسی کو (ان کی) خبر ہی نہیں\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvi{اور جن کو پہلے وہ (خدا کے سوا) پکارا کرتے تھے (سب) ان سے غائب ہوجائیں گے اور وہ یقین کرلیں گے کہ ان کے لئے مخلصی نہیں\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmcclxvii{انسان بھلائی کی دعائیں کرتا کرتا تو تھکتا نہیں اور اگر تکلیف پہنچ جاتی ہے تو ناامید ہوجاتا اور آس توڑ بیٹھتا ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmcclxviii{اور اگر تکلیف پہنچنے کے بعد ہم اس کو اپنی رحمت کا مزہ چکھاتے ہیں تو کہتا ہے کہ یہ تو میرا حق تھا اور میں نہیں خیال کرتا کہ قیامت برپا ہو۔ اور اگر (قیامت سچ مچ بھی ہو اور) میں اپنے پروردگار کی طرف لوٹایا بھی جاؤں تو میرے لئے اس کے ہاں بھی خوشحالی ہے۔ پس کافر جو عمل کیا کرتے وہ ہم ان کو ضرور جتائیں گے اور ان کو سخت عذاب کا مزہ چکھائیں گے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmcclxix{اور جب ہم انسان پر کرم کرتے ہیں تو منہ موڑ لیتا ہے اور پہلو پھیر کر چل دیتا ہے۔ اور جب اس کو تکلیف پہنچتی ہے تو لمبی لمبی دعائیں کرنے لگتا ہے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmcclxx{کہو کہ بھلا دیکھو اگر یہ (قرآن) خدا کی طرف سے ہو پھر تم اس سے انکار کرو تو اس سے بڑھ کر کون گمراہ ہے جو (حق کی) پرلے درجے کی مخالفت میں ہو\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxi{ہم عنقریب ان کو اطراف (عالم) میں بھی اور خود ان کی ذات میں بھی اپنی نشانیاں دکھائیں گے یہاں تک کہ ان پر ظاہر ہوجائے گا کہ (قرآن) حق ہے۔ کیا تم کو یہ کافی نہیں کہ تمہارا پروردگار ہر چیز سے خبردار ہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxii{دیکھو یہ اپنے پروردگار کے روبرو حاضر ہونے سے شک میں ہیں۔ سن رکھو کہ وہ ہر چیز پر احاطہ کئے ہوئے ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiii{\basmalahur حٰمٓ\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxiv{عٓسٓقٓ\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxv{خدائے غالب و دانا اسی طرح تمہاری طرف مضامین اور (براہین) بھیجتا ہے جس طرح تم سے پہلے لوگوں کی طرف وحی بھیجتا رہا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvi{جو کچھ آسمانوں میں اور جو کچھ زمین میں ہے سب اسی کا ہے۔ اور وہ عالی رتبہ اور گرامی قدر ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxvii{قریب ہے کہ آسمان اوپر سے پھٹ پڑیں اور فرشتے اپنے پروردگار کی تعریف کے ساتھ اس کی تسبیج کرتے رہتے ہیں اور جو لوگ زمین میں ہیں ان کے لئے معافی مانگتے رہتے ہیں۔ سن رکھو کہ خدا بخشنے والا مہربان ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxviii{اور جن لوگوں نے اس کے سوا کارساز بنا رکھے ہیں وہ خدا کو یاد ہیں۔ اور تم ان پر داروغہ نہیں ہو\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxix{اور اسی طرح تمہارے پاس قرآن عربی بھیجا ہے تاکہ تم بڑے گاؤں (یعنی مکّے) کے رہنے والوں کو اور جو لوگ اس کے اردگرد رہتے ہیں ان کو رستہ دکھاؤ اور انہیں قیامت کے دن کا بھی جس میں کچھ شک نہیں ہے خوف دلاؤ۔ اس روز ایک فریق بہشت میں ہوگا اور ایک فریق دوزخ میں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxx{اور اگر خدا چاہتا تو ان کو ایک ہی جماعت کردیتا لیکن وہ جس کو چاہتا ہے اپنی رحمت میں داخل کرلیتا ہے اور ظالموں کا نہ کوئی یار ہے اور نہ مددگار\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxi{کیا انہوں نے اس کے سوا کارساز بنائے ہیں؟ کارساز تو خدا ہی ہے اور وہی مردوں کو زندہ کرے گا اور وہ ہر چیز پر قدرت رکھتا ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxii{اور تم جس بات میں اختلاف کرتے ہو اس کا فیصلہ خدا کی طرف (سے ہوگا) یہی خدا میرا پروردگار ہے میں اسی پر بھروسہ رکھتا ہوں۔ اور اسی کی طرف رجوع کرتا ہوں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiii{آسمانوں اور زمین کا پیدا کرنے والا (وہی ہے) ۔ اسی نے تمہارے لئے تمہاری ہی جنس کے جوڑے بنائے اور چارپایوں کے بھی جوڑے (بنائے اور) اسی طریق پر تم کو پھیلاتا رہتا ہے۔ اس جیسی کوئی چیز نہیں۔ اور وہ دیکھتا سنتا ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxiv{آسمانوں اور زمین کی کنجیاں اسی کے ہاتھ میں ہیں۔ وہ جس کے لئے چاہتا ہے رزق فراخ کردیتا ہے (اور جس کے لئے چاہتا ہے) تنگ کردیتا ہے۔ بےشک وہ ہر چیز سے واقف ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxv{اسی نے تمہارے لئے دین کا وہی رستہ مقرر کیا جس (کے اختیار کرنے کا) نوح کو حکم دیا تھا اور جس کی (اے محمدﷺ) ہم نے تمہاری طرف وحی بھیجی ہے اور جس کا ابراہیم اور موسیٰ اور عیسیٰ کو حکم دیا تھا (وہ یہ) کہ دین کو قائم رکھنا اور اس میں پھوٹ نہ ڈالنا۔ جس چیز کی طرف تم مشرکوں کو بلاتے ہو وہ ان کو دشوار گزرتی ہے۔ الله جس کو چاہتا ہے اپنی بارگاہ کا برگزیدہ کرلیتا ہے اور جو اس کی طرف رجوع کرے اسے اپنی طرف رستہ دکھا دیتا ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvi{اور یہ لوگ جو الگ الگ ہوئے ہیں تو علم (حق) آچکنے کے بعد آپس کی ضد سے (ہوئے ہیں) ۔ اور اگر تمہارے پروردگار کی طرف سے ایک وقت مقرر تک کے لئے بات نہ ٹھہر چکی ہوتی تو ان میں فیصلہ کردیا جاتا۔ اور جو لوگ ان کے بعد (خدا کی) کتاب کے وارث ہوئے وہ اس (کی طرف) سے شبہے کی الجھن میں (پھنسے ہوئے) ہیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxvii{تو (اے محمدﷺ) اسی (دین کی) طرف (لوگوں کو) بلاتے رہنا اور جیسا تم کو حکم ہوا ہے (اسی پر) قائم رہنا۔ اور ان کی خواہشوں کی پیروی نہ کرنا۔ اور کہہ دو کہ جو کتاب خدا نے نازل فرمائی ہے میں اس پر ایمان رکھتا ہوں۔ اور مجھے حکم ہوا ہے کہ تم میں انصاف کروں۔ خدا ہی ہمارا اور تمہارا پروردگار ہے۔ ہم کو ہمارے اعمال (کا بدلہ ملے گا) اور تم کو تمہارے اعمال کا۔ ہم میں اور تم میں کچھ بحث وتکرار نہیں۔ خدا ہم (سب) کو اکھٹا کرے گا۔ اور اسی کی طرف لوٹ کر جانا ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxviii{اور جو لوگ خدا (کے بارے) میں بعد اس کے کہ اسے (مومنوں نے) مان لیا ہو جھگڑتے ہیں ان کے پروردگار کے نزدیک ان کا جھگڑا لغو ہے۔ اور ان پر (خدا کا) غضب اور ان کے لئے سخت عذاب ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcclxxxix{خدا ہی تو ہے جس نے سچائی کے ساتھ کتاب نازل فرمائی اور (عدل وانصاف کی) ترازو۔ اور تم کو کیا معلوم شاید قیامت قریب ہی آ پہنچی ہو\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmccxc{جو لوگ اس پر ایمان نہیں رکھتے وہ اس کے لئے جلدی کر رہے ہیں۔ اور جو مومن ہیں وہ اس سے ڈرتے ہیں۔ اور جانتے ہیں کہ وہ برحق ہے۔ دیکھو جو لوگ قیامت میں جھگڑتے ہیں وہ پرلے درجے کی گمراہی میں ہیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmccxci{خدا اپنے بندوں پر مہربان ہے وہ جس کو چاہتا ہے رزق دیتا ہے۔ اور وہ زور والا (اور) زبردست ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmccxcii{جو شخص آخرت کی کھیتی کا خواستگار ہو اس کو ہم اس میں سے دیں گے۔ اور جو دنیا کی کھیتی کا خواستگار ہو اس کو ہم اس میں سے دے دیں گے۔ اور اس کا آخرت میں کچھ حصہ نہ ہوگا\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmccxciii{کیا ان کے وہ شریک ہیں جنہوں نے ان کے لئے ایسا دین مقرر کیا ہے جس کا خدا نے حکم نہیں دیا۔ اور اگر فیصلے (کے دن) کا وعدہ نہ ہوتا تو ان میں فیصلہ کردیا جاتا اور جو ظالم ہیں ان کے لئے درد دینے والا عذاب ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmccxciv{تم دیکھو گے کہ ظالم اپنے اعمال (کے وبال) سے ڈر رہے ہوں گے اور وہ ان پر پڑے گا۔ اور جو لوگ ایمان لائے اور نیک عمل کرتے رہے وہ بہشت کے باغوں میں ہوں گے۔ وہ جو کچھ چاہیں گے ان کے لیے ان کے پروردگار کے پاس (موجود) ہوگا۔ یہی بڑا فضل ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmccxcv{یہی وہ (انعام ہے) جس کی خدا اپنے ان بندوں کو جو ایمان لاتے اور عمل نیک کرتے ہیں بشارت دیتا ہے۔ کہہ دو کہ میں اس کا تم سے صلہ نہیں مانگتا مگر (تم کو) قرابت کی محبت (تو چاہیئے) اور جو کوئی نیکی کرے گا ہم اس کے لئے اس میں ثواب بڑھائیں گے۔ بےشک خدا بخشنے والا قدردان ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvi{کیا یہ لوگ کہتے ہیں کہ پیغمبر نے خدا پر جھوٹ باندھ لیا ہے؟ اگر خدا چاہے تو (اے محمدﷺ) تمہارے دل پر مہر لگا دے۔ اور خدا جھوٹ کو نابود کرتا اور اپنی باتوں سے حق کو ثابت کرتا ہے۔ بےشک وہ سینے تک کی باتوں سے واقف ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmccxcvii{اور وہی تو ہے جو اپنے بندوں کی توبہ قبول کرتا اور (ان کے) قصور معاف فرماتا ہے اور جو تم کرتے ہو (سب) جانتا ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmccxcviii{اور جو ایمان لائے اور عمل نیک کئے ان کی (دعا) قبول فرماتا ہے اور ان کو اپنے فضل سے بڑھاتا ہے۔ اور جو کافر ہیں ان کے لئے سخت عذاب ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmccxcix{اور اگر خدا اپنے بندوں کے لئے رزق میں فراخی کردیتا تو زمین میں فساد کرنے لگتے۔ لیکن وہ جو چیز چاہتا ہے اندازے کے ساتھ نازل کرتا ہے۔ بےشک وہ اپنے بندوں کو جانتا اور دیکھتا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmccc{اور وہی تو ہے جو لوگوں کے ناامید ہوجانے کے بعد مینہ برساتا اور اپنی رحمت (یعنی بارش) کی برکت کو پھیلا دیتا ہے۔ اور وہ کارساز اور سزاوار تعریف ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmccci{اور اسی کی نشانیوں میں سے ہے آسمانوں اور زمین کا پیدا کرنا اور ان جانوروں کا جو اس نے ان میں پھیلا رکھے ہیں اور وہ جب چاہے ان کے جمع کرلینے پر قادر ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmcccii{اور جو مصیبت تم پر واقع ہوتی ہے سو تمہارے اپنے فعلوں سے اور وہ بہت سے گناہ تو معاف ہی کردیتا ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmccciii{اور تم زمین میں (خدا کو) عاجز نہیں کرسکتے۔ اور خدا کے سوا نہ تمہارا کوئی دوست ہے اور نہ مددگار\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmccciv{اور اسی کی نشانیوں میں سے سمندر کے جہاز ہیں (جو) گویا پہاڑ (ہیں)\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmcccv{اگر خدا چاہے تو ہوا کو ٹھیرا دے اور جہاز اس کی سطح پر کھڑے رہ جائیں۔ تمام صبر اور شکر کرنے والوں کے لئے ان (باتوں) میں قدرت خدا کے نمونے ہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmcccvi{یا ان کے اعمال کے سبب ان کو تباہ کردے۔ اور بہت سے قصور معاف کردے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmcccvii{اور (انتقام اس لئے لیا جائے کہ) جو لوگ ہماری آیتوں میں جھگڑتے ہیں۔ وہ جان لیں کہ ان کے لئے خلاصی نہیں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmcccviii{لوگو) جو (مال ومتاع) تم کو دیا گیا ہے وہ دنیا کی زندگی کا (ناپائدار) فائدہ ہے۔ اور جو کچھ خدا کے ہاں ہے وہ بہتر اور قائم رہنے والا ہے (یعنی) ان لوگوں کے لئے جو ایمان لائے اور اپنے پروردگار پر بھروسا رکھتے ہیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmcccix{اور جو بڑے بڑے گناہوں اور بےحیائی کی باتوں سے پرہیز کرتے ہیں۔ اور جب غصہ آتا ہے تو معاف کردیتے ہیں\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmcccx{اور جو اپنے پروردگار کا فرمان قبول کرتے ہیں اور نماز پڑھتے ہیں۔ اور اپنے کام آپس کے مشورے سے کرتے ہیں۔ اور جو مال ہم نے ان کو عطا فرمایا ہے اس میں سے خرچ کرتے ہیں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmcccxi{اور جو ایسے ہیں کہ جب ان پر ظلم وتعدی ہو تو (مناسب طریقے سے) بدلہ لیتے ہیں\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmcccxii{اور برائی کا بدلہ تو اسی طرح کی برائی ہے۔ مگر جو درگزر کرے اور (معاملے کو) درست کردے تو اس کا بدلہ خدا کے ذمے ہے۔ اس میں شک نہیں کہ وہ ظلم کرنے والوں کو پسند نہیں کرتا\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiii{اور جس پر ظلم ہوا ہو اگر وہ اس کے بعد انتقام لے تو ایسے لوگوں پر کچھ الزام نہیں\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmcccxiv{الزام تو ان لوگوں پر ہے جو لوگوں پر ظلم کرتے ہیں اور ملک میں ناحق فساد پھیلاتے ہیں۔ یہی لوگ ہیں جن کو تکلیف دینے والا عذاب ہوگا\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmcccxv{اور جو صبر کرے اور قصور معاف کردے تو یہ ہمت کے کام ہیں\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvi{اور جس شخص کو خدا گمراہ کرے تو اس کے بعد اس کا کوئی دوست نہیں۔ اور تم ظالموں کو دیکھو گے کہ جب وہ (دوزخ کا) عذاب دیکھیں گے تو کہیں گے کیا (دنیا میں) واپس جانے کی بھی کوئی سبیل ہے؟\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmcccxvii{اور تم ان کو دیکھو گے کہ دوزخ کے سامنے لائے جائیں گے ذلت سے عاجزی کرتے ہوئے چھپی (اور نیچی) نگاہ سے دیکھ رہے ہوں گے۔ اور مومن لوگ کہیں کے کہ خسارہ اٹھانے والے تو وہ ہیں جنہوں نے قیامت کے دن اپنے آپ کو اور اپنے گھر والوں کو خسارے میں ڈالا۔ دیکھو کہ بےانصاف لوگ ہمیشہ کے دکھ میں (پڑے) رہیں گے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmcccxviii{اور خدا کے سوا ان کے کوئی دوست نہ ہوں گے کہ خدا کے سوا ان کو مدد دے سکیں۔ اور جس کو خدا گمراہ کرے اس کے لئے (ہدایت کا) کوئی رستہ نہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmcccxix{ان سے کہہ دو کہ) قبل اس کے کہ وہ دن جو ٹلے گا نہیں خدا کی طرف سے آ موجود ہو اپنے پروردگار کا حکم قبول کرو۔ اس دن تمہارے لئے نہ کوئی جائے پناہ ہوگی اور نہ تم سے گناہوں کا انکار ہی بن پڑے گا\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmcccxx{پھر اگر یہ منہ پھیر لیں تو ہم نے تم کو ان پر نگہبان بنا کر نہیں بھیجا۔ تمہارا کام تو صرف (احکام کا) پہنچا دینا ہے۔ اور جب ہم انسان کو اپنی رحمت کا مزہ چکھاتے ہیں تو اس سے خوش ہوجاتا ہے۔ اور اگر ان کو ان ہی کے اعمال کے سبب کوئی سختی پہنچتی ہے تو (سب احسانوں کو بھول جاتے ہیں) بےشک انسان بڑا ناشکرا ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxi{تمام) بادشاہت خدا ہی کی ہے آسمانوں کی بھی اور زمین کی بھی۔ وہ جو چاہتا ہے پیدا کرتا ہے۔ جسے چاہتا ہے بیٹیاں عطا کرتا ہے اور جسے چاہتا ہے بیٹے بخشتا ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxii{یا ان کو بیٹے اور بیٹیاں دونوں عنایت فرماتا ہے۔ اور جس کو چاہتا ہے بےاولاد رکھتا ہے۔ وہ تو جاننے والا (اور) قدرت والا ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiii{اور کسی آدمی کے لئے ممکن نہیں کہ خدا اس سے بات کرے مگر الہام (کے ذریعے) سے یا پردے کے پیچھے سے یا کوئی فرشتہ بھیج دے تو وہ خدا کے حکم سے جو خدا چاہے القا کرے۔ بےشک وہ عالی رتبہ (اور) حکمت والا ہے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxiv{اور اسی طرح ہم نے اپنے حکم سے تمہاری طرف روح القدس کے ذریعے سے (قرآن) بھیجا ہے۔ تم نہ تو کتاب کو جانتے تھے اور نہ ایمان کو۔ لیکن ہم نے اس کو نور بنایا ہے کہ اس سے ہم اپنے بندوں میں سے جس کو چاہتے ہیں ہدایت کرتے ہیں۔ اور بےشک (اے محمدﷺ) تم سیدھا رستہ دکھاتے ہو\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxv{یعنی) خدا کا رستہ جو آسمانوں اور زمین کی سب چیزوں کا مالک ہے۔ دیکھو سب کام خدا کی طرف رجوع ہوں گے (اور وہی ان میں فیصلہ کرے گا)\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvi{\basmalahur حٰم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxvii{کتاب روشن کی قسم\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxviii{کہ ہم نے اس کو قرآن عربی بنایا ہے تاکہ تم سمجھو\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxix{اور یہ بڑی کتاب (یعنی لوح محفوظ) میں ہمارے پاس (لکھی ہوئی اور) بڑی فضیلت اور حکمت والی ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxx{بھلا اس لئے کہ تم حد سے نکلے ہوئے لوگ ہو ہم تم کو نصیحت کرنے سے باز رہیں گے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxi{اور ہم نے پہلے لوگوں میں بھی بہت سے پیغمبر بھیجے تھے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxii{اور کوئی پیغمبر ان کے پاس نہیں آتا تھا مگر وہ اس سے تمسخر کرتے تھے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiii{تو جو ان میں سخت زور والے تھے ان کو ہم نے ہلاک کردیا اور اگلے لوگوں کی حالت گزر گئی\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxiv{اور اگر تم ان سے پوچھو کہ آسمانوں اور زمین کو کس نے پیدا کیا ہے تو کہہ دیں گے کہ ان کو غالب اور علم والے (خدا) نے پیدا کیا ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxv{جس نے تمہارے لئے زمین کو بچھونا بنایا۔ اور اس میں تمہارے لئے رستے بنائے تاکہ تم راہ معلوم کرو\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvi{اور جس نے ایک اندازے کے ساتھ آسمان سے پانی نازل کیا۔ پھر ہم نے اس سے شہر مردہ کو زندہ کیا۔ اسی طرح تم زمین سے نکالے جاؤ گے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxvii{اور جس نے تمام قسم کے حیوانات پیدا کئے اور تمہارے لئے کشتیاں اور چارپائے بنائے جن پر تم سوار ہوتے ہو\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxviii{تاکہ تم ان کی پیٹھ پر چڑھ بیٹھو اور جب اس پر بیٹھ جاؤ پھر اپنے پروردگار کے احسان کو یاد کرو اور کہو کہ وہ (ذات) پاک ہے جس نے اس کو ہمارے زیر فرمان کر دیا اور ہم میں طاقت نہ تھی کہ اس کو بس میں کرلیتے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcccxxxix{اور ہم اپنے پروردگار کی طرف لوٹ کر جانے والے ہیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcccxl{اور انہوں نے اس کے بندوں میں سے اس کے لئے اولاد مقرر کی۔ بےشک انسان صریح ناشکرا ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcccxli{کیا اس نے اپنی مخلوقات میں سے خود تو بیٹیاں لیں اور تم کو چن کر بیٹے دیئے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlii{حالانکہ جب ان میں سے کسی کو اس چیز کی خوشخبری دی جاتی ہے جو انہوں نے خدا کے لئے بیان کی ہے تو اس کا منہ سیاہ ہوجاتا اور وہ غم سے بھر جاتا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliii{کیا وہ جو زیور میں پرورش پائے اور جھگڑے کے وقت بات نہ کرسکے (خدا کی) بیٹی ہوسکتی ہے؟\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmcccxliv{اور انہوں نے فرشتوں کو کہ وہ بھی خدا کے بندے ہیں (خدا کی) بیٹیاں مقرر کیا۔ کیا یہ ان کی پیدائش کے وقت حاضر تھے عنقریب ان کی شہادت لکھ لی جائے گی اور ان سے بازپرس کی جائے گی\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlv{اور کہتے ہیں اگر خدا چاہتا تو ہم ان کو نہ پوجتے۔ ان کو اس کا کچھ علم نہیں۔ یہ تو صرف اٹکلیں دوڑا رہے ہیں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvi{یا ہم نے ان کو اس سے پہلے کوئی کتاب دی تھی تو یہ اس سے سند پکڑتے ہیں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlvii{بلکہ کہنے لگے کہ ہم نے اپنے باپ دادا کو ایک رستے پر پایا ہے اور ہم انہی کے قدم بقدم چل رہے ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlviii{اور اسی طرح ہم نے تم سے پہلے کسی بستی میں کوئی ہدایت کرنے والا نہیں بھیجا مگر وہاں کے خوشحال لوگوں نے کہا کہ ہم نے اپنے باپ دادا کو ایک راہ پر پایا اور ہم قدم بقدم ان ہی کے پیچھے چلتے ہیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmcccxlix{پیغمبر نے کہا اگرچہ میں تمہارے پاس ایسا (دین) لاؤں کہ جس رستے پر تم نے اپنے باپ دادا کو پایا وہ اس سے کہیں سیدھا رستہ دکھاتا ہے کہنے لگے کہ جو (دین) تم دے کر بھیجے گئے ہو ہم اس کو نہیں مانتے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmcccl{تو ہم نے ان سے انتقام لیا سو دیکھ لو کہ جھٹلانے والوں کا انجام کیسا ہوا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmcccli{اور جب ابراہیم نے اپنے باپ اور اپنی قوم کے لوگوں سے کہا کہ جن چیزوں کو تم پوجتے ہو میں ان سے بیزار ہوں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmccclii{ہاں جس نے مجھ کو پیدا کیا وہی مجھے سیدھا رستہ دکھائے گا\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmcccliii{اور یہی بات اپنی اولاد میں پیچھے چھوڑ گئے تاکہ وہ (خدا کی طرف) رجوع کریں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmcccliv{بات یہ ہے کہ میں ان کفار کو اور ان کے باپ دادا کو متمتع کرتا رہا یہاں تک کہ ان کے پاس حق اور صاف صاف بیان کرنے والا پیغمبر آ پہنچا\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmccclv{اور جب ان کے پاس حق (یعنی قرآن) آیا تو کہنے لگے کہ یہ تو جادو ہے اور ہم اس کو نہیں مانتے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmccclvi{اور (یہ بھی) کہنے لگے کہ یہ قرآن ان دونوں بستیوں (یعنی مکّے اور طائف) میں سے کسی بڑے آدمی پر کیوں نازل نہ کیا گیا؟\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmccclvii{کیا یہ لوگ تمہارے پروردگار کی رحمت کو بانٹتے ہیں؟ ہم نے ان میں ان کی معیشت کو دنیا کی زندگی میں تقسیم کردیا اور ایک کے دوسرے پر درجے بلند کئے تاکہ ایک دوسرے سے خدمت لے اور جو کچھ یہ جمع کرتے ہیں تمہارے پروردگار کی رحمت اس سے کہیں بہتر ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmccclviii{اور اگر یہ خیال نہ ہوتا کہ سب لوگ ایک ہی جماعت ہوجائیں گے تو جو لوگ خدا سے انکار کرتے ہیں ہم ان کے گھروں کی چھتیں چاندی کی بنا دیتے اور سیڑھیاں (بھی) جن پر وہ چڑھتے ہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmccclix{اور ان کے گھروں کے دروازے بھی اور تخت بھی جن پر تکیہ لگاتے ہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmccclx{اور (خوب) تجمل وآرائش (کردیتے) اور یہ سب دنیا کی زندگی کا تھوڑا سا سامان ہے۔ اور آخرت تمہارے پروردگار کے ہاں پرہیزگاروں کے لئے ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmccclxi{اور جو کوئی خدا کی یاد سے آنکھیں بند کرکے (یعنی تغافل کرے) ہم اس پر ایک شیطان مقرر کردیتے ہیں تو وہ اس کا ساتھی ہوجاتا ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmccclxii{اور یہ (شیطان) ان کو رستے سے روکتے رہتے ہیں اور وہ سمجھتے ہیں کہ سیدھے رستے پر ہیں\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiii{یہاں تک کہ جب ہمارے پاس آئے گا تو کہے گا کہ اے کاش مجھ میں اور تجھ میں مشرق ومغرب کا فاصلہ ہوتا تو برا ساتھی ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmccclxiv{اور جب تم ظلم کرتے رہے تو آج تمہیں یہ بات فائدہ نہیں دے سکتی کہ تم (سب) عذاب میں شریک ہو\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmccclxv{کیا تم بہرے کو سنا سکتے ہو یا اندھے کو رستہ دکھا سکتے ہو اور جو صریح گمراہی میں ہو (اسے راہ پر لاسکتے ہو)\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvi{اگر ہم تم کو (وفات دے کر) اٹھا لیں تو ان لوگوں سے تو ہم انتقام لے کر رہیں گے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmccclxvii{یا (تمہاری زندگی ہی میں) تمہیں وہ (عذاب) دکھا دیں گے جن کا ہم نے ان سے وعدہ کیا ہے ہم ان پر قابو رکھتے ہیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmccclxviii{پس تمہاری طرف جو وحی کی گئی ہے اس کو مضبوط پکڑے رہو۔ بےشک تم سیدھے رستے پر ہو\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmccclxix{اور یہ (قرآن) تمہارے لئے اور تمہاری قوم کے لئے نصیحت ہے اور (لوگو) تم سے عنقریب پرسش ہوگی\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmccclxx{اور (اے محمدﷺ) جو اپنے پیغمبر ہم نے تم سے پہلے بھیجے ہیں ان سے دریافت کرلو۔ کیا ہم نے (خدائے) رحمٰن کے سوا اور معبود بنائے تھے کہ ان کی عبادت کی جائے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxi{اور ہم نے موسیٰ کو اپنی نشانیاں دے کر فرعون اور اس کے درباریوں کی طرف بھیجا تو انہوں نے کہا کہ میں پروردگار عالم کا بھیجا ہوا ہوں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxii{جب وہ ان کے پاس ہماری نشانیاں لے کر آئے تو وہ نشانیوں سے ہنسی کرنے لگے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiii{اور جو نشانی ہم ان کو دکھاتے تھے وہ دوسری سے بڑی ہوتی تھی اور ہم نے ان کو عذاب میں پکڑ لیا تاکہ باز آئیں\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxiv{اور کہنے لگے کہ اے جادوگر اس عہد کے مطابق جو تیرے پروردگار نے تجھ سے کر رکھا ہے اس سے دعا کر بےشک ہم ہدایت یاب ہو جائیں گے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxv{سو جب ہم نے ان سے عذاب کو دور کردیا تو وہ عہد شکنی کرنے لگے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvi{اور فرعون نے اپنی قوم سے پکار کر کہا کہ اے قوم کیا مصر کی حکومت میرے ہاتھ میں نہیں ہے۔ اور یہ نہریں جو میرے (محلوں کے) نیچے بہہ رہی ہیں (میری نہیں ہیں) کیا تم دیکھتے نہیں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxvii{بےشک میں اس شخص سے جو کچھ عزت نہیں رکھتا اور صاف گفتگو بھی نہیں کرسکتا کہیں بہتر ہوں\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxviii{تو اس پر سونے کے کنگن کیوں نہ اُتارے گئے یا (یہ ہوتا کہ) فرشتے جمع ہو کر اس کے ساتھ آتے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxix{غرض اس نے اپنی قوم کی عقل مار دی۔ اور انہوں نے اس کی بات مان لی۔ بےشک وہ نافرمان لوگ تھے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxx{جب انہوں نے ہم کو خفا کیا تو ہم نے ان سے انتقام لے کر اور ان سب کو ڈبو کر چھوڑا\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxi{اور ان کو گئے گزرے کردیا اور پچھلوں کے لئے عبرت بنا دیا\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxii{اور جب مریم کے بیٹے (عیسیٰ) کا حال بیان کیا گیا تو تمہاری قوم کے لوگ اس سے چِلا اُٹھے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiii{اور کہنے لگے کہ بھلا ہمارے معبود اچھے ہیں یا عیسیٰ؟ انہوں نے عیسیٰ کی جو مثال بیان کی ہے تو صرف جھگڑنے کو۔ حقیقت یہ ہے یہ لوگ ہیں ہی جھگڑالو\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxiv{وہ تو ہمارے ایسے بندے تھے جن پر ہم نے فضل کیا اور بنی اسرائیل کے لئے ان کو (اپنی قدرت کا) نمونہ بنا دیا\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxv{اور اگر ہم چاہتے تو تم میں سے فرشتے بنا دیتے جو تمہاری جگہ زمین میں رہتے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvi{اور وہ قیامت کی نشانی ہیں۔ تو (کہہ دو کہ لوگو) اس میں شک نہ کرو اور میرے پیچھے چلو۔ یہی سیدھا رستہ ہے\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxvii{اور (کہیں) شیطان تم کو (اس سے) روک نہ دے۔ وہ تو تمہارا اعلاینہ دشمن ہے\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxviii{اور جب عیسیٰ نشانیاں لے کر آئے تو کہنے لگے کہ میں تمہارے پاس دانائی (کی کتاب) لے کر آیا ہوں۔ نیز اس لئے کہ بعض باتیں جن میں تم اختلاف کر رہے ہو تم کو سمجھا دوں۔ تو خدا سے ڈرو اور میرا کہا مانو\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmccclxxxix{کچھ شک نہیں کہ خدا ہی میرا اور تمہارا پروردگار ہے پس اسی کی عبادت کرو۔ یہی سیدھا رستہ ہے\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmcccxc{پھر کتنے فرقے ان میں سے پھٹ گئے۔ سو جو لوگ ظالم ہیں ان کی درد دینے والے دن کے عذاب سے خرابی ہے\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmcccxci{یہ صرف اس بات کے منتظر ہیں کہ قیامت ان پر ناگہاں آموجود ہو اور ان کو خبر تک نہ ہو\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcii{جو آپس میں) دوست (ہیں) اس روز ایک دوسرے کے دشمن ہوں گے۔ مگر پرہیزگار (کہ باہم دوست ہی رہیں گے)\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciii{میرے بندو آج تمہیں نہ کچھ خوف ہے اور نہ تم غمناک ہوگے\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmcccxciv{جو لوگ ہماری آیتوں پر ایمان لائے اور فرمانبردار ہوگئے\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcv{ان سے کہا جائے گا) کہ تم اور تمہاری بیویاں عزت (واحترام) کے ساتھ بہشت میں داخل ہوجاؤ\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvi{ان پر سونے کی پرچوں اور پیالوں کا دور چلے گا۔ اور وہاں جو جی چاہے اور جو آنکھوں کو اچھا لگے (موجود ہوگا) اور (اے اہل جنت) تم اس میں ہمیشہ رہو گے\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcvii{اور یہ جنت جس کے تم مالک کر دیئے گئے ہو تمہارے اعمال کا صلہ ہے\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcviii{وہاں تمہارے لئے بہت سے میوے ہیں جن کو تم کھاؤ گے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmcccxcix{اور کفار) گنہگار ہمیشہ دوزخ کے عذاب میں رہیں گے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmcd{جو ان سے ہلکا نہ کیا جائے گا اور وہ اس میں نامید ہو کر پڑے رہیں گے\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmcdi{اور ہم نے ان پر ظلم نہیں کیا۔ بلکہ وہی (اپنے آپ پر) ظلم کرتے تھے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmmcdii{اور پکاریں گے کہ اے مالک تمہارا پروردگار ہمیں موت دے دے۔ وہ کہے گا کہ تم ہمیشہ (اسی حالت میں) رہو گے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmmcdiii{ہم تمہارے پاس حق لے کر آئے ہیں لیکن تم اکثر حق سے ناخوش ہوتے رہے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmmcdiv{کیا انہوں نے کوئی بات ٹھہرا رکھی ہے تو ہم بھی کچھ ٹھہرانے والے ہیں\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmmcdv{کیا یہ لوگ یہ خیال کرتے ہیں کہ ہم ان کی پوشیدہ باتوں اور سرگوشیوں کو سنتے نہیں؟ ہاں ہاں (سب سنتے ہیں) اور ہمارے فرشتے ان کے پاس (ان کی سب باتیں) لکھ لیتے ہیں\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmmcdvi{کہہ دو کہ اگر خدا کے اولاد ہو تو میں (سب سے) پہلے (اس کی) عبادت کرنے والا ہوں\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmmcdvii{یہ جو کچھ بیان کرتے ہیں آسمانوں اور زمین کا مالک (اور) عرش کا مالک اس سے پاک ہے\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmmcdviii{تو ان کو بک بک کرنے اور کھیلنے دو۔ یہاں تک کہ جس دن کا ان سے وعدہ کیا جاتا ہے اس کو دیکھ لیں\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmmcdix{اور وہی (ایک) آسمانوں میں معبود ہے اور (وہی) زمین میں معبود ہے۔ اور وہ دانا (اور) علم والا ہے\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmmcdx{اور وہ بہت بابرکت ہے جس کے لئے آسمانوں اور زمین کی اور جو کچھ ان دونوں میں ہے سب کی بادشاہت ہے۔ اور اسی کو قیامت کا علم ہے اور اسی کی طرف تم لوٹ کر جاؤ گے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmmcdxi{اور جن کو یہ لوگ خدا کے سوا پکارتے ہیں وہ سفارش کا کچھ اختیار نہیں رکھتے۔ ہاں جو علم ویقین کے ساتھ حق کی گواہی دیں (وہ سفارش کرسکتے ہیں)\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmmcdxii{اور اگر تم ان سے پوچھو کہ ان کو کس نے پیدا کیا ہے تو کہہ دیں گے کہ خدا نے۔ تو پھر یہ کہاں بہکے پھرتے ہیں؟\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiii{اور (بسااوقات) پیغمبر کہا کرتے ہیں کہ اے پروردگار یہ ایسے لوگ ہیں کہ ایمان نہیں لاتے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmmcdxiv{تو ان سے منہ پھیر لو اور سلام کہہ دو۔ ان کو عنقریب (انجام) معلوم ہوجائے گا\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmmmcdxv{\basmalahur حٰم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvi{اس کتاب روشن کی قسم\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcdxvii{کہ ہم نے اس کو مبارک رات میں نازل فرمایا ہم تو رستہ دکھانے والے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcdxviii{اسی رات میں تمام حکمت کے کام فیصل کئے جاتے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcdxix{یعنی) ہمارے ہاں سے حکم ہو کر۔ بےشک ہم ہی (پیغمبر کو) بھیجتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcdxx{یہ) تمہارے پروردگار کی رحمت ہے۔ وہ تو سننے والا جاننے والا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxi{آسمانوں اور زمین کا اور جو کچھ ان دونوں میں ہے سب کا مالک۔ بشرطیکہ تم لوگ یقین کرنے والے ہو\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxii{اس کے سوا کوئی معبود نہیں۔ (وہی) جِلاتا ہے اور (وہی) مارتا ہے۔ وہی تمہارا اور تمہارے باپ دادا کا پروردگار ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiii{لیکن یہ لوگ شک میں کھیل رہے ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxiv{تو اس دن کا انتظار کرو کہ آسمان سے صریح دھواں نکلے گا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxv{جو لوگوں پر چھا جائے گا۔ یہ درد دینے والا عذاب ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvi{اے پروردگار ہم سے اس عذاب کو دور کر ہم ایمان لاتے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxvii{اس وقت) ان کو نصیحت کہاں مفید ہوگی جب کہ ان کے پاس پیغمبر آچکے جو کھول کھول کر بیان کر دیتے ہیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxviii{پھر انہوں نے ان سے منہ پھیر لیا اور کہنے لگے (یہ تو) پڑھایا ہوا (اور) دیوانہ ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxix{ہم تو تھوڑے دنوں عذاب ٹال دیتے ہیں (مگر) تم پھر کفر کرنے لگتے ہو\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxx{جس دن ہم بڑی سخت پکڑ پکڑیں گے تو بےشک انتقام لے کر چھوڑیں گے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxi{اور ان سے پہلے ہم نے قوم فرعون کی آزمائش کی اور ان کے پاس ایک عالی قدر پیغمبر آئے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxii{جنہوں نے) یہ (کہا) کہ خدا کے بندوں (یعنی بنی اسرائیل) کو میرے حوالے کردو میں تمہارا امانت دار پیغمبر ہوں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiii{اور خدا کے سامنے سرکشی نہ کرو۔ میں تمہارے پاس کھلی دلیل لے کر آیا ہوں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxiv{اور اس (بات) سے کہ تم مجھے سنگسار کرو اپنے اور تمہارے پروردگار کی پناہ مانگتا ہوں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxv{اور اگر تم مجھ پر ایمان نہیں لاتے تو مجھ سے الگ ہو جاؤ\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvi{تب موسیٰ نے اپنے پروردگار سے دعا کی کہ یہ نافرمان لوگ ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxvii{خدا نے فرمایا کہ) میرے بندوں کو راتوں رات لے کر چلے جاؤ اور (فرعونی) ضرور تمہارا تعاقب کریں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxviii{اور دریا سے (کہ) خشک (ہو رہا ہوگا) پار ہو جاؤ (تمہارے بعد) ان کا تمام لشکر ڈبو دیا جائے گا\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmcdxxxix{وہ لوگ بہت سے باغ اور چشمے چھوڑ گئے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmcdxl{اور کھیتیاں اور نفیس مکان\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmcdxli{اور آرام کی چیزیں جن میں عیش کیا کرتے تھے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlii{اسی طرح (ہوا) اور ہم نے دوسرے لوگوں کو ان چیزوں کا مالک بنا دیا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliii{پھر ان پر نہ تو آسمان کو اور زمین کو رونا آیا اور نہ ان کو مہلت ہی دی گئی\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmcdxliv{اور ہم نے بنی اسرائیل کو ذلت کے عذاب سے نجات دی\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlv{یعنی) فرعون سے۔ بےشک وہ سرکش (اور) حد سے نکلا ہوا تھا\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvi{اور ہم نے بنی اسرائیل کو اہل عالم سے دانستہ منتخب کیا تھا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlvii{اور ان کو ایسی نشانیاں دی تھیں جن میں صریح آزمائش تھی\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlviii{یہ لوگ یہ کہتے ہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmcdxlix{کہ ہمیں صرف پہلی دفعہ (یعنی ایک بار) مرنا ہے اور (پھر) اُٹھنا نہیں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmcdl{پس اگر تم سچے ہو تو ہمارے باپ دادا کو (زندہ کر) لاؤ\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmcdli{بھلا یہ اچھے ہیں یا تُبّع کی قوم اور وہ لوگ جو تم سے پہلے ہوچکے ہیں۔ ہم نے ان (سب) کو ہلاک کردیا۔ بےشک وہ گنہگار تھے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmcdlii{اور ہم نے آسمانوں اور زمین کو اور جو کچھ ان میں ہے ان کو کھیلتے ہوئے نہیں بنایا\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmcdliii{ان کو ہم نے تدبیر سے پیدا کیا ہے لیکن اکثر لوگ نہیں جانتے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmcdliv{کچھ شک نہیں کہ فیصلے کا دن ان سب (کے اُٹھنے) کا وقت ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmcdlv{جس دن کوئی دوست کسی دوست کے کچھ کام نہ آئے گا اور نہ ان کو مدد ملے گی\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvi{مگر جس پر خدا مہربانی کرے۔ وہ تو غالب اور مہربان ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmcdlvii{بلاشبہ تھوہر کا درخت\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmcdlviii{گنہگار کا کھانا ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmcdlix{جیسے پگھلا ہوا تانبا۔ پیٹوں میں (اس طرح) کھولے گا\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmcdlx{جس طرح گرم پانی کھولتا ہے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxi{حکم دیا جائے گا کہ) اس کو پکڑ لو اور کھینچتے ہوئے دوزخ کے بیچوں بیچ لے جاؤ\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxii{پھر اس کے سر پر کھولتا ہوا پانی انڈیل دو (کہ عذاب پر) عذاب (ہو)\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiii{اب) مزہ چکھ۔ تو بڑی عزت والا (اور) سردار ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxiv{یہ وہی (دوزخ) ہے جس میں تم لوگ شک کیا کرتے تھے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxv{بےشک پرہیزگار لوگ امن کے مقام میں ہوں گے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvi{یعنی) باغوں اور چشموں میں\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxvii{حریر کا باریک اور دبیز لباس پہن کر ایک دوسرے کے سامنے بیٹھے ہوں گے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxviii{اس طرح (کا حال ہوگا) اور ہم بڑی بڑی آنکھوں والی سفید رنگ کی عورتوں سے ان کے جوڑے لگائیں گے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxix{وہاں خاطر جمع سے ہر قسم کے میوے منگوائیں گے (اور کھائیں گے)\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxx{اور) پہلی دفعہ کے مرنے کے سوا (کہ مرچکے تھے) موت کا مزہ نہیں چکھیں گے۔ اور خدا ان کو دوزخ کے عذاب سے بچا لے گا\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxi{یہ تمہارے پروردگار کا فضل ہے۔ یہی تو بڑی کامیابی ہے\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxii{ہم نے اس (قرآن) کو تمہاری زبان میں آسان کردیا ہے تاکہ یہ لوگ نصیحت پکڑیں\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiii{پس تم بھی انتظار کرو یہ بھی انتظار کر رہے ہیں\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxiv{\basmalahur حٰم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxv{اس کتاب کا اُتارا جانا خدائے غالب (اور) دانا (کی طرف) سے ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvi{بےشک آسمانوں اور زمین میں ایمان والوں کے لئے (خدا کی قدرت کی) نشانیاں ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxvii{اور تمہاری پیدائش میں بھی۔ اور جانوروں میں بھی جن کو وہ پھیلاتا ہے یقین کرنے والوں کے لئے نشانیاں ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxviii{اور رات اور دن کے آگے پیچھے آنے جانے میں اور وہ جو خدا نے آسمان سے (ذریعہٴ) رزق نازل فرمایا پھر اس سے زمین کو اس کے مرجانے کے بعد زندہ کیا اس میں اور ہواؤں کے بدلنے میں عقل والوں کے لئے نشانیاں ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxix{یہ خدا کی آیتیں ہیں جو ہم تم کو سچائی کے ساتھ پڑھ کر سناتے ہیں۔ تو یہ خدا اور اس کی آیتوں کے بعد کس بات پر ایمان لائیں گے؟\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxx{ہر جھوٹے گنہگار پر افسوس ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxi{کہ) خدا کی آیتیں اس کو پڑھ کر سنائی جاتی ہیں تو ان کو سن تو لیتا ہے (مگر) پھر غرور سے ضد کرتا ہے کہ گویا ان کو سنا ہی نہیں۔ سو ایسے شخص کو دکھ دینے والے عذاب کی خوشخبری سنا دو\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxii{اور جب ہماری کچھ آیتیں اسے معلوم ہوتی ہیں تو ان کی ہنسی اُڑاتا ہے۔ ایسے لوگوں کے لئے ذلیل کرنے والا عذاب ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiii{ان کے سامنے دوزخ ہے۔ اور جو کام وہ کرتے رہے کچھ بھی ان کے کام نہ آئیں گے۔ اور نہ وہی (کام آئیں گے) جن کو انہوں نے خدا کے سوا معبود بنا رکھا تھا۔ اور ان کے لئے بڑا عذاب ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxiv{یہ ہدایت (کی کتاب) ہے۔ اور جو لوگ اپنے پروردگار کی آیتوں سے انکار کرتے ہیں ان کو سخت قسم کا درد دینے والا عذاب ہوگا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxv{خدا ہی تو ہے جس نے دریا کو تمہارے قابو کردیا تاکہ اس کے حکم سے اس میں کشتیاں چلیں اور تاکہ تم اس کے فضل سے (معاش) تلاش کرو اور تاکہ شکر کرو\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvi{اور جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے سب کو اپنے (حکم) سے تمہارے کام میں لگا دیا۔ جو لوگ غور کرتے ہیں ان کے لئے اس میں (قدرت خدا کی) نشانیاں ہیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxvii{مومنوں سے کہہ دو کہ جو لوگ خدا کے دنوں کی (جو اعمال کے بدلے کے لئے مقرر ہیں) توقع نہیں رکھتے ان سے درگزر کریں۔ تاکہ وہ ان لوگوں کو ان کے اعمال کا بدلے دے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxviii{جو کوئی عمل نیک کرے گا تو اپنے لئے۔ اور جو برے کام کرے گا تو ان کا ضرر اسی کو ہوگا۔ پھر تم اپنے پروردگار کی طرف لوٹ کر جاؤ گے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcdlxxxix{اور ہم نے بنی اسرائیل کو کتاب (ہدایت) اور حکومت اور نبوت بخشی اور پاکیزہ چیزیں عطا فرمائیں اور اہل عالم پر فضیلت دی\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcdxc{اور ان کو دین کے بارے میں دلیلیں عطا کیں۔ تو انہوں نے جو اختلاف کیا تو علم آچکنے کے بعد آپس کی ضد سے کیا۔ بےشک تمہارا پروردگار قیامت کے دن ان میں ان باتوں کا جن میں وہ اختلاف کرتے تھے فیصلہ کرے گا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcdxci{پھر ہم نے تم کو دین کے کھلے رستے پر (قائم) کر دیا تو اسی (رستے) پر چلے چلو اور نادانوں کی خواہشوں کے پیچھے نہ چلنا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcii{یہ خدا کے سامنے تمہارے کسی کام نہیں آئیں گے۔ اور ظالم لوگ ایک دوسرے کے دوست ہوتے ہیں۔ اور خدا پرہیزگاروں کا دوست ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciii{یہ قرآن لوگوں کے لئے دانائی کی باتیں ہیں اور جو یقین رکھتے ہیں ان کے لئے ہدایت اور رحمت ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmcdxciv{جو لوگ برے کام کرتے ہیں کیا وہ یہ خیال کرتے ہیں کہ ہم ان کو ان لوگوں جیسا کردیں گے جو ایمان لائے اور عمل نیک کرتے رہے اور ان کی زندگی اور موت یکساں ہوگی۔ یہ جو دعوے کرتے ہیں برے ہیں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcv{اور خدا نے آسمانوں اور زمین کو حکمت سے پیدا کیا ہے اور تاکہ ہر شخص اپنے اعمال کا بدلہ پائے اور ان پر ظلم نہیں کیا جائے گا\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvi{بھلا تم نے اس شخص کو دیکھا جس نے اپنی خواہش کو معبود بنا رکھا ہے اور باوجود جاننے بوجھنے کے (گمراہ ہو رہا ہے تو) خدا نے (بھی) اس کو گمراہ کردیا اور اس کے کانوں اور دل پر مہر لگا دی اور اس کی آنکھوں پر پردہ ڈال دیا۔ اب خدا کے سوا اس کو کون راہ پر لاسکتا ہے۔ بھلا تم کیوں نصیحت نہیں پکڑتے؟\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcvii{اور کہتے ہیں کہ ہماری زندگی تو صرف دنیا ہی کی ہے کہ (یہیں) مرتے اور جیتے ہیں اور ہمیں تو زمانہ مار دیتا ہے۔ اور ان کو اس کا کچھ علم نہیں۔ صرف ظن سے کام لیتے ہیں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcviii{اور جب ان کے سامنے ہماری کھلی کھلی آیتیں پڑھی جاتی ہیں تو ان کی یہی حجت ہوتی ہے کہ اگر تم سچے ہو تو ہمارے باپ دادا کو (زندہ کر) لاؤ\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmcdxcix{کہہ دو کہ خدا ہی تم کو جان بخشتا ہے پھر (وہی) تم کو موت دیتا ہے پھر تم کو قیامت کے روز جس (کے آنے) میں کچھ شک نہیں تم کو جمع کرے گا لیکن بہت سے لوگ نہیں جانتے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmd{اور آسمانوں اور زمین کی بادشاہت خدا ہی کی ہے۔ اور جس روز قیامت برپا ہوگی اس روز اہل باطل خسارے میں پڑ جائیں گے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdi{اور تم ہر ایک فرقے کو دیکھو گے کہ گھٹنوں کے بل بیٹھا ہوگا۔ اور ہر ایک جماعت اپنی کتاب (اعمال) کی طرف بلائی جائے گی۔ جو کچھ تم کرتے رہے ہو آج تم کو اس کا بدلہ دیا جائے گا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdii{یہ ہماری کتاب تمہارے بارے میں سچ سچ بیان کردے گی۔ جو کچھ تم کیا کرتے تھے ہم لکھواتے جاتے ہیں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdiii{تو جو لوگ ایمان لائے اور نیک کام کرتے رہے ان کا پروردگار انہیں رحمت (کے باغ) میں داخل کرے گا۔ یہی صریح کامیابی ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdiv{اور جنہوں نے کفر کیا۔ (ان سے کہا جائے گا کہ) بھلا ہماری آیتیں تم کو پڑھ کر سنائی نہیں جاتی تھیں؟ پھر تم نے تکبر کیا اور تم نافرمان لوگ تھے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdv{اور جب کہا جاتا تھا کہ خدا کا وعدہ سچا ہے اور قیامت میں کچھ شک نہیں تو تم کہتے تھے ہم نہیں جانتے کہ قیامت کیا ہے۔ ہم اس کو محض ظنی خیال کرتے ہیں اور ہمیں یقین نہیں آتا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdvi{اور ان کے اعمال کی برائیاں ان پر ظاہر ہوجائیں گی اور جس (عذاب) کی وہ ہنسی اُڑاتے تھے وہ ان کو آگھیرے گا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdvii{اور کہا جائے گا کہ جس طرح تم نے اس دن کے آنے کو بھلا رکھا تھا۔ اسی طرح آج ہم تمہیں بھلا دیں گے اور تمہارا ٹھکانا دوزخ ہے اور کوئی تمہارا مددگار نہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdviii{یہ اس لئے کہ تم نے خدا کی آیتوں کو مخول بنا رکھا تھا اور دنیا کی زندگی نے تم کو دھوکے میں ڈال رکھا تھا۔ سو آج یہ لوگ نہ دوزخ سے نکالے جائیں گے اور نہ ان کی توبہ قبول کی جائے گی\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdix{پس خدا ہی کو ہر طرح کی تعریف (سزاوار) ہے جو آسمانوں کا مالک اور زمین کا مالک اور تمام جہان کا پروردگار ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdx{اور آسمانوں اور زمین میں اُسی کے لئے بڑائی ہے۔ اور وہ غالب اور دانا ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdxi{\basmalahur حٰم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdxii{یہ) کتاب خدائے غالب (اور) حکمت والے کی طرف سے نازل ہوئی ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdxiii{ہم نے آسمانوں اور زمین کو اور جو کچھ ان دونوں میں ہے مبنی برحکمت اور ایک وقت مقرر تک کے لئے پیدا کیا ہے۔ اور کافروں کو جس چیز کی نصیحت کی جاتی ہے اس سے منہ پھیر لیتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdxiv{کہو کہ بھلا تم نے ان چیزوں کو دیکھا ہے جن کو تم خدا کے سوا پکارتے ہو (ذرا) مجھے بھی تو دکھاؤ کہ انہوں نے زمین میں کون سی چیز پیدا کی ہے۔ یا آسمانوں میں ان کی شرکت ہے۔ اگر سچے ہو تو اس سے پہلے کی کوئی کتاب میرے پاس لاؤ۔ یا علم (انبیاء میں) سے کچھ (منقول) چلا آتا ہو (تو اسے پیش کرو)\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdxv{اور اس شخص سے بڑھ کر کون گمراہ ہوسکتا ہے جو ایسے کو پکارے جو قیامت تک اسے جواب نہ دے سکے اور ان کو ان کے پکارنے ہی کی خبر نہ ہو\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdxvi{اور جب لوگ جمع کئے جائیں گے تو وہ ان کے دشمن ہوں گے اور ان کی پرستش سے انکار کریں گے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdxvii{اور جب ان کے سامنے ہماری کھلی آیتیں پڑھی جاتی ہیں تو کافر حق کے بارے میں جب ان کے پاس آچکا کہتے ہیں کہ یہ تو صریح جادو ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdxviii{کیا یہ کہتے ہیں کہ اس نے اس کو از خود بنا لیا ہے۔ کہہ دو کہ اگر میں نے اس کو اپنی طرف سے بنایا ہو تو تم خدا کے سامنے میرے (بچاؤ کے) لئے کچھ اختیار نہیں رکھتے۔ وہ اس گفتگو کو خوب جانتا ہے جو تم اس کے بارے میں کرتے ہو۔ وہی میرے اور تمہارے درمیان گواہ کافی ہے۔ اور وہ بخشنے والا مہربان ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdxix{کہہ دو کہ میں کوئی نیا پیغمبر نہیں آیا۔ اور میں نہیں جانتا کہ میرے ساتھ کیا سلوک کیا جائے گا اور تمہارے ساتھ کیا (کیا جائے گا) میں تو اسی کی پیروی کرتا ہوں جو مجھ پر وحی آتی ہے اور میرا کام تو علانیہ ہدایت کرنا ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdxx{کہو کہ بھلا دیکھو تو اگر یہ (قرآن) خدا کی طرف سے ہو اور تم نے اس سے انکار کیا اور بنی اسرائیل میں سے ایک گواہ اسی طرح کی ایک (کتاب) کی گواہی دے چکا اور ایمان لے آیا اور تم نے سرکشی کی (تو تمہارے ظالم ہونے میں کیا شک ہے) ۔ بےشک خدا ظالم لوگوں کو ہدایت نہیں دیتا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdxxi{اور کافر مومنوں سے کہتے ہیں کہ اگر یہ (دین) کچھ بہتر ہوتا تو یہ لوگ اس کی طرف ہم سے پہلے نہ دوڑ پڑتے اور جب وہ اس سے ہدایت یاب نہ ہوئے تو اب کہیں گے کہ یہ پرانا جھوٹ ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdxxii{اور اس سے پہلے موسیٰ کی کتاب تھی (لوگوں کے لئے) رہنما اور رحمت۔ اور یہ کتاب عربی زبان میں ہے اسی کی تصدیق کرنے والی تاکہ ظالموں کو ڈرائے۔ اور نیکوکاروں کو خوشخبری سنائے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiii{جن لوگوں نے کہا کہ ہمارا پروردگار خدا ہے پھر وہ (اس پر) قائم رہے تو ان کو نہ کچھ خوف ہوگا اور نہ وہ غمناک ہوں گے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdxxiv{یہی اہل جنت ہیں کہ ہمیشہ اس میں رہیں گے۔ (یہ) اس کا بدلہ (ہے) جو وہ کیا کرتے تھے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdxxv{اور ہم نے انسان کو اپنے والدین کے ساتھ بھلائی کرنے کا حکم دیا۔ اس کی ماں نے اس کو تکلیف سے پیٹ میں رکھا اور تکلیف ہی سے جنا۔ اور اس کا پیٹ میں رہنا اور دودھ چھوڑنا ڈھائی برس میں ہوتا ہے۔ یہاں تک کہ جب خوب جوان ہوتا ہے اور چالیس برس کو پہنچ جاتا ہے تو کہتا ہے کہ اے میرے پروردگار مجھے توفیق دے کہ تو نے جو احسان مجھ پر اور میرے ماں باپ پر کئے ہیں ان کا شکر گزار ہوں اور یہ کہ نیک عمل کروں جن کو تو پسند کرے۔ اور میرے لئے میری اولاد میں صلاح (وتقویٰ) دے۔ میں تیری طرف رجوع کرتا ہوں اور میں فرمانبرداروں میں ہوں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvi{یہی لوگ ہیں جن کے اعمال نیک ہم قبول کریں گے اور ان کے گناہوں سے درگزر فرمائیں گے اور (یہی) اہل جنت میں (ہوں گے) ۔ (یہ) سچا وعدہ (ہے) جو ان سے کیا جاتا ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdxxvii{اور جس شخص نے اپنے ماں باپ سے کہا کہ اُف اُف! تم مجھے یہ بتاتے ہو کہ میں (زمین سے) نکالا جاؤں گا حالانکہ بہت سے لوگ مجھ سے پہلے گزر چکے ہیں۔ اور وہ دونوں خدا کی جناب میں فریاد کرتے (ہوئے کہتے) تھے کہ کم بخت ایمان لا۔ خدا کا وعدہ تو سچا ہے۔ تو کہنے لگا یہ تو پہلے لوگوں کی کہانیاں ہیں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdxxviii{یہی وہ لوگ ہیں جن کے بارے میں جنوں اور انسانوں کی (دوسری) اُمتوں میں سے جو ان سے پہلے گزر چکیں عذاب کا وعدہ متحقق ہوگیا۔ بےشک وہ نقصان اٹھانے والے تھے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdxxix{اور لوگوں نے جیسے کام کئے ہوں گے ان کے مطابق سب کے درجے ہوں گے۔ غرض یہ ہے کہ ان کو ان کے اعمال کا پورا بدلہ دے اور ان کا نقصان نہ کیا جائے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdxxx{اور جس دن کافر دوزخ کے سامنے کئے جائیں گے (تو کہا جائے گا کہ) تم اپنی دنیا کی زندگی میں لذتیں حاصل کرچکے اور ان سے متمتع ہوچکے سو آج تم کو ذلت کا عذاب ہے، (یہ) اس کی سزا (ہے) کہ تم زمین میں ناحق غرور کیا کرتے تھے۔ اور اس کی بدکرداری کرتے تھے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxi{اور (قوم) عاد کے بھائی (ہود) کو یاد کرو کہ جب انہوں نے اپنی قوم کو سرزمین احقاف میں ہدایت کی اور ان سے پہلے اور پیچھے بھی ہدایت کرنے والے گزرچکے تھے کہ خدا کے سوا کسی کی عبادت نہ کرو۔ مجھے تمہارے بارے میں بڑے دن کے عذاب کا ڈر لگتا ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxii{کہنے لگے کیا تم ہمارے پاس اس لئے آئے ہو کہ ہم کو ہمارے معبودوں سے پھیر دو۔ اگر سچے ہو تو جس چیز سے ہمیں ڈراتے ہو اسے ہم پر لے آؤ\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiii{انہوں نے) کہا کہ (اس کا) علم تو خدا ہی کو ہے۔ اور میں تو جو (احکام) دے کر بھیجا گیا ہوں وہ تمہیں پہنچا رہا ہوں لیکن میں دیکھتا ہوں کہ تم لوگ نادانی میں پھنس رہے ہو\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxiv{پھر جب انہوں نے اس (عذاب کو) دیکھا کہ بادل (کی صورت میں) ان کے میدانوں کی طرف آرہا ہے تو کہنے لگے یہ تو بادل ہے جو ہم پر برس کر رہے گا۔ (نہیں) بلکہ (یہ) وہ چیز ہے جس کے لئے تم جلدی کرتے تھے یعنی آندھی جس میں درد دینے والا عذاب بھرا ہوا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxv{ہر چیز کو اپنے پروردگار کے حکم سے تباہ کئے دیتی ہے تو وہ ایسے ہوگئے کہ ان کے گھروں کے سوا کچھ نظر ہی نہیں آتا تھا۔ گنہگار لوگوں کو ہم اسی طرح سزا دیا کرتے ہیں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvi{اور ہم نے ان کو ایسے مقدور دیئے تھے جو تم لوگوں کو نہیں دیئے اور انہیں کان اور آنکھیں اور دل دیئے تھے۔ تو جب کہ وہ خدا کی آیتوں سے انکار کرتے تھے تو نہ تو ان کے کان ہی ان کے کچھ کام آسکے اور نہ آنکھیں اور نہ دل۔ اور جس چیز سے استہزاء کیا کرتے تھے اس نے ان کو آ گھیرا\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxvii{اور تمہارے اردگرد کی بستیوں کو ہم نے ہلاک کر دیا۔ اور بار بار (اپنی) نشانیاں ظاہر کردیں تاکہ وہ رجوع کریں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxviii{تو جن کو ان لوگوں نے تقرب (خدا) کے سوا معبود بنایا تھا انہوں نے ان کی کیوں مدد نہ کی۔ بلکہ وہ ان (کے سامنے) سے گم ہوگئے۔ اور یہ ان کا جھوٹ تھا اور یہی وہ افتراء کیا کرتے تھے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdxxxix{اور جب ہم نے جنوں میں سے کئی شخص تمہاری طرف متوجہ کئے کہ قرآن سنیں۔ تو جب وہ اس کے پاس آئے تو (آپس میں) کہنے لگے کہ خاموش رہو۔ جب (پڑھنا) تمام ہوا تو اپنی برادری کے لوگوں میں واپس گئے کہ (ان کو) نصیحت کریں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdxl{کہنے لگے کہ اے قوم! ہم نے ایک کتاب سنی ہے جو موسیٰ کے بعد نازل ہوئی ہے۔ جو (کتابیں) اس سے پہلے (نازل ہوئی) ہیں ان کی تصدیق کرتی ہے (اور) سچا (دین) اور سیدھا رستہ بتاتی ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdxli{اے قوم! خدا کی طرف بلانے والے کی بات قبول کرو اور اس پر ایمان لاؤ۔ خدا تمہارے گناہ بخش دے گا اور تمہیں دکھ دینے والے عذاب سے پناہ میں رکھے گا\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdxlii{اور جو شخص خدا کی طرف بلانے والے کی بات قبول نہ کرے گا تو وہ زمین میں (خدا کو) عاجز نہیں کرسکے گا اور نہ اس کے سوا اس کے حمایتی ہوں گے۔ یہ لوگ صریح گمراہی میں ہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdxliii{کیا انہوں نے نہیں سمجھا کہ جس خدا نے آسمانوں اور زمین کو پیدا کیا اور ان کے پیدا کرنے سے تھکا نہیں۔ وہ اس (بات) پر بھی قادر ہے کہ مردوں کو زندہ کر دے۔ ہاں ہاں وہ ہر چیز پر قادر ہے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdxliv{اور جس روز آگ کے سامنے کئے جائیں گے (اور کہا جائے گا) کیا یہ حق نہیں ہے؟ تو کہیں گے کیوں نہیں ہمارے پروردگار کی قسم (حق ہے) حکم ہوگا کہ تم جو (دنیا میں) انکار کیا کرتے تھے (اب) عذاب کے مزے چکھو\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdxlv{پس (اے محمدﷺ) جس طرح اور عالی ہمت پیغمبر صبر کرتے رہے ہیں اسی طرح تم بھی صبر کرو اور ان کے لئے (عذاب) جلدی نہ مانگو۔ جس دن یہ اس چیز کو دیکھیں گے جس کا ان سے وعدہ کیا جاتا ہے تو (خیال کریں گے کہ) گویا (دنیا میں) رہے ہی نہ تھے مگر گھڑی بھر دن۔ (یہ قرآن) پیغام ہے۔ سو (اب) وہی ہلاک ہوں گے جو نافرمان تھے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvi{\basmalahur جن لوگوں نے کفر کیا اور (اَوروں کو) خدا کے رستے سے روکا۔ خدا نے ان کے اعمال برباد کر دیئے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdxlvii{اور جو ایمان لائے اور نیک عمل کرتے رہے اور جو (کتاب) محمدﷺ پر نازل ہوئی اسے مانتے رہے اور وہ ان کے پروردگار کی طرف سے برحق ہے ان سے ان کے گناہ دور کردیئے اور ان کی حالت سنوار دی\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdxlviii{یہ (حبط اعمال اور اصلاح حال) اس لئے ہے کہ جن لوگوں نے کفر کیا انہوں نے جھوٹی بات کی پیروی کی اور جو ایمان لائے وہ اپنے پروردگار کی طرف سے (دین) حق کے پیچھے چلے۔ اسی طرح خدا لوگوں سے ان کے حالات بیان فرماتا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdxlix{جب تم کافروں سے بھڑ جاؤ تو ان کی گردنیں اُڑا دو۔ یہاں تک کہ جب ان کو خوب قتل کرچکو تو (جو زندہ پکڑے جائیں ان کو) مضبوطی سے قید کرلو۔ پھر اس کے بعد یا تو احسان رکھ کر چھوڑ دینا چاہیئے یا کچھ مال لے کر یہاں تک کہ (فریق مقابل) لڑائی (کے) ہتھیار (ہاتھ سے) رکھ دے۔ (یہ حکم یاد رکھو) اور اگر خدا چاہتا تو (اور طرح) ان سے انتقام لے لیتا۔ لیکن اس نے چاہا کہ تمہاری آزمائش ایک (کو) دوسرے سے (لڑوا کر) کرے۔ اور جو لوگ خدا کی راہ میں مارے گئے ان کے عملوں کو ہرگز ضائع نہ کرے گا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdl{ان کو سیدھے رستے پر چلائے گا اور ان کی حالت درست کر دے گا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdli{اور ان کو بہشت میں جس سے انہیں شناسا کر رکھا ہے داخل کرے گا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdlii{اے اہل ایمان! اگر تم خدا کی مدد کرو گے تو وہ بھی تمہاری مدد کرے گا اور تم کو ثابت قدم رکھے گا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdliii{اور جو کافر ہیں ان کے لئے ہلاکت ہے۔ اور وہ ان کے اعمال کو برباد کر دے گا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdliv{یہ اس لئے کہ خدا نے جو چیز نازل فرمائی انہوں نے اس کو ناپسند کیا تو خدا نے بھی ان کے اعمال اکارت کردیئے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdlv{کیا انہوں نے ملک میں سیر نہیں کی تاکہ دیکھتے کہ جو لوگ ان سے پہلے تھے ان کا انجام کیسا ہوا؟ خدا نے ان پر تباہی ڈال دی۔ اور اسی طرح کا (عذاب) ان کافروں کو ہوگا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdlvi{یہ اس لئے کہ جو مومن ہیں ان کا خدا کارساز ہے اور کافروں کا کوئی کارساز نہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdlvii{جو لوگ ایمان لائے اور عمل نیک کرتے رہے ان کو خدا بہشتوں میں جن کے نیچے نہریں بہہ رہی ہیں داخل فرمائے گا۔ اور جو کافر ہیں وہ فائدے اٹھاتے ہیں اور (اس طرح) کھاتے ہیں جیسے حیوان کھاتے ہیں۔ اور ان کا ٹھکانہ دوزخ ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdlviii{اور بہت سی بستیاں تمہاری بستی سے جس (کے باشندوں نے تمہیں وہاں) سے نکال دیا زور وقوت میں کہیں بڑھ کر تھیں ہم نے ان کا ستیاناس کردیا اور ان کا کوئی مددگار نہ ہوا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdlix{بھلا جو شخص اپنے پروردگار (کی مہربانی) سے کھلے رستے پر (چل رہا) ہو وہ ان کی طرح (ہوسکتا) ہے جن کے اعمال بد انہیں اچھے کرکے دکھائی جائیں اور جو اپنی خواہشوں کی پیروی کریں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdlx{جنت جس کا پرہیزگاروں سے وعدہ کیا جاتا ہے۔ اس کی صفت یہ ہے کہ اس میں پانی کی نہریں ہیں جو بو نہیں کرے گا۔ اور دودھ کی نہریں ہیں جس کا مزہ نہیں بدلے گا۔ اور شراب کی نہریں ہیں جو پینے والوں کے لئے (سراسر) لذت ہے۔ اور شہد مصفا کی نہریں ہیں (جو حلاوت ہی حلاوت ہے) اور (وہاں) ان کے لئے ہر قسم کے میوے ہیں اور ان کے پروردگار کی طرف سے مغفرت ہے۔ (کیا یہ پرہیزگار) ان کی طرح (ہوسکتے) ہیں جو ہمیشہ دوزخ میں رہیں گے اور جن کو کھولتا ہوا پانی پلایا جائے گا تو ان کی انتڑیوں کو کاٹ ڈالے گا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdlxi{اور ان میں بعض ایسے بھی ہیں جو تمہاری طرف کان لگائے یہاں تک کہ (سب کچھ سنتے ہیں لیکن) جب تمہارے پاس سے نکل کر چلے جاتے ہیں تو جن لوگوں کو علم (دین) دیا گیا ہے ان سے کہتے ہیں کہ (بھلا) انہوں نے ابھی کیا کہا تھا؟ یہی لوگ ہیں جن کے دلوں پر خدا نے مہر لگا رکھی ہے اور وہ اپنی خواہشوں کے پیچھے چل رہے ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdlxii{اور جو لوگ ہدایت یافتہ ہیں ان کو وہ ہدایت مزید بخشتا اور پرہیزگاری عنایت کرتا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiii{اب تو یہ لوگ قیامت ہی کو دیکھ رہے ہیں کہ ناگہاں ان پر آ واقع ہو۔ سو اس کی نشانیاں (وقوع میں) آچکی ہیں۔ پھر جب وہ ان پر آ نازل ہوگی اس وقت انہیں نصیحت کہاں (مفید ہوسکے گی؟)\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdlxiv{پس جان رکھو کہ خدا کے سوا کوئی معبود نہیں اور اپنے گناہوں کی معافی مانگو اور (اور) مومن مردوں اور مومن عورتوں کے لئے بھی۔ اور خدا تم لوگوں کے چلنے پھرنے اور ٹھیرنے سے واقف ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdlxv{اور مومن لوگ کہتے ہیں کہ (جہاد کی) کوئی سورت کیوں نازل نہیں ہوتی؟ لیکن جب کوئی صاف معنوں کی سورت نازل ہو اور اس میں جہاد کا بیان ہو تو جن لوگوں کے دلوں میں (نفاق کا) مرض ہے تم ان کو دیکھو کہ تمہاری طرف اس طرح دیکھنے لگیں جس طرح کسی پر موت کی بےہوشی (طاری) ہو رہی ہو۔ سو ان کے لئے خرابی ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvi{خوب کام تو) فرمانبرداری اور پسندیدہ بات کہنا (ہے) پھر جب (جہاد کی) بات پختہ ہوگئی تو اگر یہ لوگ خدا سے سچے رہنا چاہتے تو ان کے لئے بہت اچھا ہوتا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdlxvii{اے منافقو!) تم سے عجب نہیں کہ اگر تم حاکم ہو جاؤ تو ملک میں خرابی کرنے لگو اور اپنے رشتوں کو توڑ ڈالو\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdlxviii{یہی لوگ ہیں جن پر خدا نے لعنت کی ہے اور ان (کے کانوں) کو بہرا اور (ان کی) آنکھوں کو اندھا کردیا ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdlxix{بھلا یہ لوگ قرآن میں غور نہیں کرتے یا (ان کے) دلوں پر قفل لگ رہے ہیں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdlxx{جو لوگ راہ ہدایت ظاہر ہونے کے بعد پیٹھ دے کر پھر گئے۔ شیطان نے (یہ کام) ان کو مزین کر دکھایا اور انہیں طول (عمر کا وعدہ) دیا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxi{یہ اس لئے کہ جو لوگ خدا کی اُتاری ہوئی (کتاب) سے بیزار ہیں یہ ان سے کہتے ہیں کہ بعض کاموں میں ہم تمہاری بات بھی مانیں گے۔ اور خدا ان کے پوشیدہ مشوروں سے واقف ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxii{تو اُس وقت (ان کا) کیسا (حال) ہوگا جب فرشتے ان کی جان نکالیں گے اور ان کے مونہوں اور پیٹھوں پر مارتے جائیں گے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiii{یہ اس لئے کہ جس چیز سے خدا ناخوش ہے یہ اس کے پیچھے چلے اور اس کی خوشنودی کو اچھا نہ سمجھے تو اُس نے بھی ان کے عملوں کو برباد کر دیا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxiv{کیا وہ لوگ جن کے دلوں میں بیماری ہے یہ خیال کئے ہوئے ہیں کہ خدا ان کے کینوں کو ظاہر نہیں کرے گا؟\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxv{اور اگر ہم چاہتے تو وہ لوگ تم کو دکھا بھی دیتے اور تم ان کو ان کے چہروں ہی سے پہچان لیتے۔ اور تم انہیں (ان کے) انداز گفتگو ہی سے پہچان لو گے! اور خدا تمہارے اعمال سے واقف ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvi{اور ہم تو لوگوں کو آزمائیں گے تاکہ جو تم میں لڑائی کرنے والے اور ثابت قدم رہنے والے ہیں ان کو معلوم کریں۔ اور تمہارے حالات جانچ لیں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxvii{جن لوگوں کو سیدھا رستہ معلوم ہوگیا (اور) پھر بھی انہوں نے کفر کیا اور (لوگوں کو) خدا کی راہ سے روکا اور پیغمبر کی مخالفت کی وہ خدا کا کچھ بھی بگاڑ نہیں سکیں گے۔ اور خدا ان کا سب کیا کرایا اکارت کردے گا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxviii{مومنو! خدا کا ارشاد مانو اور پیغمبر کی فرمانبرداری کرو اور اپنے عملوں کو ضائع نہ ہونے دو\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxix{جو لوگ کافر ہوئے اور خدا کے رستے سے روکتے رہے پھر کافر ہی مرگئے خدا ان کو ہرگز نہیں بخشے گا\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxx{تو تم ہمت نہ ہارو اور (دشمنوں کو) صلح کی طرف نہ بلاؤ۔ اور تم تو غالب ہو۔ اور خدا تمہارے ساتھ ہے وہ ہرگز تمہارے اعمال کو کم (اور گم) نہیں کرے گا\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxi{دنیا کی زندگی تو محض کھیل اور تماشا ہے۔ اور اگر تم ایمان لاؤ گے اور پرہیزگاری کرو گے تو وہ تم کو تمہارا اجر دے گا۔ اور تم سے تمہارا مال طلب نہیں کرے گا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxii{اگر وہ تم سے مال طلب کرے اور تمہیں تنگ کرے تو تم بخل کرنے لگو اور وہ (بخل) تمہاری بدنیتی ظاہر کرکے رہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiii{دیکھو تم وہ لوگ ہو کہ خدا کی راہ میں خرچ کرنے کے لئے بلائے جاتے ہو۔ تو تم میں ایسے شخص بھی ہیں جو بخل کرنے لگتے ہیں۔ اور جو بخل کرتا ہے اپنے آپ سے بخل کرتا ہے۔ اور خدا بےنیاز ہے اور تم محتاج۔ اور اگر تم منہ پھیرو گے تو وہ تمہاری جگہ اور لوگوں کو لے آئے گا اور وہ تمہاری طرح کے نہیں ہوں گے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxiv{\basmalahur (اے محمدﷺ) ہم نے تم کو فتح دی۔ فتح بھی صریح وصاف\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxv{تاکہ خدا تمہارے اگلے اور پچھلے گناہ بخش دے اور تم پر اپنی نعمت پوری کردے اور تمہیں سیدھے رستے چلائے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvi{اور خدا تمہاری زبردست مدد کرے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxvii{وہی تو ہے جس نے مومنوں کے دلوں پر تسلی نازل فرمائی تاکہ ان کے ایمان کے ساتھ اور ایمان بڑھے۔ اور آسمانوں اور زمین کے لشکر (سب) خدا ہی کے ہیں۔ اور خدا جاننے والا (اور) حکمت والا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxviii{یہ) اس لئے کہ وہ مومن مردوں اور مومن عورتوں کو بہشتوں میں جن کے نیچے نہریں بہہ رہی ہیں داخل کرے وہ اس میں ہمیشہ رہیں گے اور ان سے ان کے گناہوں کو دور کردے۔ اور یہ خدا کے نزدیک بڑی کامیابی ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdlxxxix{اور (اس لئے کہ) منافق مردوں اور منافق عورتوں اور مشرک مردوں اور مشرک عورتوں کو جو خدا کے حق میں برے برے خیال رکھتے ہیں عذاب دے۔ ان ہی پر برے حادثے واقع ہوں۔ اور خدا ان پر غصے ہوا اور ان پر لعنت کی اور ان کے لئے دوزخ تیار کی۔ اور وہ بری جگہ ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdxc{اور آسمانوں اور زمین کے لشکر خدا ہی کے ہیں۔ اور خدا غالب (اور) حکمت والا ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdxci{اور ہم نے (اے محمدﷺ) تم کو حق ظاہر کرنے والا اور خوشخبری سنانے والا اور خوف دلانے والا (بنا کر) بھیجا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdxcii{تاکہ (مسلمانو) تم لوگ خدا پر اور اس کے پیغمبر پر ایمان لاؤ اور اس کی مدد کرو اور اس کو بزرگ سمجھو۔ اور صبح وشام اس کی تسبیح کرتے رہو\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdxciii{جو لوگ تم سے بیعت کرتے ہیں وہ خدا سے بیعت کرتے ہیں۔ خدا کا ہاتھ ان کے ہاتھوں پر ہے۔ پھر جو عہد کو توڑے تو عہد توڑنے کا نقصان اسی کو ہے۔ اور جو اس بات کو جس کا اس نے خدا سے عہد کیا ہے پورا کرے تو وہ اسے عنقریب اجر عظیم دے گا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdxciv{جو گنوار پیچھے رہ گئے وہ تم سے کہیں گے کہ ہم کو ہمارے مال اور اہل وعیال نے روک رکھا آپ ہمارے لئے (خدا سے) بخشش مانگیں۔ یہ لوگ اپنی زبان سے وہ بات کہتے ہیں جو ان کے دل میں نہیں ہے۔ کہہ دو کہ اگر خدا تم (لوگوں) کو نقصان پہنچانا چاہے یا تمہیں فائدہ پہنچانے کا ارادہ فرمائے تو کون ہے جو اس کے سامنے تمہارے لئے کسی بات کا کچھ اختیار رکھے (کوئی نہیں) بلکہ جو کچھ تم کرتے ہو خدا اس سے واقف ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdxcv{بات یہ ہے کہ تم لوگ یہ سمجھ بیٹھے تھے کہ پیغمبر اور مومن اپنے اہل وعیال میں کبھی لوٹ کر آنے ہی کے نہیں۔ اور یہی بات تمہارے دلوں کو اچھی معلوم ہوئی۔ اور (اسی وجہ سے) تم نے برے برے خیال کئے اور (آخرکار) تم ہلاکت میں پڑ گئے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvi{اور جو شخص خدا پر اور اس کے پیغمبر پر ایمان نہ لائے تو ہم نے (ایسے) کافروں کے لئے آگ تیار کر رکھی ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdxcvii{اور آسمانوں اور زمین کی بادشاہی خدا ہی کی ہے۔ وہ جسے چاہے بخشے اور جسے چاہے سزا دے۔ اور خدا بخشنے والا مہربان ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdxcviii{جب تم لوگ غنیمتیں لینے چلو گے تو جو لوگ پیچھے رہ گئے تھے وہ کہیں گے ہمیں بھی اجازت دیجیئے کہ آپ کے ساتھ چلیں۔ یہ چاہتے ہیں کہ خدا کے قول کو بدل دیں۔ کہہ دو کہ تم ہرگز ہمارے ساتھ نہیں چل سکتے۔ اسی طرح خدا نے پہلے سے فرما دیا ہے۔ پھر کہیں گے (نہیں) تم تو ہم سے حسد کرتے ہو۔ بات یہ ہے کہ یہ لوگ سمجھتے ہی نہیں مگر بہت کم\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdxcix{جو گنوار پیچھے رہ گئے تھے ان سے کہہ دو کہ تم ایک سخت جنگجو قوم کے (ساتھ لڑائی کے) لئے بلائے جاؤ گے ان سے تم (یا تو) جنگ کرتے رہو گے یا وہ اسلام لے آئیں گے۔ اگر تم حکم مانو گے تو خدا تم کو اچھا بدلہ دے گا۔ اور اگر منہ پھیر لو گے جیسے پہلی دفعہ پھیرا تھا تو وہ تم کو بری تکلیف کی سزا دے گا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdc{نہ تو اندھے پر گناہ ہے (کہ سفر جنگ سے پیچھے رہ جائے) اور نہ لنگڑے پر گناہ ہے اور نہ بیمار پر گناہ ہے۔ اور جو شخص خدا اور اس کے پیغمبر کے فرمان پر چلے گا خدا اس کو بہشتوں میں داخل کرے گا جن کے تلے نہریں بہہ رہی ہیں۔ اور جو روگردانی کرے گا اسے برے دکھ کی سزا دے گا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdci{اے پیغمبر) جب مومن تم سے درخت کے نیچے بیعت کر رہے تھے تو خدا ان سے خوش ہوا۔ اور جو (صدق وخلوص) ان کے دلوں میں تھا وہ اس نے معلوم کرلیا۔ تو ان پر تسلی نازل فرمائی اور انہیں جلد فتح عنایت کی\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdcii{اور بہت سی غنیمتیں جو انہوں نے حاصل کیں۔ اور خدا غالب حکمت والا ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdciii{خدا نے تم سے بہت سی غنیمتوں کا وعدہ فرمایا کہ تم ان کو حاصل کرو گے سو اس نے غنیمت کی تمہارے لئے جلدی فرمائی اور لوگوں کے ہاتھ تم سے روک دیئے۔ غرض یہ تھی کہ یہ مومنوں کے لئے (خدا کی) قدرت کا نمونہ ہو اور وہ تم کو سیدھے رستے پر چلائے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdciv{اور اَور (غنیمتیں دیں) جن پر تم قدرت نہیں رکھتے تھے (اور) وہ خدا ہی کی قدرت میں تھیں۔ اور خدا ہر چیز پر قادر ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdcv{اور اگر تم سے کافر لڑتے تو پیٹھ پھیر کر بھاگ جاتے پھر کسی کو دوست نہ پاتے اور نہ مددگار\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdcvi{یہی) خدا کی عادت ہے جو پہلے سے چلی آتی ہے۔ اور تم خدا کی عادت کبھی بدلتی نہ دیکھو گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdcvii{اور وہی تو ہے جس نے تم کو ان (کافروں) پر فتحیاب کرنے کے بعد سرحد مکہ میں ان کے ہاتھ تم سے اور تمہارے ہاتھ ان سے روک دیئے۔ اور جو کچھ تم کرتے ہو خدا اس کو دیکھ رہا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdcviii{یہ وہی لوگ ہیں جنہوں نے کفر کیا اور تم کو مسجد حرام سے روک دیا اور قربانیوں کو بھی کہ اپنی جگہ پہنچنے سے رکی رہیں۔ اور اگر ایسے مسلمان مرد اور مسلمان عورتیں نہ ہوتیں جن کو تم جانتے نہ تھے کہ اگر تم ان کو پامال کر دیتے تو تم کو ان کی طرف سے بےخبری میں نقصان پہنچ جاتا۔ (تو بھی تمہارے ہاتھ سے فتح ہوجاتی مگر تاخیر) اس لئے (ہوئی) کہ خدا اپنی رحمت میں جس کو چاہے داخل کرلے۔ اور اگر دونوں فریق الگ الگ ہوجاتے تو جو ان میں کافر تھے ان ہم دکھ دینے والا عذاب دیتے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdcix{جب کافروں نے اپنے دلوں میں ضد کی اور ضد بھی جاہلیت کی۔ تو خدا نے اپنے پیغمبر اور مومنوں پر اپنی طرف سے تسکین نازل فرمائی اور ان کو پرہیزگاری کی بات پر قائم رکھا اور وہ اسی کے مستحق اور اہل تھے۔ اور خدا ہر چیز سے خبردار ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdcx{بےشک خدا نے اپنے پیغمبر کو سچا (اور) صحیح خواب دکھایا۔ کہ تم خدا نے چاہا تو مسجد حرام میں اپنے سر منڈوا کر اور اپنے بال کتروا کر امن وامان سے داخل ہوگے۔ اور کسی طرح کا خوف نہ کرو گے۔ جو بات تم نہیں جانتے تھے اس کو معلوم تھی سو اس نے اس سے پہلے ہی جلد فتح کرادی\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdcxi{وہی تو ہے جس نے اپنے پیغمبر کو ہدایت (کی کتاب) اور دین حق دے کر بھیجا تاکہ اس کو تمام دینوں پر غالب کرے۔ اور حق ظاہر کرنے کے لئے خدا ہی کافی ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdcxii{محمدﷺ خدا کے پیغمبر ہیں اور جو لوگ ان کے ساتھ ہیں وہ کافروں کے حق میں سخت ہیں اور آپس میں رحم دل، (اے دیکھنے والے) تو ان کو دیکھتا ہے کہ (خدا کے آگے) جھکے ہوئے سر بسجود ہیں اور خدا کا فضل اور اس کی خوشنودی طلب کر رہے ہیں۔ (کثرت) سجود کے اثر سے ان کی پیشانیوں پر نشان پڑے ہوئے ہیں۔ ان کے یہی اوصاف تورات میں (مرقوم) ہیں۔ اور یہی اوصاف انجیل میں ہیں۔ (وہ) گویا ایک کھیتی ہیں جس نے (پہلے زمین سے) اپنی سوئی نکالی پھر اس کو مضبوط کیا پھر موٹی ہوئی اور پھر اپنی نال پر سیدھی کھڑی ہوگئی اور لگی کھیتی والوں کو خوش کرنے تاکہ کافروں کا جی جلائے۔ جو لوگ ان میں سے ایمان لائے اور نیک عمل کرتے رہے ان سے خدا نے گناہوں کی بخشش اور اجر عظیم کا وعدہ کیا ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiii{\basmalahur مومنو! (کسی بات کے جواب میں) خدا اور اس کے رسول سے پہلے نہ بول اٹھا کرو اور خدا سے ڈرتے رہو۔ بےشک خدا سنتا جانتا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdcxiv{اے اہل ایمان! اپنی آوازیں پیغمبر کی آواز سے اونچی نہ کرو اور جس طرح آپس میں ایک دوسرے سے زور سے بولتے ہو (اس طرح) ان کے روبرو زور سے نہ بولا کرو (ایسا نہ ہو) کہ تمہارے اعمال ضائع ہوجائیں اور تم کو خبر بھی نہ ہو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdcxv{جو لوگ پیغمبر خدا کے سامنے دبی آواز سے بولتے ہیں خدا نے ان کے دل تقویٰ کے لئے آزما لئے ہیں۔ ان کے لئے بخشش اور اجر عظیم ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvi{جو لوگ تم کو حجروں کے باہر سے آواز دیتے ہیں ان میں اکثر بےعقل ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdcxvii{اور اگر وہ صبر کئے رہتے یہاں تک کہ تم خود نکل کر ان کے پاس آتے تو یہ ان کے لئے بہتر تھا۔ اور خدا تو بخشنے والا مہربان ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdcxviii{مومنو! اگر کوئی بدکردار تمہارے پاس کوئی خبر لے کر آئے تو خوب تحقیق کرلیا کرو (مبادا) کہ کسی قوم کو نادانی سے نقصان پہنچا دو۔ پھر تم کو اپنے کئے پر نادم ہونا پڑے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdcxix{اور جان رکھو کہ تم میں خدا کے پیغمبرﷺ ہیں۔ اگر بہت سی باتوں میں وہ تمہارا کہا مان لیا کریں تو تم مشکل میں پڑ جاؤ لیکن خدا نے تم کو ایمان عزیز بنا دیا اور اس کو تمہارے دلوں میں سجا دیا اور کفر اور گناہ اور نافرمانی سے تم کو بیزار کردیا۔ یہی لوگ راہ ہدایت پر ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdcxx{یعنی) خدا کے فضل اور احسان سے۔ اور خدا جاننے والا (اور) حکمت والا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxi{اور اگر مومنوں میں سے کوئی دو فریق آپس میں لڑ پڑیں تو ان میں صلح کرا دو۔ اور اگر ایک فریق دوسرے پر زیادتی کرے تو زیادتی کرنے والے سے لڑو یہاں تک کہ وہ خدا کے حکم کی طرف رجوع لائے۔ پس جب وہ رجوع لائے تو وہ دونوں فریق میں مساوات کے ساتھ صلح کرا دو اور انصاف سے کام لو۔ کہ خدا انصاف کرنے والوں کو پسند کرتا ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxii{مومن تو آپس میں بھائی بھائی ہیں۔ تو اپنے دو بھائیوں میں صلح کرادیا کرو۔ اور خدا سے ڈرتے رہو تاکہ تم پر رحمت کی جائے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiii{مومنو! کوئی قوم کسی قوم سے تمسخر نہ کرے ممکن ہے کہ وہ لوگ ان سے بہتر ہوں اور نہ عورتیں عورتوں سے (تمسخر کریں) ممکن ہے کہ وہ ان سے اچھی ہوں۔ اور اپنے (مومن بھائی) کو عیب نہ لگاؤ اور نہ ایک دوسرے کا برا نام رکھو۔ ایمان لانے کے بعد برا نام (رکھنا) گناہ ہے۔ اور جو توبہ نہ کریں وہ ظالم ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxiv{اے اہل ایمان! بہت گمان کرنے سے احتراز کرو کہ بعض گمان گناہ ہیں۔ اور ایک دوسرے کے حال کا تجسس نہ کیا کرو اور نہ کوئی کسی کی غیبت کرے۔ کیا تم میں سے کوئی اس بات کو پسند کرے گا کہ اپنے مرے ہوئے بھائی کا گوشت کھائے؟ اس سے تو تم ضرور نفرت کرو گے۔ (تو غیبت نہ کرو) اور خدا کا ڈر رکھو بےشک خدا توبہ قبول کرنے والا مہربان ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxv{لوگو! ہم نے تم کو ایک مرد اور ایک عورت سے پیدا کیا اور تمہاری قومیں اور قبیلے بنائے۔ تاکہ ایک دوسرے کو شناخت کرو۔ اور خدا کے نزدیک تم میں زیادہ عزت والا وہ ہے جو زیادہ پرہیزگار ہے۔ بےشک خدا سب کچھ جاننے والا (اور) سب سے خبردار ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvi{دیہاتی کہتے ہیں کہ ہم ایمان لے آئے۔ کہہ دو کہ تم ایمان نہیں لائے (بلکہ یوں) کہو کہ ہم اسلام لائے ہیں اور ایمان تو ہنوز تمہارے دلوں میں داخل ہی نہیں ہوا۔ اور تم خدا اور اس کے رسول کی فرمانبرداری کرو گے تو خدا تمہارے اعمال سے کچھ کم نہیں کرے گا۔ بےشک خدا بخشنے والا مہربان ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxvii{مومن تو وہ ہیں جو خدا اور اس کے رسول پر ایمان لائے پھر شک میں نہ پڑے اور خدا کی راہ میں مال اور جان سے لڑے۔ یہی لوگ (ایمان کے) سچے ہیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxviii{ان سے کہو کیا تم خدا کو اپنی دینداری جتلاتے ہو۔ اور خدا تو آسمانوں اور زمین کی سب چیزوں سے واقف ہے۔ اور خدا ہر شے کو جانتا ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxix{یہ لوگ تم پر احسان رکھتے ہیں کہ مسلمان ہوگئے ہیں۔ کہہ دو کہ اپنے مسلمان ہونے کا مجھ پر احسان نہ رکھو۔ بلکہ خدا تم پر احسان رکھتا ہے کہ اس نے تمہیں ایمان کا رستہ دکھایا بشرطیکہ تم سچے (مسلمان) ہو\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxx{بےشک خدا آسمانوں اور زمین کی پوشیدہ باتوں کو جانتا ہے اور جو کچھ تم کرتے ہو اسے دیکھتا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxi{\basmalahur قٓ۔ قرآن مجید کی قسم (کہ محمد پیغمبر خدا ہیں)\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxii{لیکن ان لوگوں نے تعجب کیا کہ انہی میں سے ایک ہدایت کرنے والا ان کے پاس آیا تو کافر کہنے لگے کہ یہ بات تو (بڑی) عجیب ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiii{بھلا جب ہم مر گئے اور مٹی ہوگئے (تو پھر زندہ ہوں گے؟) یہ زندہ ہونا (عقل سے) بعید ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxiv{ان کے جسموں کو زمین جتنا (کھا کھا کر) کم کرتی جاتی ہے ہمیں معلوم ہے۔ اور ہمارے پاس تحریری یادداشت بھی ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxv{بلکہ (عجیب بات یہ ہے کہ) جب ان کے پاس (دین) حق آ پہنچا تو انہوں نے اس کو جھوٹ سمجھا سو یہ ایک الجھی ہوئی بات میں (پڑ رہے) ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvi{کیا انہوں نے اپنے اوپر آسمان کی طرف نگاہ نہیں کی کہ ہم نے اس کو کیونکر بنایا اور (کیونکر) سجایا اور اس میں کہیں شگاف تک نہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxvii{اور زمین کو (دیکھو اسے) ہم نے پھیلایا اور اس میں پہاڑ رکھ دیئے اور اس میں ہر طرح کی خوشنما چیزیں اُگائیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxviii{تاکہ رجوع لانے والے بندے ہدایت اور نصیحت حاصل کریں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdcxxxix{اور آسمان سے برکت والا پانی اُتارا اور اس سے باغ وبستان اُگائے اور کھیتی کا اناج\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdcxl{اور لمبی لمبی کھجوریں جن کا گابھا تہہ بہ تہہ ہوتا ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdcxli{یہ سب کچھ) بندوں کو روزی دینے کے لئے (کیا ہے) اور اس (پانی) سے ہم نے شہر مردہ (یعنی زمین افتادہ) کو زندہ کیا۔ (بس) اسی طرح (قیامت کے روز) نکل پڑنا ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlii{ان سے پہلے نوح کی قوم اور کنوئیں والے اور ثمود جھٹلا چکے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliii{اور عاد اور فرعون اور لوط کے بھائی\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdcxliv{اور بن کے رہنے والے اور تُبّع کی قوم۔ (غرض) ان سب نے پیغمبروں کو جھٹلایا تو ہمارا وعید (عذاب) بھی پورا ہو کر رہا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlv{کیا ہم پہلی بار پیدا کرکے تھک گئے ہیں؟ (نہیں) بلکہ یہ ازسرنو پیدا کرنے میں شک میں (پڑے ہوئے) ہیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvi{اور ہم ہی نے انسان کو پیدا کیا ہے اور جو خیالات اس کے دل میں گزرتے ہیں ہم ان کو جانتے ہیں۔ اور ہم اس کی رگ جان سے بھی اس سے زیادہ قریب ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlvii{جب (وہ کوئی کام کرتا ہے تو) دو لکھنے والے جو دائیں بائیں بیٹھے ہیں، لکھ لیتے ہیں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlviii{کوئی بات اس کی زبان پر نہیں آتی مگر ایک نگہبان اس کے پاس تیار رہتا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdcxlix{اور موت کی بےہوشی حقیقت کھولنے کو طاری ہوگئی۔ (اے انسان) یہی (وہ حالت) ہے جس سے تو بھاگتا تھا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdcl{اور صور پھونکا جائے گا۔ یہی (عذاب کے) وعید کا دن ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdcli{اور ہر شخص (ہمارے سامنے) آئے گا۔ ایک (فرشتہ) اس کے ساتھ چلانے والا ہوگا اور ایک (اس کے عملوں کی) گواہی دینے والا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdclii{یہ وہ دن ہے کہ) اس سے تو غافل ہو رہا تھا۔ اب ہم نے تجھ پر سے پردہ اُٹھا دیا۔ تو آج تیری نگاہ تیز ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdcliii{اور اس کا ہم نشین (فرشتہ) کہے گا کہ یہ (اعمال نامہ) میرے پاس حاضر ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdcliv{حکم ہوگا کہ) ہر سرکش ناشکرے کو دوزخ میں ڈال دو\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdclv{جو مال میں بخل کرنے والا حد سے بڑھنے والا شبہے نکالنے والا تھا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdclvi{جس نے خدا کے ساتھ اور معبود مقرر کر رکھے تھے۔ تو اس کو سخت عذاب میں ڈال دو\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdclvii{اس کا ساتھی (شیطان) کہے گا کہ اے ہمارے پروردگار میں نے اس کو گمراہ نہیں کیا تھا بلکہ یہ آپ ہی رستے سے دور بھٹکا ہوا تھا\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdclviii{خدا) فرمائے گا کہ ہمارے حضور میں ردوکد نہ کرو۔ ہم تمہارے پاس پہلے ہی (عذاب کی) وعید بھیج چکے تھے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdclix{ہمارے ہاں بات بدلا نہیں کرتی اور ہم بندوں پر ظلم نہیں کیا کرتے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdclx{اس دن ہم دوزخ سے پوچھیں گے کہ کیا تو بھر گئی؟ وہ کہے گی کہ کچھ اور بھی ہے؟\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdclxi{اور بہشت پرہیزگاروں کے قریب کردی جائے گی (کہ مطلق) دور نہ ہوگی\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdclxii{یہی وہ چیز ہے جس کا تم سے وعدہ کیا جاتا تھا (یعنی) ہر رجوع لانے والے حفاظت کرنے والے سے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiii{جو خدا سے بن دیکھے ڈرتا ہے اور رجوع لانے والا دل لے کر آیا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdclxiv{اس میں سلامتی کے ساتھ داخل ہوجاؤ۔ یہ ہمیشہ رہنے کا دن ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdclxv{وہاں وہ جو چاہیں گے ان کے لئے حاضر ہے اور ہمارے ہاں اور بھی (بہت کچھ) ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvi{اور ہم نے ان سے پہلے کئی اُمتیں ہلاک کر ڈالیں۔ وہ ان سے قوت میں کہیں بڑھ کر تھے وہ شہروں میں گشت کرنے لگے۔ کیا کہیں بھاگنے کی جگہ ہے؟\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdclxvii{جو شخص دل (آگاہ) رکھتا ہے یا دل سے متوجہ ہو کر سنتا ہے اس کے لئے اس میں نصیحت ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdclxviii{اور ہم نے آسمانوں اور زمین کو اور جو (مخلوقات) ان میں ہے سب کو چھ دن میں بنا دیا۔ اور ہم کو ذرا تکان نہیں ہوئی\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdclxix{تو جو کچھ یہ (کفار) بکتے ہیں اس پر صبر کرو اور آفتاب کے طلوع ہونے سے پہلے اور اس کے غروب ہونے سے پہلے اپنے پروردگار کی تعریف کے ساتھ تسبیح کرتے رہو\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmdclxx{اور رات کے بعض اوقات میں بھی اور نماز کے بعد بھی اس (کے نام) کی تنزیہ کیا کرو\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxi{اور سنو جس دن پکارنے والا نزدیک کی جگہ سے پکارے گا\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxii{جس دن لوگ چیخ یقیناً سن لیں گے۔ وہی نکل پڑنے کا دن ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiii{ہم ہی تو زندہ کرتے ہیں اور ہم ہی مارتے ہیں اور ہمارے ہی پاس لوٹ کر آنا ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxiv{اس دن زمین ان پر سے پھٹ جائے گی اور وہ جھٹ پٹ نکل کھڑے ہوں گے۔ یہ جمع کرنا ہمیں آسان ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxv{یہ لوگ جو کچھ کہتے ہیں ہمیں خوب معلوم ہے اور تم ان پر زبردستی کرنے والے نہیں ہو۔ پس جو ہمارے (عذاب کی) وعید سے ڈرے اس کو قرآن سے نصیحت کرتے رہو\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvi{\basmalahur بکھیرنے والیوں کی قسم جو اُڑا کر بکھیر دیتی ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxvii{پھر (پانی کا) بوجھ اٹھاتی ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxviii{پھر آہستہ آہستہ چلتی ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxix{پھر چیزیں تقسیم کرتی ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxx{کہ جس چیز کا تم سے وعدہ کیا جاتا ہے وہ سچا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxi{اور انصاف (کا دن) ضرور واقع ہوگا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxii{اور آسمان کی قسم جس میں رسے ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiii{کہ (اے اہل مکہ) تم ایک متناقض بات میں (پڑے ہوئے) ہو\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxiv{اس سے وہی پھرتا ہے جو (خدا کی طرف سے) پھیرا جائے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxv{اٹکل دوڑانے والے ہلاک ہوں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvi{جو بےخبری میں بھولے ہوئے ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxvii{پوچھتے ہیں کہ جزا کا دن کب ہوگا؟\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxviii{اُس دن (ہوگا) جب ان کو آگ میں عذاب دیا جائے گا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdclxxxix{اب اپنی شرارت کا مزہ چکھو۔ یہ وہی ہے جس کے لئے تم جلدی مچایا کرتے تھے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdcxc{بےشک پرہیزگار بہشتوں اور چشموں میں (عیش کر رہے) ہوں گے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdcxci{اور) جو جو (نعمتیں) ان کا پروردگار انہیں دیتا ہوگا ان کو لے رہے ہوں گے۔ بےشک وہ اس سے پہلے نیکیاں کرتے تھے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcii{رات کے تھوڑے سے حصے میں سوتے تھے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciii{اور اوقات سحر میں بخشش مانگا کرتے تھے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdcxciv{اور ان کے مال میں مانگنے والے اور نہ مانگنے والے (دونوں) کا حق ہوتا تھا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcv{اور یقین کرنے والوں کے لئے زمین میں (بہت سی) نشانیاں ہیں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvi{اور خود تمہارے نفوس میں تو کیا تم دیکھتے نہیں؟\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcvii{اور تمہارا رزق اور جس چیز کا تم سے وعدہ کیا جاتا ہے آسمان میں ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcviii{تو آسمانوں اور زمین کے مالک کی قسم! یہ (اسی طرح) قابل یقین ہے جس طرح تم بات کرتے ہو\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdcxcix{بھلا تمہارے پاس ابراہیمؑ کے معزز مہمانوں کی خبر پہنچی ہے؟\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdcc{جب وہ ان کے پاس آئے تو سلام کہا۔ انہوں نے بھی (جواب میں) سلام کہا (دیکھا تو) ایسے لوگ کہ نہ جان نہ پہچان\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdcci{تو اپنے گھر جا کر ایک (بھنا ہوا) موٹا بچھڑا لائے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdccii{اور کھانے کے لئے) ان کے آگے رکھ دیا۔ کہنے لگے کہ آپ تناول کیوں نہیں کرتے؟\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdcciii{اور دل میں ان سے خوف معلوم کیا۔ (انہوں نے) کہا کہ خوف نہ کیجیئے۔ اور ان کو ایک دانشمند لڑکے کی بشارت بھی سنائی\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdcciv{تو ابراہیمؑ کی بیوی چلاّتی آئی اور اپنا منہ پیٹ کر کہنے لگی کہ (اے ہے ایک تو) بڑھیا اور (دوسرے) بانجھ\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdccv{انہوں نے) کہا (ہاں) تمہارے پروردگار نے یوں ہی فرمایا ہے۔ وہ بےشک صاحبِ حکمت (اور) خبردار ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdccvi{ابراہیمؑ نے کہا کہ فرشتو! تمہارا مدعا کیا ہے؟\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdccvii{انہوں نے کہا کہ ہم گنہگار لوگوں کی طرف بھیجے گئے ہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdccviii{تاکہ ان پر کھنگر برسائیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdccix{جن پر حد سے بڑھ جانے والوں کے لئے تمہارے پروردگار کے ہاں سے نشان کردیئے گئے ہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdccx{تو وہاں جتنے مومن تھے ان کو ہم نے نکال لیا\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdccxi{اور اس میں ایک گھر کے سوا مسلمانوں کا کوئی گھر نہ پایا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdccxii{اور جو لوگ عذاب الیم سے ڈرتے ہیں ان کے لئے وہاں نشانی چھوڑ دی\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiii{اور موسیٰ (کے حال) میں (بھی نشانی ہے) جب ہم نے ان کو فرعون کی طرف کھلا ہوا معجزہ دے کر بھیجا\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdccxiv{تو اس نے اپنی جماعت (کے گھمنڈ) پر منہ موڑ لیا اور کہنے لگا یہ تو جادوگر ہے یا دیوانہ\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmdccxv{تو ہم نے اس کو اور اس کے لشکروں کو پکڑ لیا اور ان کو دریا میں پھینک دیا اور وہ کام ہی قابل ملامت کرتا تھا\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvi{اور عاد (کی قوم کے حال) میں بھی (نشانی ہے) جب ہم نے ان پر نامبارک ہوا چلائی\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmdccxvii{وہ جس چیز پر چلتی اس کو ریزہ ریزہ کئے بغیر نہ چھوڑتی\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmdccxviii{اور (قوم) ثمود (کے حال) میں (نشانی ہے) جب ان سے کہا گیا کہ ایک وقت تک فائدہ اٹھالو\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmdccxix{تو انہوں نے اپنے پروردگار کے حکم سے سرکشی کی۔ سو ان کو کڑک نے آ پکڑا اور وہ دیکھ رہے تھے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmdccxx{پھر وہ نہ تو اُٹھنے کی طاقت رکھتے تھے اور نہ مقابلہ ہی کرسکتے تھے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxi{اور اس سے پہلے (ہم) نوح کی قوم کو (ہلاک کرچکے تھے) بےشک وہ نافرمان لوگ تھے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxii{اور آسمانوں کو ہم ہی نے ہاتھوں سے بنایا اور ہم کو سب مقدور ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiii{اور زمین کو ہم ہی نے بچھایا تو (دیکھو) ہم کیا خوب بچھانے والے ہیں\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxiv{اور ہر چیز کی ہم نے دو قسمیں بنائیں تاکہ تم نصیحت پکڑو\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxv{تو تم لوگ خدا کی طرف بھاگ چلو میں اس کی طرف سے تم کو صریح رستہ بتانے والا ہوں\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvi{اور خدا کے ساتھ کسی اَور کو معبود نہ بناؤ۔ میں اس کی طرف سے تم کو صریح رستہ بتانے والا ہوں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxvii{اسی طرح ان سے پہلے لوگوں کے پاس جو پیغمبر آتا وہ اس کو جادوگر یا دیوانہ کہتے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxviii{کیا یہ کہ ایک دوسرے کو اسی بات کی وصیت کرتے آئے ہیں بلکہ یہ شریر لوگ ہیں\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxix{تو ان سے اعراض کرو۔ تم کو (ہماری) طرف سے ملامت نہ ہوگی\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxx{اور نصیحت کرتے رہو کہ نصیحت مومنوں کو نفع دیتی ہے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxi{اور میں نے جنوں اور انسانوں کو اس لئے پیدا کیا ہے کہ میری عبادت کریں\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxii{میں ان سے طالب رزق نہیں اور نہ یہ چاہتا ہوں کہ مجھے (کھانا) کھلائیں\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiii{خدا ہی تو رزق دینے والا زور آور اور مضبوط ہے\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxiv{کچھ شک نہیں کہ ان ظالموں کے لئے بھی (عذاب کی) نوبت مقرر ہے جس طرح ان کے ساتھیوں کی نوبت تھی تو ان کو مجھ سے (عذاب) جلدی نہیں طلب کرنا چاہیئے\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxv{جس دن کا ان کافروں سے وعدہ کیا جاتا ہے اس سے ان کے لئے خرابی ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvi{\basmalahur (کوہ) طور کی قسم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxvii{اور کتاب کی جو لکھی ہوئی ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxviii{کشادہ اوراق میں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdccxxxix{اور آباد گھر کی\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdccxl{اور اونچی چھت کی\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdccxli{اور ابلتے ہوئے دریا کی\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlii{کہ تمہارے پروردگار کا عذاب واقع ہو کر رہے گا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliii{اور) اس کو کوئی روک نہیں سکے گا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdccxliv{جس دن آسمان لرزنے لگا کپکپا کر\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlv{اور پہاڑ اُڑنے لگے اون ہو کر\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvi{اس دن جھٹلانے والوں کے لئے خرابی ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlvii{جو خوض (باطل) میں پڑے کھیل رہے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlviii{جس دن ان کو آتش جہنم کی طرف دھکیل دھکیل کر لے جائیں گے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdccxlix{یہی وہ جہنم ہے جس کو تم جھوٹ سمجھتے تھے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdccl{تو کیا یہ جادو ہے یا تم کو نظر ہی نہیں آتا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdccli{اس میں داخل ہوجاؤ اور صبر کرو یا نہ کرو تمہارے لئے یکساں ہے۔ جو کام تم کیا کرتے تھے (یہ) انہی کا تم کو بدلہ مل رہا ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdcclii{جو پرہیزگار ہیں وہ باغوں اور نعتموں میں ہوں گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdccliii{جو کچھ ان کے پروردگار نے ان کو بخشا اس (کی وجہ) سے خوشحال۔ اور ان کے پروردگار نے ان کو دوزخ کے عذاب سے بچا لیا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdccliv{اپنے اعمال کے صلے میں مزے سے کھاؤ اور پیو\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdcclv{تختوں پر جو برابر برابر بچھے ہوئے ہیں تکیہ لگائے ہوئے اور بڑی بڑی آنکھوں والی حوروں سے ہم ان کا عقد کر دیں گے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvi{اور جو لوگ ایمان لائے اور ان کی اولاد بھی (راہ) ایمان میں ان کے پیچھے چلی۔ ہم ان کی اولاد کو بھی ان (کے درجے) تک پہنچا دیں گے اور ان کے اعمال میں سے کچھ کم نہ کریں گے۔ ہر شخص اپنے اعمال میں پھنسا ہوا ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdcclvii{اور جس طرح کے میوے اور گوشت کو ان کا جی چاہے گا ہم ان کو عطا کریں گے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdcclviii{وہاں وہ ایک دوسرے سے جام شراب جھپٹ لیا کریں گے جس (کے پینے) سے نہ ہذیان سرائی ہوگی نہ کوئی گناہ کی بات\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdcclix{اور نوجوان خدمت گار (جو ایسے ہوں گے) جیسے چھپائے ہوئے موتی ان کے آس پاس پھریں گے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdcclx{اور ایک دوسرے کی طرف رخ کرکے آپس میں گفتگو کریں گے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxi{کہیں گے کہ اس سے پہلے ہم اپنے گھر میں (خدا سے) ڈرتے رہتے تھے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxii{تو خدا نے ہم پر احسان فرمایا اور ہمیں لو کے عذاب سے بچا لیا\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiii{اس سے پہلے ہم اس سے دعائیں کیا کرتے تھے۔ بےشک وہ احسان کرنے والا مہربان ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxiv{تو (اے پیغمبر) تم نصیحت کرتے رہو تم اپنے پروردگار کے فضل سے نہ تو کاہن ہو اور نہ دیوانے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxv{کیا کافر کہتے ہیں کہ یہ شاعر ہے (اور) ہم اس کے حق میں زمانے کے حوادث کا انتظار کر رہے ہیں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvi{کہہ دو کہ انتظار کئے جاؤ میں بھی تمہارے ساتھ انتظار کرتا ہوں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxvii{کیا ان کی عقلیں ان کو یہی سکھاتی ہیں۔ بلکہ یہ لوگ ہیں ہی شریر\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxviii{کیا (کفار) کہتے ہیں کہ ان پیغمبر نے قرآن از خود بنا لیا ہے بات یہ ہے کہ یہ (خدا پر) ایمان نہیں رکھتے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxix{اگر یہ سچے ہیں تو ایسا کلام بنا تو لائیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxx{کیا یہ کسی کے پیدا کئے بغیر ہی پیدا ہوگئے ہیں۔ یا یہ خود (اپنے تئیں) پیدا کرنے والے ہیں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxi{یا انہوں نے آسمانوں اور زمین کو پیدا کیا ہے؟ (نہیں) بلکہ یہ یقین ہی نہیں رکھتے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxii{کیا ان کے پاس تمہارے پروردگار کے خزانے ہیں۔ یا یہ (کہیں کے) داروغہ ہیں؟\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiii{یا ان کے پاس کوئی سیڑھی ہے جس پر (چڑھ کر آسمان سے باتیں) سن آتے ہیں۔ تو جو سن آتا ہے وہ صریح سند دکھائے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxiv{کیا خدا کی تو بیٹیاں اور تمہارے بیٹے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxv{اے پیغمبر) کیا تم ان سے صلہ مانگتے ہو کہ ان پر تاوان کا بوجھ پڑ رہا ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvi{یا ان کے پاس غیب (کا علم) ہے کہ وہ اسے لکھ لیتے ہیں\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxvii{کیا یہ کوئی داؤں کرنا چاہتے ہیں تو کافر تو خود داؤں میں آنے والے ہیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxviii{کیا خدا کے سوا ان کا کوئی اور معبود ہے؟ خدا ان کے شریک بنانے سے پاک ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxix{اور اگر یہ آسمان سے (عذاب) کا کوئی ٹکڑا گرتا ہوا دیکھیں تو کہیں کہ یہ گاڑھا بادل ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxx{پس ان کو چھوڑ دو یہاں تک کہ وہ روز جس میں وہ بےہوش کردیئے جائیں گے، سامنے آجائے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxi{جس دن ان کا کوئی داؤں کچھ بھی کام نہ آئے اور نہ ان کو (کہیں سے) مدد ہی ملے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxii{اور ظالموں کے لئے اس کے سوا اور عذاب بھی ہے لیکن ان میں کے اکثر نہیں جانتے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiii{اور تم اپنے پروردگار کے حکم کے انتظار میں صبر کئے رہو۔ تم تو ہماری آنکھوں کے سامنے ہو اور جب اُٹھا کرو تو اپنے پروردگار کی تعریف کے ساتھ تسبیح کیا کرو\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxiv{اور رات کے بعض اوقات میں بھی اور ستاروں کے غروب ہونے کے بعد بھی اس کی تنزیہ کیا کرو\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxv{\basmalahur تارے کی قسم جب غائب ہونے لگے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvi{کہ تمہارے رفیق (محمدﷺ) نہ رستہ بھولے ہیں نہ بھٹکے ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxvii{اور نہ خواہش نفس سے منہ سے بات نکالتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxviii{یہ (قرآن) تو حکم خدا ہے جو (ان کی طرف) بھیجا جاتا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdcclxxxix{ان کو نہایت قوت والے نے سکھایا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdccxc{یعنی جبرائیل) طاقتور نے پھر وہ پورے نظر آئے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdccxci{اور وہ (آسمان کے) اونچے کنارے میں تھے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcii{پھر قریب ہوئے اوراَور آگے بڑھے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciii{تو دو کمان کے فاصلے پر یا اس سے بھی کم\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdccxciv{پھر خدا نے اپنے بندے کی طرف جو بھیجا سو بھیجا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcv{جو کچھ انہوں نے دیکھا ان کے دل نے اس کو جھوٹ نہ مانا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvi{کیا جو کچھ وہ دیکھتے ہیں تم اس میں ان سے جھگڑتے ہو؟\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcvii{اور انہوں نے اس کو ایک بار بھی دیکھا ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcviii{پرلی حد کی بیری کے پاس\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdccxcix{اسی کے پاس رہنے کی جنت ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdccc{جب کہ اس بیری پر چھا رہا تھا جو چھا رہا تھا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdccci{ان کی آنکھ نہ تو اور طرف مائل ہوئی اور نہ (حد سے) آگے بڑھی\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdcccii{انہوں نے اپنے پروردگار (کی قدرت) کی کتنی ہی بڑی بڑی نشانیاں دیکھیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdccciii{بھلا تم لوگوں نے لات اور عزیٰ کو دیکھا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdccciv{اور تیسرے منات کو (کہ یہ بت کہیں خدا ہوسکتے ہیں)\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdcccv{مشرکو!) کیا تمہارے لئے تو بیٹے اور خدا کے لئے بیٹیاں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvi{یہ تقسیم تو بہت بےانصافی کی ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdcccvii{وہ تو صرف نام ہی نام ہیں جو تم نے اور تمہارے باپ دادا نے گھڑ لئے ہیں۔ خدا نے تو ان کی کوئی سند نازل نہیں کی۔ یہ لوگ محض ظن (فاسد) اور خواہشات نفس کے پیچھے چل رہے ہیں۔ حالانکہ ان کے پروردگار کی طرف سے ان کے پاس ہدایت آچکی ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdcccviii{کیا جس چیز کی انسان آرزو کرتا ہے وہ اسے ضرور ملتی ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdcccix{آخرت اور دنیا تو الله ہی کے ہاتھ میں ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdcccx{اور آسمانوں میں بہت سے فرشتے ہیں جن کی سفارش کچھ بھی فائدہ نہیں دیتی مگر اس وقت کہ خدا جس کے لئے چاہے اجازت بخشے اور (سفارش) پسند کرے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxi{جو لوگ آخرت پر ایمان نہیں لاتے وہ فرشتوں کو (خدا کی) لڑکیوں کے نام سے موسوم کرتے ہیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxii{حالانکہ ان کو اس کی کچھ خبر نہیں۔ وہ صرف ظن پر چلتے ہیں۔ اور ظن یقین کے مقابلے میں کچھ کام نہیں آتا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiii{تو جو ہماری یاد سے روگردانی اور صرف دنیا ہی کی زندگی کا خواہاں ہو اس سے تم بھی منہ پھیر لو\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxiv{ان کے علم کی انتہا یہی ہے۔ تمہارا پروردگار اس کو بھی خوب جانتا ہے جو اس کے رستے سے بھٹک گیا اور اس سے بھی خوب واقف ہے جو رستے پر چلا\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxv{اور جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے سب خدا ہی کا ہے (اور اس نے خلقت کو) اس لئے (پیدا کیا ہے) کہ جن لوگوں نے برے کام کئے ان کو ان کے اعمال کا (برا) بدلا دے اور جنہوں نے نیکیاں کیں ان کو نیک بدلہ دے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvi{جو صغیرہ گناہوں کے سوا بڑے بڑے گناہوں اور بےحیائی کی باتوں سے اجتناب کرتے ہیں۔ بےشک تمہارا پروردگار بڑی بخشش والا ہے۔ وہ تم کو خوب جانتا ہے۔ جب اس نے تم کو مٹی سے پیدا کیا اور جب تم اپنی ماؤں کے پیٹ میں بچّے تھے۔ تو اپنے آپ کو پاک صاف نہ جتاؤ۔ جو پرہیزگار ہے وہ اس سے خوب واقف ہے\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxvii{بھلا تم نے اس شخص کو دیکھا جس نے منہ پھیر لیا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxviii{اور تھوڑا سا دیا (پھر) ہاتھ روک لیا\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxix{کیا اس کے پاس غیب کا علم ہے کہ وہ اس کو دیکھ رہا ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxx{کیا جو باتیں موسیٰ کے صحیفوں میں ہیں ان کی اس کو خبر نہیں پہنچی\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxi{اور ابراہیمؑ کی جنہوں نے (حق طاعت ورسالت) پورا کیا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxii{یہ کہ کوئی شخص دوسرے (کے گناہ) کا بوجھ نہیں اٹھائے گا\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiii{اور یہ کہ انسان کو وہی ملتا ہے جس کی وہ کوشش کرتا ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxiv{اور یہ کہ اس کی کوشش دیکھی جائے گی\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxv{پھر اس کو اس کا پورا پورا بدلا دیا جائے گا\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvi{اور یہ کہ تمہارے پروردگار ہی کے پاس پہنچنا ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxvii{اور یہ کہ وہ ہنساتا اور رلاتا ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxviii{اور یہ کہ وہی مارتا اور جلاتا ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxix{اور یہ کہ وہی نر اور مادہ دو قسم (کے حیوان) پیدا کرتا ہے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxx{یعنی) نطفے سے جو (رحم میں) ڈالا جاتا ہے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxi{اور یہ کہ (قیامت کو) اسی پر دوبارہ اٹھانا لازم ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxii{اور یہ کہ وہی دولت مند بناتا اور مفلس کرتا ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiii{اور یہ کہ وہی شعریٰ کا مالک ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxiv{اور یہ کہ اسی نے عاد اول کو ہلاک کر ڈالا\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxv{اور ثمود کو بھی۔ غرض کسی کو باقی نہ چھوڑا\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvi{اور ان سے پہلے قوم نوحؑ کو بھی۔ کچھ شک نہیں کہ وہ لوگ بڑے ہی ظالم اور بڑے ہی سرکش تھے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxvii{اور اسی نے الٹی ہوئی بستیوں کو دے پٹکا\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxviii{پھر ان پر چھایا جو چھایا\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxxxix{تو (اے انسان) تو اپنے پروردگار کی کون سی نعمت پر جھگڑے گا\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxl{یہ (محمدﷺ) بھی اگلے ڈر سنانے والوں میں سے ایک ڈر سنانے والے ہیں\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxli{آنے والی (یعنی قیامت) قریب آ پہنچی\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlii{اس (دن کی تکلیفوں) کو خدا کے سوا کوئی دور نہیں کرسکے گا\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliii{اے منکرین خدا) کیا تم اس کلام سے تعجب کرتے ہو؟\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxliv{اور ہنستے ہو اور روتے نہیں؟\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlv{اور تم غفلت میں پڑ رہے ہو\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvi{تو خدا کے آگے سجدہ کرو اور (اسی کی) عبادت کرو\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlvii{\basmalahur قیامت قریب آ پہنچی اور چاند شق ہوگیا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlviii{اور اگر (کافر) کوئی نشانی دیکھتے ہیں تو منہ پھیر لیتے ہیں اور کہتے ہیں کہ یہ ایک ہمیشہ کا جادو ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxlix{اور انہوں نے جھٹلایا اور اپنی خواہشوں کی پیروی کی اور ہر کام کا وقت مقرر ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmdcccl{اور ان کو ایسے حالات (سابقین) پہنچ چکے ہیں جن میں عبرت ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmdcccli{اور کامل دانائی (کی کتاب بھی) لیکن ڈرانا ان کو کچھ فائدہ نہیں دیتا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmdccclii{تو تم بھی ان کی کچھ پروا نہ کرو۔ جس دن بلانے والا ان کو ایک ناخوش چیز کی طرف بلائے گا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliii{تو آنکھیں نیچی کئے ہوئے قبروں سے نکل پڑیں گے گویا بکھری ہوئی ٹڈیاں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmdcccliv{اس بلانے والے کی طرف دوڑتے جاتے ہوں گے۔ کافر کہیں گے یہ دن بڑا سخت ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmdccclv{ان سے پہلے نوحؑ کی قوم نے بھی تکذیب کی تھی تو انہوں نے ہمارے بندے کو جھٹلایا اور کہا کہ دیوانہ ہے اور انہیں ڈانٹا بھی\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvi{تو انہوں نے اپنے پروردگار سے دعا کی کہ (بار الٓہا) میں (ان کے مقابلے میں) کمزور ہوں تو (ان سے) بدلہ لے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmdccclvii{پس ہم نے زور کے مینہ سے آسمان کے دہانے کھول دیئے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmdccclviii{اور زمین میں چشمے جاری کردیئے تو پانی ایک کام کے لئے جو مقدر ہوچکا تھا جمع ہوگیا\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmdccclix{اور ہم نے نوحؑ کو ایک کشتی پر جو تختوں اور میخوں سے تیار کی گئی تھی سوار کرلیا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmdccclx{وہ ہماری آنکھوں کے سامنے چلتی تھی۔ (یہ سب کچھ) اس شخص کے انتقام کے لئے (کیا گیا) جس کو کافر مانتے نہ تھے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxi{اور ہم نے اس کو ایک عبرت بنا چھوڑا تو کوئی ہے کہ سوچے سمجھے؟\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxii{سو (دیکھ لو کہ) میرا عذاب اور ڈرانا کیسا ہوا؟\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiii{اور ہم نے قرآن کو سمجھنے کے لئے آسان کردیا ہے تو کوئی ہے کہ سوچے سمجھے؟\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxiv{عاد نے بھی تکذیب کی تھی سو (دیکھ لو کہ) میرا عذاب اور ڈرانا کیسا ہوا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxv{ہم نے ان پر سخت منحوس دن میں آندھی چلائی\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvi{وہ لوگوں کو (اس طرح) اکھیڑے ڈالتی تھی گویا اکھڑی ہوئی کھجوروں کے تنے ہیں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxvii{سو (دیکھ لو کہ) میرا عذاب اور ڈرانا کیسا ہوا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxviii{اور ہم نے قرآن کو سمجھنے کے لئے آسان کردیا ہے تو کوئی ہے کہ سوچے سمجھے؟\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxix{ثمود نے بھی ہدایت کرنے والوں کو جھٹلایا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxx{اور کہا کہ بھلا ایک آدمی جو ہم ہی میں سے ہے ہم اس کی پیروی کریں؟ یوں ہو تو ہم گمراہی اور دیوانگی میں پڑ گئے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxi{کیا ہم سب میں سے اسی پر وحی نازل ہوئی ہے؟ (نہیں) بلکہ یہ جھوٹا خود پسند ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxii{ان کو کل ہی معلوم ہوجائے گا کہ کون جھوٹا خود پسند ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiii{اے صالح) ہم ان کی آزمائش کے لئے اونٹنی بھیجنے والے ہیں تو تم ان کو دیکھتے رہو اور صبر کرو\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxiv{اور ان کو آگاہ کردو کہ ان میں پانی کی باری مقرر کر دی گئی ہے۔ ہر (باری والے کو اپنی) باری پر آنا چاہیئے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxv{تو ان لوگوں نے اپنے رفیق کو بلایا اور اس نے (اونٹنی کو پکڑ کر اس کی) کونچیں کاٹ ڈالیں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvi{سو (دیکھ لو کہ) میرا عذاب اور ڈرانا کیسا ہوا\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxvii{ہم نے ان پر (عذاب کے لئے) ایک چیخ بھیجی تو وہ ایسے ہوگئے جیسے باڑ والے کی سوکھی اور ٹوٹی ہوئی باڑ\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxviii{اور ہم نے قرآن کو سمجھنے کے لئے آسان کردیا ہے تو کوئی ہے کہ سوچے سمجھے؟\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxix{لوط کی قوم نے بھی ڈر سنانے والوں کو جھٹلایا تھا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxx{تو ہم نے ان پر کنکر بھری ہوا چلائی مگر لوط کے گھر والے کہ ہم نے ان کو پچھلی رات ہی سے بچا لیا\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxi{اپنے فضل سے۔ شکر کرنے والوں کو ہم ایسا ہی بدلہ دیا کرتے ہیں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxii{اور لوطؑ نے ان کو ہماری پکڑ سے ڈرایا بھی تھا مگر انہوں نے ڈرانے میں شک کیا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiii{اور ان سے ان کے مہمانوں کو لے لینا چاہا تو ہم نے ان کی آنکھیں مٹا دیں سو (اب) میرے عذاب اور ڈرانے کے مزے چکھو\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxiv{اور ان پر صبح سویرے ہی اٹل عذاب آ نازل ہوا\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxv{تو اب میرے عذاب اور ڈرانے کے مزے چکھو\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvi{اور ہم نے قرآن کو سمجھنے کے لئے آسان کردیا ہے تو کوئی ہے کہ سوچے سمجھے؟\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxvii{اور قوم فرعون کے پاس بھی ڈر سنانے والے آئے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxviii{انہوں نے ہماری تمام نشانیوں کو جھٹلایا تو ہم نے ان کو اس طرح پکڑ لیا جس طرح ایک قوی اور غالب شخص پکڑ لیتا ہے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmdccclxxxix{اے اہل عرب) کیا تمہارے کافر ان لوگوں سے بہتر ہیں یا تمہارے لئے (پہلی) کتابوں میں کوئی فارغ خطی لکھ دی گئی ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxc{کیا یہ لوگ کہتے ہیں کہ ہماری جماعت بڑی مضبوط ہے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxci{عنقریب یہ جماعت شکست کھائے گی اور یہ لوگ پیٹھ پھیر کر بھاگ جائیں گے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcii{ان کے وعدے کا وقت تو قیامت ہے اور قیامت بڑی سخت اور بہت تلخ ہے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciii{بےشک گنہگار لوگ گمراہی اور دیوانگی میں (مبتلا) ہیں\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxciv{اس روز منہ کے بل دوزخ میں گھسیٹے جائیں گے اب آگ کا مزہ چکھو\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcv{ہم نے ہر چیز اندازہٴ مقرر کے ساتھ پیدا کی ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvi{اور ہمارا حکم تو آنکھ کے جھپکنے کی طرح ایک بات ہوتی ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcvii{اور ہم تمہارے ہم مذہبوں کو ہلاک کرچکے ہیں تو کوئی ہے کہ سوچے سمجھے؟\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcviii{اور جو کچھ انہوں نے کیا، (ان کے) اعمال ناموں میں (مندرج) ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmdcccxcix{یعنی) ہر چھوٹا اور بڑا کام لکھ دیا گیا ہے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcm{جو پرہیزگار ہیں وہ باغوں اور نہروں میں ہوں گے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmcmi{یعنی) پاک مقام میں ہر طرح کی قدرت رکھنے والے بادشاہ کی بارگاہ میں\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmcmii{\basmalahur (خدا جو) نہایت مہربان\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcmiii{اسی نے قرآن کی تعلیم فرمائی\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcmiv{اسی نے انسان کو پیدا کیا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcmv{اسی نے اس کو بولنا سکھایا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcmvi{سورج اور چاند ایک حساب مقرر سے چل رہے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcmvii{اور بوٹیاں اور درخت سجدہ کر رہے ہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcmviii{اور اسی نے آسمان کو بلند کیا اور ترازو قائم کی\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcmix{کہ ترازو (سے تولنے) میں حد سے تجاوز نہ کرو\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcmx{اور انصاف کے ساتھ ٹھیک تولو۔ اور تول کم مت کرو\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcmxi{اور اسی نے خلقت کے لئے زمین بچھائی\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcmxii{اس میں میوے اور کھجور کے درخت ہیں جن کے خوشوں پر غلاف ہوتے ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiii{اور اناج جس کے ساتھ بھس ہوتا ہے اور خوشبودار پھول\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcmxiv{تو (اے گروہ جن وانس) تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcmxv{اسی نے انسان کو ٹھیکرے کی طرح کھنکھناتی مٹی سے بنایا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvi{اور جنات کو آگ کے شعلے سے پیدا کیا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcmxvii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcmxviii{وہی دونوں مشرقوں اور دونوں مغربوں کا مالک (ہے)\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcmxix{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmcmxx{اسی نے دو دریا رواں کئے جو آپس میں ملتے ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxi{دونوں میں ایک آڑ ہے کہ (اس سے) تجاوز نہیں کرسکتے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiii{دونوں دریاؤں سے موتی اور مونگے نکلتے ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxiv{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxv{اور جہاز بھی اسی کے ہیں جو دریا میں پہاڑوں کی طرح اونچے کھڑے ہوتے ہیں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvi{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxvii{جو (مخلوق) زمین پر ہے سب کو فنا ہونا ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxviii{اور تمہارے پروردگار ہی کی ذات (بابرکات) جو صاحب جلال وعظمت ہے باقی رہے گی\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxix{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxx{آسمان اور زمین میں جتنے لوگ ہیں سب اسی سے مانگتے ہیں۔ وہ ہر روز کام میں مصروف رہتا ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxi{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxii{اے دونوں جماعتو! ہم عنقریب تمہاری طرف متوجہ ہوتے ہیں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxiv{اے گروہِ جن وانس اگر تمہیں قدرت ہو کہ آسمان اور زمین کے کناروں سے نکل جاؤ تو نکل جاؤ۔ اور زور کے سوا تم نکل سکنے ہی کے نہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxv{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvi{تم پر آگ کے شعلے اور دھواں چھوڑ دیا جائے گا تو پھر تم مقابلہ نہ کرسکو گے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxvii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxviii{پھر جب آسمان پھٹ کر تیل کی تلچھٹ کی طرح گلابی ہوجائے گا (تو) وہ کیسا ہولناک دن ہوگا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmcmxxxix{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmcmxl{اس روز نہ تو کسی انسان سے اس کے گناہوں کے بارے میں پرسش کی جائے گی اور نہ کسی جن سے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmcmxli{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlii{گنہگار اپنے چہرے ہی سے پہچان لئے جائیں گے تو پیشانی کے بالوں اور پاؤں سے پکڑ لئے جائیں گے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmcmxliv{یہی وہ جہنم ہے جسے گنہگار لوگ جھٹلاتے تھے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlv{وہ دوزخ اور کھولتے ہوئے گرم پانی کے درمیان گھومتے پھریں گے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvi{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlvii{اور جو شخص اپنے پروردگار کے سامنے کھڑے ہونے سے ڈرا اس کے لئے دو باغ ہیں\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlviii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmcmxlix{ان دونوں میں بہت سی شاخیں (یعنی قسم قسم کے میووں کے درخت ہیں)\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmcml{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmcmli{ان میں دو چشمے بہہ رہے ہیں\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmcmlii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmcmliii{ان میں سب میوے دو دو قسم کے ہیں\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmcmliv{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmcmlv{اہل جنت) ایسے بچھونوں پر جن کے استرا طلس کے ہیں تکیہ لگائے ہوئے ہوں گے۔ اور دونوں باغوں کے میوے قریب (جھک رہے) ہیں\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvi{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmcmlvii{ان میں نیچی نگاہ والی عورتیں ہیں جن کو اہل جنت سے پہلے نہ کسی انسان نے ہاتھ لگایا اور نہ کسی جن نے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmcmlviii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmcmlix{گویا وہ یاقوت اور مرجان ہیں\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmcmlx{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxi{نیکی کا بدلہ نیکی کے سوا کچھ نہیں ہے\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiii{اور ان باغوں کے علاوہ دو باغ اور ہیں\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxiv{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxv{دونوں خوب گہرے سبز\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvi{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxvii{ان میں دو چشمے ابل رہے ہیں\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxviii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxix{ان میں میوے اور کھجوریں اور انار ہیں\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxx{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxi{ان میں نیک سیرت (اور) خوبصورت عورتیں ہیں\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiii{وہ) حوریں (ہیں جو) خیموں میں مستور (ہیں)\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxiv{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxv{ان کو اہل جنت سے پہلے نہ کسی انسان نے ہاتھ لگایا اور نہ کسی جن نے\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvi{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxvii{سبز قالینوں اور نفیس مسندوں پر تکیہ لگائے بیٹھے ہوں گے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxviii{تو تم اپنے پروردگار کی کون کون سی نعمت کو جھٹلاؤ گے؟\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxix{اے محمدﷺ) تمہارا پروردگار جو صاحب جلال وعظمت ہے اس کا نام بڑا بابرکت ہے\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxx{\basmalahur جب واقع ہونے والی واقع ہوجائے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxi{اس کے واقع ہونے میں کچھ جھوٹ نہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxii{کسی کو پست کرے کسی کو بلند\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiii{جب زمین بھونچال سے لرزنے لگے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxiv{اور پہاڑ ٹوٹ کر ریزہ ریزہ ہوجائیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxv{پھر غبار ہو کر اُڑنے لگیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvi{اور تم لوگ تین قسم ہوجاؤ\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxvii{تو داہنے ہاتھ والے (سبحان الله) داہنے ہاتھ والے کیا (ہی چین میں) ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxviii{اور بائیں ہاتھ والے (افسوس) بائیں ہاتھ والے کیا (گرفتار عذاب) ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmcmlxxxix{اور جو آگے بڑھنے والے ہیں (ان کا کیا کہنا) وہ آگے ہی بڑھنے والے ہیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmcmxc{وہی (خدا کے) مقرب ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmcmxci{نعمت کے بہشتوں میں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcii{وہ بہت سے تو اگلے لوگوں میں سے ہوں گے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciii{اور تھوڑے سے پچھلوں میں سے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmcmxciv{لعل و یاقوت وغیرہ سے) جڑے ہوئے تختوں پر\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcv{آمنے سامنے تکیہ لگائے ہوئے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvi{نوجوان خدمت گزار جو ہمیشہ (ایک ہی حالت میں) رہیں گے ان کے آس پاس پھریں گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcvii{یعنی آبخورے اور آفتابے اور صاف شراب کے گلاس لے لے کر\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcviii{اس سے نہ تو سر میں درد ہوگا اور نہ ان کی عقلیں زائل ہوں گی\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmcmxcix{اور میوے جس طرح کے ان کو پسند ہوں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmm{اور پرندوں کا گوشت جس قسم کا ان کا جی چاہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmi{اور بڑی بڑی آنکھوں والی حوریں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmii{جیسے (حفاظت سے) تہہ کئے ہوئے (آب دار) موتی\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmiii{یہ ان اعمال کا بدلہ ہے جو وہ کرتے تھے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmiv{وہاں نہ بیہودہ بات سنیں گے اور نہ گالی گلوچ\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmv{ہاں ان کا کلام سلام سلام (ہوگا)\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmvi{اور داہنے ہاتھ والے (سبحان الله) داہنے ہاتھ والے کیا (ہی عیش میں) ہیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmvii{یعنی) بےخار کی بیریوں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmviii{اور تہہ بہ تہہ کیلوں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmix{اور لمبے لمبے سایوں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmx{اور پانی کے جھرنوں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmxi{اور میوہ ہائے کثیرہ (کے باغوں) میں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmxii{جو نہ کبھی ختم ہوں اور نہ ان سے کوئی روکے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmxiii{اور اونچے اونچے فرشوں میں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmxiv{ہم نے ان (حوروں) کو پیدا کیا\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmxv{تو ان کو کنواریاں بنایا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmxvi{اور شوہروں کی) پیاریاں اور ہم عمر\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmxvii{یعنی داہنے ہاتھ والوں کے لئے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmxviii{یہ) بہت سے اگلے لوگوں میں سے ہیں\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmxix{اور بہت سے پچھلوں میں سے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmxx{اور بائیں ہاتھ والے (افسوس) بائیں ہاتھ والے کیا (ہی عذاب میں) ہیں\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmxxi{یعنی دوزخ کی) لپٹ اور کھولتے ہوئے پانی میں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmxxii{اور سیاہ دھوئیں کے سائے میں\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiii{جو) نہ ٹھنڈا (ہے) نہ خوشنما\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmxxiv{یہ لوگ اس سے پہلے عیشِ نعیم میں پڑے ہوئے تھے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmxxv{اور گناہ عظیم پر اڑے ہوئے تھے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvi{اور کہا کرتے تھے کہ بھلا جب ہم مرگئے اور مٹی ہوگئے اور ہڈیاں (ہی ہڈیاں رہ گئے) تو کیا ہمیں پھر اُٹھنا ہوگا؟\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmmxxvii{اور کیا ہمارے باپ دادا کو بھی؟\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmmxxviii{کہہ دو کہ بےشک پہلے اور پچھلے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmmxxix{سب) ایک روز مقرر کے وقت پر جمع کئے جائیں گے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmmxxx{پھر تم اے جھٹلانے والے گمرا ہو!\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxi{تھوہر کے درخت کھاؤ گے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxii{اور اسی سے پیٹ بھرو گے\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiii{اور اس پر کھولتا ہوا پانی پیو گے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxiv{اور پیو گے بھی تو اس طرح جیسے پیاسے اونٹ پیتے ہیں\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxv{جزا کے دن یہ ان کی ضیافت ہوگی\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvi{ہم نے تم کو (پہلی بار بھی تو) پیدا کیا ہے تو تم (دوبارہ اُٹھنے کو) کیوں سچ نہیں سمجھتے؟\qt@no{57}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxvii{دیکھو تو کہ جس (نطفے) کو تم (عورتوں کے رحم میں) ڈالتے ہو\qt@no{58}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxviii{کیا تم اس (سے انسان) کو بناتے ہو یا ہم بناتے ہیں؟\qt@no{59}}%
\qt@newcmd\qurantrans@ur@mmmmmxxxix{ہم نے تم میں مرنا ٹھہرا دیا ہے اور ہم اس (بات) سے عاجز نہیں\qt@no{60}}%
\qt@newcmd\qurantrans@ur@mmmmmxl{کہ تمہاری طرح کے اور لوگ تمہاری جگہ لے آئیں اور تم کو ایسے جہان میں جس کو تم نہیں جانتے پیدا کر دیں\qt@no{61}}%
\qt@newcmd\qurantrans@ur@mmmmmxli{اور تم نے پہلی پیدائش تو جان ہی لی ہے۔ پھر تم سوچتے کیوں نہیں؟\qt@no{62}}%
\qt@newcmd\qurantrans@ur@mmmmmxlii{بھلا دیکھو تو کہ جو کچھ تم بوتے ہو\qt@no{63}}%
\qt@newcmd\qurantrans@ur@mmmmmxliii{تو کیا تم اسے اُگاتے ہو یا ہم اُگاتے ہیں؟\qt@no{64}}%
\qt@newcmd\qurantrans@ur@mmmmmxliv{اگر ہم چاہیں تو اسے چورا چورا کردیں اور تم باتیں بناتے رہ جاؤ\qt@no{65}}%
\qt@newcmd\qurantrans@ur@mmmmmxlv{کہ ہائے) ہم تو مفت تاوان میں پھنس گئے\qt@no{66}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvi{بلکہ ہم ہیں ہی بےنصیب\qt@no{67}}%
\qt@newcmd\qurantrans@ur@mmmmmxlvii{بھلا دیکھو تو کہ جو پانی تم پیتے ہو\qt@no{68}}%
\qt@newcmd\qurantrans@ur@mmmmmxlviii{کیا تم نے اس کو بادل سے نازل کیا ہے یا ہم نازل کرتے ہیں؟\qt@no{69}}%
\qt@newcmd\qurantrans@ur@mmmmmxlix{اگر ہم چاہیں تو ہم اسے کھاری کردیں پھر تم شکر کیوں نہیں کرتے؟\qt@no{70}}%
\qt@newcmd\qurantrans@ur@mmmmml{بھلا دیکھو تو جو آگ تم درخت سے نکالتے ہو\qt@no{71}}%
\qt@newcmd\qurantrans@ur@mmmmmli{کیا تم نے اس کے درخت کو پیدا کیا ہے یا ہم پیدا کرتے ہیں؟\qt@no{72}}%
\qt@newcmd\qurantrans@ur@mmmmmlii{ہم نے اسے یاد دلانے اور مسافروں کے برتنے کو بنایا ہے\qt@no{73}}%
\qt@newcmd\qurantrans@ur@mmmmmliii{تو تم اپنے پروردگار بزرگ کے نام کی تسبیح کرو\qt@no{74}}%
\qt@newcmd\qurantrans@ur@mmmmmliv{ہمیں تاروں کی منزلوں کی قسم\qt@no{75}}%
\qt@newcmd\qurantrans@ur@mmmmmlv{اور اگر تم سمجھو تو یہ بڑی قسم ہے\qt@no{76}}%
\qt@newcmd\qurantrans@ur@mmmmmlvi{کہ یہ بڑے رتبے کا قرآن ہے\qt@no{77}}%
\qt@newcmd\qurantrans@ur@mmmmmlvii{جو) کتاب محفوظ میں (لکھا ہوا ہے)\qt@no{78}}%
\qt@newcmd\qurantrans@ur@mmmmmlviii{اس کو وہی ہاتھ لگاتے ہیں جو پاک ہیں\qt@no{79}}%
\qt@newcmd\qurantrans@ur@mmmmmlix{پروردگار عالم کی طرف سے اُتارا گیا ہے\qt@no{80}}%
\qt@newcmd\qurantrans@ur@mmmmmlx{کیا تم اس کلام سے انکار کرتے ہو؟\qt@no{81}}%
\qt@newcmd\qurantrans@ur@mmmmmlxi{اور اپنا وظیفہ یہ بناتے ہو کہ (اسے) جھٹلاتے ہو\qt@no{82}}%
\qt@newcmd\qurantrans@ur@mmmmmlxii{بھلا جب روح گلے میں آ پہنچتی ہے\qt@no{83}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiii{اور تم اس وقت کی (حالت کو) دیکھا کرتے ہو\qt@no{84}}%
\qt@newcmd\qurantrans@ur@mmmmmlxiv{اور ہم اس (مرنے والے) سے تم سے بھی زیادہ نزدیک ہوتے ہیں لیکن تم کو نظر نہیں آتے\qt@no{85}}%
\qt@newcmd\qurantrans@ur@mmmmmlxv{پس اگر تم کسی کے بس میں نہیں ہو\qt@no{86}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvi{تو اگر سچے ہو تو روح کو پھیر کیوں نہیں لیتے؟\qt@no{87}}%
\qt@newcmd\qurantrans@ur@mmmmmlxvii{پھر اگر وہ (خدا کے) مقربوں میں سے ہے\qt@no{88}}%
\qt@newcmd\qurantrans@ur@mmmmmlxviii{تو (اس کے لئے) آرام اور خوشبودار پھول اور نعمت کے باغ ہیں\qt@no{89}}%
\qt@newcmd\qurantrans@ur@mmmmmlxix{اور اگر وہ دائیں ہاتھ والوں میں سے ہے\qt@no{90}}%
\qt@newcmd\qurantrans@ur@mmmmmlxx{تو (کہا جائے گا کہ) تجھ پر داہنے ہاتھ والوں کی طرف سے سلام\qt@no{91}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxi{اور اگر وہ جھٹلانے والے گمراہوں میں سے ہے\qt@no{92}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxii{تو (اس کے لئے) کھولتے پانی کی ضیافت ہے\qt@no{93}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiii{اور جہنم میں داخل کیا جانا\qt@no{94}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxiv{یہ (داخل کیا جانا یقیناً صحیح یعنی) حق الیقین ہے\qt@no{95}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxv{تو تم اپنے پروردگار بزرگ کے نام کی تسبیح کرتے رہو\qt@no{96}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvi{\basmalahur جو مخلوق آسمانوں اور زمین میں ہے خدا کی تسبیح کرتی ہے۔ اور وہ غالب (اور) حکمت والا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxvii{آسمانوں اور زمین کی بادشاہی اسی کی ہے۔ (وہی) زندہ کرتا اور مارتا ہے۔ اور وہ ہر چیز پر قادر ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxviii{وہ (سب سے) پہلا اور (سب سے) پچھلا اور (اپنی قدرتوں سے سب پر) ظاہر اور (اپنی ذات سے) پوشیدہ ہے اور وہ تمام چیزوں کو جانتا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxix{وہی ہے جس نے آسمانوں اور زمین کو چھ دن میں پیدا کیا پھر عرش پر جا ٹھہرا۔ جو چیز زمین میں داخل ہوتی اور جو اس سے نکلتی ہے اور جو آسمان سے اُترتی اور جو اس کی طرف چڑھتی ہے سب اس کو معلوم ہے۔ اور تم جہاں کہیں ہو وہ تمہارے ساتھ ہے۔ اور جو کچھ تم کرتے ہو خدا اس کو دیکھ رہا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxx{آسمانوں اور زمین کی بادشاہی اسی کی ہے۔ اور سب امور اسی کی طرف رجوع ہوتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxi{رات کو دن میں داخل کرتا اور دن کو رات میں داخل کرتا ہے۔ اور وہ دلوں کے بھیدوں تک سے واقف ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxii{تو) خدا پر اور اس کے رسول پر ایمان لاؤ اور جس (مال) میں اس نے تم کو (اپنا) نائب بنایا ہے اس میں سے خرچ کرو۔ جو لوگ تم میں سے ایمان لائے اور (مال) خرچ کرتے رہے ان کے لئے بڑا ثواب ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiii{اور تم کیسے لوگ ہو کہ خدا پر ایمان نہیں لاتے۔ حالانکہ (اس کے) پیغمبر تمہیں بلا رہے ہیں کہ اپنے پروردگار پر ایمان لاؤ اور اگر تم کو باور ہو تو وہ تم سے (اس کا) عہد بھی لے چکا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxiv{وہی تو ہے جو اپنے بندے پر واضح (المطالب) آیتیں نازل کرتا ہے تاکہ تم کو اندھیروں میں سے نکال کر روشنی میں لائے۔ بےشک خدا تم پر نہایت شفقت کرنے والا (اور) مہربان ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxv{اور تم کو کیا ہوا ہے کہ خدا کے رستے میں خرچ نہیں کرتے حالانکہ آسمانوں اور زمین کی وراثت خدا ہی کی ہے۔ جس شخص نے تم میں سے فتح (مکہ) سے پہلے خرچ کیا اور لڑائی کی وہ (اور جس نے یہ کام پیچھے کئے وہ) برابر نہیں۔ ان کا درجہ ان لوگوں سے کہیں بڑھ کر ہے جنہوں نے بعد میں خرچ (اموال) اور (کفار سے) جہاد وقتال کیا۔ اور خدا نے سب سے (ثواب) نیک (کا) وعدہ تو کیا ہے۔ اور جو کام تم کرتے ہو خدا ان سے واقف ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvi{کون ہے جو خدا کو (نیت) نیک (اور خلوص سے) قرض دے تو وہ اس کو اس سے دگنا کرے اور اس کے لئے عزت کا صلہ (یعنی جنت) ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxvii{جس دن تم مومن مردوں اور مومن عورتوں کو دیکھو گے کہ ان (کے ایمان) کا نور ان کے آگے آگے اور داہنی طرف چل رہا ہے (تو ان سے کہا جائے گا کہ) تم کو بشارت ہو (کہ آج تمہارے لئے) باغ ہیں جن کے تلے نہریں بہہ رہی ہیں ان میں ہمیشہ رہو گے۔ یہی بڑی کامیابی ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxviii{اُس دن منافق مرد اور منافق عورتیں مومنوں سے کہیں گے کہ ہماری طرف سے (شفقت) کیجیئے کہ ہم بھی تمہارے نور سے روشنی حاصل کریں۔ تو ان سے کہا جائے گا کہ پیچھے کو لوٹ جاؤ اور (وہاں) نور تلاش کرو۔ پھر ان کے بیچ میں ایک دیوار کھڑی کر دی جائے گی۔ جس میں ایک دروازہ ہوگا جو اس کی جانب اندرونی ہے اس میں تو رحمت ہے اور جو جانب بیرونی ہے اس طرف عذاب (واذیت)\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmlxxxix{تو منافق لوگ مومنوں سے کہیں گے کہ کیا ہم (دنیا میں) تمہارے ساتھ نہ تھے وہ کہیں گے کیوں نہیں تھے۔ لیکن تم نے خود اپنے تئیں بلا میں ڈالا اور (ہمارے حق میں حوادث کے) منتظر رہے اور (اسلام میں) شک کیا اور (لاطائل) آرزوؤں نے تم کو دھوکہ دیا یہاں تک کہ خدا کا حکم آ پہنچا اور خدا کے بارے میں تم کو (شیطان) دغاباز دغا دیتا رہا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmxc{تو آج تم سے معاوضہ نہیں لیا جائے گا اور نہ (وہ) کافروں ہی سے (قبول کیا جائے گا) تم سب کا ٹھکانا دوزخ ہے۔ (کہ) وہی تمہارے لائق ہے اور وہ بری جگہ ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmxci{کیا ابھی تک مومنوں کے لئے اس کا وقت نہیں آیا کہ خدا کی یاد کرنے کے وقت اور (قرآن) جو (خدائے) برحق (کی طرف) سے نازل ہوا ہے اس کے سننے کے وقت ان کے دل نرم ہوجائیں اور وہ ان لوگوں کی طرف نہ ہوجائیں جن کو (ان سے) پہلے کتابیں دی گئی تھیں۔ پھر ان پر زمان طویل گزر گیا تو ان کے دل سخت ہوگئے۔ اور ان میں سے اکثر نافرمان ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmxcii{جان رکھو کہ خدا ہی زمین کو اس کے مرنے کے بعد زندہ کرتا ہے۔ ہم نے اپنی نشانیاں تم سے کھول کھول کر بیان کردی ہیں تاکہ تم سمجھو\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmxciii{جو لوگ خیرات کرنے والے ہیں مرد بھی اور عورتیں بھی۔ اور خدا کو (نیت) نیک (اور خلوص سے) قرض دیتے ہیں ان کو دوچند ادا کیا جائے گا اور ان کے لئے عزت کا صلہ ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmxciv{اور جو لوگ خدا اور اس کے پیغمبروں پر ایمان لائے یہی اپنے پروردگار کے نزدیک صدیق اور شہید ہیں۔ ان کے لئے ان (کے اعمال) کا صلہ ہوگا۔ اور ان (کے ایمان) کی روشنی۔ اور جن لوگوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا وہی اہل دوزخ ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmxcv{جان رکھو کہ دنیا کی زندگی محض کھیل اور تماشا اور زینت (وآرائش) اور تمہارے آپس میں فخر (وستائش) اور مال واولاد کی ایک دوسرے سے زیادہ طلب (وخواہش) ہے (اس کی مثال ایسی ہے) جیسے بارش کہ (اس سے کھیتی اُگتی اور) کسانوں کو کھیتی بھلی لگتی ہے پھر وہ خوب زور پر آتی ہے پھر (اے دیکھنے والے) تو اس کو دیکھتا ہے کہ (پک کر) زرد پڑ جاتی ہے پھر چورا چورا ہوجاتی ہے اور آخرت میں (کافروں کے لئے) عذاب شدید اور (مومنوں کے لئے) خدا کی طرف سے بخشش اور خوشنودی ہے۔ اور دنیا کی زندگی تو متاع فریب ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvi{بندو) اپنے پروردگار کی بخشش کی طرف اور جنت کی (طرف) جس کا عرض آسمان اور زمین کے عرض کا سا ہے۔ اور جو ان لوگوں کے لئے تیار کی گئی ہے جو خدا پر اور اس کے پیغمبروں پر ایمان لائے ہیں لپکو۔ یہ خدا کا فضل ہے جسے چاہے عطا فرمائے۔ اور خدا بڑے فضل کا مالک ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmxcvii{کوئی مصیبت ملک پر اور خود تم پر نہیں پڑتی مگر پیشتر اس کے کہ ہم اس کو پیدا کریں ایک کتاب میں (لکھی ہوئی) ہے۔ (اور) یہ (کام) خدا کو آسان ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmxcviii{تاکہ جو (مطلب) تم سے فوت ہوگیا ہو اس کا غم نہ کھایا کرو اور جو تم کو اس نے دیا ہو اس پر اترایا نہ کرو۔ اور خدا کسی اترانے اور شیخی بگھارنے والے کو دوست نہیں رکھتا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmxcix{جو خود بھی بخل کریں اور لوگوں کو بھی بخل سکھائیں اور جو شخص روگردانی کرے تو خدا بھی بےپروا (اور) وہی سزاوار حمد (وثنا) ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmc{ہم نے اپنے پیغمبروں کو کھلی نشانیاں دے کر بھیجا۔ اور اُن پر کتابیں نازل کیں اور ترازو (یعنی قواعد عدل) تاکہ لوگ انصاف پر قائم رہیں۔ اور لوہا پیدا کیا اس میں (اسلحہٴ جنگ کے لحاظ سے) خطرہ بھی شدید ہے۔ اور لوگوں کے لئے فائدے بھی ہیں اور اس لئے کہ جو لوگ بن دیکھے خدا اور اس کے پیغمبروں کی مدد کرتے ہیں خدا ان کو معلوم کرے۔ بےشک خدا قوی (اور) غالب ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmci{اور ہم نے نوح اور ابراہیم کو (پیغمبر بنا کر) بھیجا اور ان کی اولاد میں پیغمبری اور کتاب (کے سلسلے) کو (وقتاً فوقتاً جاری) رکھا تو بعض تو ان میں سے ہدایت پر ہیں۔ اور اکثر ان میں سے خارج از اطاعت ہیں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcii{پھر ان کے پیچھے انہی کے قدموں پر (اور) پیغمبر بھیجے اور ان کے پیچھے مریمؑ کے بیٹے عیسیٰ کو بھیجا اور ان کو انجیل عنایت کی۔ اور جن لوگوں نے ان کی پیروی کی ان کے دلوں میں شفقت اور مہربانی ڈال دی۔ اور لذات سے کنارہ کشی کی تو انہوں نے خود ایک نئی بات نکال لی ہم نے ان کو اس کا حکم نہیں دیا تھا مگر (انہوں نے اپنے خیال میں) خدا کی خوشنودی حاصل کرنے کے لئے (آپ ہی ایسا کرلیا تھا) پھر جیسا اس کو نباہنا چاہیئے تھا نباہ بھی نہ سکے۔ پس جو لوگ ان میں سے ایمان لائے ان کو ہم نے ان کا اجر دیا اور ان میں بہت سے نافرمان ہیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmciii{مومنو! خدا سے ڈرو اور اس کے پیغمبر پر ایمان لاؤ وہ تمہیں اپنی رحمت سے دگنا اجر عطا فرمائے گا اور تمہارے لئے روشنی کردے گا جس میں چلو گے اور تم کو بخش دے گا۔ اور خدا بخشنے والا مہربان ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmciv{یہ باتیں) اس لئے (بیان کی گئی ہیں) کہ اہل کتاب جان لیں کہ وہ خدا کے فضل پر کچھ بھی قدرت نہیں رکھتے۔ اور یہ کہ فضل خدا ہی کے ہاتھ ہے جس کو چاہتا ہے دیتا ہے اور خدا بڑے فضل کا مالک ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmcv{\basmalahur (اے پیغمبر) جو عورت تم سے اپنے شوہر کے بارے میں بحث جدال کرتی اور خدا سے شکایت (رنج وملال) کرتی تھی۔ خدا نے اس کی التجا سن لی اور خدا تم دونوں کی گفتگو سن رہا تھا۔ کچھ شک نہیں کہ خدا سنتا دیکھتا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcvi{جو لوگ تم میں سے اپنی عورتوں کو ماں کہہ دیتے ہیں وہ ان کی مائیں نہیں (ہوجاتیں) ۔ ان کی مائیں تو وہی ہیں جن کے بطن سے وہ پیدا ہوئے۔ بےشک وہ نامعقول اور جھوٹی بات کہتے ہیں اور خدا بڑا معاف کرنے والا (اور) بخشنے والا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcvii{اور جو لوگ اپنی بیویوں کو ماں کہہ بیٹھیں پھر اپنے قول سے رجوع کرلیں تو (ان کو) ہم بستر ہونے سے پہلے ایک غلام آزاد کرنا (ضروری) ہے۔ (مومنو) اس (حکم) سے تم کو نصیحت کی جاتی ہے۔ اور جو کچھ تم کرتے ہو خدا اس سے خبردار ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcviii{جس کو غلام نہ ملے وہ مجامعت سے پہلے متواتر دو مہینے کے روزے (رکھے) جس کو اس کا بھی مقدور نہ ہوا (اسے) ساٹھ مسکینوں کو کھانا کھلانا (چاہیئے) ۔ یہ (حکم) اس لئے (ہے) کہ تم خدا اور اسکے رسول کے فرمانبردار ہوجاؤ۔ اور یہ خدا کی حدیں ہیں۔ اور نہ ماننے والوں کے لئے درد دینے والا عذاب ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcix{جو لوگ خدا اور اس کے رسول کی مخالفت کرتے ہیں وہ (اسی طرح) ذلیل کئے جائیں گے جس طرح ان سے پہلے لوگ ذلیل کئے گئے تھے اور ہم نے صاف اور صریح آیتیں نازل کردی ہیں۔ جو نہیں مانتے ان کو ذلت کا عذاب ہوگا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcx{جس دن خدا ان سب کو جلا اٹھائے گا تو جو کام وہ کرتے رہے ان کو جتائے گا۔ خدا کو وہ سب (کام) یاد ہیں اور یہ ان کو بھول گئے ہیں اور خدا ہر چیز سے واقف ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcxi{کیا تم کو معلوم نہیں کہ جو کچھ آسمانوں میں ہے اور جو کچھ زمین میں ہے خدا کو سب معلوم ہے۔ (کسی جگہ) تین (شخصوں) کا (مجمع اور) کانوں میں صلاح ومشورہ نہیں ہوتا مگر وہ ان میں چوتھا ہوتا ہے اور نہ کہیں پانچ کا مگر وہ ان میں چھٹا ہوتا ہے اور نہ اس سے کم یا زیادہ مگر وہ ان کے ساتھ ہوتا ہے خواہ وہ کہیں ہوں۔ پھر جو جو کام یہ کرتے رہے ہیں قیامت کے دن وہ (ایک ایک) ان کو بتائے گا۔ بےشک خدا ہر چیز سے واقف ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcxii{کیا تم نے ان لوگوں کو نہیں دیکھا جن کو سرگوشیاں کرنے سے منع کیا گیا تھا۔ پھر جس (کام) سے منع کیا گیا تھا وہی پھر کرنے لگے اور یہ تو گناہ اور ظلم اور رسول (خدا) کی نافرمانی کی سرگوشیاں کرتے ہیں۔ اور جب تمہارے پاس آتے ہیں تو جس (کلمے) سے خدا نے تم کو دعا نہیں دی اس سے تمہیں دعا دیتے ہیں۔ اور اپنے دل میں کہتے ہیں کہ (اگر یہ واقعی پیغمبر ہیں تو) جو کچھ ہم کہتے ہیں خدا ہمیں اس کی سزا کیوں نہیں دیتا؟ (اے پیغمبر) ان کو دوزخ (ہی کی سزا) کافی ہے۔ یہ اسی میں داخل ہوں گے۔ اور وہ بری جگہ ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiii{مومنو! جب تم آپس میں سرگوشیاں کرنے لگو تو گناہ اور زیادتی اور پیغمبر کی نافرمانی کی باتیں نہ کرنا بلکہ نیکوکاری اور پرہیزگاری کی باتیں کرنا۔ اور خدا سے جس کے سامنے جمع کئے جاؤ گے ڈرتے رہنا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcxiv{کافروں کی) سرگوشیاں تو شیطان (کی حرکات) سے ہیں (جو) اس لئے (کی جاتی ہیں) کہ مومن (ان سے) غمناک ہوں مگر خدا کے حکم کے سوا ان سے انہیں کچھ نقصان نہیں پہنچ سکتا۔ تو مومنو کو چاہیئے کہ خدا ہی پر بھروسہ رکھیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcxv{مومنو! جب تم سے کہا جائے کہ مجلس میں کھل کر بیٹھو تو کھل بیٹھا کرو۔ خدا تم کو کشادگی بخشے گا۔ اور جب کہا جائے کہ اُٹھ کھڑے ہو تو اُٹھ کھڑے ہوا کرو۔ جو لوگ تم میں سے ایمان لائے ہیں اور جن کو علم عطا کیا گیا ہے خدا ان کے درجے بلند کرے گا۔ اور خدا تمہارے سب کاموں سے واقف ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvi{مومنو! جب تم پیغمبر کے کان میں کوئی بات کہو تو بات کہنے سے پہلے (مساکین کو) کچھ خیرات دے دیا کرو۔ یہ تمہارے لئے بہت بہتر اور پاکیزگی کی بات ہے۔ اور اگر خیرات تم کو میسر نہ آئے تو خدا بخشنے والا مہربان ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcxvii{کیا تم اس سےکہ پیغمبر کے کان میں کوئی بات کہنے سے پہلے خیرات دیا کرو ڈر گئے؟ پھر جب تم نے (ایسا) نہ کیا اور خدا نے تمہیں معاف کردیا تو نماز پڑھتے اور زکوٰة دیتے رہو اور خدا اور اس کے رسول کی فرمانبرداری کرتے رہو۔ اور جو کچھ تم کرتے ہو خدا اس سے خبردار ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcxviii{بھلا تم نے ان لوگوں کو نہیں دیکھا جو ایسوں سے دوستی کرتے ہیں جن پر خدا کا غضب ہوا۔ وہ نہ تم میں ہیں نہ ان میں۔ اور جان بوجھ کر جھوٹی باتوں پر قسمیں کھاتے ہیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcxix{خدا نے ان کے لئے سخت عذاب تیار کر رکھا ہے۔ یہ جو کچھ کرتے ہیں یقیناً برا ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcxx{انہوں نے اپنی قسموں کو ڈھال بنا لیا اور (لوگوں کو) خدا کے راستے سے روک دیا ہے سو ان کے لئے ذلت کا عذاب ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxi{خدا کے (عذاب کے) سامنے نہ تو ان کا مال ہی کچھ کام آئے گا اور نہ اولاد ہی (کچھ فائدہ دے گی) ۔ یہ لوگ اہل دوزخ ہیں اس میں ہمیشہ (جلتے) رہیں گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxii{جس دن خدا ان سب کو جلا اٹھائے گا تو جس طرح تمہارے سامنے قسمیں کھاتے (اسی طرح) خدا کے سامنے قسمیں کھائیں گے اور خیال کریں گے کہ (ایسا کرنے سے) کام لے نکلے ہیں۔ دیکھو یہ جھوٹے (اور برسر غلط) ہیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiii{شیطان نے ان کو قابو میں کرلیا ہے۔ اور خدا کی یاد ان کو بھلا دی ہے۔ یہ (جماعت) شیطان کا لشکر ہے۔ اور سن رکھو کہ شیطان کا لشکر نقصان اٹھانے والا ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxiv{جو لوگ خدا اور اس کے رسول کی مخالفت کرتے ہیں وہ نہایت ذلیل ہوں گے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxv{خدا کا حکم ناطق ہے کہ میں اور میرے پیغمبر ضرور غالب رہیں گے۔ بےشک خدا زورآور (اور) زبردست ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvi{جو لوگ خدا پر اور روز قیامت پر ایمان رکھتے ہیں تم ان کو خدا اور اس کے رسول کے دشمنوں سے دوستی کرتے ہوئے نہ دیکھو گے۔ خواہ وہ ان کے باپ یا بیٹے یا بھائی یا خاندان ہی کے لوگ ہوں۔ یہ وہ لوگ ہیں جن کے دلوں میں خدا نے ایمان (پتھر پر لکیر کی طرح) تحریر کردیا ہے اور فیض غیبی سے ان کی مدد کی ہے۔ اور وہ ان کو بہشتوں میں جن کے تلے نہریں بہہ رہی ہیں داخل کرے گا ہمیشہ ان میں رہیں گے۔ خدا ان سے خوش اور وہ خدا سے خوش۔ یہی گروہ خدا کا لشکر ہے۔ (اور) سن رکھو کہ خدا ہی کا لشکر مراد حاصل کرنے والا ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxvii{\basmalahur جو چیزیں آسمانوں میں ہیں اور جو چیزیں زمین میں ہیں (سب) خدا کی تسبیح کرتی ہیں۔ اور وہ غالب حکمت والا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxviii{وہی تو ہے جس نے کفار اہل کتاب کو حشر اول کے وقت ان کے گھروں سے نکال دیا۔ تمہارے خیال میں بھی نہ تھا کہ وہ نکل جائیں گے اور وہ لوگ یہ سمجھے ہوئے تھے کہ ان کے قلعے ان کو خدا (کے عذاب) سے بچا لیں گے۔ مگر خدا نے ان کو وہاں سے آ لیا جہاں سے ان کو گمان بھی نہ تھا۔ اور ان کے دلوں میں دہشت ڈال دی کہ اپنے گھروں کو خود اپنے ہاتھوں اور مومنوں کے ہاتھوں سے اُجاڑنے لگے تو اے (بصیرت کی) آنکھیں رکھنے والو عبرت پکڑو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxix{اور اگر خدا نے ان کے بارے میں جلاوطن کرنا نہ لکھ رکھا ہوتا تو ان کو دنیا میں بھی عذاب دے دیتا۔ اور آخرت میں تو ان کے لئے آگ کا عذاب (تیار) ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxx{یہ اس لئے کہ انہوں نے خدا اور اس کے رسول کی مخالفت کی۔ اور جو شخص خدا کی مخالفت کرے تو خدا سخت عذاب دینے والا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxi{مومنو) کھجور کے جو درخت تم نے کاٹ ڈالے یا ان کو اپنی جڑوں پر کھڑا رہنے دیا سو خدا کے حکم سے تھا اور مقصود یہ تھا کہ وہ نافرمانوں کو رسوا کرے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxii{اور جو (مال) خدا نے اپنے پیغمبر کو ان لوگوں سے (بغیر لڑائی بھڑائی کے) دلوایا ہے اس میں تمہارا کچھ حق نہیں کیونکہ اس کے لئے نہ تم نے گھوڑے دوڑائے نہ اونٹ لیکن خدا اپنے پیغمبروں کو جن پر چاہتا ہے مسلط کردیتا ہے۔ اور خدا ہر چیز پر قادر ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiii{جو مال خدا نے اپنے پیغمبر کو دیہات والوں سے دلوایا ہے وہ خدا کے اور پیغمبر کے اور (پیغمبر کے) قرابت والوں کے اور یتیموں کے اور حاجتمندوں کے اور مسافروں کے لئے ہے۔ تاکہ جو لوگ تم میں دولت مند ہیں ان ہی کے ہاتھوں میں نہ پھرتا رہے۔ سو جو چیز تم کو پیغمبر دیں وہ لے لو۔ اور جس سے منع کریں (اس سے) باز رہو۔ اور خدا سے ڈرتے رہو۔ بےشک خدا سخت عذاب دینے والا ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxiv{اور) ان مفلسان تارک الوطن کے لئے بھی جو اپنے گھروں اور مالوں سے خارج (اور جدا) کر دیئے گئے ہیں (اور) خدا کے فضل اور اس کی خوشنودی کے طلبگار اور خدا اور اس کے پیغمبر کے مددگار ہیں۔ یہی لوگ سچے (ایماندار) ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxv{اور (ان لوگوں کے لئے بھی) جو مہاجرین سے پہلے (ہجرت کے) گھر (یعنی مدینے) میں مقیم اور ایمان میں (مستقل) رہے (اور) جو لوگ ہجرت کرکے ان کے پاس آتے ہیں ان سے محبت کرتے ہیں اور جو کچھ ان کو ملا اس سے اپنے دل میں کچھ خواہش (اور خلش) نہیں پاتے اور ان کو اپنی جانوں سے مقدم رکھتے ہیں خواہ ان کو خود احتیاج ہی ہو۔ اور جو شخص حرص نفس سے بچا لیا گیا تو ایسے لوگ مراد پانے والے ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvi{اور (ان کے لئے بھی) جو ان (مہاجرین) کے بعد آئے (اور) دعا کرتے ہیں کہ اے پروردگار ہمارے اور ہمارے بھائیوں کے جو ہم سے پہلے ایمان لائے ہیں گناہ معاف فرما اور مومنوں کی طرف سے ہمارے دل میں کینہ (وحسد) نہ پیدا ہونے دے۔ اے ہمارے پروردگار تو بڑا شفقت کرنے والا مہربان ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxvii{کیا تم نے ان منافقوں کو نہیں دیکھا جو اپنے کافر بھائیوں سے جو اہل کتاب ہیں کہا کرتے ہیں کہ اگر تم جلا وطن کئے گئے تو ہم بھی تمہارے ساتھ نکل چلیں گے اور تمہارے بارے میں کبھی کسی کا کہا نہ مانیں گے۔ اور اگر تم سے جنگ ہوئی تو تمہاری مدد کریں گے۔ مگر خدا ظاہر کئے دیتا ہے کہ یہ جھوٹے ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxviii{اگر وہ نکالے گئے تو یہ ان کے ساتھ نہیں نکلیں گے۔ اور اگر ان سے جنگ ہوئی تو ان کی مدد نہیں کریں گے۔ اگر مدد کریں گے تو پیٹھ پھیر کر بھاگ جائیں گے۔ پھر ان کو (کہیں سے بھی) مدد نہ ملے گی\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcxxxix{مسلمانو!) تمہاری ہیبت ان لوگوں کے دلوں میں خدا سے بھی بڑھ کر ہے۔ یہ اس لئے کہ یہ سمجھ نہیں رکھتے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcxl{یہ سب جمع ہو کر بھی تم سے (بالمواجہہ) نہیں لڑ سکیں گے مگر بستیوں کے قلعوں میں (پناہ لے کر) یا دیواروں کی اوٹ میں (مستور ہو کر) ان کا آپس میں بڑا رعب ہے۔ تم شاید خیال کرتے ہو کہ یہ اکھٹے (اور ایک جان) ہیں مگر ان کے دل پھٹے ہوئے ہیں یہ اس لئے کہ یہ بےعقل لوگ ہیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcxli{ان کا حال ان لوگوں کا سا ہے جو ان سے کچھ ہی پیشتر اپنے کاموں کی سزا کا مزہ چکھ چکے ہیں۔ اور (ابھی) ان کے لئے دکھ دینے والا عذاب (تیار) ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlii{منافقوں کی) مثال شیطان کی سی ہے کہ انسان سے کہتا رہا کہ کافر ہوجا۔ جب وہ کافر ہوگیا تو کہنے لگا کہ مجھے تجھ سے کچھ سروکار نہیں۔ مجھ کو خدائے رب العالمین سے ڈر لگتا ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliii{تو دونوں کا انجام یہ ہوا کہ دونوں دوزخ میں (داخل ہوئے) ہمیشہ اس میں رہیں گے۔ اور بےانصافوں کی یہی سزا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcxliv{اے ایمان والوں! خدا سے ڈرتے رہو اور ہر شخص کو دیکھنا چاہیئے کہ اس نے کل (یعنی فردائے قیامت) کے لئے کیا (سامان) بھیجا ہے اور (ہم پھر کہتے ہیں کہ) خدا سے ڈرتے رہو بےشک خدا تمہارے سب اعمال سے خبردار ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlv{اور ان لوگوں جیسے نہ ہونا جنہوں نے خدا کو بھلا دیا تو خدا نے انہیں ایسا کردیا کہ خود اپنے تئیں بھول گئے۔ یہ بدکردار لوگ ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvi{اہل دوزخ اور اہل بہشت برابر نہیں۔ اہل بہشت تو کامیابی حاصل کرنے والے ہیں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlvii{اگر ہم یہ قرآن کسی پہاڑ پر نازل کرتے تو تم اس کو دیکھتے کہ خدا کے خوف سے دبا اور پھٹا جاتا ہے۔ اور یہ باتیں ہم لوگوں کے لئے بیان کرتے ہیں تاکہ وہ فکر کریں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlviii{وہی خدا ہے جس کے سوا کوئی معبود نہیں۔ پوشیدہ اور ظاہر کا جاننے والا ہے وہ بڑا مہربان نہایت رحم والا ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcxlix{وہی خدا ہے جس کے سوا کوئی عبادت کے لائق نہیں۔ بادشاہ (حقیقی) پاک ذات (ہر عیب سے) سلامتی امن دینے والا نگہبان غالب زبردست بڑائی والا۔ خدا ان لوگوں کے شریک مقرر کرنے سے پاک ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcl{وہی خدا (تمام مخلوقات کا) خالق۔ ایجاد واختراع کرنے والا صورتیں بنانے والا اس کے سب اچھے سے اچھے نام ہیں۔ جتنی چیزیں آسمانوں اور زمین میں ہیں سب اس کی تسبیح کرتی ہیں اور وہ غالب حکمت والا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcli{\basmalahur مومنو! اگر تم میری راہ میں لڑنے اور میری خوشنودی طلب کرنے کے لئے (مکے سے) نکلے ہو تو میرے اور اپنے دشمنوں کو دوست نہ بناؤ۔ تم تو ان کو دوستی کے پیغام بھیجتے ہو اور وہ (دین) حق سے جو تمہارے پاس آیا ہے منکر ہیں۔ اور اس باعث سے کہ تم اپنے پروردگار خدا تعالیٰ پر ایمان لائے ہو پیغمبر کو اور تم کو جلاوطن کرتے ہیں۔ تم ان کی طرف پوشیدہ پوشیدہ دوستی کے پیغام بھیجتے ہو۔ اور جو کچھ تم مخفی طور پر اور جو علیٰ الاعلان کرتے ہو وہ مجھے معلوم ہے۔ اور جو کوئی تم میں سے ایسا کرے گا وہ سیدھے راستے سے بھٹک گیا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmclii{اگر یہ کافر تم پر قدرت پالیں تو تمہارے دشمن ہوجائیں اور ایذا کے لئے تم پر ہاتھ (بھی) چلائیں اور زبانیں (بھی) اور چاہتے ہیں کہ تم کسی طرح کافر ہوجاؤ\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcliii{قیامت کے دن نہ تمہارے رشتے ناتے کام آئیں گے اور نہ اولاد۔ اس روز وہی تم میں فیصلہ کرے گا۔ اور جو کچھ تم کرتے ہو خدا اس کو دیکھتا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcliv{تمہیں ابراہیم اور ان کے رفقاء کی نیک چال چلنی (ضرور) ہے۔ جب انہوں نے اپنی قوم کے لوگوں سے کہا کہ ہم تم سے اور ان (بتوں) سے جن کو تم خدا کے سوا پوجتے ہو بےتعلق ہیں (اور) تمہارے (معبودوں کے کبھی) قائل نہیں (ہوسکتے) اور جب تک تم خدائے واحد اور ایمان نہ لاؤ ہم میں تم میں ہمیشہ کھلم کھلا عداوت اور دشمنی رہے گی۔ ہاں ابراہیمؑ نے اپنے باپ سے یہ (ضرور) کہا کہ میں آپ کے لئے مغفرت مانگوں گا اور خدا کے سامنے آپ کے بارے میں کسی چیز کا کچھ اختیار نہیں رکھتا۔ اے ہمارے پروردگار تجھ ہی پر ہمارا بھروسہ ہے اور تیری ہی طرف ہم رجوع کرتے ہیں اور تیرے ہی حضور میں (ہمیں) لوٹ کر آنا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmclv{اے ہمارے پروردگار ہم کو کافروں کے ہاتھ سے عذاب نہ دلانا اور اے پروردگار ہمارے ہمیں معاف فرما۔ بےشک تو غالب حکمت والا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmclvi{تم (مسلمانوں) کو یعنی جو کوئی خدا (کے سامنے جانے) اور روز آخرت (کے آنے) کی امید رکھتا ہو اسے ان لوگوں کی نیک چال چلنی (ضرور) ہے۔ اور روگردانی کرے تو خدا بھی بےپرواہ اور سزاوار حمد (وثنا) ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmclvii{عجب نہیں کہ خدا تم میں اور ان لوگوں میں جن سے تم دشمنی رکھتے ہو دوستی پیدا کردے۔ اور خدا قادر ہے اور خدا بخشنے والا مہربان ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmclviii{جن لوگوں نے تم سے دین کے بارے میں جنگ نہیں کی اور نہ تم کو تمہارے گھروں سے نکالا ان کے ساتھ بھلائی اور انصاف کا سلوک کرنے سے خدا تم کو منع نہیں کرتا۔ خدا تو انصاف کرنے والوں کو دوست رکھتا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmclix{خدا ان ہی لوگوں کے ساتھ تم کو دوستی کرنے سے منع کرتا ہے جنہوں نے تم سے دین کے بارے میں لڑائی کی اور تم کو تمہارے گھروں سے نکالا اور تمہارے نکالنے میں اوروں کی مدد کی۔ تو جو لوگ ایسوں سے دوستی کریں گے وہی ظالم ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmclx{مومنو! جب تمہارے پاس مومن عورتیں وطن چھوڑ کر آئیں تو ان کی آزمائش کرلو۔ (اور) خدا تو ان کے ایمان کو خوب جانتا ہے۔ سو اگر تم کو معلوم ہو کہ مومن ہیں تو ان کو کفار کے پاس واپس نہ بھیجو۔ کہ نہ یہ ان کو حلال ہیں اور نہ وہ ان کو جائز۔ اور جو کچھ انہوں نے (ان پر) خرچ کیا ہو وہ ان کو دے دو۔ اور تم پر کچھ گناہ نہیں کہ ان عورتوں کو مہر دے کر ان سے نکاح کرلو اور کافر عورتوں کی ناموس کو قبضے میں نہ رکھو (یعنی کفار کو واپس دے دو) اور جو کچھ تم نے ان پر خرچ کیا ہو تم ان سے طلب کرلو اور جو کچھ انہوں نے (اپنی عورتوں پر) خرچ کیا ہو وہ تم سے طلب کرلیں۔ یہ خدا کا حکم ہے جو تم میں فیصلہ کئے دیتا ہے اور خدا جاننے والا حکمت والا ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmclxi{اور اگر تمہاری عورتوں میں سے کوئی عورت تمہارے ہاتھ سے نکل کر کافروں کے پاس چلی جائے (اور اس کا مہر وصول نہ ہوا ہو) پھر تم ان سے جنگ کرو (اور ان سے تم کو غنیمت ہاتھ لگے) تو جن کی عورتیں چلی گئی ہیں ان کو (اس مال میں سے) اتنا دے دو جتنا انہوں نے خرچ کیا تھا اور خدا سے جس پر تم ایمان لائے ہو ڈرو\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmclxii{اے پیغمبر! جب تمہارے پاس مومن عورتیں اس بات پر بیعت کرنے کو آئیں کہ خدا کے ساتھ نہ شرک کریں گی نہ چوری کریں گی نہ بدکاری کریں گی نہ اپنی اولاد کو قتل کریں گی نہ اپنے ہاتھ پاؤں میں کوئی بہتان باندھ لائیں گی اور نہ نیک کاموں میں تمہاری نافرمانی کریں گی تو ان سے بیعت لے لو اور ان کے لئے خدا سے بخشش مانگو۔ بےشک خدا بخشنے والا مہربان ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiii{مومنو! ان لوگوں سے جن پر خدا غصے ہوا ہے دوستی نہ کرو (کیونکہ) جس طرح کافروں کو مردوں (کے جی اُٹھنے) کی امید نہیں اسی طرح ان لوگوں کو بھی آخرت (کے آنے) کی امید نہیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmclxiv{\basmalahur جو چیز آسمانوں میں ہے اور زمین میں ہے سب خدا کی تنزیہ کرتی ہے اور وہ غالب حکمت والا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmclxv{مومنو! تم ایسی باتیں کیوں کہا کرتے ہو جو کیا نہیں کرتے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvi{خدا اس بات سے سخت بیزار ہے کہ ایسی بات کہو جو کرو نہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmclxvii{جو لوگ خدا کی راہ میں (ایسے طور پر) پرے جما کر لڑتے کہ گویا سیسہ پلائی دیوار ہیں وہ بےشک محبوب کردگار ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmclxviii{اور وہ وقت یاد کرنے کے لائق ہے جب موسیٰ نے اپنی قوم سے کہا کہ اے قوم! تم مجھے کیوں ایذا دیتے ہو حالانکہ تم جانتے ہو کہ میں تمہارے پاس خدا کا بھیجا ہوا آیا ہوں۔ تو جب ان لوگوں نے کج روی کی خدا نے بھی ان کے دل ٹیڑھے کردیئے۔ اور خدا نافرمانوں کو ہدایت نہیں دیتا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmclxix{اور (وہ وقت بھی یاد کرو) جب مریمؑ کے بیٹے عیسیٰ نے کہا کے اے بنی اسرائیل میں تمہارے پاس خدا کا بھیجا ہوا آیا ہوں (اور) جو (کتاب) مجھ سے پہلے آچکی ہے (یعنی) تورات اس کی تصدیق کرتا ہوں اور ایک پیغمبر جو میرے بعد آئیں گے جن کا نام احمدﷺ ہوگا ان کی بشارت سناتا ہوں۔ (پھر) جب وہ ان لوگوں کے پاس کھلی نشانیاں لے کر آئے تو کہنے لگے کہ یہ تو صریح جادو ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmclxx{اور اس سے ظالم کون کہ بلایا تو جائے اسلام کی طرف اور وہ خدا پر جھوٹ بہتان باندھے۔ اور خدا ظالم لوگوں کو ہدایت نہیں دیا کرتا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxi{یہ چاہتے ہیں کہ خدا کے (چراغ) کی روشنی کو منہ سے (پھونک مار کر) بجھا دیں۔ حالانکہ خدا اپنی روشنی کو پورا کرکے رہے گا خواہ کافر ناخوش ہی ہوں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxii{وہی تو ہے جس نے اپنے پیغمبر کو ہدایت اور دین حق دے کر بھیجا تاکہ اسے اور سب دینوں پر غالب کرے خواہ مشرکوں کو برا ہی لگے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiii{مومنو! میں تم کو ایسی تجارت بتاؤں جو تمہیں عذاب الیم سے مخلصی دے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxiv{وہ یہ کہ) خدا پر اور اس کے رسولﷺ پر ایمان لاؤ اور خدا کی راہ میں اپنے مال اور جان سے جہاد کرو۔ اگر سمجھو تو یہ تمہارے حق میں بہتر ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxv{وہ تمہارے گناہ بخش دے گا اور تم کو باغہائے جنت میں جن میں نہریں بہہ رہیں ہیں اور پاکیزہ مکانات میں جو بہشت ہائے جاودانی میں (تیار) ہیں داخل کرے گا۔ یہ بڑی کامیابی ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvi{اور ایک اور چیز جس کو تم بہت چاہتے ہو (یعنی تمہیں) خدا کی طرف سے مدد (نصیب ہوگی) اور فتح عنقریب ہوگی اور مومنوں کو (اس کی) خوشخبری سنا دو\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxvii{مومنو! خدا کے مددگار بن جاؤ جیسے عیسیٰ ابن مریم نے حواریوں سے کہا کہ بھلا کون ہیں جو خدا کی طرف (بلانے میں) میرے مددگار ہوں۔ حواریوں نے کہا کہ ہم خدا کے مددگار ہیں۔ تو بنی اسرائیل میں سے ایک گروہ تو ایمان لے آیا اور ایک گروہ کافر رہا۔ آخر الامر ہم نے ایمان لانے والوں کو ان کے دشمنوں کے مقابلے میں مدد دی اور وہ غالب ہوگئے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxviii{\basmalahur جو چیز آسمانوں میں ہے اور جو چیز زمین میں ہے سب خدا کی تسبیح کرتی ہے جو بادشاہ حقیقی پاک ذات زبردست حکمت والا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxix{وہی تو ہے جس نے ان پڑھوں میں ان ہی میں سے (محمدﷺ) کو پیغمبر (بنا کر) بھیجا جو ان کے سامنے اس کی آیتیں پڑھتے اور ان کو پاک کرتے اور (خدا کی) کتاب اور دانائی سکھاتے ہیں۔ اور اس ے پہلے تو یہ لوگ صریح گمراہی میں تھے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxx{اور ان میں سے اور لوگوں کی طرف بھی (ان کو بھیجا ہے) جو ابھی ان (مسلمانوں سے) نہیں ملے۔ اور وہ غالب حکمت والا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxi{یہ خدا کا فضل ہے جسے چاہتا ہے عطا کرتا ہے۔ اور خدا بڑے فضل کا مالک ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxii{جن لوگوں (کے سر) پر تورات لدوائی گئی پھر انہوں نے اس (کے بار تعمیل) کو نہ اٹھایا ان کی مثال گدھے کی سی ہے جن پر بڑی بڑی کتابیں لدی ہوں۔ جو لوگ خدا کی آیتوں کی تکذیب کرتے ہیں ان کی مثال بری ہے۔ اور خدا ظالم لوگوں کو ہدایت نہیں دیتا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiii{کہہ دو کہ اے یہود اگر تم کو دعویٰ ہو کہ تم ہی خدا کے دوست ہو اور لوگ نہیں تو اگر تم سچے ہو تو (ذرا) موت کی آرزو تو کرو\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxiv{اور یہ ان (اعمال) کے سبب جو کرچکے ہیں ہرگز اس کی آرزو نہیں کریں گے۔ اور خدا ظالموں سے خوب واقف ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxv{کہہ دو کہ موت جس سے تم گریز کرتے ہو وہ تو تمہارے سامنے آ کر رہے گی۔ پھر تم پوشیدہ اور ظاہر کے جاننے والے (خدا) کی طرف لوٹائے جاؤ گے پھر جو کچھ تم کرتے رہے ہو وہ سب تمہیں بتائے گا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvi{مومنو! جب جمعے کے دن نماز کے لئے اذان دی جائے تو خدا کی یاد (یعنی نماز) کے لئے جلدی کرو اور (خریدو) فروخت ترک کردو۔ اگر سمجھو تو یہ تمہارے حق میں بہتر ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxvii{پھر جب نماز ہوچکے تو اپنی اپنی راہ لو اور خدا کا فضل تلاش کرو اور خدا کو بہت بہت یاد کرتے رہو تاکہ نجات پاؤ\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxviii{اور جب یہ لوگ سودا بکتا یا تماشا ہوتا دیکھتے ہیں تو ادھر بھاگ جاتے ہیں اور تمہیں (کھڑے کا) کھڑا چھوڑ جاتے ہیں۔ کہہ دو کہ جو چیز خدا کے ہاں ہے وہ تماشے اور سودے سے کہیں بہتر ہے اور خدا سب سے بہتر رزق دینے والا ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmclxxxix{\basmalahur (اے محمدﷺ) جب منافق لوگ تمہارے پاس آتے ہیں تو (از راہ نفاق) کہتے ہیں کہ ہم اقرار کرتے ہیں کہ آپ بےشک خدا کے پیغمبر ہیں اور خدا جانتا ہے کہ درحقیقت تم اس کے پیغمبر ہو لیکن خدا ظاہر کئے دیتا ہے کہ منافق (دل سے اعتقاد نہ رکھنے کے لحاظ سے) جھوٹے ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcxc{انہوں نے اپنی قسموں کو ڈھال بنا رکھا ہے اور ان کے ذریعے سے (لوگوں کو) راہ خدا سے روک رہے ہیں۔ کچھ شک نہیں کہ جو کام یہ کرتے ہیں برے ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcxci{یہ اس لئے کہ یہ (پہلے تو) ایمان لائے پھر کافر ہوگئے تو ان کے دلوں پر مہر لگادی گئی۔ سو اب یہ سمجھتے ہی نہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcii{اور جب تم ان (کے تناسب اعضا) کو دیکھتے ہو تو ان کے جسم تمہیں (کیا ہی) اچھے معلوم ہوتے ہیں۔ اور جب وہ گفتگو کرتے ہیں تو تم ان کی تقریر کو توجہ سے سنتے ہو (مگر فہم وادراک سے خالی) گویا لکڑیاں ہیں جو دیواروں سے لگائی گئی ہیں۔ (بزدل ایسے کہ) ہر زور کی آواز کو سمجھیں (کہ) ان پر بلا آئی۔ یہ (تمہارے) دشمن ہیں ان سے بےخوف نہ رہنا۔ خدا ان کو ہلاک کرے۔ یہ کہاں بہکے پھرتے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciii{اور جب ان سے کہا جائے کہ آؤ رسول خدا تمہارے لئے مغفرت مانگیں تو سر ہلا دیتے ہیں اور تم ان کو دیکھو کہ تکبر کرتے ہوئے منہ پھیر لیتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcxciv{تم ان کے لئے مغفرت مانگو یا نہ مانگو ان کے حق میں برابر ہے۔ خدا ان کو ہرگز نہ بخشے گا۔ بےشک خدا نافرمانوں کو ہدایت نہیں دیا کرتا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcv{یہی ہیں جو کہتے ہیں کہ جو لوگ رسول خدا کے پاس (رہتے) ہیں ان پر (کچھ) خرچ نہ کرو۔ یہاں تک کہ یہ (خود بخود) بھاگ جائیں۔ حالانکہ آسمانوں اور زمین کے خزانے خدا ہی کہ ہیں لیکن منافق نہیں سمجھتے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvi{کہتے ہیں کہ اگر ہم لوٹ کر مدینے پہنچے تو عزت والے ذلیل لوگوں کو وہاں سے نکال باہر کریں گے۔ حالانکہ عزت خدا کی ہے اور اس کے رسول کی اور مومنوں کی لیکن منافق نہیں جانتے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcvii{مومنو! تمہارا مال اور اولاد تم کو خدا کی یاد سے غافل نہ کردے۔ اور جو ایسا کرے گا تو وہ لوگ خسارہ اٹھانے والے ہیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcviii{اور جو (مال) ہم نے تم کو دیا ہے اس میں سے اس (وقت) سے پیشتر خرچ کرلو کہ تم میں سے کسی کی موت آجائے تو (اس وقت) کہنے لگے کہ اے میرے پروردگار تو نے مجھے تھوڑی سی اور مہلت کیوں نہ دی تاکہ میں خیرات کرلیتا اور نیک لوگوں میں داخل ہوجاتا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcxcix{اور جب کسی کی موت آجاتی ہے تو خدا اس کو ہرگز مہلت نہیں دیتا اور جو کچھ تم کرتے ہو خدا اس سے خبردار ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcc{\basmalahur جو چیز آسمانوں میں ہے اور جو چیز زمین میں ہے (سب) خدا کی تسبیح کرتی ہے۔ اسی کی سچی بادشاہی ہے اور اسی کی تعریف (لامتناہی) ہے اور وہ ہر چیز پر قادر ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcci{وہی تو ہے جس نے تم کو پیدا کیا پھر کوئی تم میں کافر ہے اور کوئی مومن۔ اور جو کچھ تم کرتے ہو خدا اس کو دیکھتا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmccii{اسی نے آسمانوں اور زمین کو مبنی برحکمت پیدا کیا اور اسی نے تمہاری صورتیں بنائیں اور صورتیں بھی پاکیزہ بنائیں۔ اور اسی کی طرف (تمہیں) لوٹ کر جانا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcciii{جو کچھ آسمانوں اور زمین میں ہے وہ سب جانتا ہے اور جو کچھ تم چھپا کر کرتے ہو اور جو کھلم کھلا کرتے ہو اس سے بھی آگاہ ہے۔ اور خدا دل کے بھیدوں سے واقف ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcciv{کیا تم کو ان لوگوں کے حال کی خبر نہیں پہنچی جو پہلے کافر ہوئے تھے تو انہوں نے اپنے کاموں کی سزا کا مزہ چکھ لیا اور (ابھی) دکھ دینے والا عذاب (اور) ہونا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmccv{یہ اس لئے کہ ان کے پاس پیغمبر کھلی نشانیاں لے کر آئے تو یہ کہتے کہ کیا آدمی ہمارے ہادی بنتے ہیں؟ تو انہوں نے (ان کو) نہ مانا اور منہ پھیر لیا اور خدا نے بھی بےپروائی کی۔ اور خدا بےپروا (اور) سزاوار حمد (وثنا) ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmccvi{جو لوگ کافر ہیں ان کا اعتقاد ہے کہ وہ (دوبارہ) ہرگز نہیں اٹھائے جائیں گے۔ کہہ دو کہ ہاں ہاں میرے پروردگار کی قسم تم ضرور اٹھائے جاؤ گے پھر جو کام تم کرتے رہے ہو وہ تمہیں بتائے جائیں گے اور یہ (بات) خدا کو آسان ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmccvii{تو خدا پر اور اس کے رسول پر اور نور (قرآن) پر جو ہم نے نازل فرمایا ہے ایمان لاؤ۔ اور خدا تمہارے سب اعمال سے خبردار ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmccviii{جس دن وہ تم کو اکھٹا ہونے (یعنی قیامت) کے دن اکھٹا کرے گا وہ نقصان اٹھانے کا دن ہے۔ اور جو شخص خدا پر ایمان لائے اور نیک عمل کرے وہ اس سے اس کی برائیاں دور کردے گا اور باغہائے بہشت میں جن کے نیچے نہریں بہہ رہی ہیں داخل کرے گا۔ ہمیشہ ان میں رہیں گے۔ یہ بڑی کامیابی ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmccix{اور جنہوں نے کفر کیا اور ہماری آیتوں کو جھٹلایا وہی اہل ذوزخ ہیں۔ ہمیشہ اس میں رہیں گے۔ اور وہ بری جگہ ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmccx{کوئی مصیبت نازل نہیں ہوتی مگر خدا کے حکم سے۔ اور جو شخص خدا پر ایمان لاتا ہے وہ اس کے دل کو ہدایت دیتا ہے۔ اور خدا ہر چیز سے باخبر ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmccxi{اور خدا کی اطاعت کرو اور اس کے رسول کی اطاعت کرو۔ اگر تم منہ پھیر لو گے تو ہمارے پیغمبر کے ذمے تو صرف پیغام کا کھول کھول کر پہنچا دینا ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmccxii{خدا (جو معبود برحق ہے اس) کے سوا کوئی عبادت کے لائق نہیں تو مومنوں کو چاہیئے کہ خدا ہی پر بھروسا رکھیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiii{مومنو! تمہاری عورتیں اور اولاد میں سے بعض تمہارے دشمن (بھی) ہیں سو ان سے بچتے رہو۔ اور اگر معاف کردو اور درگزر کرو اور بخش دو تو خدا بھی بخشنے والا مہربان ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmccxiv{تمہارا مال اور تمہاری اولاد تو آزمائش ہے۔ اور خدا کے ہاں بڑا اجر ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmccxv{سو جہاں تک ہوسکے خدا سے ڈرو اور (اس کے احکام کو) سنو اور (اس کے) فرمانبردار رہو اور (اس کی راہ میں) خرچ کرو (یہ) تمہارے حق میں بہتر ہے۔ اور جو شخص طبعیت کے بخل سے بچایا گیا تو ایسے ہی لوگ راہ پانے والے ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvi{اگر تم خدا کو (اخلاص اور نیت) نیک (سے) قرض دو گے تو وہ تم کو اس کا دوچند دے گا اور تمہارے گناہ بھی معاف کردے گا۔ اور خدا قدر شناس اور بردبار ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmccxvii{پوشیدہ اور ظاہر کا جاننے والا غالب اور حکمت والا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmccxviii{\basmalahur اے پیغمبر (مسلمانوں سے کہہ دو کہ) جب تم عورتوں کو طلاق دینے لگو تو عدت کے شروع میں طلاق دو اور عدت کا شمار رکھو۔ اور خدا سے جو تمہارا پروردگار ہے ڈرو۔ (نہ تو تم ہی) ان کو (ایام عدت میں) ان کے گھروں سے نکالو اور نہ وہ (خود ہی) نکلیں۔ ہاں اگر وہ صریح بےحیائی کریں (تو نکال دینا چاہیئے) اور یہ خدا کی حدیں ہیں۔ جو خدا کی حدوں سے تجاوز کرے گا وہ اپنے آپ پر ظلم کرے گا۔ (اے طلاق دینے والے) تجھے کیا معلوم شاید خدا اس کے بعد کوئی (رجعت کی) سبیل پیدا کردے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmccxix{پھر جب وہ اپنی میعاد (یعنی انقضائے عدت) کے قریب پہنچ جائیں تو یا تو ان کو اچھی طرح (زوجیت میں) رہنے دو یا اچھی طرح سے علیحدہ کردو اور اپنے میں سے دو منصف مردوں کو گواہ کرلو اور (گواہ ہو!) خدا کے لئے درست گواہی دینا۔ ان باتوں سے اس شخص کو نصیحت کی جاتی ہے جو خدا پر اور روز آخرت پر ایمان رکھتا ہے۔ اور جو کوئی خدا سے ڈرے گا وہ اس کے لئے (رنج ومحن سے) مخلصی (کی صورت) پیدا کرے گا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmccxx{اور اس کو ایسی جگہ سے رزق دے گا جہاں سے (وہم و) گمان بھی نہ ہو۔ اور جو خدا پر بھروسہ رکھے گا تو وہ اس کو کفایت کرے گا۔ خدا اپنے کام کو (جو وہ کرنا چاہتا ہے) پورا کردیتا ہے۔ خدا نے ہر چیز کا اندازہ مقرر کر رکھا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxi{اور تمہاری (مطلقہ) عورتیں جو حیض سے ناامید ہوچکی ہوں اگر تم کو (ان کی عدت کے بارے میں) شبہ ہو تو ان کی عدت تین مہینے ہے اور جن کو ابھی حیض نہیں آنے لگا (ان کی عدت بھی یہی ہے) اور حمل والی عورتوں کی عدت وضع حمل (یعنی بچّہ جننے) تک ہے۔ اور جو خدا سے ڈرے گا خدا اس کے کام میں سہولت پیدا کردے گا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxii{یہ خدا کے حکم ہیں جو خدا نے تم پر نازل کئے ہیں۔ اور جو خدا سے ڈرے گا وہ اس سے اس کے گناہ دور کر دے گا اور اسے اجر عظیم بخشے گا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiii{عورتوں کو (ایام عدت میں) اپنے مقدور کے مطابق وہیں رکھو جہاں خود رہتے ہو اور ان کو تنگ کرنے کے لئے تکلیف نہ دو اور اگر حمل سے ہوں تو بچّہ جننے تک ان کا خرچ دیتے رہو۔ پھر اگر وہ بچّے کو تمہارے کہنے سے دودھ پلائیں تو ان کو ان کی اجرت دو۔ اور (بچّے کے بارے میں) پسندیدہ طریق سے مواقفت رکھو۔ اور اگر باہم ضد (اور نااتفاقی) کرو گے تو (بچّے کو) اس کے (باپ کے) کہنے سے کوئی اور عورت دودھ پلائے گی\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxiv{صاحب وسعت کو اپنی وسعت کے مطابق خرچ کرنا چاہیئے۔ اور جس کے رزق میں تنگی ہو وہ جتنا خدا نے اس کو دیا ہے اس کے موافق خرچ کرے۔ خدا کسی کو تکلیف نہیں دیتا مگر اسی کے مطابق جو اس کو دیا ہے۔ اور خدا عنقریب تنگی کے بعد کشائش بخشے گا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxv{اور بہت سی بستیوں (کے رہنے والوں) نے اپنے پروردگار اور اس کے پیغمبروں کے احکام سے سرکشی کی تو ہم نے ان کو سخت حساب میں پکڑ لیا اور ان پر (ایسا) عذاب نازل کیا جو نہ دیکھا تھا نہ سنا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvi{سو انہوں نے اپنے کاموں کی سزا کا مزہ چکھ لیا اور ان کا انجام نقصان ہی تو تھا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxvii{خدا نے ان کے لئے سخت عذاب تیار کر رکھا ہے۔ تو اے ارباب دانش جو ایمان لائے ہو خدا سے ڈرو۔ خدا نے تمہارے پاس نصیحت (کی کتاب) بھیجی ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxviii{اور اپنے) پیغمبر (بھی بھیجے ہیں) جو تمہارے سامنے خدا کی واضح المطالب آیتیں پڑھتے ہیں تاکہ جو لوگ ایمان لائے اور عمل نیک کرتے رہے ہیں ان کو اندھیرے سے نکال کر روشنی میں لے آئیں اور جو شخص ایمان لائے گا اور عمل نیک کرے گا ان کو باغہائے بہشت میں داخل کرے گا جن کے نیچے نہریں بہہ رہیں ہیں ابد الاآباد ان میں رہیں گے۔ خدا نے ان کو خوب رزق دیا ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxix{خدا ہی تو ہے جس نے سات آسمان پیدا کئے اور ایسی ہی زمینیں۔ ان میں (خدا کے) حکم اُترتے رہتے ہیں تاکہ تم لوگ جان لو کہ خدا چیز پر قادر ہے۔ اور یہ کہ خدا اپنے علم سے ہر چیز پر احاطہ کئے ہوئے ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxx{\basmalahur اے پیغمبر جو چیز خدا نے تمہارے لئے جائز کی ہے تم اس سے کنارہ کشی کیوں کرتے ہو؟ (کیا اس سے) اپنی بیویوں کی خوشنودی چاہتے ہو؟ اور خدا بخشنے والا مہربان ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxi{خدا نے تم لوگوں کے لئے تمہاری قسموں کا کفارہ مقرر کردیا ہے۔ اور خدا ہی تمہارا کارساز ہے۔ اور وہ دانا (اور) حکمت والا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxii{اور (یاد کرو) جب پیغمبر نے اپنی ایک بی بی سے ایک بھید کی بات کہی تو (اس نے دوسری کو بتا دی) ۔ جب اس نے اس کو افشاء کیا اور خدا نے اس (حال) سے پیغمبر کو آگاہ کردیا تو پیغمبر نے ان (بی بی کو وہ بات) کچھ تو بتائی اور کچھ نہ بتائی۔ تو جب وہ ان کو جتائی تو پوچھنے لگیں کہ آپ کو کس نے بتایا؟ انہوں نے کہا کہ مجھے اس نے بتایا ہے جو جاننے والا خبردار ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiii{اگر تم دونوں خدا کے آگے توبہ کرو (تو بہتر ہے کیونکہ) تمہارے دل کج ہوگئے ہیں۔ اور اگر پیغمبر (کی ایذا) پر باہم اعانت کرو گی تو خدا اور جبریل اور نیک کردار مسلمان ان کے حامی (اور دوستدار) ہیں۔ اور ان کے علاوہ (اور) فرشتے بھی مددگار ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxiv{اگر پیغمبر تم کو طلاق دے دیں تو عجب نہیں کہ ان کا پروردگار تمہارے بدلے ان کو تم سے بہتر بیبیاں دے دے۔ مسلمان، صاحب ایمان فرمانبردار توبہ کرنے والیاں عبادت گذار روزہ رکھنے والیاں بن شوہر اور کنواریاں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxv{مومنو! اپنے آپ کو اور اپنے اہل عیال کو آتش (جہنم) سے بچاؤ جس کا ایندھن آدمی اور پتھر ہیں اور جس پر تند خو اور سخت مزاج فرشتے (مقرر) ہیں جو ارشاد خدا ان کو فرماتا ہے اس کی نافرمانی نہیں کرتے اور جو حکم ان کو ملتا ہے اسے بجا لاتے ہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvi{کافرو! آج بہانے مت بناؤ۔ جو عمل تم کیا کرتے ہو ان ہی کا تم کو بدلہ دیا جائے گا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxvii{مومنو! خدا کے آگے صاف دل سے توبہ کرو۔ امید ہے کہ وہ تمہارے گناہ تم سے دور کر دے گا اور تم کو باغہائے بہشت میں جن کے نیچے نہریں بہہ رہی ہیں داخل کرے گا۔ اس دن پیغمبر کو اور ان لوگوں کو جو ان کے ساتھ ایمان لائے ہیں رسوا نہیں کرے گا (بلکہ) ان کا نور ایمان ان کے آگے اور داہنی طرف (روشنی کرتا ہوا) چل رہا ہوگا۔ اور وہ خدا سے التجا کریں گے کہ اے پروردگار ہمارا نور ہمارے لئے پورا کر اور ہمیں معاف کرنا۔ بےشک خدا ہر چیز پر قادر ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxviii{اے پیغمبر! کافروں اور منافقوں سے لڑو اور ان پر سختی کرو۔ ان کا ٹھکانا دوزخ ہے۔ اور وہ بہت بری جگہ ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmccxxxix{خدا نے کافروں کے لئے نوحؑ کی بیوی اور لوطؑ کی بیوی کی مثال بیان فرمائی ہے۔ دونوں ہمارے دو نیک بندوں کے گھر میں تھیں اور دونوں نے ان کی خیانت کی تو وہ خدا کے مقابلے میں اور ان عورتوں کے کچھ بھی کام نہ آئے اور ان کو حکم دیا گیا کہ اور داخل ہونے والوں کے ساتھ تم بھی دوزخ میں داخل ہو جاؤ\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmccxl{اور مومنوں کے لئے (ایک) مثال (تو) فرعون کی بیوی کی بیان فرمائی کہ اس نے خدا سے التجا کی کہ اے میرے پروردگار میرے لئے بہشت میں اپنے پاس ایک گھر بنا اور مجھے فرعون اور اس کے اعمال (زشت مآل) سے نجات بخش اور ظالم لوگوں کے ہاتھ سے مجھ کو مخلصی عطا فرما\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmccxli{اور (دوسری) عمران کی بیٹی مریمؑ کی جنہوں نے اپنی شرمگاہ کو محفوظ رکھا تو ہم نے اس میں اپنی روح پھونک دی اور اپنے پروردگار کے کلام اور اس کی کتابوں کو برحق سمجھتی تھیں اور فرمانبرداروں میں سے تھیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlii{\basmalahur وہ (خدا) جس کے ہاتھ میں بادشاہی ہے بڑی برکت والا ہے۔ اور وہ ہر چیز پر قادر ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliii{اسی نے موت اور زندگی کو پیدا کیا تاکہ تمہاری آزمائش کرے کہ تم میں کون اچھے عمل کرتا ہے۔ اور وہ زبردست (اور) بخشنے والا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmccxliv{اس نے سات آسمان اوپر تلے بنائے۔ (اے دیکھنے والے) کیا تو (خدا) رحمٰن کی آفرینش میں کچھ نقص دیکھتا ہے؟ ذرا آنکھ اٹھا کر دیکھ بھلا تجھ کو (آسمان میں) کوئی شگاف نظر آتا ہے؟\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlv{پھر دو بارہ (سہ بارہ) نظر کر، تو نظر (ہر بار) تیرے پاس ناکام اور تھک کر لوٹ آئے گی\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvi{اور ہم نے قریب کے آسمان کو (تاروں کے) چراغوں سے زینت دی۔ اور ان کو شیطان کے مارنے کا آلہ بنایا اور ان کے لئے دہکتی آگ کا عذاب تیار کر رکھا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlvii{اور جن لوگوں نے اپنے پروردگار سے انکار کیا ان کے لئے جہنم کا عذاب ہے۔ اور وہ برا ٹھکانہ ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlviii{جب وہ اس میں ڈالے جائیں گے تو اس کا چیخنا چلانا سنیں گے اور وہ جوش مار رہی ہوگی\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmccxlix{گویا مارے جوش کے پھٹ پڑے گی۔ جب اس میں ان کی کوئی جماعت ڈالی جائے گی تو دوزخ کے داروغہ ان سے پوچھیں گے کہ تمہارے پاس کوئی ہدایت کرنے والا نہیں آیا تھا؟\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmccl{وہ کہیں گے کیوں نہیں ضرور ہدایت کرنے والا آیا تھا لیکن ہم نے اس کو جھٹلا دیا اور کہا کہ خدا نے تو کوئی چیز نازل ہی نہیں کی۔ تم تو بڑی غلطی میں (پڑے ہوئے) ہو\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmccli{اور کہیں گے اگر ہم سنتے یا سمجھتے ہوتے تو دوزخیوں میں نہ ہوتے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcclii{پس وہ اپنے گناہ کا اقرار کرلیں گے۔ سو دوزخیوں کے لئے (رحمت خدا سے) دور ہی ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmccliii{اور) جو لوگ بن دیکھے اپنے پروردگار سے ڈرتے ہیں ان کے لئے بخشش اور اجر عظیم ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmccliv{اور تم (لوگ) بات پوشیدہ کہو یا ظاہر۔ وہ دل کے بھیدوں تک سے واقف ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcclv{بھلا جس نے پیدا کیا وہ بےخبر ہے؟ وہ تو پوشیدہ باتوں کا جاننے والا اور (ہر چیز سے) آگاہ ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvi{وہی تو ہے جس نے تمہارے لئے زمین کو نرم کیا تو اس کی راہوں میں چلو پھرو اور خدا کا (دیا ہو) رزق کھاؤ اور تم کو اسی کے پاس (قبروں سے) نکل کر جانا ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcclvii{کیا تم اس سے جو آسمان میں ہے بےخوف ہو کہ تم کو زمین میں دھنسا دے اور وہ اس وقت حرکت کرنے لگے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcclviii{کیا تم اس سے جو آسمان میں ہے نڈر ہو کہ تم پر کنکر بھری ہوا چھوڑ دے۔ سو تم عنقریب جان لو گے کہ میرا ڈرانا کیسا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcclix{اور جو لوگ ان سے پہلے تھے انہوں نے بھی جھٹلایا تھا سو (دیکھ لو کہ) میرا کیسا عذاب ہوا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcclx{کیا انہوں نے اپنے سروں پر اڑتے ہوئے جانوروں کو نہیں دیکھا جو پروں کو پھیلائے رہتے ہیں اور ان کو سکیڑ بھی لیتے ہیں۔ خدا کے سوا انہیں کوئی تھام نہیں سکتا۔ بےشک وہ ہر چیز کو دیکھ رہا ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxi{بھلا ایسا کون ہے جو تمہاری فوج ہو کر خدا کے سوا تمہاری مدد کرسکے۔ کافر تو دھوکے میں ہیں\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxii{بھلا اگر وہ اپنا رزق بند کرلے تو کون ہے جو تم کو رزق دے؟ لیکن یہ سرکشی اور نفرت میں پھنسے ہوئے ہیں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiii{بھلا جو شخص چلتا ہوا منہ کے بل گر پڑتا ہے وہ سیدھے رستے پر ہے یا وہ جو سیدھے رستے پر برابر چل رہا ہو؟\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxiv{کہو وہ خدا ہی تو ہے جس نے تم کو پیدا کیا۔ اور تمہارے کان اور آنکھیں اور دل بنائے (مگر) تم کم احسان مانتے ہو\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxv{کہہ دو کہ وہی ہے جس نے تم کو زمین میں پھیلایا اور اسی کے روبرو تم جمع کئے جاؤ گے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvi{اور کافر کہتے ہیں کہ اگر تم سچے ہو تو یہ وعید کب (پورا) ہوگا؟\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxvii{کہہ دو اس کا علم خدا ہی کو ہے۔ اور میں تو کھول کھول کر ڈر سنانے دینے والا ہوں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxviii{سو جب وہ دیکھ لیں گے کہ وہ (وعدہ) قریب آگیا تو کافروں کے منہ برے ہوجائیں گے اور (ان سے) کہا جائے گا کہ یہ وہی ہے جس کے تم خواستگار تھے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxix{کہو کہ بھلا دیکھو تو اگر خدا مجھ کو اور میرے ساتھیوں کو ہلاک کردے یا ہم پر مہربانی کرے۔ تو کون ہے کافروں کو دکھ دینے والے عذاب سے پناہ دے؟\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxx{کہہ دو کہ وہ جو (خدائے) رحمٰن (ہے) ہم اسی پر ایمان لائے اور اسی پر بھروسا رکھتے ہیں۔ تم کو جلد معلوم ہوجائے گا کہ صریح گمراہی میں کون پڑ رہا تھا\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxi{کہو کہ بھلا دیکھو تو اگر تمہارا پانی (جو تم پیتے ہو اور برتے ہو) خشک ہوجائے تو (خدا کے) سوا کون ہے جو تمہارے لئے شیریں پانی کا چشمہ بہا لائے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxii{\basmalahur نٓ۔ قلم کی اور جو (اہل قلم) لکھتے ہیں اس کی قسم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiii{کہ (اے محمدﷺ) تم اپنے پروردگار کے فضل سے دیوانے نہیں ہو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxiv{اور تمہارے لئے بے انتہا اجر ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxv{اور اخلاق تمہارے بہت (عالی) ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvi{سو عنقریب تم بھی دیکھ لو گے اور یہ (کافر) بھی دیکھ لیں گے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxvii{کہ تم میں سے کون دیوانہ ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxviii{تمہارا پروردگار اس کو بھی خوب جانتا ہے جو اس کے رستے سے بھٹک گیا اور ان کو بھی خوب جانتا ہے جو سیدھے راستے پر چل رہے ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxix{تو تم جھٹلانے والوں کا کہا نہ ماننا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxx{یہ لوگ چاہتے ہیں کہ تم نرمی اختیار کرو تو یہ بھی نرم ہوجائیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxi{اور کسی ایسے شخص کے کہے میں نہ آجانا جو بہت قسمیں کھانے والا ذلیل اوقات ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxii{طعن آمیز اشارتیں کرنے والا چغلیاں لئے پھرنے والا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiii{مال میں بخل کرنے والا حد سے بڑھا ہوا بدکار\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxiv{سخت خو اور اس کے علاوہ بدذات ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxv{اس سبب سے کہ مال اور بیٹے رکھتا ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvi{جب اس کو ہماری آیتیں پڑھ کر سنائی جاتی ہیں تو کہتا ہے کہ یہ اگلے لوگوں کے افسانے ہیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxvii{ہم عنقریب اس کی ناک پر داغ لگائیں گے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxviii{ہم نے ان لوگوں کی اسی طرح آزمائش کی ہے جس طرح باغ والوں کی آزمائش کی تھی۔ جب انہوں نے قسمیں کھا کھا کر کہا کہ صبح ہوتے ہوتے ہم اس کا میوہ توڑ لیں گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcclxxxix{اور انشاء الله نہ کہا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmccxc{سو وہ ابھی سو ہی رہے تھے کہ تمہارے پروردگار کی طرف سے (راتوں رات) اس پر ایک آفت پھر گئی\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmccxci{تو وہ ایسا ہوگیا جیسے کٹی ہوئی کھیتی\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcii{جب صبح ہوئی تو وہ لوگ ایک دوسرے کو پکارنے لگے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciii{اگر تم کو کاٹنا ہے تو اپنی کھیتی پر سویرے ہی جا پہنچو\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmccxciv{تو وہ چل پڑے اور آپس میں چپکے چپکے کہتے جاتے تھے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcv{آج یہاں تمہارے پاس کوئی فقیر نہ آنے پائے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvi{اور کوشش کے ساتھ سویرے ہی جا پہنچے (گویا کھیتی پر) قادر ہیں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcvii{جب باغ کو دیکھا تو (ویران) کہنے لگے کہ ہم رستہ بھول گئے ہیں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcviii{نہیں بلکہ ہم (برگشتہ نصیب) بےنصیب ہیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmccxcix{ایک جو اُن میں فرزانہ تھا بولا کہ کیا میں نے تم سے نہیں کہا تھا کہ تم تسبیح کیوں نہیں کرتے؟\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmccc{تب) وہ کہنے لگے کہ ہمارا پروردگار پاک ہے بےشک ہم ہی قصوروار تھے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmccci{پھر لگے ایک دوسرے کو رو در رو ملامت کرنے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmcccii{کہنے لگے ہائے شامت ہم ہی حد سے بڑھ گئے تھے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmccciii{امید ہے کہ ہمارا پروردگار اس کے بدلے میں ہمیں اس سے بہتر باغ عنایت کرے ہم اپنے پروردگار کی طرف سے رجوع لاتے ہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmccciv{دیکھو) عذاب یوں ہوتا ہے۔ اور آخرت کا عذاب اس سے کہیں بڑھ کر ہے۔ کاش! یہ لوگ جانتے ہوتے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmcccv{پرہیزگاروں کے لئے ان کے پروردگار کے ہاں نعمت کے باغ ہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvi{کیا ہم فرمانبرداروں کو نافرمانوں کی طرف (نعمتوں سے) محروم کردیں گے؟\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmcccvii{تمہیں کیا ہوگیا ہے کیسی تجویزیں کرتے ہو؟\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmcccviii{کیا تمہارے پاس کوئی کتاب ہے جس میں (یہ) پڑھتے ہو\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmcccix{کہ جو چیز تم پسند کرو گے وہ تم کو ضرور ملے گی\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmcccx{یا تم نے ہم سے قسمیں لے رکھی ہیں جو قیامت کے دن تک چلی جائیں گی کہ جس شے کا تم حکم کرو گے وہ تمہارے لئے حاضر ہوگی\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxi{ان سے پوچھو کہ ان میں سے اس کا کون ذمہ لیتا ہے؟\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxii{کیا (اس قول میں) ان کے اور بھی شریک ہیں؟ اگر یہ سچے ہیں تو اپنے شریکوں کو لا سامنے کریں\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiii{جس دن پنڈلی سے کپڑا اٹھا دیا جائے گا اور کفار سجدے کے لئے بلائے جائیں گے تو سجدہ نہ کرسکیں گے\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxiv{ان کی آنکھیں جھکی ہوئی ہوں گی اور ان پر ذلت چھا رہی ہوگی حالانکہ پہلے (اُس وقت) سجدے کے لئے بلاتے جاتے تھے جب کہ صحیح وسالم تھے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxv{تو مجھ کو اس کلام کے جھٹلانے والوں سے سمجھ لینے دو۔ ہم ان کو آہستہ آہستہ ایسے طریق سے پکڑیں گے کہ ان کو خبر بھی نہ ہوگی\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvi{اور میں ان کو مہلت دیئے جاتا ہوں میری تدبیر قوی ہے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxvii{کیا تم ان سے کچھ اجر مانگتے ہو کہ ان پر تاوان کا بوجھ پڑ رہا ہے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxviii{یا ان کے پاس غیب کی خبر ہے کہ (اسے) لکھتے جاتے ہیں\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxix{تو اپنے پروردگار کے حکم کے انتظار میں صبر کئے رہو اور مچھلی (کا لقمہ ہونے) والے یونس کی طرح رہو نا کہ انہوں نے (خدا) کو پکارا اور وہ (غم و) غصے میں بھرے ہوئے تھے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxx{اگر تمہارے پروردگار کی مہربانی ان کی یاوری نہ کرتی تو وہ چٹیل میدان میں ڈال دیئے جاتے اور ان کا حال ابتر ہوجاتا\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxi{پھر پروردگار نے ان کو برگزیدہ کرکے نیکوکاروں میں کرلیا\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxii{اور کافر جب (یہ) نصیحت (کی کتاب) سنتے ہیں تو یوں لگتے ہیں کہ تم کو اپنی نگاہوں سے پھسلا دیں گے اور کہتے یہ تو دیوانہ ہے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiii{اور (لوگو) یہ (قرآن) اہل عالم کے لئے نصیحت ہے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxiv{\basmalahur سچ مچ ہونے والی\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxv{وہ سچ مچ ہونے والی کیا ہے؟\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvi{اور تم کو کیا معلوم ہے کہ سچ مچ ہونے والی کیا ہے؟\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxvii{کھڑکھڑانے والی (جس) کو ثمود اور عاد (دونوں) نے جھٹلایا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxviii{سو ثمود تو کڑک سے ہلاک کردیئے گئے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxix{رہے عاد تو ان کا نہایت تیز آندھی سے ستیاناس کردیا گیا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxx{خدا نے اس کو سات رات اور آٹھ دن لگاتار ان پر چلائے رکھا تو (اے مخاطب) تو لوگوں کو اس میں (اس طرح) ڈھئے (اور مرے) پڑے دیکھے جیسے کھجوروں کے کھوکھلے تنے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxi{بھلا تو ان میں سے کسی کو بھی باقی دیکھتا ہے؟\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxii{اور فرعون اور جو لوگ اس سے پہلے تھے اور وہ جو الٹی بستیوں میں رہتے تھے سب گناہ کے کام کرتے تھے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiii{انہوں نے اپنے پروردگار کے پیغمبر کی نافرمانی کی تو خدا نے بھی ان کو بڑا سخت پکڑا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxiv{جب پانی طغیانی پر آیا تو ہم نے تم (لوگوں) کو کشتی میں سوار کرلیا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxv{تاکہ اس کو تمہارے لئے یادگار بنائیں اور یاد رکھنے والے کان اسے یاد رکھیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvi{تو جب صور میں ایک (بار) پھونک مار دی جائے گی\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxvii{اور زمین اور پہاڑ دونوں اٹھا لئے جائیں گے۔ پھر ایک بارگی توڑ پھوڑ کر برابر کردیئے جائیں گے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxviii{تو اس روز ہو پڑنے والی (یعنی قیامت) ہو پڑے گی\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxxxix{اور آسمان پھٹ جائے گا تو وہ اس دن کمزور ہوگا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxl{اور فرشتے اس کے کناروں پر (اُتر آئیں گے) اور تمہارے پروردگار کے عرش کو اس روز آٹھ فرشتے اپنے سروں پر اُٹھائے ہوں گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxli{اس روز تم (سب لوگوں کے سامنے) پیش کئے جاؤ گے اور تمہاری کوئی پوشیدہ بات چھپی نہ رہے گی\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlii{تو جس کا (اعمال) نامہ اس کے داہنے ہاتھ میں دیا جائے گا وہ (دوسروں سے) کہے گا کہ لیجیئے میرا نامہ (اعمال) پڑھیئے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliii{مجھے یقین تھا کہ مجھ کو میرا حساب (کتاب) ضرور ملے گا\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxliv{پس وہ (شخص) من مانے عیش میں ہوگا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlv{یعنی) اونچے (اونچے محلوں) کے باغ میں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvi{جن کے میوے جھکے ہوئے ہوں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlvii{جو (عمل) تم ایام گزشتہ میں آگے بھیج چکے ہو اس کے صلے میں مزے سے کھاؤ اور پیو\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlviii{اور جس کا نامہ (اعمال) اس کے بائیں ہاتھ میں یاد جائے گا وہ کہے گا اے کاش مجھ کو میرا (اعمال) نامہ نہ دیا جاتا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxlix{اور مجھے معلوم نہ ہو کہ میرا حساب کیا ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcccl{اے کاش موت (ابد الاآباد کے لئے میرا کام) تمام کرچکی ہوتی\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmcccli{آج) میرا مال میرے کچھ بھی کام بھی نہ آیا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmccclii{ہائے) میری سلطنت خاک میں مل گئی\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliii{حکم ہوگا کہ) اسے پکڑ لو اور طوق پہنا دو\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmcccliv{پھر دوزخ کی آگ میں جھونک دو\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmccclv{پھر زنجیر سے جس کی ناپ ستر گز ہے جکڑ دو\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvi{یہ نہ تو خدائے جل شانہ پر ایمان لاتا تھا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmccclvii{اور نہ فقیر کے کھانا کھلانے پر آمادہ کرتا تھا\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmccclviii{سو آج اس کا بھی یہاں کوئی دوستدار نہیں\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmccclix{اور نہ پیپ کے سوا (اس کے لئے) کھانا ہے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmccclx{جس کو گنہگاروں کے سوا کوئی نہیں کھائے گا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxi{تو ہم کو ان چیزوں کی قسم جو تم کو نظر آتی ہیں\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxii{اور ان کی جو نظر میں نہیں آتیں\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiii{کہ یہ (قرآن) فرشتہٴ عالی مقام کی زبان کا پیغام ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxiv{اور یہ کسی شاعر کا کلام نہیں۔ مگر تم لوگ بہت ہی کم ایمان لاتے ہو\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxv{اور نہ کسی کاہن کے مزخرفات ہیں۔ لیکن تم لوگ بہت ہی کم فکر کرتے ہو\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvi{یہ تو) پروردگار عالم کا اُتارا (ہوا) ہے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxvii{اگر یہ پیغمبر ہماری نسبت کوئی بات جھوٹ بنا لاتے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxviii{تو ہم ان کا داہنا ہاتھ پکڑ لیتے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxix{پھر ان کی رگ گردن کاٹ ڈالتے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxx{پھر تم میں سے کوئی (ہمیں) اس سے روکنے والا نہ ہوتا\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxi{اور یہ (کتاب) تو پرہیزگاروں کے لئے نصیحت ہے\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxii{اور ہم جانتے ہیں کہ تم میں سے بعض اس کو جھٹلانے والے ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiii{نیز یہ کافروں کے لئے (موجب) حسرت ہے\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxiv{اور کچھ شک نہیں کہ یہ برحق قابل یقین ہے\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxv{سو تم اپنے پروردگار عزوجل کے نام کی تنزیہ کرتے رہو\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvi{\basmalahur ایک طلب کرنے والے نے عذاب طلب کیا جو نازل ہو کر رہے گا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxvii{یعنی) کافروں پر (اور) کوئی اس کو ٹال نہ سکے گا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxviii{اور وہ) خدائے صاحب درجات کی طرف سے (نازل ہوگا)\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxix{جس کی طرف روح (الامین) اور فرشتے پڑھتے ہیں (اور) اس روز (نازل ہوگا) جس کا اندازہ پچاس ہزار برس کا ہوگا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxx{تو تم کافروں کی باتوں کو) قوت کے ساتھ برداشت کرتے رہو\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxi{وہ ان لوگوں کی نگاہ میں دور ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxii{اور ہماری نظر میں نزدیک\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiii{جس دن آسمان ایسا ہو جائے گا جیسے پگھلا ہوا تانبا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxiv{اور پہاڑ (ایسے) جیسے (دھنکی ہوئی) رنگین اون\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxv{اور کوئی دوست کسی دوست کا پرسان نہ ہوگا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvi{ایک دوسرے کو سامنے دیکھ رہے ہوں گے (اس روز) گنہگار خواہش کرے گا کہ کسی طرح اس دن کے عذاب کے بدلے میں (سب کچھ) دے دے یعنی اپنے بیٹے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxvii{اور اپنی بیوی اور اپنے بھائی\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxviii{اور اپنا خاندان جس میں وہ رہتا تھا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmccclxxxix{اور جتنے آدمی زمین میں ہیں (غرض) سب (کچھ دے دے) اور اپنے تئیں عذاب سے چھڑا لے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxc{لیکن) ایسا ہرگز نہیں ہوگا وہ بھڑکتی ہوئی آگ ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxci{کھال ادھیڑ ڈالنے والی\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcii{ان لوگوں کو اپنی طرف بلائے گی جنہوں نے (دین حق سے) اعراض کیا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciii{اور (مال) جمع کیا اور بند کر رکھا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxciv{کچھ شک نہیں کہ انسان کم حوصلہ پیدا ہوا ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcv{جب اسے تکلیف پہنچتی ہے تو گھبرا اٹھتا ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvi{اور جب آسائش حاصل ہوتی ہے تو بخیل بن جاتا ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcvii{مگر نماز گزار\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcviii{جو نماز کا التزام رکھتے (اور بلاناغہ پڑھتے) ہیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcccxcix{اور جن کے مال میں حصہ مقرر ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcd{یعنی) مانگنے والے کا۔ اور نہ مانگے والے والا کا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcdi{اور جو روز جزا کو سچ سمجھتے ہیں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcdii{اور جو اپنے پروردگار کے عذاب سے خوف رکھتے ہیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiii{بےشک ان کے پروردگار کا عذاب ہے ہی ایسا کہ اس سے بےخوف نہ ہوا جائے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmcdiv{اور جو اپنی شرمگاہوں کی حفاظت کرتے ہیں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmcdv{مگر اپنی بیویوں یا لونڈیوں سے کہ (ان کے پاس جانے پر) انہیں کچھ ملامت نہیں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvi{اور جو لوگ ان کے سوا اور کے خواستگار ہوں وہ حد سے نکل جانے والے ہیں\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmcdvii{اور جو اپنی امانتوں اور اقراروں کا پاس کرتے ہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmcdviii{اور جو اپنی شہادتوں پر قائم رہتے ہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmcdix{اور جو اپنی نماز کی خبر رکھتے ہیں\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmcdx{یہی لوگ باغہائے بہشت میں عزت واکرام سے ہوں گے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxi{تو ان کافروں کو کیا ہوا ہے کہ تمہاری طرف دوڑے چلے آتے ہیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxii{اور) دائیں بائیں سے گروہ گروہ ہو کر (جمع ہوتے جاتے ہیں)\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiii{کیا ان میں سے ہر شخص یہ توقع رکھتا ہے کہ نعمت کے باغ میں داخل کیا جائے گا\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxiv{ہرگز نہیں۔ ہم نے ان کو اس چیز سے پیدا کیا ہے جسے وہ جانتے ہیں\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxv{ہمیں مشرقوں اور مغربوں کے مالک کی قسم کہ ہم طاقت رکھتے ہیں\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvi{یعنی) اس بات پر (قادر ہیں) کہ ان سے بہتر لوگ بدل لائیں اور ہم عاجز نہیں ہیں\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxvii{تو (اے پیغمبر) ان کو باطل میں پڑے رہنے اور کھیل لینے دو یہاں تک کہ جس دن کا ان سے وعدہ کیا جاتا ہے وہ ان کے سامنے آ موجود ہو\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxviii{اس دن یہ قبر سے نکل کر (اس طرح) دوڑیں گے جیسے (شکاری) شکار کے جال کی طرف دوڑتے ہیں\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxix{ان کی آنکھیں جھک رہی ہوں گی اور ذلت ان پر چھا رہی ہوگی۔ یہی وہ دن ہے جس کا ان سے وعدہ کیا جاتا تھا\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxx{\basmalahur ہم نے نوحؑ کو ان کی قوم کی طرف بھیجا کہ پیشتر اس کے کہ ان پر درد دینے والا عذاب واقع ہو اپنی قوم کو ہدایت کردو\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxi{انہوں نے کہا کہ اے قوم! میں تم کو کھلے طور پر نصیحت کرتا ہوں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxii{کہ خدا کی عبات کرو اور اس سے ڈرو اور میرا کہا مانو\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiii{وہ تمہارے گناہ بخش دے گا اور (موت کے) وقت مقررہ تک تم کو مہلت عطا کرے گا۔ جب خدا کا مقرر کیا ہوگا وقت آجاتا ہے تو تاخیر نہیں ہوتی۔ کاش تم جانتے ہوتے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxiv{جب لوگوں نے نہ مانا تو (نوحؑ نے) خدا سے عرض کی کہ پروردگار میں اپنی قوم کو رات دن بلاتا رہا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxv{لیکن میرے بلانے سے وہ اور زیادہ گزیر کرتے رہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvi{جب جب میں نے ان کو بلایا کہ (توبہ کریں اور) تو ان کو معاف فرمائے تو انہوں نے اپنے کانوں میں انگلیاں دے لیں اور کپڑے اوڑھ لئے اور اڑ گئے اور اکڑ بیٹھے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxvii{پھر میں ان کو کھلے طور پر بھی بلاتا رہا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxviii{اور ظاہر اور پوشیدہ ہر طرح سمجھاتا رہا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxix{اور کہا کہ اپنے پروردگار سے معافی مانگو کہ وہ بڑا معاف کرنے والا ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxx{وہ تم پر آسمان سے لگاتار مینہ برسائے گا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxi{اور مال اور بیٹوں سے تمہاری مدد فرمائے گا اور تمہیں باغ عطا کرے گا اور ان میں تمہارے لئے نہریں بہا دے گا\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxii{تم کو کیا ہوا ہے کہ تم خدا کی عظمت کا اعتقاد نہیں رکھتے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiii{حالانکہ اس نے تم کو طرح طرح (کی حالتوں) کا پیدا کیا ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxiv{کیا تم نے نہیں دیکھا کہ خدا نے سات آسمان کیسے اوپر تلے بنائے ہیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxv{اور چاند کو ان میں (زمین کا) نور بنایا ہے اور سورج کو چراغ ٹھہرایا ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvi{اور خدا ہی نے تم کو زمین سے پیدا کیا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxvii{پھر اسی میں تمہیں لوٹا دے گا اور (اسی سے) تم کو نکال کھڑا کرے گا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxviii{اور خدا ہی نے زمین کو تمہارے لئے فرش بنایا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxxxix{تاکہ اس کے بڑے بڑے کشادہ رستوں میں چلو پھرو\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxl{اس کے بعد) نوح نے عرض کی کہ میرے پروردگار! یہ لوگ میرے کہنے پر نہیں چلے اور ایسوں کے تابع ہوئے جن کو ان کے مال اور اولاد نے نقصان کے سوا کچھ فائدہ نہیں دیا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxli{اور وہ بڑی بڑی چالیں چلے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlii{اور کہنے لگے کہ اپنے معبودوں کو ہرگز نہ چھوڑنا اور ود اور سواع اور یغوث اور یعقوب اور نسر کو کبھی ترک نہ کرنا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliii{پروردگار) انہوں نے بہت لوگوں کو گمراہ کردیا ہے۔ تو تُو ان کو اور گمراہ کردے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxliv{آخر) وہ اپنے گناہوں کے سبب پہلے غرقاب کردیئے گئے پھر آگ میں ڈال دیئے گئے۔ تو انہوں نے خدا کے سوا کسی کو اپنا مددگار نہ پایا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlv{اور (پھر) نوحؑ نے (یہ) دعا کی کہ میرے پروردگار اگر کسی کافر کو روئے زمین پر بسا نہ رہنے دے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvi{اگر تم ان کو رہنے دے گا تو تیرے بندوں کو گمراہ کریں گے اور ان سے جو اولاد ہوگی وہ بھی بدکار اور ناشکر گزار ہوگی\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlvii{اے میرے پروردگار مجھ کو اور میرے ماں باپ کو اور جو ایمان لا کر میرے گھر میں آئے اس کو اور تمام ایمان والے مردوں اور ایمان والی عورتوں کو معاف فرما اور ظالم لوگوں کے لئے اور زیادہ تباہی بڑھا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlviii{\basmalahur (اے پیغمبر لوگوں سے) کہہ دو کہ میرے پاس وحی آئی ہے کہ جنوں کی ایک جماعت نے (اس کتاب کو) سنا تو کہنے لگے کہ ہم نے ایک عجیب قرآن سنا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxlix{جو بھلائی کا رستہ بتاتا ہے سو ہم اس پر ایمان لے آئے۔ اور ہم اپنے پروردگار کے ساتھ کسی کو شریک نہیں بنائیں گے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcdl{اور یہ کہ ہمارے پروردگار کی عظمت (شان) بہت بڑی ہے اور وہ نہ بیوی رکھتا ہے نہ اولاد\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcdli{اور یہ کہ ہم میں سے بعض بےوقوف خدا کے بارے میں جھوٹ افتراء کرتا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlii{اور ہمارا (یہ) خیال تھا کہ انسان اور جن خدا کی نسبت جھوٹ نہیں بولتے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliii{اور یہ کہ بعض بنی آدم بعض جنات کی پناہ پکڑا کرتے تھے (اس سے) ان کی سرکشی اور بڑھ گئی تھی\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcdliv{اور یہ کہ ان کا بھی یہی اعتقاد تھا جس طرح تمہارا تھا کہ خدا کسی کو نہیں جلائے گا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlv{اور یہ کہ ہم نے آسمان کو ٹٹولا تو اس کو مضبوط چوکیداروں اور انگاروں سے سے بھرا پایا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvi{اور یہ کہ پہلے ہم وہاں بہت سے مقامات میں (خبریں) سننے کے لئے بیٹھا کرتے تھے۔ اب کوئی سننا چاہے تو اپنے لئے انگارا تیار پائے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlvii{اور یہ کہ ہمیں معلوم نہیں کہ اس سے اہل زمین کے حق میں برائی مقصود ہے یا ان کے پروردگار نے ان کی بھلائی کا ارادہ فرمایا ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlviii{اور یہ کہ ہم میں کوئی نیک ہیں اور کوئی اور طرح کے۔ ہمارے کئی طرح کے مذہب ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlix{اور یہ کہ ہم نے یقین کرلیا ہے کہ ہم زمین میں (خواہ کہیں ہوں) خدا کو ہرا نہیں سکتے اور نہ بھاگ کر اس کو تھکا سکتے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlx{اور جب ہم نے ہدایت (کی کتاب) سنی اس پر ایمان لے آئے۔ تو جو شخص اپنے پروردگار پر ایمان لاتا ہے اس کو نہ نقصان کا خوف ہے نہ ظلم کا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxi{اور یہ کہ ہم میں بعض فرمانبردار ہیں اور بعض (نافرمان) گنہگار ہیں۔ تو جو فرمانبردار ہوئے وہ سیدھے رستے پر چلے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxii{اور جو گنہگار ہوئے وہ دوزخ کا ایندھن بنے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiii{اور (اے پیغمبر) یہ (بھی ان سے کہہ دو) کہ اگر یہ لوگ سیدھے رستے پر رہتے تو ہم ان کے پینے کو بہت سا پانی دیتے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxiv{تاکہ اس سے ان کی آزمائش کریں۔ اور جو شخص اپنے پروردگار کی یاد سے منہ پھیرے گا وہ اس کو سخت عذاب میں داخل کرے گا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxv{اور یہ کہ مسجدیں (خاص) خدا کی ہیں تو خدا کے ساتھ کسی اور کی عبادت نہ کرو\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvi{اور جب خدا کے بندے (محمدﷺ) اس کی عبادت کو کھڑے ہوئے تو کافر ان کے گرد ہجوم کرلینے کو تھے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxvii{کہہ دو کہ میں تو اپنے پروردگار ہی کی عبادت کرتا ہوں اور کسی کو اس کا شریک نہیں بناتا\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxviii{یہ بھی) کہہ دو کہ میں تمہارے حق میں نقصان اور نفع کا کچھ اختیار نہیں رکھتا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxix{یہ بھی) کہہ دو کہ خدا (کے عذاب) سے مجھے کوئی پناہ نہیں دے سکتا۔ اور میں اس کے سوا کہیں جائے پناہ نہیں دیکھتا\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxx{ہاں خدا کی طرف سے احکام کا اور اس کے پیغاموں کا پہنچا دینا (ہی) میرے ذمے ہے۔ اور جو شخص خدا اور اس کے پیغمبر کی نافرمانی کرے گا تو ایسوں کے لئے جہنم کی آگ ہے ہمیشہ ہمیشہ اس میں رہیں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxi{یہاں تک کہ جب یہ لوگ وہ (دن) دیکھ لیں گے جس کا ان سے وعدہ کیا جاتا ہے تب ان کو معلوم ہو جائے گا کہ مددگار کس کے کمزور اور شمار کن کا تھوڑا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxii{کہہ دو کہ جس (دن) کا تم سے وعدہ کیا جاتا ہے میں نہیں جانتا کہ وہ (عن) قریب (آنے والا ہے) یا میرے پروردگار نے اس کی مدت دراز کر دی ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiii{غیب (کی بات) جاننے والا ہے اور کسی پر اپنے غیب کو ظاہر نہیں کرتا\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxiv{ہاں جس پیغمبر کو پسند فرمائے تو اس (کو غیب کی باتیں بتا دیتا اور اس) کے آگے اور پیچھے نگہبان مقرر کر دیتا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxv{تاکہ معلوم فرمائے کہ انہوں نے اپنے پروردگار کے پیغام پہنچا دیئے ہیں اور (یوں تو) اس نے ان کی سب چیزوں کو ہر طرف سے قابو کر رکھا ہے اور ایک ایک چیز گن رکھی ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvi{\basmalahur اے (محمدﷺ) جو کپڑے میں لپٹ رہے ہو\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxvii{رات کو قیام کیا کرو مگر تھوڑی سی رات\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxviii{قیام) آدھی رات (کیا کرو)\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxix{یا اس سے کچھ کم یا کچھ زیادہ اور قرآن کو ٹھہر ٹھہر کر پڑھا کرو\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxx{ہم عنقریب تم پر ایک بھاری فرمان نازل کریں گے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxi{کچھ شک نہیں کہ رات کا اٹھنا (نفس بہیمی) کو سخت پامال کرتا ہے اور اس وقت ذکر بھی خوب درست ہوتا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxii{دن کے وقت تو تمہیں اور بہت سے شغل ہوتے ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiii{تو اپنے پروردگار کے نام کا ذکر کرو اور ہر طرف سے بےتعلق ہو کر اسی کی طرف متوجہ ہوجاؤ\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxiv{مشرق اور مغرب کا مالک (ہے اور) اس کے سوا کوئی معبود نہیں تو اسی کو اپنا کارساز بناؤ\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxv{اور جو جو (دل آزار) باتیں یہ لوگ کہتے ہیں ان کو سہتے رہو اور اچھے طریق سے ان سے کنارہ کش رہو\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvi{اور مجھے ان جھٹلانے والوں سے جو دولتمند ہیں سمجھ لینے دو اور ان کو تھوڑی سی مہلت دے دو\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxvii{کچھ شک نہیں کہ ہمارے پاس بیڑیاں ہیں اور بھڑکتی ہوئی آگ ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxviii{اور گلوگیر کھانا ہے اور درد دینے والا عذاب (بھی) ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcdlxxxix{جس دن زمین اور پہاڑ کانپنے لگیں اور پہاڑ ایسے بھر بھرے (گویا) ریت کے ٹیلے ہوجائیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxc{اے اہل مکہ) جس طرح ہم نے فرعون کے پاس (موسیٰ کو) پیغمبر (بنا کر) بھیجا تھا (اسی طرح) تمہارے پاس بھی (محمدﷺ) رسول بھیجے ہیں جو تمہارے مقابلے میں گواہ ہوں گے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxci{سو فرعون نے (ہمارے) پیغمبر کا کہا نہ مانا تو ہم نے اس کو بڑے وبال میں پکڑ لیا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcii{اگر تم بھی (ان پیغمبروں کو) نہ مانو گے تو اس دن سے کیونکر بچو گے جو بچّوں کو بوڑھا کر دے گا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciii{اور) جس سے آسمان پھٹ جائے گا۔ یہ اس کا وعدہ (پورا) ہو کر رہے گا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxciv{یہ (قرآن) تو نصیحت ہے۔ سو جو چاہے اپنے پروردگار تک (پہنچنے کا) رستہ اختیار کرلے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcv{تمہارا پروردگار خوب جانتا ہے کہ تم اور تمہارے ساتھ کے لوگ (کبھی) دو تہائی رات کے قریب اور (کبھی) آدھی رات اور (کبھی) تہائی رات قیام کیا کرتے ہو۔ اور خدا تو رات اور دن کا اندازہ رکھتا ہے۔ اس نے معلوم کیا کہ تم اس کو نباہ نہ سکو گے تو اس نے تم پر مہربانی کی۔ پس جتنا آسانی سے ہوسکے (اتنا) قرآن پڑھ لیا کرو۔ اس نے جانا کہ تم میں بعض بیمار بھی ہوتے ہیں اور بعض خدا کے فضل (یعنی معاش) کی تلاش میں ملک میں سفر کرتے ہیں اور بعض خدا کی راہ میں لڑتے ہیں۔ تو جتنا آسانی سے ہوسکے اتنا پڑھ لیا کرو۔ اور نماز پڑھتے رہو اور زکوٰة ادا کرتے رہو اور خدا کو نیک (اور خلوص نیت سے) قرض دیتے رہو۔ اور جو عمل نیک تم اپنے لئے آگے بھیجو گے اس کو خدا کے ہاں بہتر اور صلے میں بزرگ تر پاؤ گے۔ اور خدا سے بخشش مانگتے رہو۔ بےشک خدا بخشنے والا مہربان ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvi{\basmalahur اے (محمدﷺ) جو کپڑا لپیٹے پڑے ہو\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcvii{اُٹھو اور ہدایت کرو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcviii{اور اپنے پروردگار کی بڑائی کرو\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcdxcix{اور اپنے کپڑوں کو پاک رکھو\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmd{اور ناپاکی سے دور رہو\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdi{اور (اس نیت سے) احسان نہ کرو کہ اس سے زیادہ کے طالب ہو\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdii{اور اپنے پروردگار کے لئے صبر کرو\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdiii{جب صور پھونکا جائے گا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdiv{وہ دن کا مشکل دن ہوگا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdv{یعنی) کافروں پر آسان نہ ہوگا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdvi{ہمیں اس شخص سے سمجھ لینے دو جس کو ہم نے اکیلا پیدا کیا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdvii{اور مال کثیر دیا\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdviii{اور (ہر وقت اس کے پاس) حاضر رہنے والے بیٹے دیئے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdix{اور ہر طرح کے سامان میں وسعت دی\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdx{ابھی خواہش رکھتا ہے کہ اور زیادہ دیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdxi{ایسا ہرگز نہیں ہوگا۔ یہ ہماری آیتیں کا دشمن رہا ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdxii{ہم اسے صعود پر چڑھائیں گے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiii{اس نے فکر کیا اور تجویز کی\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdxiv{یہ مارا جائے اس نے کیسی تجویز کی\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdxv{پھر یہ مارا جائے اس نے کیسی تجویز کی\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvi{پھر تامل کیا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdxvii{پھر تیوری چڑھائی اور منہ بگاڑ لیا\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdxviii{پھر پشت پھیر کر چلا اور (قبول حق سے) غرور کیا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdxix{پھر کہنے لگا کہ یہ تو جادو ہے جو (اگلوں سے) منتقل ہوتا آیا ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdxx{پھر بولا) یہ (خدا کا کلام نہیں بلکہ) بشر کا کلام ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxi{ہم عنقریب اس کو سقر میں داخل کریں گے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxii{اور تم کیا سمجھے کہ سقر کیا ہے؟\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiii{وہ آگ ہے کہ) نہ باقی رکھے گی اور نہ چھوڑے گی\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxiv{اور بدن جھلس کر سیاہ کردے گی\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxv{اس پر اُنیس داروغہ ہیں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvi{اور ہم نے دوزخ کے داروغہ فرشتے بنائے ہیں۔ اور ان کا شمار کافروں کی آزمائش کے لئے مقرر کیا ہے (اور) اس لئے کہ اہل کتاب یقین کریں اور مومنوں کا ایمان اور زیادہ ہو اور اہل کتاب اور مومن شک نہ لائیں۔ اور اس لئے کہ جن لوگوں کے دلوں میں (نفاق کا) مرض ہے اور (جو) کافر (ہیں) کہیں کہ اس مثال (کے بیان کرنے) سے خدا کا مقصد کیا ہے؟ اسی طرح خدا جس کو چاہتا ہے گمراہ کرتا ہے اور جس کو چاہتا ہے ہدایت کرتا ہے اور تمہارے پروردگار کے لشکروں کو اس کے سوا کوئی نہیں جانتا۔ اور یہ تو بنی آدم کے لئے نصیحت ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxvii{ہاں ہاں (ہمیں) چاند کی قسم\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxviii{اور رات کی جب پیٹھ پھیرنے لگے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxix{اور صبح کی جب روشن ہو\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxx{کہ وہ (آگ) ایک بہت بڑی (آفت) ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxi{اور) بنی آدم کے لئے مؤجب خوف\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxii{جو تم میں سے آگے بڑھنا چاہے یا پیچھے رہنا چاہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiii{ہر شخص اپنے اعمال کے بدلے گرو ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxiv{مگر داہنی طرف والے (نیک لوگ)\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxv{کہ) وہ باغہائے بہشت میں (ہوں گے اور) پوچھتے ہوں گے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvi{یعنی آگ میں جلنے والے) گنہگاروں سے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxvii{کہ تم دوزخ میں کیوں پڑے؟\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxviii{وہ جواب دیں گے کہ ہم نماز نہیں پڑھتے تھے\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmdxxxix{اور نہ فقیروں کو کھانا کھلاتے تھے\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmdxl{اور اہل باطل کے ساتھ مل کر (حق سے) انکار کرتے تھے\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmdxli{اور روز جزا کو جھٹلاتے تھے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlii{یہاں تک کہ ہمیں موت آگئی\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliii{تو اس حال میں) سفارش کرنے والوں کی سفارش ان کے حق میں کچھ فائدہ نہ دے گی\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmmdxliv{ان کو کیا ہوا ہے کہ نصیحت سے روگرداں ہو رہے ہیں\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlv{گویا گدھے ہیں کہ بدک جاتے ہیں\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvi{یعنی) شیر سے ڈر کر بھاگ جاتے ہیں\qt@no{51}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlvii{اصل یہ ہے کہ ان میں سے ہر شخص یہ چاہتا ہے کہ اس کے پاس کھلی ہوئی کتاب آئے\qt@no{52}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlviii{ایسا ہرگز نہیں ہوگا۔ حقیقت یہ ہے کہ ان کو آخرت کا خوف ہی نہیں\qt@no{53}}%
\qt@newcmd\qurantrans@ur@mmmmmdxlix{کچھ شک نہیں کہ یہ نصیحت ہے\qt@no{54}}%
\qt@newcmd\qurantrans@ur@mmmmmdl{تو جو چاہے اسے یاد رکھے\qt@no{55}}%
\qt@newcmd\qurantrans@ur@mmmmmdli{اور یاد بھی تب ہی رکھیں گے جب خدا چاہے۔ وہی ڈرنے کے لائق اور بخشش کا مالک ہے\qt@no{56}}%
\qt@newcmd\qurantrans@ur@mmmmmdlii{\basmalahur ہم کو روز قیامت کی قسم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdliii{اور نفس لوامہ کی (کہ سب لوگ اٹھا کر) کھڑے کئے جائیں گے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdliv{کیا انسان یہ خیال کرتا ہے کہ ہم اس کی (بکھری ہوئی) ہڈیاں اکٹھی نہیں کریں گے؟\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdlv{ضرور کریں گے (اور) ہم اس بات پر قادر ہیں کہ اس کی پور پور درست کردیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvi{مگر انسان چاہتا ہے کہ آگے کو خود سری کرتا جائے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdlvii{پوچھتا ہے کہ قیامت کا دن کب ہوگا؟\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdlviii{جب آنکھیں چندھیا جائیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdlix{اور چاند گہنا جائے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdlx{اور سورج اور چاند جمع کردیئے جائیں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxi{اس دن انسان کہے گا کہ (اب) کہاں بھاگ جاؤں؟\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxii{بےشک کہیں پناہ نہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiii{اس روز پروردگار ہی کے پاس ٹھکانا ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxiv{اس دن انسان کو جو (عمل) اس نے آگے بھیجے اور پیچھے چھوڑے ہوں گے سب بتا دیئے جائیں گے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxv{بلکہ انسان آپ اپنا گواہ ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvi{اگرچہ عذر ومعذرت کرتا رہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxvii{اور (اے محمدﷺ) وحی کے پڑھنے کے لئے اپنی زبان نہ چلایا کرو کہ اس کو جلد یاد کرلو\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxviii{اس کا جمع کرنا اور پڑھانا ہمارے ذمے ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxix{جب ہم وحی پڑھا کریں تو تم (اس کو سنا کرو اور) پھر اسی طرح پڑھا کرو\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxx{پھر اس (کے معانی) کا بیان بھی ہمارے ذمے ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxi{مگر (لوگو) تم دنیا کو دوست رکھتے ہو\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxii{اور آخرت کو ترک کئے دیتے ہو\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiii{اس روز بہت سے منہ رونق دار ہوں گے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxiv{اور) اپنے پروردگار کے محو دیدار ہوں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxv{اور بہت سے منہ اس دن اداس ہوں گے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvi{خیال کریں گے کہ ان پر مصیبت واقع ہونے کو ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxvii{دیکھو جب جان گلے تک پہنچ جائے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxviii{اور لوگ کہنے لگیں (اس وقت) کون جھاڑ پھونک کرنے والا ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxix{اور اس (جان بلب) نے سمجھا کہ اب سب سے جدائی ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxx{اور پنڈلی سے پنڈلی لپٹ جائے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxi{اس دن تجھ کو اپنے پروردگار کی طرف چلنا ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxii{تو اس (ناعاقبت) اندیش نے نہ تو (کلام خدا) کی تصدیق کی نہ نماز پڑھی\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiii{بلکہ جھٹلایا اور منہ پھیر لیا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxiv{پھر اپنے گھر والوں کے پاس اکڑتا ہوا چل دیا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxv{افسوس ہے تجھ پر پھر افسوس ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvi{پھر افسوس ہے تجھ پر پھر افسوس ہے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxvii{کیا انسان خیال کرتا ہے کہ یوں ہی چھوڑ دیا جائے گا؟\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxviii{کیا وہ منی کا جو رحم میں ڈالی جاتی ہے ایک قطرہ نہ تھا؟\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdlxxxix{پھر لوتھڑا ہوا پھر (خدا نے) اس کو بنایا پھر (اس کے اعضا کو) درست کیا\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdxc{پھر اس کی دو قسمیں بنائیں (ایک) مرد اور (ایک) عورت\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdxci{کیا اس خالق کو اس بات پر قدرت نہیں کہ مردوں کو جلا اُٹھائے؟\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcii{\basmalahur بےشک انسان پر زمانے میں ایک ایسا وقت بھی آچکا ہے کہ وہ کوئی چیز قابل ذکر نہ تھی\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciii{ہم نے انسان کو نطفہٴ مخلوط سے پیدا کیا تاکہ اسے آزمائیں تو ہم نے اس کو سنتا دیکھتا بنایا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdxciv{اور) اسے رستہ بھی دکھا دیا۔ (اب) وہ خواہ شکرگزار ہو خواہ ناشکرا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcv{ہم نے کافروں کے لئے زنجیر اور طوق اور دہکتی آگ تیار کر رکھی ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvi{جو نیکو کار ہیں اور وہ ایسی شراب نوش جان کریں گے جس میں کافور کی آمیزش ہوگی\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcvii{یہ ایک چشمہ ہے جس میں سے خدا کے بندے پئیں گے اور اس میں سے (چھوٹی چھوٹی) نہریں نکالیں گے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcviii{یہ لوگ نذریں پوری کرتے ہیں اور اس دن سے جس کی سختی پھیل رہی ہوگی خوف رکھتے ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdxcix{اور باوجود یہ کہ ان کو خود طعام کی خواہش (اور حاجت) ہے فقیروں اور یتیموں اور قیدیوں کو کھلاتے ہیں\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdc{اور کہتے ہیں کہ) ہم تم کو خالص خدا کے لئے کھلاتے ہیں۔ نہ تم سے عوض کے خواستگار ہیں نہ شکرگزاری کے (طلبگار)\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdci{ہم کو اپنے پروردگار سے اس دن کا ڈر لگتا ہے (جو چہروں کو) کریہہ المنظر اور (دلوں کو) سخت (مضطر کر دینے والا) ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcii{تو خدا ان کو اس دن کی سختی سے بچالے گا اور تازگی اور خوش دلی عنایت فرمائے گا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdciii{اور ان کے صبر کے بدلے ان کو بہشت (کے باغات) اور ریشم (کے ملبوسات) عطا کرے گا\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdciv{ان میں وہ تختوں پر تکیے لگائے بیٹھے ہوں گے۔ وہاں نہ دھوپ (کی حدت) دیکھیں گے نہ سردی کی شدت\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcv{ان سے (ثمردار شاخیں اور) ان کے سائے قریب ہوں گے اور میوؤں کے گچھے جھکے ہوئے لٹک رہے ہوں گے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvi{خدام) چاندی کے باسن لئے ہوئے ان کے اردگرد پھریں گے اور شیشے کے (نہایت شفاف) گلاس\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdcvii{اور شیشے بھی چاندی کے جو ٹھیک اندازے کے مطابق بنائے گئے ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdcviii{اور وہاں ان کو ایسی شراب (بھی) پلائی جائے گی جس میں سونٹھ کی آمیزش ہوگی\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcix{یہ بہشت میں ایک چشمہ ہے جس کا نام سلسبیل ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcx{اور ان کے پاس لڑکے آتے جاتے ہوں گے جو ہمیشہ (ایک ہی حالت پر) رہیں گے۔ جب تم ان پر نگاہ ڈالو تو خیال کرو کہ بکھرے ہوئے موتی ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxi{اور بہشت میں (جہاں) آنکھ اٹھاؤ گے کثرت سے نعمت اور عظیم (الشان) سلطنت دیکھو گے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxii{ان (کے بدنوں) پر دیبا سبز اور اطلس کے کپڑے ہوں گے۔ اور انہیں چاندی کے کنگن پہنائے جائیں گے اور ان کا پروردگار ان کو نہایت پاکیزہ شراب پلائے گا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiii{یہ تمہارا صلہ اور تمہاری کوشش (خدا کے ہاں) مقبول ہوئی\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxiv{اے محمد (ﷺ) ہم نے تم پر قرآن آہستہ آہستہ نازل کیا ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxv{تو اپنے پروردگار کے حکم کے مطابق صبر کئے رہو اور ان لوگوں میں سے کسی بد عمل اور ناشکرے کا کہا نہ مانو\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvi{اور صبح وشام اپنے پروردگار کا نام لیتے رہو\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxvii{اور رات کو بڑی رات تک سجدے کرو اور اس کی پاکی بیان کرتے رہو\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxviii{یہ لوگ دنیا کو دوست رکھتے ہیں اور (قیامت کے) بھاری دن کو پس پشت چھوڑے دیتے ہیں\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxix{ہم نے ان کو پیدا کیا اور ان کے مقابل کو مضبوط بنایا۔ اور اگر ہم چاہیں تو ان کے بدلے ان ہی کی طرح اور لوگ لے آئیں\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxx{یہ تو نصیحت ہے۔ جو چاہے اپنے پروردگار کی طرف پہنچنے کا رستہ اختیار کرے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxi{اور تم کچھ بھی نہیں چاہ سکتے مگر جو خدا کو منظور ہو۔ بےشک خدا جاننے والا حکمت والا ہے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxii{جس کو چاہتا ہے اپنی رحمت میں داخل کرلیتا ہے اور ظالموں کے لئے اس نے دکھ دینے والا عذاب تیار کر رکھا ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiii{\basmalahur ہواؤں کی قسم جو نرم نرم چلتی ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxiv{پھر زور پکڑ کر جھکڑ ہو جاتی ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxv{اور (بادلوں کو) پھاڑ کر پھیلا دیتی ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvi{پھر ان کو پھاڑ کر جدا جدا کر دیتی ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxvii{پھر فرشتوں کی قسم جو وحی لاتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxviii{تاکہ عذر (رفع) کردیا جائے یا ڈر سنا دیا جائے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxix{کہ جس بات کا تم سے وعدہ کیا جاتا ہے وہ ہو کر رہے گی\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxx{جب تاروں کی چمک جاتی رہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxi{اور جب آسمان پھٹ جائے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxii{اور جب پہاڑ اُڑے اُڑے پھریں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiii{اور جب پیغمبر فراہم کئے جائیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxiv{بھلا (ان امور میں) تاخیر کس دن کے لئے کی گئی؟\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxv{فیصلے کے دن کے لئے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvi{اور تمہیں کیا خبر کہ فیصلے کا دن کیا ہے؟\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxvii{اس دن جھٹلانے والوں کے لئے خرابی ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxviii{کیا ہم نے پہلے لوگوں کو ہلاک نہیں کر ڈالا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxxxix{پھر ان پچھلوں کو بھی ان کے پیچھے بھیج دیتے ہیں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxl{ہم گنہگاروں کے ساتھ ایسا ہی کیا کرتے ہیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxli{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlii{کیا ہم نے تم کو حقیر پانی سے نہیں پیدا کیا؟\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliii{اس کو ایک محفوظ جگہ میں رکھا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxliv{ایک وقت معین تک\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlv{پھر اندازہ مقرر کیا اور ہم کیا ہی خوب اندازہ مقرر کرنے والے ہیں\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvi{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlvii{کیا ہم نے زمین کو سمیٹنے والی نہیں بنایا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlviii{یعنی) زندوں اور مردوں کو\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxlix{بنایا) اور اس پر اونچے اونچے پہاڑ رکھ دیئے اور تم لوگوں کو میٹھا پانی پلایا\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdcl{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdcli{جس چیز کو تم جھٹلایا کرتے تھے۔ (اب) اس کی طرف چلو\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdclii{یعنی) اس سائے کی طرف چلو جس کی تین شاخیں ہیں\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliii{نہ ٹھنڈی چھاؤں اور نہ لپٹ سے بچاؤ\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdcliv{اس سے (آگ کی اتنی اتنی بڑی) چنگاریاں اُڑتی ہیں جیسے محل\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdclv{گویا زرد رنگ کے اونٹ ہیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvi{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdclvii{یہ وہ دن ہے کہ (لوگ) لب تک نہ ہلا سکیں گے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdclviii{اور نہ ان کو اجازت دی جائے گی کہ عذر کرسکیں\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdclix{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdclx{یہی فیصلے کا دن ہے (جس میں) ہم نے تم کو اور پہلے لوگوں کو جمع کیا ہے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxi{اگر تم کو کوئی داؤں آتا ہو تو مجھ سے کر لو\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxii{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiii{بےشک پرہیزگار سایوں اور چشموں میں ہوں گے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxiv{اور میؤوں میں جو ان کو مرغوب ہوں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxv{اور جو عمل تم کرتے رہے تھے ان کے بدلے میں مزے سے کھاؤ اور پیو\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvi{ہم نیکو کاروں کو ایسا ہی بدلہ دیا کرتے ہیں\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxvii{اس دن جھٹلانے والوں کی خرابی ہوگی\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxviii{اے جھٹلانے والو!) تم کسی قدر کھا لو اور فائدے اُٹھا لو تم بےشک گنہگار ہو\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxix{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{47}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxx{اور جب ان سے کہا جاتا ہے کہ (خدا کے آگے) جھکو تو جھکتے نہیں\qt@no{48}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxi{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{49}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxii{اب اس کے بعد یہ کون سی بات پر ایمان لائیں گے؟\qt@no{50}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiii{\basmalahur (یہ) لوگ کس چیز کی نسبت پوچھتے ہیں؟\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxiv{کیا) بڑی خبر کی نسبت؟\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxv{جس میں یہ اختلاف کر رہے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvi{دیکھو یہ عنقریب جان لیں گے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxvii{پھر دیکھو یہ عنقریب جان لیں گے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxviii{کیا ہم نے زمین کو بچھونا نہیں بنایا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxix{اور پہاڑوں کو (ا س کی) میخیں (نہیں ٹھہرایا؟)\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxx{بے شک بنایا) اور تم کو جوڑا جوڑابھی پیدا کیا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxi{اور نیند کو تمہارے لیے (موجب) آرام بنایا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxii{اور رات کو پردہ مقرر کیا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiii{اور دن کو معاش (کا وقت) قرار دیا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxiv{اور تمہارے اوپر سات مضبوط (آسمان) بنائے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxv{اور (آفتاب کا) روشن چراغ بنایا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvi{اور نچڑتے بادلوں سے موسلا دھار مینہ برسایا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxvii{تاکہ اس سے اناج اور سبزہ پیدا کریں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxviii{اور گھنے گھنے باغ\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdclxxxix{بےشک فیصلہ کا دن مقرر ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxc{جس دن صور پھونکا جائے گا تو تم لوگ غٹ کے غٹ آ موجود ہو گے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxci{اور آسمان کھولا جائے گا تو (اس میں) دروازے ہو جائیں گے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcii{اور پہاڑ چلائے جائیں گے تو وہ ریت ہو کر رہ جائیں گے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciii{بےشک دوزخ گھات میں ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxciv{یعنی) سرکشوں کا وہی ٹھکانہ ہے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcv{اس میں وہ مدتوں پڑے رہیں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvi{وہاں نہ ٹھنڈک کا مزہ چکھیں گے۔ نہ (کچھ) پینا (نصیب ہو گا)\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcvii{مگر گرم پانی اور بہتی پیپ\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcviii{یہ) بدلہ ہے پورا پورا\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdcxcix{یہ لوگ حساب (آخرت) کی امید ہی نہیں رکھتے تھے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdcc{اور ہماری آیتوں کو جھوٹ سمجھ کر جھٹلاتے رہتے تھے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdcci{اور ہم نے ہر چیز کو لکھ کر ضبط کر رکھا ہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdccii{سو (اب) مزہ چکھو۔ ہم تم پر عذاب ہی بڑھاتے جائیں گے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciii{بے شک پرہیز گاروں کے لیے کامیابی ہے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdcciv{یعنی) باغ اور انگور\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdccv{اور ہم عمر نوجوان عورتیں\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvi{اور شراب کے چھلکتے ہوئے گلاس\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdccvii{وہاں نہ بیہودہ بات سنیں گے نہ جھوٹ (خرافات)\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdccviii{یہ تمہارے پروردگار کی طرف سے صلہ ہے انعام کثیر\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdccix{وہ جو آسمانوں اور زمین اور جو ان دونوں میں ہے سب کا مالک ہے بڑا مہربان کسی کو اس سے بات کرنے کا یارا نہیں ہوگا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdccx{جس دن روح (الامین) اور فرشتے صف باندھ کر کھڑے ہوں گے تو کوئی بول نہ سکے گا مگر جس کو (خدائے رحمٰن) اجازت بخشے اور اس نے بات بھی درست کہی ہو\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxi{یہ دن برحق ہے۔ پس جو شخص چاہے اپنے پروردگار کے پاس ٹھکانہ بنا ئے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxii{ہم نے تم کو عذاب سے جو عنقریب آنے والا ہے آگاہ کر دیا ہے جس دن ہر شخص ان (اعمال) کو جو اس نے آگے بھیجے ہوں گے دیکھ لے گا اور کافر کہے گا کہ اے کاش میں مٹی ہوتا\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiii{\basmalahur ان (فرشتوں) کی قسم جو ڈوب کر کھینچ لیتے ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxiv{اور ان کی جو آسانی سے کھول دیتے ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxv{اور ان کی جو تیرتے پھرتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvi{پھر لپک کر آگے بڑھتے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxvii{پھر (دنیا کے) کاموں کا انتظام کرتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxviii{کہ وہ دن آ کر رہے گا) جس دن زمین کو بھونچال آئے گا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxix{پھر اس کے پیچھے اور (بھونچال) آئے گا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxx{اس دن (لوگوں) کے دل خائف ہو رہے ہوں گے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxi{اور آنکھیں جھکی ہوئی\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxii{کافر) کہتے ہیں کیا ہم الٹے پاؤں پھر لوٹ جائیں گے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiii{بھلا جب ہم کھوکھلی ہڈیاں ہو جائیں گے (تو پھر زندہ کئے جائیں گے)\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxiv{کہتے ہیں کہ یہ لوٹنا تو (موجب) زیاں ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxv{وہ تو صرف ایک ڈانٹ ہوگی\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvi{اس وقت وہ (سب) میدان (حشر) میں آ جمع ہوں گے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxvii{بھلا تم کو موسیٰ کی حکایت پہنچی ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxviii{جب اُن کے پروردگار نے ان کو پاک میدان (یعنی) طویٰ میں پکارا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxix{اور حکم دیا) کہ فرعون کے پاس جاؤ وہ سرکش ہو رہا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxx{اور (اس سے) کہو کہ کیا تو چاہتا ہے کہ پاک ہو جائے؟\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxi{اور میں تجھے تیرے پروردگار کا رستہ بتاؤں تاکہ تجھ کو خوف (پیدا) ہو\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxii{غرض انہوں نے اس کو بڑی نشانی دکھائی\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiii{مگر اس نے جھٹلایا اور نہ مانا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxiv{پھر لوٹ گیا اور تدبیریں کرنے لگا\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxv{اور (لوگوں کو) اکٹھا کیا اور پکارا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvi{کہنے لگا کہ تمہارا سب سے بڑا مالک میں ہوں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxvii{تو خدا نے اس کو دنیا اور آخرت (دونوں) کے عذاب میں پکڑ لیا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxviii{جو شخص (خدا سے) ڈر رکھتا ہے اس کے لیے اس (قصے) میں عبرت ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxxxix{بھلا تمہارا بنانا آسان ہے یا آسمان کا؟ اسی نے اس کو بنایا\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxl{اس کی چھت کو اونچا کیا اور پھر اسے برابر کر دیا\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxli{اور اسی نے رات کو تاریک بنایا اور (دن کو) دھوپ نکالی\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlii{اور اس کے بعد زمین کو پھیلا دیا\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliii{اسی نے اس میں سے اس کا پانی نکالا اور چارا اگایا\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxliv{اور اس پر پہاڑوں کابوجھ رکھ دیا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlv{یہ سب کچھ تمہارے اور تمہارے چارپایوں کے فائدے کے لیے (کیا)\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvi{تو جب بڑی آفت آئے گی\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlvii{اس دن انسان اپنے کاموں کو یاد کرے گا\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlviii{اور دوزخ دیکھنے والے کے سامنے نکال کر رکھ دی جائے گی\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxlix{تو جس نے سرکشی کی\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdccl{اور دنیا کی زندگی کو مقدم سمجھا\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdccli{اس کا ٹھکانہ دوزخ ہے\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclii{اور جو اپنے پروردگار کے سامنے کھڑے ہونے سے ڈرتا اور جی کو خواہشوں سے روکتا رہا\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliii{اس کا ٹھکانہ بہشت ہے\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmdccliv{اے پیغمبر، لوگ) تم سے قیامت کے بارے میں پوچھتے ہیں کہ اس کا وقوع کب ہو گا؟\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclv{سو تم اس کے ذکر سے کس فکر میں ہو\qt@no{43}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvi{اس کا منتہا (یعنی واقع ہونے کا وقت) تمہارے پروردگار ہی کو (معلوم ہے)\qt@no{44}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclvii{جو شخص اس سے ڈر رکھتا ہے تم تو اسی کو ڈر سنانے والے ہو\qt@no{45}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclviii{جب وہ اس کو دیکھیں گے (تو ایسا خیال کریں گے) کہ گویا (دنیا میں صرف) ایک شام یا صبح رہے تھے\qt@no{46}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclix{\basmalahur (محمد مصطفٰےﷺ) ترش رُو ہوئے اور منہ پھیر بیٹھے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclx{کہ ان کے پاس ایک نابینا آیا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxi{اور تم کو کیا خبر شاید وہ پاکیزگی حاصل کرتا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxii{یا سوچتا تو سمجھانا اسے فائدہ دیتا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiii{جو پروا نہیں کرتا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxiv{اس کی طرف تو تم توجہ کرتے ہو\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxv{حالانکہ اگر وہ نہ سنورے تو تم پر کچھ (الزام) نہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvi{اور جو تمہارے پاس دوڑتا ہوا آیا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxvii{اور (خدا سے) ڈرتا ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxviii{اس سے تم بےرخی کرتے ہو\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxix{دیکھو یہ (قرآن) نصیحت ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxx{پس جو چاہے اسے یاد رکھے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxi{قابل ادب ورقوں میں (لکھا ہوا)\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxii{جو بلند مقام پر رکھے ہوئے (اور) پاک ہیں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiii{لکھنے والوں کے ہاتھوں میں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxiv{جو سردار اور نیکو کار ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxv{انسان ہلاک ہو جائے کیسا ناشکرا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvi{اُسے (خدا نے) کس چیز سے بنایا؟\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxvii{نطفے سے بنایا پھر اس کا اندازہ مقرر کیا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxviii{پھر اس کے لیے رستہ آسان کر دیا\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxix{پھر اس کو موت دی پھر قبر میں دفن کرایا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxx{پھر جب چاہے گا اسے اٹھا کھڑا کرے گا\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxi{کچھ شک نہیں کہ خدا نے اسے جو حکم دیا اس نے اس پر عمل نہ کیا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxii{تو انسان کو چاہیئے کہ اپنے کھانے کی طرف نظر کرے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiii{بے شک ہم ہی نے پانی برسایا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxiv{پھر ہم ہی نے زمین کو چیرا پھاڑا\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxv{پھر ہم ہی نے اس میں اناج اگایا\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvi{اور انگور اور ترکاری\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxvii{اور زیتون اور کھجوریں\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxviii{اور گھنے گھنے باغ\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdcclxxxix{اور میوے اور چارا\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxc{یہ سب کچھ) تمہارے اور تمہارے چارپایوں کے لیے بنایا\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxci{تو جب (قیامت کا) غل مچے گا\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcii{اس دن آدمی اپنے بھائی سے دور بھاگے گا\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciii{اور اپنی ماں اور اپنے باپ سے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxciv{اور اپنی بیوی اور اپنے بیٹے سے\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcv{ہر شخص اس روز ایک فکر میں ہو گا جو اسے (مصروفیت کے لیے) بس کرے گا\qt@no{37}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvi{اور کتنے منہ اس روز چمک رہے ہوں گے\qt@no{38}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcvii{خنداں و شاداں (یہ مومنان نیکو کار ہیں)\qt@no{39}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcviii{اور کتنے منہ ہوں گے جن پر گرد پڑ رہی ہو گی\qt@no{40}}%
\qt@newcmd\qurantrans@ur@mmmmmdccxcix{اور) سیاہی چڑھ رہی ہو گی\qt@no{41}}%
\qt@newcmd\qurantrans@ur@mmmmmdccc{یہ کفار بدکردار ہیں\qt@no{42}}%
\qt@newcmd\qurantrans@ur@mmmmmdccci{\basmalahur جب سورج لپیٹ لیا جائے گا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccii{جب تارے بےنور ہو جائیں گے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciii{اور جب پہاڑ چلائے جائیں گے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdccciv{اور جب بیانے والی اونٹنیاں بےکار ہو جائیں گی\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccv{اور جب وحشی جانور جمع اکٹھے ہو جائیں گے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvi{اور جب دریا آگ ہو جائیں گے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccvii{اور جب روحیں (بدنوں سے) ملا دی جائیں گی\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccviii{اور جب لڑکی سے جو زندہ دفنا دی گئی ہو پوچھا جائے گا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccix{کہ وہ کس گناہ پرماری گئی\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccx{اور جب (عملوں کے) دفتر کھولے جائیں گے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxi{اور جب آسمانوں کی کھال کھینچ لی جائے گی\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxii{اور جب دوزخ (کی آگ) بھڑکائی جائے گی\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiii{اور بہشت جب قریب لائی جائے گی\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxiv{تب ہر شخص معلوم کر لے گا کہ وہ کیا لے کر آیا ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxv{ہم کو ان ستاروں کی قسم جو پیچھے ہٹ جاتے ہیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvi{اور) جو سیر کرتے اور غائب ہو جاتے ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxvii{اور رات کی قسم جب ختم ہونے لگتی ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxviii{اور صبح کی قسم جب نمودار ہوتی ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxix{کہ بےشک یہ (قرآن) فرشتہٴ عالی مقام کی زبان کا پیغام ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxx{جو صاحب قوت مالک عرش کے ہاں اونچے درجے والا ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxi{سردار (اور) امانت دار ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxii{اور (مکے والو) تمہارے رفیق (یعنی محمدﷺ) دیوانے نہیں ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiii{بےشک انہوں نے اس (فرشتے) کو (آسمان کے کھلے یعنی) مشرقی کنارے پر دیکھا ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxiv{اور وہ پوشیدہ باتوں (کے ظاہر کرنے) میں بخیل نہیں\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxv{اور یہ شیطان مردود کا کلام نہیں\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvi{پھر تم کدھر جا رہے ہو\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxvii{یہ تو جہان کے لوگوں کے لیے نصیحت ہے\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxviii{یعنی) اس کے لیے جو تم میں سے سیدھی چال چلنا چاہے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxix{اور تم کچھ بھی نہیں چاہ سکتے مگر وہی جو خدائے رب العالمین چاہے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxx{\basmalahur جب آسمان پھٹ جائے گا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxi{اور جب تارے جھڑ پڑیں گے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxii{اور جب دریا بہہ (کر ایک دوسرے سے مل) جائیں گے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiii{اور جب قبریں اکھیڑ دی جائیں گی\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxiv{تب ہر شخص معلوم کرلے گا کہ اس نے آگے کیا بھیجا تھا اور پیچھے کیا چھوڑا تھا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxv{اے انسان تجھ کو اپنے پروردگار کرم گستر کے باب میں کس چیز نے دھوکا دیا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvi{وہی تو ہے) جس نے تجھے بنایا اور (تیرے اعضا کو) ٹھیک کیا اور (تیرے قامت کو) معتدل رکھا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxvii{اور جس صورت میں چاہا تجھے جوڑ دیا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxviii{مگر ہیہات تم لوگ جزا کو جھٹلاتے ہو\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxxxix{حالانکہ تم پر نگہبان مقرر ہیں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxl{عالی قدر (تمہاری باتوں کے) لکھنے والے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxli{جو تم کرتے ہو وہ اسے جانتے ہیں\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlii{بے شک نیکوکار نعمتوں (کی بہشت) میں ہوں گے۔\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliii{اور بدکردار دوزخ میں\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxliv{یعنی) جزا کے دن اس میں داخل ہوں گے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlv{اور اس سے چھپ نہیں سکیں گے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvi{اور تمہیں کیا معلوم کہ جزا کا دن کیسا ہے؟\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlvii{پھر تمہیں کیا معلوم کہ جزا کا دن کیسا ہے؟\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlviii{جس روز کوئی کسی کا بھلا نہ کر سکے گا اور حکم اس روز خدا ہی کا ہو گا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxlix{\basmalahur ناپ اور تول میں کمی کرنے والوں کے لیے خرابی ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccl{جو لوگوں سے ناپ کر لیں تو پورا لیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccli{اور جب ان کو ناپ کر یا تول کر دیں تو کم کر دیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclii{کیا یہ لوگ نہیں جانتے کہ اٹھائے بھی جائیں گے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliii{یعنی) ایک بڑے (سخت) دن میں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccliv{جس دن (تمام) لوگ رب العالمین کے سامنے کھڑے ہوں گے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclv{سن رکھو کہ بدکارروں کے اعمال سجّین میں ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvi{اور تم کیا جانتے ہوں کہ سجّین کیا چیز ہے؟\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclvii{ایک دفتر ہے لکھا ہوا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclviii{اس دن جھٹلانے والوں کی خرابی ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclix{یعنی) جو انصاف کے دن کو جھٹلاتے ہیں\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclx{اور اس کو جھٹلاتا وہی ہے جو حد سے نکل جانے والا گنہگار ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxi{جب اس کو ہماری آیتیں سنائی جاتی ہیں تو کہتا ہے کہ یہ تو اگلے لوگوں کے افسانے ہیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxii{دیکھو یہ جو (اعمال بد) کرتے ہیں ان کا ان کے دلوں پر زنگ بیٹھ گیا ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiii{بےشک یہ لوگ اس روز اپنے پروردگار (کے دیدار) سے اوٹ میں ہوں گے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxiv{پھر دوزخ میں جا داخل ہوں گے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxv{پھر ان سے کہا جائے گا کہ یہ وہی چیز ہے جس کو تم جھٹلاتے تھے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvi{یہ بھی) سن رکھو کہ نیکوکاروں کے اعمال علیین میں ہیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxvii{اور تم کو کیا معلوم کہ علیین کیا چیز ہے؟\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxviii{ایک دفتر ہے لکھا ہوا\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxix{جس کے پاس مقرب (فرشتے) حاضر رہتے ہیں\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxx{بےشک نیک لوگ چین میں ہوں گے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxi{تختوں پر بیٹھے ہوئے نظارے کریں گے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxii{تم ان کے چہروں ہی سے راحت کی تازگی معلوم کر لو گے\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiii{ان کو خالص شراب سربمہر پلائی جائے گی\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxiv{جس کی مہر مشک کی ہو گی تو (نعمتوں کے) شائقین کو چاہیے کہ اسی سے رغبت کریں\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxv{اور اس میں تسنیم (کے پانی) کی آمیزش ہو گی\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvi{وہ ایک چشمہ ہے جس میں سے (خدا کے) مقرب پیئیں گے\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxvii{جو گنہگار (یعنی کفار) ہیں وہ (دنیا میں) مومنوں سے ہنسی کیا کرتے تھے\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxviii{اور جب ان کے پاس سے گزرتے تو حقارت سے اشارے کرتے\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxix{اور جب اپنے گھر کو لوٹتے تو اتراتے ہوئے لوٹتے\qt@no{31}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxx{اور جب ان (مومنوں) کو دیکھتے تو کہتے کہ یہ تو گمراہ ہیں\qt@no{32}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxi{حالانکہ وہ ان پر نگراں بنا کر نہیں بھیجے گئے تھے\qt@no{33}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxii{تو آج مومن کافروں سے ہنسی کریں گے\qt@no{34}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiii{اور) تختوں پر (بیٹھے ہوئے ان کا حال) دیکھ رہے ہوں گے\qt@no{35}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxiv{تو کافروں کو ان کے عملوں کا (پورا پورا) بدلہ مل گیا\qt@no{36}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxv{\basmalahur جب آسمان پھٹ جائے گا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvi{اور اپنے پروردگار کا فرمان بجا لائے گا اور اسے واجب بھی یہ ہی ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxvii{اور جب زمین ہموار کر دی جائے گی\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxviii{جو کچھ اس میں ہے اسے نکال کر باہر ڈال دے گی اور (بالکل) خالی ہو جائے گی\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmdccclxxxix{اور اپنے پروردگار کے ارشاد کی تعمیل کرے گی اور اس کو لازم بھی یہی ہے (تو قیامت قائم ہو جائے گی)\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxc{اے انسان! تو اپنے پروردگار کی طرف (پہنچنے میں) خوب کوشِش کرتا ہے سو اس سے جا ملے گا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxci{تو جس کا نامہٴ (اعمال) اس کے داہنے ہاتھ میں دیا جائے گا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcii{اس سے حساب آسان لیا جائے گا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciii{اور وہ اپنے گھر والوں میں خوش خوش آئے گا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxciv{اور جس کا نامہٴ (اعمال) اس کی پیٹھ کے پیچھے سے دیا جائے گا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcv{وہ موت کو پکارے گا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvi{اور وہ دوزخ میں داخل ہو گا\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcvii{یہ اپنے اہل (و عیال) میں مست رہتا تھا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcviii{اور خیال کرتا تھا کہ (خدا کی طرف) پھر کر نہ جائے گا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmdcccxcix{ہاں ہاں۔ اس کا پروردگار اس کو دیکھ رہا تھا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcm{ہمیں شام کی سرخی کی قسم\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcmi{اور رات کی اور جن چیزوں کو وہ اکٹھا کر لیتی ہے ان کی\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcmii{اور چاند کی جب کامل ہو جائے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiii{کہ تم درجہ بدرجہ (رتبہٴ اعلیٰ پر) چڑھو گے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcmiv{تو ان لوگوں کو کیا ہوا ہے کہ ایمان نہیں لاتے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcmv{اور جب ان کے سامنے قرآن پڑھا جاتا ہے تو سجدہ نہیں کرتے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvi{بلکہ کافر جھٹلاتے ہیں\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcmvii{اور خدا ان باتوں کو جو یہ اپنے دلوں میں چھپاتے ہیں خوب جانتا ہے\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcmviii{تو ان کو دکھ دینے والے عذاب کی خبر سنا دو\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcmix{ہاں جو لوگ ایمان لائے اور نیک عمل کرتے رہے ان کے لیے بےانتہا اجر ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcmx{\basmalahur آسمان کی قسم جس میں برج ہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxi{اور اس دن کی جس کا وعدہ ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxii{اور حاضر ہونے والے کی اور جو اس کے پاس حاضر کیا جائے اسکی\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiii{کہ خندقوں (کے کھودنے) والے ہلاک کر دیئے گئے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxiv{یعنی) آگ (کی خندقیں) جس میں ایندھن (جھونک رکھا) تھا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxv{جب کہ وہ ان (کے کناروں) پر بیٹھے ہوئے تھے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvi{اور جو (سختیاں) اہل ایمان پر کر رہے تھے ان کو سامنے دیکھ رہے تھے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxvii{ان کو مومنوں کی یہی بات بری لگتی تھی کہ وہ خدا پر ایمان لائے ہوئے تھے جو غالب (اور) قابل ستائش ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxviii{وہی جس کی آسمانوں اور زمین میں بادشاہت ہے۔ اور خدا ہر چیز سے واقف ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxix{جن لوگوں نے مومن مردوں اور مومن عورتوں کو تکلیفیں دیں اور توبہ نہ کی ان کو دوزخ کا (اور) عذاب بھی ہوگا اور جلنے کا عذاب بھی ہوگا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxx{اور) جو لوگ ایمان لائے اور نیک کام کرتے رہے ان کے لیے باغات ہیں جن کے نیچے نہریں بہہ رہی ہیں۔ یہ ہی بڑی کامیابی ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxi{بےشک تمہارے پروردگار کی پکڑ بڑی سخت ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxii{وہی پہلی دفعہ پیدا کرتا ہے اور وہی دوبارہ (زندہ) کرے گا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiii{اور وہ بخشنے والا اور محبت کرنے والا ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxiv{عرش کا مالک بڑی شان والا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxv{جو چاہتا ہے کر دیتا ہے\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvi{بھلا تم کو لشکروں کا حال معلوم ہوا ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxvii{یعنی) فرعون اور ثمود کا\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxviii{لیکن کافر (جان بوجھ کر) تکذیب میں (گرفتار) ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxix{اور خدا (بھی) ان کو گردا گرد سے گھیرے ہوئے ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxx{یہ کتاب ہزل و بطلان نہیں) بلکہ یہ قرآن عظیم الشان ہے\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxi{لوح محفوظ میں (لکھا ہوا)\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxii{\basmalahur آسمان اور رات کے وقت آنے والے کی قسم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiii{اور تم کو کیا معلوم کہ رات کے وقت آنے والا کیا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxiv{وہ تارا ہے چمکنے والا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxv{کہ کوئی متنفس نہیں جس پر نگہبان مقرر نہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvi{تو انسان کو دیکھنا چاہئے کہ وہ کاہے سے پیدا ہوا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxvii{وہ اچھلتے ہوئے پانی سے پیدا ہوا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxviii{جو پیٹھ اور سینے کے بیچ میں سے نکلتا ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxxxix{بےشک خدا اس کے اعادے (یعنی پھر پیدا کرنے) پر قادر ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxl{جس دن دلوں کے بھید جانچے جائیں گے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxli{تو انسان کی کچھ پیش نہ چل سکے گی اور نہ کوئی اس کا مددگار ہو گا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlii{آسمان کی قسم جو مینہ برساتا ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliii{اور زمین کی قسم جو پھٹ جاتی ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxliv{کہ یہ کلام (حق کو باطل سے) جدا کرنے والا ہے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlv{اور بیہودہ بات نہیں ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvi{یہ لوگ تو اپنی تدبیروں میں لگ رہے ہیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlvii{اور ہم اپنی تدبیر کر رہے ہیں\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlviii{تو تم کافروں کو مہلت دو بس چند روز ہی مہلت دو\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxlix{\basmalahur (اے پیغمبر) اپنے پروردگار جلیل الشان کے نام کی تسبیح کرو\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcml{جس نے (انسان کو) بنایا پھر (اس کے اعضاء کو) درست کیا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcmli{اور جس نے (اس کا) اندازہ ٹہرایا (پھر اس کو) رستہ بتایا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlii{اور جس نے چارہ اگایا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliii{پھر اس کو سیاہ رنگ کا کوڑا کر دیا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcmliv{ہم تمہیں پڑھا دیں گے کہ تم فراموش نہ کرو گے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlv{مگر جو خدا چاہے۔ وہ کھلی بات کو بھی جانتا ہے اور چھپی کو بھی\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvi{ہم تم کو آسان طریقے کی توفیق دیں گے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlvii{سو جہاں تک نصیحت (کے) نافع (ہونے کی امید) ہو نصیحت کرتے رہو\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlviii{جو خوف رکھتا ہے وہ تو نصیحت پکڑے گا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlix{اور (بےخوف) بدبخت پہلو تہی کرے گا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlx{جو (قیامت کو) بڑی (تیز) آگ میں داخل ہو گا\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxi{پھر وہاں نہ مرے گا اور نہ جئے گا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxii{بے شک وہ مراد کو پہنچ گیا جو پاک ہوا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiii{اور اپنے پروردگار کے نام کا ذکر کرتا رہا اور نماز پڑھتا رہا\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxiv{مگر تم لوگ تو دنیا کی زندگی کو اختیار کرتے ہو\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxv{حالانکہ آخرت بہت بہتر اور پائندہ تر ہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvi{یہ بات پہلے صحیفوں میں (مرقوم) ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxvii{یعنی) ابراہیم اور موسیٰ کے صحیفوں میں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxviii{\basmalahur بھلا تم کو ڈھانپ لینے والی (یعنی قیامت کا) حال معلوم ہوا ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxix{اس روز بہت سے منہ (والے) ذلیل ہوں گے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxx{سخت محنت کرنے والے تھکے ماندے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxi{دہکتی آگ میں داخل ہوں گے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxii{ایک کھولتے ہوئے چشمے کا ان کو پانی پلایا جائے گا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiii{اور خار دار جھاڑ کے سوا ان کے لیے کوئی کھانا نہیں (ہو گا)\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxiv{جو نہ فربہی لائے اور نہ بھوک میں کچھ کام آئے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxv{اور بہت سے منہ (والے) اس روز شادماں ہوں گے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvi{اپنے اعمال (کی جزا) سے خوش دل\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxvii{بہشت بریں میں\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxviii{وہاں کسی طرح کی بکواس نہیں سنیں گے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxix{اس میں چشمے بہ رہے ہوں گے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxx{وہاں تخت ہوں گے اونچے بچھے ہوئے\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxi{اور آبخورے (قرینے سے) رکھے ہوئے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxii{اور گاؤ تکیے قطار کی قطار لگے ہوئے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiii{اور نفیس مسندیں بچھی ہوئی\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxiv{یہ لوگ اونٹوں کی طرف نہیں دیکھتے کہ کیسے (عجیب) پیدا کیے گئے ہیں\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxv{اور آسمان کی طرف کہ کیسا بلند کیا گیا ہے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvi{اور پہاڑوں کی طرف کہ کس طرح کھڑے کیے گئے ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxvii{اور زمین کی طرف کہ کس طرح بچھائی گئی\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxviii{تو تم نصیحت کرتے رہو کہ تم نصیحت کرنے والے ہی ہو\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmcmlxxxix{تم ان پر داروغہ نہیں ہو\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxc{ہاں جس نے منہ پھیرا اور نہ مانا\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxci{تو خدا اس کو بڑا عذاب دے گا\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcii{بےشک ان کو ہمارے پاس لوٹ کر آنا ہے\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciii{پھر ہم ہی کو ان سے حساب لینا ہے\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxciv{\basmalahur فجر کی قسم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcv{اور دس راتوں کی\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvi{اور جفت اور طاق کی\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcvii{اور رات کی جب جانے لگے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcviii{اور بے شک یہ چیزیں عقلمندوں کے نزدیک قسم کھانے کے لائق ہیں کہ (کافروں کو ضرور عذاب ہو گا)\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmcmxcix{کیا تم نے نہیں دیکھا کہ تمہارے پروردگار نے عاد کے ساتھ کیا کیا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmm{جو) ارم (کہلاتے تھے اتنے) دراز قد\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmi{کہ تمام ملک میں ایسے پیدا نہیں ہوئے تھے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmii{اور ثمود کے ساتھ (کیا کیا) جو وادئِ (قریٰ) میں پتھر تراشتے تھے (اور گھر بناتے) تھے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmiii{اور فرعون کے ساتھ (کیا کیا) جو خیمے اور میخیں رکھتا تھا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmiv{یہ لوگ ملکوں میں سرکش ہو رہے تھے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmv{اور ان میں بہت سی خرابیاں کرتے تھے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmmvi{تو تمہارے پروردگار نے ان پر عذاب کا کوڑا نازل کیا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmmvii{بے شک تمہارا پروردگار تاک میں ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmmviii{مگر انسان (عجیب مخلوق ہے کہ) جب اس کا پروردگار اس کو آزماتا ہے تو اسے عزت دیتا اور نعمت بخشتا ہے۔ تو کہتا ہے کہ (آہا) میرے پروردگار نے مجھے عزت بخشی\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmmix{اور جب (دوسری طرح) آزماتا ہے کہ اس پر روزی تنگ کر دیتا ہے تو کہتا ہے کہ (ہائے) میرے پروردگار نے مجھے ذلیل کیا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmmx{نہیں بلکہ تم لوگ یتیم کی خاطر نہیں کرتے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmmxi{اور نہ مسکین کو کھانا کھلانے کی ترغیب دیتے ہو\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmmxii{اور میراث کے مال سمیٹ کر کھا جاتے ہو\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiii{اور مال کو بہت ہی عزیز رکھتے ہو\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmmxiv{تو جب زمین کی بلندی کوٹ کوٹ کو پست کر دی جائے گی\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmmxv{اور تمہارا پروردگار (جلوہ فرما ہو گا) اور فرشتے قطار باندھ باندھ کر آ موجود ہوں گے\qt@no{22}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvi{اور دوزخ اس دن حاضر کی جائے گی تو انسان اس دن متنبہ ہو گا مگر تنبہ (سے) اسے (فائدہ) کہاں (مل سکے گا)\qt@no{23}}%
\qt@newcmd\qurantrans@ur@mmmmmmxvii{کہے گا کاش میں نے اپنی زندگی (جاودانی کے لیے) کچھ آگے بھیجا ہوتا\qt@no{24}}%
\qt@newcmd\qurantrans@ur@mmmmmmxviii{تو اس دن نہ کوئی خدا کے عذاب کی طرح کا (کسی کو) عذاب دے گا\qt@no{25}}%
\qt@newcmd\qurantrans@ur@mmmmmmxix{اور نہ کوئی ویسا جکڑنا جکڑے گا\qt@no{26}}%
\qt@newcmd\qurantrans@ur@mmmmmmxx{اے اطمینان پانے والی روح!\qt@no{27}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxi{اپنے پروردگار کی طرف لوٹ چل۔ تو اس سے راضی وہ تجھ سے راضی\qt@no{28}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxii{تو میرے (ممتاز) بندوں میں شامل ہو جا\qt@no{29}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiii{اور میری بہشت میں داخل ہو جا\qt@no{30}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxiv{\basmalahur ہمیں اس شہر (مکہ) کی قسم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxv{اور تم اسی شہر میں تو رہتے ہو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvi{اور باپ (یعنی آدم) اور اس کی اولاد کی قسم\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxvii{کہ ہم نے انسان کو تکلیف (کی حالت) میں (رہنے والا) بنایا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxviii{کیا وہ خیال رکھتا ہے کہ اس پر کوئی قابو نہ پائے گا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxix{کہتا ہے کہ میں نے بہت سا مال برباد کیا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxx{کیا اسے یہ گمان ہے کہ اس کو کسی نے دیکھا نہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxi{بھلا ہم نےاس کو دو آنکھیں نہیں دیں؟\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxii{اور زبان اور دو ہونٹ (نہیں دیئے)\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiii{یہ چیزیں بھی دیں) اور اس کو (خیر و شر کے) دونوں رستے بھی دکھا دیئے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxiv{مگر وہ گھاٹی پر سے ہو کر نہ گزرا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxv{اور تم کیا سمجھے کہ گھاٹی کیا ہے؟\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvi{کسی (کی) گردن کا چھڑانا\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxvii{یا بھوک کے دن کھانا کھلانا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxviii{یتیم رشتہ دار کو\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmmxxxix{یا فقیر خاکسار کو\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmmxl{پھر ان لوگوں میں بھی (داخل) ہو جو ایمان لائے اور صبر کی نصیحت اور (لوگوں پر) شفقت کرنے کی وصیت کرتے رہے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmmxli{یہی لوگ صاحب سعادت ہیں\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlii{اور جنہوں نے ہماری آیتوں کو نہ مانا وہ بدبخت ہیں\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliii{یہ لوگ آگ میں بند کر دیئے جائیں گے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmmxliv{\basmalahur سورج کی قسم اور اس کی روشنی کی\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlv{اور چاند کی جب اس کے پیچھے نکلے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvi{اور دن کی جب اُسے چمکا دے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlvii{اور رات کی جب اُسے چھپا لے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlviii{اور آسمان کی اور اس ذات کی جس نے اسے بنایا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmxlix{اور زمین کی اور اس کی جس نے اسے پھیلایا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmml{اور انسان کی اور اس کی جس نے اس (کے اعضا) کو برابر کیا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmli{پھر اس کو بدکاری (سے بچنے) اور پرہیزگاری کرنے کی سمجھ دی\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmlii{کہ جس نے (اپنے) نفس (یعنی روح) کو پاک رکھا وہ مراد کو پہنچا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmliii{اور جس نے اسے خاک میں ملایا وہ خسارے میں رہا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmliv{قوم) ثمود نے اپنی سرکشی کے سبب (پیغمبر کو) جھٹلایا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmlv{جب ان میں سے ایک نہایت بدبخت اٹھا\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvi{تو خدا کے پیغمبر (صالح) نے ان سے کہا کہ خدا کی اونٹنی اور اس کے پانی پینے کی باری سے عذر کرو\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmmlvii{مگر انہوں نے پیغمبر کو جھٹلایا اور اونٹنی کی کونچیں کاٹ دیں تو خدا نے ان کےگناہ کے سبب ان پر عذاب نازل کیا اور سب کو (ہلاک کر کے) برابر کر دیا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmmlviii{اور اس کو ان کے بدلہ لینے کا کچھ بھی ڈر نہیں\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmmlix{\basmalahur رات کی قسم جب (دن کو) چھپالے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmlx{اور دن کی قسم جب چمک اٹھے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxi{اور اس (ذات) کی قسم جس نے نر اور مادہ پیدا کیے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxii{کہ تم لوگوں کی کوششں طرح طرح کی ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiii{تو جس نے (خدا کے رستے میں مال) دیا اور پرہیز گاری کی\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxiv{اور نیک بات کو سچ جانا\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxv{اس کو ہم آسان طریقے کی توفیق دیں گے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvi{اور جس نے بخل کیا اور بےپروا بنا رہا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxvii{اور نیک بات کو جھوٹ سمجھا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxviii{اسے سختی میں پہنچائیں گے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxix{اور جب وہ (دوزخ کے گڑھے میں) گرے گا تو اس کا مال اس کے کچھ کام نہ آئے گا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxx{ہمیں تو راہ دکھا دینا ہے\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxi{اور آخرت او ردنیا ہماری ہی چیزیں ہیں\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxii{سو میں نے تم کو بھڑکتی آگ سے متنبہ کر دیا\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiii{اس میں وہی داخل ہو گا جو بڑا بدبخت ہے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxiv{جس نے جھٹلایا اور منہ پھیرا\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxv{اور جو بڑا پرہیزگار ہے وہ (اس سے) بچا لیا جائے گا\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvi{جو مال دیتا ہے تاکہ پاک ہو\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxvii{اور (اس لیے) نہیں (دیتا کہ) اس پر کسی کا احسان (ہے) جس کا وہ بدلہ اتارتا ہے\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxviii{بلکہ اپنے خداوند اعلیٰ کی رضامندی حاصل کرنے کے لیے دیتا ہے\qt@no{20}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxix{اور وہ عنقریب خوش ہو جائے گا\qt@no{21}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxx{\basmalahur آفتاب کی روشنی کی قسم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxi{اور رات (کی تاریکی) کی جب چھا جائے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxii{کہ (اے محمدﷺ) تمہارے پروردگار نے نہ تو تم کو چھوڑا اور نہ (تم سے) ناراض ہوا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiii{اور آخرت تمہارے لیے پہلی (حالت یعنی دنیا) سے کہیں بہتر ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxiv{اور تمہیں پروردگار عنقریب وہ کچھ عطا فرمائے گا کہ تم خوش ہو جاؤ گے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxv{بھلا اس نے تمہیں یتیم پا کر جگہ نہیں دی؟ (بےشک دی)\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvi{اور رستے سے ناواقف دیکھا تو رستہ دکھایا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxvii{اور تنگ دست پایا تو غنی کر دیا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxviii{تو تم بھی یتیم پر ستم نہ کرنا\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmlxxxix{اور مانگنے والے کو جھڑکی نہ دینا\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmxc{اور اپنے پروردگار کی نعمتوں کا بیان کرتے رہنا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmxci{\basmalahur (اے محمدﷺ) کیا ہم نے تمہارا سینہ کھول نہیں دیا؟ (بےشک کھول دیا)\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcii{اور تم پر سے بوجھ بھی اتار دیا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciii{جس نے تمہاری پیٹھ توڑ رکھی تھی\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmxciv{اور تمہارا ذکر بلند کیا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcv{ہاں ہاں مشکل کے ساتھ آسانی بھی ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvi{اور) بے شک مشکل کے ساتھ آسانی ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcvii{تو جب فارغ ہوا کرو تو (عبادت میں) محنت کیا کرو\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcviii{اور اپنے پروردگار کی طرف متوجہ ہو جایا کرو\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmxcix{\basmalahur انجیر کی قسم اور زیتون کی\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmc{اور طور سینین کی\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmci{اور اس امن والے شہر کی\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcii{کہ ہم نے انسان کو بہت اچھی صورت میں پیدا کیا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmciii{پھر (رفتہ رفتہ) اس (کی حالت) کو (بدل کر) پست سے پست کر دیا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmciv{مگر جو لوگ ایمان لائے اور نیک عمل کرتے رہے انکے لیے بےانتہا اجر ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcv{تو (اے آدم زاد) پھر تو جزا کے دن کو کیوں جھٹلاتا ہے؟\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvi{کیا خدا سب سے بڑا حاکم نہیں ہے؟\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmcvii{\basmalahur (اے محمدﷺ) اپنے پروردگار کا نام لے کر پڑھو جس نے (عالم کو) پیدا کیا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcviii{جس نے انسان کو خون کی پھٹکی سے بنایا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcix{پڑھو اور تمہارا پروردگار بڑا کریم ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcx{جس نے قلم کے ذریعے سے علم سکھایا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxi{اور انسان کو وہ باتیں سکھائیں جس کا اس کو علم نہ تھا\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxii{مگر انسان سرکش ہو جاتا ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiii{جب کہ اپنے تیئں غنی دیکھتا ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxiv{کچھ شک نہیں کہ (اس کو) تمہارے پروردگار ہی کی طرف لوٹ کر جانا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxv{بھلا تم نے اس شخص کو دیکھا جو منع کرتا ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvi{یعنی) ایک بندے کو جب وہ نماز پڑھنے لگتا ہے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxvii{بھلا دیکھو تو اگر یہ راہِ راست پر ہو\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxviii{یا پرہیز گاری کا حکم کرے (تو منع کرنا کیسا)\qt@no{12}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxix{اور دیکھو تو اگر اس نے دین حق کو جھٹلایا اور اس سے منہ موڑا (تو کیا ہوا)\qt@no{13}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxx{کیااس کو معلوم نہیں کہ خدا دیکھ رہا ہے\qt@no{14}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxi{دیکھو اگر وہ باز نہ آئے گا تو ہم (اس کی) پیشانی کے بال پکڑ گھسیٹیں گے\qt@no{15}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxii{یعنی اس جھوٹے خطاکار کی پیشانی کے بال\qt@no{16}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiii{تو وہ اپنے یاروں کی مجلس کو بلالے\qt@no{17}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxiv{ہم بھی اپنے موکلانِ دوزخ کو بلا لیں گے\qt@no{18}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxv{دیکھو اس کا کہا نہ ماننا اور قربِ (خدا) حاصل کرتے رہنا\qt@no{19}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvi{\basmalahur ہم نے اس (قرآن) کو شب قدر میں نازل (کرنا شروع) کیا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxvii{اور تمہیں کیا معلوم کہ شب قدر کیا ہے؟\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxviii{شب قدر ہزار مہینے سے بہتر ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxix{اس میں روح (الامین) اور فرشتے ہر کام کے (انتظام کے) لیے اپنے پروردگار کے حکم سے اترتے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxx{یہ (رات) طلوع صبح تک (امان اور) سلامتی ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxi{\basmalahur جو لوگ کافر ہیں (یعنی) اہل کتاب اور مشرک وہ (کفر سے) باز رہنے والے نہ تھے جب تک ان کے پاس کھلی دلیل (نہ) آتی\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxii{یعنی) خدا کے پیغمبر جو پاک اوراق پڑھتے ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiii{جن میں (مستحکم) آیتیں لکھی ہوئی ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxiv{اور اہل کتاب جو متفرق (و مختلف) ہوئے ہیں تو دلیل واضح آنے کے بعد (ہوئے ہیں)\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxv{اور ان کو حکم تو یہی ہوا تھا کہ اخلاص عمل کے ساتھ خدا کی عبادت کریں (اور) یکسو ہو کراورنماز پڑھیں اور زکوٰة دیں اور یہی سچا دین ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvi{جو لوگ کافر ہیں (یعنی) اہل کتاب اور مشرک وہ دوزخ کی آگ میں پڑیں گے (اور) ہمیشہ اس میں رہیں گے۔ یہ لوگ سب مخلوق سے بدتر ہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxvii{اور) جو لوگ ایمان لائے اور نیک عمل کرتے رہے وہ تمام خلقت سے بہتر ہیں\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxviii{ان کا صلہ ان کے پروردگار کے ہاں ہمیشہ رہنے کے باغ ہیں جن کے نیچے نہریں بہہ رہی ہیں ابدالاباد ان میں رہیں گے۔ خدا ان سے خوش اور وہ اس سے خوش۔ یہ (صلہ) اس کے لیے ہے جو اپنے پروردگار سے ڈرتا رہا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxxxix{\basmalahur جب زمین بھونچال سے ہلا دی جائے گی\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxl{اور زمین اپنے (اندر) کے بوجھ نکال ڈالے گی\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxli{اور انسان کہے گا کہ اس کو کیا ہوا ہے؟\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlii{اس روز وہ اپنے حالات بیان کردے گی\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliii{کیونکہ تمہارے پروردگار نے اس کو حکم بھیجا (ہوگا)\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxliv{اس دن لوگ گروہ گروہ ہو کر آئیں گے تاکہ ان کو ان کے اعمال دکھا دیئے جائیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlv{تو جس نے ذرہ بھر نیکی کی ہو گی وہ اس کو دیکھ لے گا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvi{اور جس نے ذرہ بھر برائی کی ہوگی وہ اسے دیکھ لے گا\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlvii{\basmalahur ان سرپٹ دوڑنے والے گھوڑوں کی قسم جو ہانپ اٹھتےہیں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlviii{پھر (پتھروں پر نعل) مار کر آگ نکالتے ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxlix{پھر صبح کو چھاپہ مارتے ہیں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcl{پھر اس میں گرد اٹھاتے ہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcli{پھر اس وقت دشمن کی فوج میں جا گھستے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmclii{کہ انسان اپنے پروردگار کا احسان ناشناس (اور ناشکرا) ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliii{اور وہ اس سے آگاہ بھی ہے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmcliv{وہ تو مال سے سخت محبت کرنے والا ہے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmclv{کیا وہ اس وقت کو نہیں جانتا کہ جو (مردے) قبروں میں ہیں وہ باہر نکال لیے جائیں گے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvi{اور جو (بھید) دلوں میں ہیں وہ ظاہر کر دیئے جائیں گے\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmclvii{بےشک ان کا پروردگار اس روز ان سے خوب واقف ہوگا\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmclviii{\basmalahur کھڑ کھڑانے والی\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmclix{کھڑ کھڑانے والی کیا ہے؟\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmclx{اور تم کیا جانوں کھڑ کھڑانے والی کیا ہے؟\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxi{وہ قیامت ہے) جس دن لوگ ایسے ہوں گے جیسے بکھرے ہوئے پتنگے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxii{اور پہاڑ ایسے ہو جائیں گے جیسے دھنکی ہوئی رنگ برنگ کی اون\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiii{تو جس کے (اعمال کے) وزن بھاری نکلیں گے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxiv{وہ دل پسند عیش میں ہو گا\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxv{اور جس کے وزن ہلکے نکلیں گے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvi{اس کا مرجع ہاویہ ہے\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxvii{اور تم کیا سمجھے کہ ہاویہ کیا چیز ہے؟\qt@no{10}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxviii{دہکتی ہوئی آگ ہے\qt@no{11}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxix{\basmalahur (لوگو) تم کو (مال کی) بہت سی طلب نے غافل کر دیا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxx{یہاں تک کہ تم نے قبریں جا دیکھیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxi{دیکھو تمہیں عنقریب معلوم ہو جائے گا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxii{پھر دیکھو تمہیں عنقریب معلوم ہو جائے گا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiii{دیکھو اگر تم جانتے (یعنی) علم الیقین (رکھتے تو غفلت نہ کرتے)\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxiv{تم ضرور دوزخ کو دیکھو گے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxv{پھر اس کو (ایسا) دیکھو گے (کہ) عین الیقین (آ جائے گا)\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvi{پھر اس روز تم سے (شکر) نعمت کے بارے میں پرسش ہو گی\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxvii{\basmalahur عصر کی قسم\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxviii{کہ انسان نقصان میں ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxix{مگر وہ لوگ جو ایمان لائے اور نیک عمل کرتے رہے اور آپس میں حق (بات) کی تلقین اور صبر کی تاکید کرتے رہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxx{\basmalahur ہر طعن آمیز اشارتیں کرنے والے چغل خور کی خرابی ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxi{جو مال جمع کرتا اور اس کو گن گن کر رکھتا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxii{اور) خیال کرتا ہے کہ اس کا مال اس کی ہمیشہ کی زندگی کا موجب ہو گا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiii{ہر گز نہیں وہ ضرور حطمہ میں ڈالا جائے گا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxiv{اور تم کیا سمجھے حطمہ کیا ہے؟\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxv{وہ خدا کی بھڑکائی ہوئی آگ ہے\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvi{جو دلوں پر جا لپٹے گی\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxvii{اور) وہ اس میں بند کر دیئے جائیں گے\qt@no{8}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxviii{یعنی آگ کے) لمبے لمبے ستونوں میں\qt@no{9}}%
\qt@newcmd\qurantrans@ur@mmmmmmclxxxix{\basmalahur کیا تم نے نہیں دیکھا کہ تمہارے پروردگار نے ہاتھی والوں کے ساتھ کیا کیا\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxc{کیا ان کا داؤں غلط نہیں کیا؟ (گیا)\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxci{اور ان پر جھلڑ کے جھلڑ جانور بھیجے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcii{جو ان پر کھنگر کی پتھریاں پھینکتے تھے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciii{تو ان کو ایسا کر دیا جیسے کھایا ہوا بھس\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxciv{\basmalahur قریش کے مانوس کرنے کے سبب\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcv{یعنی) ان کو جاڑے اور گرمی کے سفر سے مانوس کرنے کے سبب\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvi{لوگوں کو چاہیئے کہ (اس نعمت کے شکر میں) اس گھر کے مالک کی عبادت کریں\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcvii{جس نے ان کو بھوک میں کھانا کھلایا اور خوف سے امن بخشا\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcviii{\basmalahur بھلا تم نے اس شخص کو دیکھا جو (روزِ) جزا کو جھٹلاتا ہے؟\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmcxcix{یہ وہی (بدبخت) ہے، جو یتیم کو دھکے دیتا ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmcc{اور فقیر کو کھانا کھلانے کے لیے (لوگوں کو) ترغیب نہیں دیتا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmcci{تو ایسے نمازیوں کی خرابی ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccii{جو نماز کی طرف سے غافل رہتے ہیں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciii{جو ریا کاری کرتے ہیں\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmcciv{اور برتنے کی چیزیں عاریتہً نہیں دیتے\qt@no{7}}%
\qt@newcmd\qurantrans@ur@mmmmmmccv{\basmalahur (اے محمدﷺ) ہم نے تم کو کوثر عطا فرمائی ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvi{تو اپنے پروردگار کے لیے نماز پڑھا کرو اور قربانی دیا کرو\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccvii{کچھ شک نہیں کہ تمہارا دشمن ہی بےاولاد رہے گا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccviii{\basmalahur (اے پیغمبر ان منکران اسلام سے) کہہ دو کہ اے کافرو!\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccix{جن (بتوں) کو تم پوچتے ہو ان کو میں نہیں پوجتا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccx{اور جس (خدا) کی میں عبادت کرتا ہوں اس کی تم عبادت نہیں کرتے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxi{اور (میں پھر کہتا ہوں کہ) جن کی تم پرستش کرتے ہوں ان کی میں پرستش کرنے والا نہیں ہوں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxii{اور نہ تم اس کی بندگی کرنے والے (معلوم ہوتے) ہو جس کی میں بندگی کرتا ہوں\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiii{تم اپنے دین پر میں اپنے دین پر\qt@no{6}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxiv{\basmalahur جب خدا کی مدد آ پہنچی اور فتح (حاصل ہو گئی)\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxv{اور تم نے دیکھ لیا کہ لوگ غول کے غول خدا کے دین میں داخل ہو رہے ہیں\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvi{تو اپنے پروردگار کی تعریف کے ساتھ تسبیح کرو اور اس سے مغفرت مانگو، بے شک وہ معاف کرنے والا ہے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxvii{\basmalahur ابولہب کے ہاتھ ٹوٹیں اور وہ ہلاک ہو\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxviii{نہ تو اس کا مال ہی اس کے کچھ کام آیا اور نہ وہ جو اس نے کمایا\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxix{وہ جلد بھڑکتی ہوئی آگ میں داخل ہو گا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxx{اور اس کی جورو بھی جو ایندھن سر پر اٹھائے پھرتی ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxi{اس کے گلے میں مونج کی رسّی ہو گی\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxii{\basmalahur کہو کہ وہ (ذات پاک جس کا نام) الله (ہے) ایک ہے\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiii{معبود برحق جو بےنیاز ہے\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxiv{نہ کسی کا باپ ہے اور نہ کسی کا بیٹا\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxv{اور کوئی اس کا ہمسر نہیں\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvi{\basmalahur کہو کہ میں صبح کے پروردگار کی پناہ مانگتا ہوں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxvii{ہر چیز کی بدی سے جو اس نے پیدا کی\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxviii{اور شب تاریکی کی برائی سے جب اس کااندھیرا چھا جائے\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxix{اور گنڈوں پر (پڑھ پڑھ کر) پھونکنے والیوں کی برائی سے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxx{اور حسد کرنے والے کی برائی سے جب حسد کرنے لگے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxi{\basmalahur کہو کہ میں لوگوں کے پروردگار کی پناہ مانگتا ہوں\qt@no{1}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxii{یعنی) لوگوں کے حقیقی بادشاہ کی\qt@no{2}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiii{لوگوں کے معبود برحق کی\qt@no{3}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxiv{شیطان) وسوسہ انداز کی برائی سے جو (خدا کا نام سن کر) پیچھے ہٹ جاتا ہے\qt@no{4}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxv{جو لوگوں کے دلوں میں وسوسے ڈالتا ہے\qt@no{5}}%
\qt@newcmd\qurantrans@ur@mmmmmmccxxxvi{وہ جنّات میں سے (ہو) یا انسانوں میں سے\qt@no{6}}%
%% End of file `qurantext-urii.translation.def'.
